
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!

C RCS file, release, date & time of last delta, author, state, [and locker]
C $Header$

C what(1) key, module and SID; SCCS file; date and time of last delta:
C %W% %P% %G% %U%

      SUBROUTINE HRPRODLOSS

C***********************************************************************
C
C  FUNCTION: To compute the production and loss rates for EBI species
C
C  PRECONDITIONS: For the CB05E51 family of mechanisms
C
C  RETURN VALUES: None
C
C  KEY SUBROUTINES/FUNCTIONS CALLED: None
C
C  REVISION HISTORY: Created by EBI solver program, May 25, 2016
C
C   18 Jul 14 B.Hutzell: revised to use real(8) variables

C***********************************************************************
      USE HRDATA

      IMPLICIT NONE


C.....INCLUDES: NONE


C.....ARGUMENTS: NONE


C.....PARAMETERS: NONE


C.....EXTERNAL FUNCTIONS: NONE


C.....SAVED VARIABLES: NONE
!     CHARACTER( 16 ), SAVE  ::  PNAME = 'HRPRODLOSS'   ! Program name


C.....LOCAL VARIABLES:


C***********************************************************************


      PROD(  HNO3         ) =    2.0000D+00 * RXRAT(  19 )      ! N2O5=0.2000D+01*HNO3
     &                      +    2.0000D+00 * RXRAT(  20 )      ! N2O5=0.2000D+01*HNO3
     &                      +                 RXRAT(  28 )      ! NO2+OH=HNO3
     &                      +                 RXRAT(  31 )      ! NO+HO2=HNO3
     &                      +                 RXRAT(  49 )      ! NO3+HO2=HNO3
     &                      +                 RXRAT(  81 )      ! FORM+NO3=HNO3+HO2+CO
     &                      +                 RXRAT(  89 )      ! ALD2+NO3=HNO3+C2O3
     &                      +                 RXRAT( 104 )      ! ALDX+NO3=HNO3+CXO3
     &                      +                 RXRAT( 136 )      ! CRES+NO3=HNO3+0.3000D+...
     &                      +                 RXRAT( 140 )      ! CRON+NO3=HNO3+CRNO
     &                      +                 RXRAT( 150 )      ! OPEN+NO3=HNO3+OPO3
     &                      +                 RXRAT( 152 )      ! CAT1+NO3=HNO3+CRO
     &                      +    1.5000D-01 * RXRAT( 171 )      ! NO3+ISPD=0.1500D+00*HNO3+...
     &                      +                 RXRAT( 260 )      ! NTRALK=HNO3
     &                      +                 RXRAT( 261 )      ! NTROH=HNO3
     &                      +                 RXRAT( 262 )      ! NTRCN=HNO3
     &                      +                 RXRAT( 263 )      ! NTRCNOH=HNO3
     &                      +                 RXRAT( 264 )      ! NTRPX=HNO3
     &                      +                 RXRAT( 265 )      ! NTRM=HNO3
     &                      +                 RXRAT( 266 )      ! NTRI=HNO3
     &                      +                 RXRAT( 267 )      ! N2O5=HNO3+H2NO3PIJ
     &                      +                 RXRAT( 268 )      ! N2O5=HNO3+H2NO3PK
     &                      +                 RXRAT( 269 )      ! H2NO3PIJ=HNO3
     &                      +                 RXRAT( 270 )      ! H2NO3PK=HNO3
     &                      +    5.0000D-01 * RXRAT( 274 )      ! NO2=0.5000D+00*HNO3+...
      LOSS(  HNO3         ) =                 RXRAT(  29 )      ! HNO3+OH=NO3
     &                      +                 RXRAT(  53 )      ! HNO3=OH+NO2

      PROD(  H2O2         ) =                 RXRAT(  35 )      ! HO2+HO2=H2O2
     &                      +                 RXRAT(  36 )      ! HO2+HO2=H2O2
     &                      +                 RXRAT(  43 )      ! OH+OH=H2O2
      LOSS(  H2O2         ) =                 RXRAT(  37 )      ! H2O2=0.2000D+01*OH
     &                      +                 RXRAT(  38 )      ! H2O2+OH=HO2
     &                      +                 RXRAT(  46 )      ! H2O2+O=OH+HO2

      PROD(  XO2          ) =                 RXRAT(  62 )      ! ROOH+OH=XO2+0.5000D+...
     &                      +    3.0000D-01 * RXRAT(  74 )      ! MEPX+OH=0.3000D+00*XO2+...
     &                      +                 RXRAT( 106 )      ! CXO3+NO=XO2+NO2+HO2+ALD2
     &                      +    4.0000D-01 * RXRAT( 109 )      ! PANX=0.4000D+00*XO2+...
     &                      +    4.4000D-01 * RXRAT( 111 )      ! CXO3+HO2=0.4400D+00*XO2+...
     &                      +    9.0000D-01 * RXRAT( 112 )      ! CXO3+MEO2=0.9000D+00*XO2+...
     &                      +    2.0000D+00 * RXRAT( 114 )      ! CXO3+CXO3=0.2000D+01*XO2+...
     &                      +                 RXRAT( 115 )      ! CXO3+C2O3=XO2+MEO2+HO2+ALD2
     &                      +    8.7000D-01 * RXRAT( 116 )      ! PAR+OH=0.8700D+00*XO2+...
     &                      +    9.6000D-01 * RXRAT( 117 )      ! ROR=0.9600D+00*XO2+0.6000D+...
     &                      +    2.0000D-01 * RXRAT( 120 )      ! O+OLE=0.2000D+00*XO2+...
     &                      +    8.0000D-01 * RXRAT( 121 )      ! OH+OLE=0.8000D+00*XO2+...
     &                      +    2.2000D-01 * RXRAT( 122 )      ! O3+OLE=0.2200D+00*XO2+...
     &                      +    9.1000D-01 * RXRAT( 123 )      ! NO3+OLE=0.9100D+00*XO2+...
     &                      +    7.0000D-01 * RXRAT( 124 )      ! O+ETH=0.7000D+00*XO2+...
     &                      +                 RXRAT( 125 )      ! OH+ETH=XO2+0.1560D+01*FORM+...
     &                      +                 RXRAT( 127 )      ! NO3+ETH=XO2+NO2+0.2000D+...
     &                      +    1.0000D-01 * RXRAT( 128 )      ! IOLE+O=0.1000D+00*XO2+...
     &                      +                 RXRAT( 129 )      ! IOLE+OH=XO2+0.7000D+...
     &                      +    1.0000D-01 * RXRAT( 132 )      ! TOL+OH=0.1000D+00*XO2+...
     &                      +    1.2000D-01 * RXRAT( 135 )      ! OH+CRES=0.1200D+00*XO2+...
     &                      +    6.0000D-01 * RXRAT( 136 )      ! CRES+NO3=0.6000D+00*XO2+...
     &                      +    3.0000D-02 * RXRAT( 149 )      ! OPEN+O3=0.3000D-01*XO2+...
     &                      +                 RXRAT( 155 )      ! OPO3+NO=XO2+NO2+HO2+ALDX
     &                      +    5.0000D-01 * RXRAT( 158 )      ! OH+XYLMN=0.5000D+00*XO2+...
     &                      +    5.0000D-01 * RXRAT( 159 )      ! OH+NAPH=0.5000D+00*XO2+...
     &                      +                 RXRAT( 160 )      ! OH+MGLY=XO2+C2O3
     &                      +    2.5000D-01 * RXRAT( 162 )      ! O+ISOP=0.2500D+00*XO2+...
     &                      +    2.0000D-01 * RXRAT( 167 )      ! O3+ISOP=0.2000D+00*XO2+...
     &                      +                 RXRAT( 168 )      ! NO3+ISOP=XO2+0.8000D+...
     &                      +    7.1300D-01 * RXRAT( 169 )      ! OH+ISPD=0.7130D+00*XO2+...
     &                      +    6.4000D-02 * RXRAT( 170 )      ! O3+ISPD=0.6400D-01*XO2+...
     &                      +    7.5000D-02 * RXRAT( 171 )      ! NO3+ISPD=0.7500D-01*XO2+...
     &                      +    7.0000D-01 * RXRAT( 172 )      ! ISPD=0.7000D+00*XO2+...
     &                      +    1.2500D+00 * RXRAT( 174 )      ! TERP+OH=0.1250D+01*XO2+...
     &                      +    7.6000D-01 * RXRAT( 179 )      ! TERP+O3=0.7600D+00*XO2+...
     &                      +    1.0300D+00 * RXRAT( 180 )      ! TERP+NO3=0.1030D+01*XO2+...
     &                      +    5.0000D-02 * RXRAT( 182 )      ! OH+ETOH=0.5000D-01*XO2+...
     &                      +    9.9100D-01 * RXRAT( 183 )      ! OH+ETHA=0.9910D+00*XO2+...
     &                      +                 RXRAT( 184 )      ! NO2+ISOP=XO2+0.8000D+...
     &                      +    8.7000D-01 * RXRAT( 194 )      ! CL+PAR=0.8700D+00*XO2+HCL+...
     &                      +    9.9100D-01 * RXRAT( 195 )      ! CL+ETHA=0.9910D+00*XO2+...
     &                      +    2.0000D+00 * RXRAT( 196 )      ! CL+ETH=0.2000D+01*XO2+FMCL+...
     &                      +    2.0000D+00 * RXRAT( 197 )      ! CL+OLE=0.2000D+01*XO2+...
     &                      +    1.7000D+00 * RXRAT( 198 )      ! CL+IOLE=0.1700D+01*XO2+...
     &                      +                 RXRAT( 199 )      ! CL+ISOP=XO2+0.1500D+00*HCL+...
     &                      +    8.8000D-01 * RXRAT( 206 )      ! CL+TOL=0.8800D+00*XO2+HCL+...
     &                      +    8.4000D-01 * RXRAT( 207 )      ! CL+XYLMN=0.8400D+00*XO2+...
     &                      +    8.4000D-01 * RXRAT( 208 )      ! CL+NAPH=0.8400D+00*XO2+HCL+...
     &                      +                 RXRAT( 232 )      ! MACO3+CXO3=XO2+ALD2+HO2+...
      LOSS(  XO2          ) =                 RXRAT(  55 )      ! XO2+NO=NO2
     &                      +                 RXRAT(  57 )      ! XO2+HO2=ROOH
     &                      +    2.0000D+00 * RXRAT(  59 )      ! XO2+XO2=
     &                      +                 RXRAT(  61 )      ! XO2+XO2N=
     &                      +                 RXRAT(  97 )      ! XO2+C2O3=0.9000D+00*MEO2+...
     &                      +                 RXRAT( 113 )      ! XO2+CXO3=0.9000D+00*ALD2+...
     &                      +                 RXRAT( 178 )      ! XO2+XO2T=
     &                      +                 RXRAT( 231 )      ! XO2+MACO3=ALD2+0.3000D+...

      PROD(  XO2N         ) =    1.3000D-01 * RXRAT( 116 )      ! PAR+OH=0.1300D+00*XO2N+...
     &                      +    4.0000D-02 * RXRAT( 117 )      ! ROR=0.4000D-01*XO2N+...
     &                      +    1.0000D-02 * RXRAT( 120 )      ! O+OLE=0.1000D-01*XO2N+...
     &                      +    9.0000D-02 * RXRAT( 123 )      ! NO3+OLE=0.9000D-01*XO2N+...
     &                      +    6.0000D-02 * RXRAT( 135 )      ! OH+CRES=0.6000D-01*XO2N+...
     &                      +    1.0000D-01 * RXRAT( 136 )      ! CRES+NO3=0.1000D+00*XO2N+...
     &                      +    9.0000D-03 * RXRAT( 183 )      ! OH+ETHA=0.9000D-02*XO2N+...
     &                      +    1.3000D-01 * RXRAT( 194 )      ! CL+PAR=0.1300D+00*XO2N+...
     &                      +    9.0000D-03 * RXRAT( 195 )      ! CL+ETHA=0.9000D-02*XO2N+...
     &                      +    1.2000D-01 * RXRAT( 206 )      ! CL+TOL=0.1200D+00*XO2N+...
     &                      +    1.6000D-01 * RXRAT( 207 )      ! CL+XYLMN=0.1600D+00*XO2N+...
     &                      +    1.6000D-01 * RXRAT( 208 )      ! CL+NAPH=0.1600D+00*XO2N+...
      LOSS(  XO2N         ) =                 RXRAT(  56 )      ! XO2N+NO=0.5000D+00*NTROH+...
     &                      +                 RXRAT(  58 )      ! XO2N+HO2=ROOH
     &                      +    2.0000D+00 * RXRAT(  60 )      ! XO2N+XO2N=
     &                      +                 RXRAT(  61 )      ! XO2N+XO2=

      PROD(  NTROH        ) =    5.0000D-01 * RXRAT(  56 )      ! XO2N+NO=0.5000D+00*NTROH+...
     &                      +    1.4000D-01 * RXRAT( 133 )      ! TO2+NO=0.1400D+00*NTROH+...
     &                      +    2.0000D+00 * RXRAT( 141 )      ! CRNO+NO2=0.2000D+01*NTROH
     &                      +    1.4000D-01 * RXRAT( 153 )      ! CAO2+NO=0.1400D+00*NTROH+...
     &                      +    8.0000D-01 * RXRAT( 184 )      ! NO2+ISOP=0.8000D+00*NTROH+...
      LOSS(  NTROH        ) =                 RXRAT( 237 )      ! NTROH+OH=NOHO2
     &                      +                 RXRAT( 256 )      ! NTROH=NO2+HO2+0.3300D+...
     &                      +                 RXRAT( 261 )      ! NTROH=HNO3

      PROD(  NTRALK       ) =    5.0000D-01 * RXRAT(  56 )      ! XO2N+NO=0.5000D+00*NTRALK+...
     &                      +                 RXRAT( 119 )      ! ROR+NO2=NTRALK
      LOSS(  NTRALK       ) =                 RXRAT( 234 )      ! NTRALK+OH=NALKO2
     &                      +                 RXRAT( 255 )      ! NTRALK=NO2+HO2+0.3300D+...
     &                      +                 RXRAT( 260 )      ! NTRALK=HNO3

      PROD(  ROOH         ) =                 RXRAT(  57 )      ! XO2+HO2=ROOH
     &                      +                 RXRAT(  58 )      ! XO2N+HO2=ROOH
     &                      +                 RXRAT( 176 )      ! XO2T+HO2=ROOH
     &                      +                 RXRAT( 259 )      ! NTRPX=ROOH+HO2+NO2
      LOSS(  ROOH         ) =                 RXRAT(  62 )      ! ROOH+OH=XO2+0.5000D+...
     &                      +                 RXRAT(  63 )      ! ROOH=OH+HO2+0.5000D+...

      PROD(  ALD2         ) =    5.0000D-01 * RXRAT(  62 )      ! ROOH+OH=0.5000D+00*ALD2+...
     &                      +    5.0000D-01 * RXRAT(  63 )      ! ROOH=0.5000D+00*ALD2+HO2+...
     &                      +    2.7500D-01 * RXRAT(  66 )      ! IEPXO2+HO2=0.2750D+00*ALD2+...
     &                      +    2.7500D-01 * RXRAT(  67 )      ! IEPXO2+NO=0.2750D+00*ALD2+...
     &                      +    2.2000D-01 * RXRAT(  68 )      ! IEPXO2+C2O3=0.2200D+...
     &                      +                 RXRAT( 106 )      ! CXO3+NO=ALD2+NO2+HO2+XO2
     &                      +    4.0000D-01 * RXRAT( 109 )      ! PANX=0.4000D+00*ALD2+...
     &                      +                 RXRAT( 110 )      ! PANX+OH=ALD2+NO2
     &                      +    9.0000D-01 * RXRAT( 112 )      ! CXO3+MEO2=0.9000D+00*ALD2+...
     &                      +    9.0000D-01 * RXRAT( 113 )      ! CXO3+XO2=0.9000D+00*ALD2+...
     &                      +    2.0000D+00 * RXRAT( 114 )      ! CXO3+CXO3=0.2000D+01*ALD2+...
     &                      +                 RXRAT( 115 )      ! CXO3+C2O3=ALD2+XO2+HO2+MEO2
     &                      +    6.0000D-02 * RXRAT( 116 )      ! PAR+OH=0.6000D-01*ALD2+...
     &                      +    6.0000D-01 * RXRAT( 117 )      ! ROR=0.6000D+00*ALD2+...
     &                      +    2.0000D-01 * RXRAT( 120 )      ! O+OLE=0.2000D+00*ALD2+...
     &                      +    3.3000D-01 * RXRAT( 121 )      ! OH+OLE=0.3300D+00*ALD2+...
     &                      +    1.8000D-01 * RXRAT( 122 )      ! O3+OLE=0.1800D+00*ALD2+...
     &                      +    3.5000D-01 * RXRAT( 123 )      ! NO3+OLE=0.3500D+00*ALD2+...
     &                      +    1.2400D+00 * RXRAT( 128 )      ! IOLE+O=0.1240D+01*ALD2+...
     &                      +    1.3000D+00 * RXRAT( 129 )      ! IOLE+OH=0.1300D+01*ALD2+...
     &                      +    6.5000D-01 * RXRAT( 130 )      ! IOLE+O3=0.6500D+00*ALD2+...
     &                      +    1.1800D+00 * RXRAT( 131 )      ! IOLE+NO3=0.1180D+01*ALD2+...
     &                      +    2.5200D-01 * RXRAT( 169 )      ! OH+ISPD=0.2520D+00*ALD2+...
     &                      +    2.0000D-02 * RXRAT( 170 )      ! O3+ISPD=0.2000D-01*ALD2+...
     &                      +    6.7000D-02 * RXRAT( 172 )      ! ISPD=0.6700D-01*ALD2+...
     &                      +    9.5000D-01 * RXRAT( 182 )      ! OH+ETOH=0.9500D+00*ALD2+...
     &                      +    9.9100D-01 * RXRAT( 183 )      ! OH+ETHA=0.9910D+00*ALD2+...
     &                      +    6.0000D-02 * RXRAT( 194 )      ! CL+PAR=0.6000D-01*ALD2+...
     &                      +    9.9100D-01 * RXRAT( 195 )      ! CL+ETHA=0.9910D+00*ALD2+...
     &                      +    3.3000D-01 * RXRAT( 197 )      ! CL+OLE=0.3300D+00*ALD2+...
     &                      +    4.5000D-01 * RXRAT( 198 )      ! CL+IOLE=0.4500D+00*ALD2+...
     &                      +                 RXRAT( 204 )      ! CL+ETOH=ALD2+HO2+HCL
     &                      +                 RXRAT( 228 )      ! MAPAN+OH=ALD2+CO+NO2
     &                      +                 RXRAT( 231 )      ! MACO3+XO2=ALD2+0.3000D+...
     &                      +                 RXRAT( 232 )      ! MACO3+CXO3=ALD2+XO2+HO2+...
     &                      +    1.5000D-01 * RXRAT( 248 )      ! NTRMO2+NO=0.1500D+00*ALD2+...
     &                      +                 RXRAT( 253 )      ! NTRM=ALD2+HO2+NO2+IOLE
     &                      +    3.3000D-01 * RXRAT( 254 )      ! NTRI=0.3300D+00*ALD2+HO2+...
     &                      +    3.3000D-01 * RXRAT( 255 )      ! NTRALK=0.3300D+00*ALD2+HO2+...
     &                      +    3.3000D-01 * RXRAT( 256 )      ! NTROH=0.3300D+00*ALD2+HO2+...
     &                      +    3.3000D-01 * RXRAT( 257 )      ! NTRCN=0.3300D+00*ALD2+HO2+...
     &                      +    3.3000D-01 * RXRAT( 258 )      ! NTRCNOH=0.3300D+00*ALD2+...
      LOSS(  ALD2         ) =                 RXRAT(  87 )      ! ALD2+O=C2O3+OH
     &                      +                 RXRAT(  88 )      ! ALD2+OH=C2O3
     &                      +                 RXRAT(  89 )      ! ALD2+NO3=C2O3+HNO3
     &                      +                 RXRAT(  90 )      ! ALD2=MEO2+CO+HO2
     &                      +                 RXRAT( 201 )      ! ALD2+CL=HCL+C2O3

      PROD(  ALDX         ) =    5.0000D-01 * RXRAT(  62 )      ! ROOH+OH=0.5000D+00*ALDX+...
     &                      +    5.0000D-01 * RXRAT(  63 )      ! ROOH=0.5000D+00*ALDX+HO2+...
     &                      +    2.9000D-02 * RXRAT(  64 )      ! ISOPX+OH=0.2900D-01*ALDX+...
     &                      +    5.0000D-02 * RXRAT( 116 )      ! PAR+OH=0.5000D-01*ALDX+...
     &                      +    5.0000D-01 * RXRAT( 117 )      ! ROR=0.5000D+00*ALDX+...
     &                      +    3.0000D-01 * RXRAT( 120 )      ! O+OLE=0.3000D+00*ALDX+...
     &                      +    6.2000D-01 * RXRAT( 121 )      ! OH+OLE=0.6200D+00*ALDX+...
     &                      +    3.2000D-01 * RXRAT( 122 )      ! O3+OLE=0.3200D+00*ALDX+...
     &                      +    5.6000D-01 * RXRAT( 123 )      ! NO3+OLE=0.5600D+00*ALDX+...
     &                      +    2.2000D-01 * RXRAT( 125 )      ! OH+ETH=0.2200D+00*ALDX+...
     &                      +    6.6000D-01 * RXRAT( 128 )      ! IOLE+O=0.6600D+00*ALDX+...
     &                      +    7.0000D-01 * RXRAT( 129 )      ! IOLE+OH=0.7000D+00*ALDX+...
     &                      +    3.5000D-01 * RXRAT( 130 )      ! IOLE+O3=0.3500D+00*ALDX+...
     &                      +    6.4000D-01 * RXRAT( 131 )      ! IOLE+NO3=0.6400D+00*ALDX+...
     &                      +    4.8000D-01 * RXRAT( 136 )      ! CRES+NO3=0.4800D+00*ALDX+...
     &                      +    3.0000D-02 * RXRAT( 149 )      ! OPEN+O3=0.3000D-01*ALDX+...
     &                      +                 RXRAT( 155 )      ! OPO3+NO=ALDX+XO2+HO2+NO2
     &                      +    1.5000D-01 * RXRAT( 167 )      ! O3+ISOP=0.1500D+00*ALDX+...
     &                      +    8.0000D-01 * RXRAT( 168 )      ! NO3+ISOP=0.8000D+00*ALDX+...
     &                      +    1.2000D-01 * RXRAT( 169 )      ! OH+ISPD=0.1200D+00*ALDX+...
     &                      +    3.5700D-01 * RXRAT( 171 )      ! NO3+ISPD=0.3570D+00*ALDX+...
     &                      +    1.5000D-01 * RXRAT( 173 )      ! TERP+O=0.1500D+00*ALDX+...
     &                      +    4.7000D-01 * RXRAT( 174 )      ! TERP+OH=0.4700D+00*ALDX+...
     &                      +    2.1000D-01 * RXRAT( 179 )      ! TERP+O3=0.2100D+00*ALDX+...
     &                      +    4.7000D-01 * RXRAT( 180 )      ! TERP+NO3=0.4700D+00*ALDX+...
     &                      +    1.0000D-02 * RXRAT( 182 )      ! OH+ETOH=0.1000D-01*ALDX+...
     &                      +    8.0000D-01 * RXRAT( 184 )      ! NO2+ISOP=0.8000D+00*ALDX+...
     &                      +    5.0000D-02 * RXRAT( 194 )      ! CL+PAR=0.5000D-01*ALDX+...
     &                      +    6.7000D-01 * RXRAT( 197 )      ! CL+OLE=0.6700D+00*ALDX+...
     &                      +    5.5000D-01 * RXRAT( 198 )      ! CL+IOLE=0.5500D+00*ALDX+...
     &                      +    3.3000D-01 * RXRAT( 254 )      ! NTRI=0.3300D+00*ALDX+HO2+...
     &                      +    3.3000D-01 * RXRAT( 255 )      ! NTRALK=0.3300D+00*ALDX+HO2+...
     &                      +    3.3000D-01 * RXRAT( 256 )      ! NTROH=0.3300D+00*ALDX+HO2+...
     &                      +    3.3000D-01 * RXRAT( 257 )      ! NTRCN=0.3300D+00*ALDX+HO2+...
     &                      +    3.3000D-01 * RXRAT( 258 )      ! NTRCNOH=0.3300D+00*ALDX+...
      LOSS(  ALDX         ) =                 RXRAT( 102 )      ! ALDX+O=CXO3+OH
     &                      +                 RXRAT( 103 )      ! ALDX+OH=CXO3
     &                      +                 RXRAT( 104 )      ! ALDX+NO3=CXO3+HNO3
     &                      +                 RXRAT( 105 )      ! ALDX=MEO2+CO+HO2
     &                      +                 RXRAT( 202 )      ! ALDX+CL=HCL+CXO3

      PROD(  ISOPX        ) =                 RXRAT( 166 )      ! ISOPO2+HO2=ISOPX
      LOSS(  ISOPX        ) =                 RXRAT(  64 )      ! ISOPX+OH=0.9040D+00*IEPOX+...

      PROD(  IEPOX        ) =    9.0400D-01 * RXRAT(  64 )      ! ISOPX+OH=0.9040D+00*IEPOX+...
      LOSS(  IEPOX        ) =                 RXRAT(  65 )      ! IEPOX+OH=IEPXO2
     &                      +                 RXRAT( 276 )      ! IEPOX=AISO3J

      PROD(  ISOPO2       ) =    6.7000D-02 * RXRAT(  64 )      ! ISOPX+OH=0.6700D-01*ISOPO2+...
     &                      +                 RXRAT( 163 )      ! ISOP+OH=ISOPO2+ISOPRXN
      LOSS(  ISOPO2       ) =                 RXRAT( 164 )      ! ISOPO2+NO=0.1000D+00*NTRM+...
     &                      +                 RXRAT( 165 )      ! ISOPO2+C2O3=0.5980D+...
     &                      +                 RXRAT( 166 )      ! ISOPO2+HO2=ISOPX

      PROD(  IOLE         ) =    2.9000D-02 * RXRAT(  64 )      ! ISOPX+OH=0.2900D-01*IOLE+...
     &                      +                 RXRAT( 253 )      ! NTRM=IOLE+HO2+ALD2+NO2
      LOSS(  IOLE         ) =                 RXRAT( 128 )      ! IOLE+O=0.1240D+01*ALD2+...
     &                      +                 RXRAT( 129 )      ! IOLE+OH=0.1300D+01*ALD2+...
     &                      +                 RXRAT( 130 )      ! IOLE+O3=0.6500D+00*ALD2+...
     &                      +                 RXRAT( 131 )      ! IOLE+NO3=0.1180D+01*ALD2+...
     &                      +                 RXRAT( 198 )      ! IOLE+CL=0.3000D+00*HCL+...

      PROD(  IEPXO2       ) =                 RXRAT(  65 )      ! IEPOX+OH=IEPXO2
      LOSS(  IEPXO2       ) =                 RXRAT(  66 )      ! IEPXO2+HO2=0.2750D+00*ALD2+...
     &                      +                 RXRAT(  67 )      ! IEPXO2+NO=0.2750D+00*ALD2+...
     &                      +                 RXRAT(  68 )      ! IEPXO2+C2O3=0.2200D+...

      PROD(  MGLY         ) =    2.7500D-01 * RXRAT(  66 )      ! IEPXO2+HO2=0.2750D+00*MGLY+...
     &                      +    2.7500D-01 * RXRAT(  67 )      ! IEPXO2+NO=0.2750D+00*MGLY+...
     &                      +    2.2000D-01 * RXRAT(  68 )      ! IEPXO2+C2O3=0.2200D+...
     &                      +    5.2000D-01 * RXRAT( 133 )      ! TO2+NO=0.5200D+00*MGLY+...
     &                      +    2.4000D-01 * RXRAT( 136 )      ! CRES+NO3=0.2400D+00*MGLY+...
     &                      +    2.0000D-01 * RXRAT( 149 )      ! OPEN+O3=0.2000D+00*MGLY+...
     &                      +    8.0000D-01 * RXRAT( 158 )      ! OH+XYLMN=0.8000D+00*MGLY+...
     &                      +    8.0000D-01 * RXRAT( 159 )      ! OH+NAPH=0.8000D+00*MGLY+...
     &                      +    1.6800D-01 * RXRAT( 169 )      ! OH+ISPD=0.1680D+00*MGLY+...
     &                      +    8.5000D-01 * RXRAT( 170 )      ! O3+ISPD=0.8500D+00*MGLY+...
      LOSS(  MGLY         ) =                 RXRAT( 160 )      ! MGLY+OH=XO2+C2O3
     &                      +                 RXRAT( 161 )      ! MGLY=C2O3+HO2+CO

      PROD(  FORM         ) =    6.5000D-01 * RXRAT(  66 )      ! IEPXO2+HO2=0.6500D+00*FORM+...
     &                      +    6.5000D-01 * RXRAT(  67 )      ! IEPXO2+NO=0.6500D+00*FORM+...
     &                      +    5.2000D-01 * RXRAT(  68 )      ! IEPXO2+C2O3=0.5200D+...
     &                      +                 RXRAT(  71 )      ! MEO2+NO=FORM+HO2+NO2
     &                      +    1.3700D+00 * RXRAT(  73 )      ! MEO2+MEO2=0.1370D+01*FORM+...
     &                      +                 RXRAT(  75 )      ! MEPX=FORM+HO2+OH
     &                      +                 RXRAT(  76 )      ! MEOH+OH=FORM+HO2
     &                      +                 RXRAT(  83 )      ! HCO3=FORM+HO2
     &                      +                 RXRAT(  96 )      ! C2O3+MEO2=FORM+0.9000D+...
     &                      +    1.0000D-01 * RXRAT( 112 )      ! CXO3+MEO2=0.1000D+00*FORM+...
     &                      +    2.0000D-01 * RXRAT( 120 )      ! O+OLE=0.2000D+00*FORM+...
     &                      +    8.0000D-01 * RXRAT( 121 )      ! OH+OLE=0.8000D+00*FORM+...
     &                      +    7.4000D-01 * RXRAT( 122 )      ! O3+OLE=0.7400D+00*FORM+...
     &                      +                 RXRAT( 123 )      ! NO3+OLE=FORM+NO2+0.9100D+...
     &                      +                 RXRAT( 124 )      ! O+ETH=FORM+0.1700D+01*HO2+...
     &                      +    1.5600D+00 * RXRAT( 125 )      ! OH+ETH=0.1560D+01*FORM+XO2+...
     &                      +                 RXRAT( 126 )      ! O3+ETH=FORM+0.6300D+00*CO+...
     &                      +    2.0000D+00 * RXRAT( 127 )      ! NO3+ETH=0.2000D+01*FORM+...
     &                      +    2.5000D-01 * RXRAT( 130 )      ! IOLE+O3=0.2500D+00*FORM+...
     &                      +    3.3600D-01 * RXRAT( 133 )      ! TO2+NO=0.3360D+00*FORM+...
     &                      +    6.0000D-02 * RXRAT( 135 )      ! OH+CRES=0.6000D-01*FORM+...
     &                      +    2.4000D-01 * RXRAT( 136 )      ! CRES+NO3=0.2400D+00*FORM+...
     &                      +    7.0000D-01 * RXRAT( 149 )      ! OPEN+O3=0.7000D+00*FORM+...
     &                      +    3.4400D-01 * RXRAT( 153 )      ! CAO2+NO=0.3440D+00*FORM+...
     &                      +    5.0000D-01 * RXRAT( 162 )      ! O+ISOP=0.5000D+00*FORM+...
     &                      +    6.7300D-01 * RXRAT( 164 )      ! ISOPO2+NO=0.6730D+00*FORM+...
     &                      +    5.9800D-01 * RXRAT( 165 )      ! ISOPO2+C2O3=0.5980D+...
     &                      +    6.0000D-01 * RXRAT( 167 )      ! O3+ISOP=0.6000D+00*FORM+...
     &                      +    1.6700D-01 * RXRAT( 169 )      ! OH+ISPD=0.1670D+00*FORM+...
     &                      +    1.5000D-01 * RXRAT( 170 )      ! O3+ISPD=0.1500D+00*FORM+...
     &                      +    2.8200D-01 * RXRAT( 171 )      ! NO3+ISPD=0.2820D+00*FORM+...
     &                      +    9.0000D-01 * RXRAT( 172 )      ! ISPD=0.9000D+00*FORM+...
     &                      +    2.8000D-01 * RXRAT( 174 )      ! TERP+OH=0.2800D+00*FORM+...
     &                      +    2.4000D-01 * RXRAT( 179 )      ! TERP+O3=0.2400D+00*FORM+...
     &                      +    8.0000D-02 * RXRAT( 182 )      ! OH+ETOH=0.8000D-01*FORM+...
     &                      +                 RXRAT( 196 )      ! CL+ETH=FORM+0.2000D+01*XO2+...
     &                      +                 RXRAT( 203 )      ! CL+MEOH=FORM+HO2+HCL
     &                      +                 RXRAT( 224 )      ! MACO3+NO=FORM+NO2+MEO2
     &                      +    4.0000D-01 * RXRAT( 227 )      ! MAPAN=0.4000D+00*FORM+...
     &                      +    4.4000D-01 * RXRAT( 229 )      ! MACO3+HO2=0.4400D+00*FORM+...
     &                      +    1.9000D+00 * RXRAT( 230 )      ! MACO3+MEO2=0.1900D+01*FORM+...
     &                      +    9.0000D-01 * RXRAT( 231 )      ! MACO3+XO2=0.9000D+00*FORM+...
     &                      +                 RXRAT( 232 )      ! MACO3+CXO3=FORM+XO2+HO2+...
     &                      +                 RXRAT( 233 )      ! MACO3+C2O3=FORM+0.1650D+...
     &                      +    5.5000D-01 * RXRAT( 248 )      ! NTRMO2+NO=0.5500D+00*FORM+...
     &                      +    3.3000D-01 * RXRAT( 254 )      ! NTRI=0.3300D+00*FORM+HO2+...
     &                      +    3.3000D-01 * RXRAT( 255 )      ! NTRALK=0.3300D+00*FORM+HO2+...
     &                      +    3.3000D-01 * RXRAT( 256 )      ! NTROH=0.3300D+00*FORM+HO2+...
     &                      +    3.3000D-01 * RXRAT( 257 )      ! NTRCN=0.3300D+00*FORM+HO2+...
     &                      +    3.3000D-01 * RXRAT( 258 )      ! NTRCNOH=0.3300D+00*FORM+...
      LOSS(  FORM         ) =                 RXRAT(  77 )      ! FORM+OH=HO2+CO
     &                      +                 RXRAT(  78 )      ! FORM=0.2000D+01*HO2+CO
     &                      +                 RXRAT(  79 )      ! FORM=CO
     &                      +                 RXRAT(  80 )      ! FORM+O=OH+HO2+CO
     &                      +                 RXRAT(  81 )      ! FORM+NO3=HNO3+HO2+CO
     &                      +                 RXRAT(  82 )      ! FORM+HO2=HCO3
     &                      +                 RXRAT( 200 )      ! FORM+CL=HCL+HO2+CO

      PROD(  FACD         ) =    7.4000D-02 * RXRAT(  66 )      ! IEPXO2+HO2=0.7400D-01*FACD+...
     &                      +                 RXRAT(  84 )      ! HCO3+NO=FACD+NO2+HO2
     &                      +    3.7000D-01 * RXRAT( 126 )      ! O3+ETH=0.3700D+00*FACD+...
      LOSS(  FACD         ) =                 RXRAT(  86 )      ! FACD+OH=HO2

      PROD(  CO           ) =    2.5100D-01 * RXRAT(  66 )      ! IEPXO2+HO2=0.2510D+00*CO+...
     &                      +    2.5100D-01 * RXRAT(  67 )      ! IEPXO2+NO=0.2510D+00*CO+...
     &                      +    2.0000D-01 * RXRAT(  68 )      ! IEPXO2+C2O3=0.2000D+00*CO+...
     &                      +                 RXRAT(  77 )      ! FORM+OH=CO+HO2
     &                      +                 RXRAT(  78 )      ! FORM=CO+0.2000D+01*HO2
     &                      +                 RXRAT(  79 )      ! FORM=CO
     &                      +                 RXRAT(  80 )      ! FORM+O=CO+HO2+OH
     &                      +                 RXRAT(  81 )      ! FORM+NO3=CO+HO2+HNO3
     &                      +                 RXRAT(  90 )      ! ALD2=CO+MEO2+HO2
     &                      +                 RXRAT( 105 )      ! ALDX=CO+MEO2+HO2
     &                      +    2.0000D-01 * RXRAT( 120 )      ! O+OLE=0.2000D+00*CO+...
     &                      +    3.3000D-01 * RXRAT( 122 )      ! O3+OLE=0.3300D+00*CO+...
     &                      +                 RXRAT( 124 )      ! O+ETH=CO+0.1700D+01*HO2+...
     &                      +    6.3000D-01 * RXRAT( 126 )      ! O3+ETH=0.6300D+00*CO+FORM+...
     &                      +    1.0000D-01 * RXRAT( 128 )      ! IOLE+O=0.1000D+00*CO+...
     &                      +    2.5000D-01 * RXRAT( 130 )      ! IOLE+O3=0.2500D+00*CO+...
     &                      +    3.3600D-01 * RXRAT( 133 )      ! TO2+NO=0.3360D+00*CO+...
     &                      +    6.0000D-02 * RXRAT( 135 )      ! OH+CRES=0.6000D-01*CO+...
     &                      +    2.4000D-01 * RXRAT( 136 )      ! CRES+NO3=0.2400D+00*CO+...
     &                      +                 RXRAT( 147 )      ! OPEN=CO+HO2+OPO3
     &                      +    6.9000D-01 * RXRAT( 149 )      ! OPEN+O3=0.6900D+00*CO+...
     &                      +    3.4400D-01 * RXRAT( 153 )      ! CAO2+NO=0.3440D+00*CO+...
     &                      +                 RXRAT( 161 )      ! MGLY=CO+HO2+C2O3
     &                      +    6.6000D-02 * RXRAT( 167 )      ! O3+ISOP=0.6600D-01*CO+...
     &                      +    3.3400D-01 * RXRAT( 169 )      ! OH+ISPD=0.3340D+00*CO+...
     &                      +    2.2500D-01 * RXRAT( 170 )      ! O3+ISPD=0.2250D+00*CO+...
     &                      +    6.4300D-01 * RXRAT( 171 )      ! NO3+ISPD=0.6430D+00*CO+...
     &                      +    3.3300D-01 * RXRAT( 172 )      ! ISPD=0.3330D+00*CO+0.6700D-...
     &                      +    1.0000D-03 * RXRAT( 179 )      ! TERP+O3=0.1000D-02*CO+...
     &                      +                 RXRAT( 191 )      ! OH+FMCL=CO+CL
     &                      +                 RXRAT( 192 )      ! FMCL=CO+CL+HO2
     &                      +                 RXRAT( 200 )      ! CL+FORM=CO+HO2+HCL
     &                      +                 RXRAT( 228 )      ! MAPAN+OH=CO+ALD2+NO2
     &                      +    2.9000D-01 * RXRAT( 229 )      ! MACO3+HO2=0.2900D+00*CO+...
     &                      +    6.0000D-01 * RXRAT( 231 )      ! MACO3+XO2=0.6000D+00*CO+...
     &                      +    6.5000D-01 * RXRAT( 232 )      ! MACO3+CXO3=0.6500D+00*CO+...
     &                      +    6.5000D-01 * RXRAT( 233 )      ! MACO3+C2O3=0.6500D+00*CO+...
      LOSS(  CO           ) =                 RXRAT(  69 )      ! CO+OH=HO2

      PROD(  PAR          ) =    2.4500D+00 * RXRAT(  66 )      ! IEPXO2+HO2=0.2450D+01*PAR+...
     &                      +    2.4500D+00 * RXRAT(  67 )      ! IEPXO2+NO=0.2450D+01*PAR+...
     &                      +    1.9600D+00 * RXRAT(  68 )      ! IEPXO2+C2O3=0.1960D+01*PAR+...
     &                      +    2.0000D-01 * RXRAT( 120 )      ! O+OLE=0.2000D+00*PAR+...
     &                      +    1.0000D-01 * RXRAT( 128 )      ! IOLE+O=0.1000D+00*PAR+...
     &                      +    1.1000D+00 * RXRAT( 158 )      ! OH+XYLMN=0.1100D+01*PAR+...
     &                      +    1.1000D+00 * RXRAT( 159 )      ! OH+NAPH=0.1100D+01*PAR+...
     &                      +    2.5000D-01 * RXRAT( 162 )      ! O+ISOP=0.2500D+00*PAR+...
     &                      +    3.5000D-01 * RXRAT( 167 )      ! O3+ISOP=0.3500D+00*PAR+...
     &                      +    2.4000D+00 * RXRAT( 168 )      ! NO3+ISOP=0.2400D+01*PAR+...
     &                      +    1.5650D+00 * RXRAT( 169 )      ! OH+ISPD=0.1565D+01*PAR+...
     &                      +    3.6000D-01 * RXRAT( 170 )      ! O3+ISPD=0.3600D+00*PAR+...
     &                      +    1.2820D+00 * RXRAT( 171 )      ! NO3+ISPD=0.1282D+01*PAR+...
     &                      +    8.3200D-01 * RXRAT( 172 )      ! ISPD=0.8320D+00*PAR+...
     &                      +    5.1200D+00 * RXRAT( 173 )      ! TERP+O=0.5120D+01*PAR+...
     &                      +    1.6600D+00 * RXRAT( 174 )      ! TERP+OH=0.1660D+01*PAR+...
     &                      +    7.0000D+00 * RXRAT( 179 )      ! TERP+O3=0.7000D+01*PAR+...
     &                      +    2.4000D+00 * RXRAT( 184 )      ! NO2+ISOP=0.2400D+01*PAR+...
     &                      +    3.0000D-01 * RXRAT( 198 )      ! CL+IOLE=0.3000D+00*PAR+...
     &                      +    4.3000D-01 * RXRAT( 248 )      ! NTRMO2+NO=0.4300D+00*PAR+...
      LOSS(  PAR          ) =    1.1100D+00 * RXRAT( 116 )      ! PAR+OH=-0.1100D+00*PAR+...
     &                      +    2.1000D+00 * RXRAT( 117 )      ! ROR=-0.2100D+01*PAR+...
     &                      +    7.0000D-01 * RXRAT( 121 )      ! OH+OLE=-0.7000D+00*PAR+...
     &                      +                 RXRAT( 122 )      ! O3+OLE=-PAR+0.7400D+...
     &                      +                 RXRAT( 123 )      ! NO3+OLE=-PAR+FORM+0.9100D+...
     &                      +    1.1100D+00 * RXRAT( 194 )      ! PAR+CL=-0.1100D+00*PAR+...
     &                      +                 RXRAT( 197 )      ! CL+OLE=-PAR+0.3300D+...
     &                      +    6.6000D-01 * RXRAT( 254 )      ! NTRI=-0.6600D+00*PAR+HO2+...
     &                      +    6.6000D-01 * RXRAT( 255 )      ! NTRALK=-0.6600D+00*PAR+HO2+...
     &                      +    6.6000D-01 * RXRAT( 256 )      ! NTROH=-0.6600D+00*PAR+HO2+...
     &                      +    6.6000D-01 * RXRAT( 257 )      ! NTRCN=-0.6600D+00*PAR+HO2+...
     &                      +    6.6000D-01 * RXRAT( 258 )      ! NTRCNOH=-0.6600D+00*PAR+...

      PROD(  MEO2         ) =    8.0000D-01 * RXRAT(  68 )      ! IEPXO2+C2O3=0.8000D+...
     &                      +                 RXRAT(  70 )      ! OH=MEO2
     &                      +    7.0000D-01 * RXRAT(  74 )      ! MEPX+OH=0.7000D+00*MEO2+...
     &                      +                 RXRAT(  90 )      ! ALD2=MEO2+CO+HO2
     &                      +                 RXRAT(  91 )      ! C2O3+NO=MEO2+NO2
     &                      +    4.0000D-01 * RXRAT(  94 )      ! PAN=0.4000D+00*MEO2+...
     &                      +    4.4000D-01 * RXRAT(  95 )      ! C2O3+HO2=0.4400D+00*MEO2+...
     &                      +    9.0000D-01 * RXRAT(  97 )      ! C2O3+XO2=0.9000D+00*MEO2+...
     &                      +    2.0000D+00 * RXRAT(  98 )      ! C2O3+C2O3=0.2000D+01*MEO2
     &                      +                 RXRAT( 100 )      ! PACD=MEO2+OH
     &                      +                 RXRAT( 101 )      ! AACD+OH=MEO2
     &                      +                 RXRAT( 105 )      ! ALDX=MEO2+CO+HO2
     &                      +                 RXRAT( 115 )      ! CXO3+C2O3=MEO2+XO2+HO2+ALD2
     &                      +    8.0000D-01 * RXRAT( 165 )      ! ISOPO2+C2O3=0.8000D+...
     &                      +                 RXRAT( 193 )      ! CL=MEO2+HCL
     &                      +                 RXRAT( 224 )      ! MACO3+NO=MEO2+NO2+FORM
     &                      +    2.9000D-01 * RXRAT( 229 )      ! MACO3+HO2=0.2900D+00*MEO2+...
     &                      +    6.0000D-01 * RXRAT( 231 )      ! MACO3+XO2=0.6000D+00*MEO2+...
     &                      +    1.6500D+00 * RXRAT( 233 )      ! MACO3+C2O3=0.1650D+01*MEO2+...
      LOSS(  MEO2         ) =                 RXRAT(  71 )      ! MEO2+NO=FORM+HO2+NO2
     &                      +                 RXRAT(  72 )      ! MEO2+HO2=MEPX
     &                      +    2.0000D+00 * RXRAT(  73 )      ! MEO2+MEO2=0.1370D+01*FORM+...
     &                      +    1.0000D-01 * RXRAT(  96 )      ! MEO2+C2O3=0.9000D+00*MEO2+...
     &                      +                 RXRAT( 112 )      ! MEO2+CXO3=0.9000D+00*ALD2+...
     &                      +    4.0000D-01 * RXRAT( 230 )      ! MEO2+MACO3=0.6000D+00*MEO2+...

      PROD(  AACD         ) =    2.0000D-01 * RXRAT(  68 )      ! IEPXO2+C2O3=0.2000D+...
     &                      +    1.5000D-01 * RXRAT(  95 )      ! C2O3+HO2=0.1500D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT(  96 )      ! C2O3+MEO2=0.1000D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT(  97 )      ! C2O3+XO2=0.1000D+00*AACD+...
     &                      +    1.5000D-01 * RXRAT( 111 )      ! CXO3+HO2=0.1500D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT( 112 )      ! CXO3+MEO2=0.1000D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT( 113 )      ! CXO3+XO2=0.1000D+00*AACD+...
     &                      +    2.0000D-01 * RXRAT( 165 )      ! ISOPO2+C2O3=0.2000D+...
     &                      +    1.5000D-01 * RXRAT( 229 )      ! MACO3+HO2=0.1500D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT( 230 )      ! MACO3+MEO2=0.1000D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT( 231 )      ! MACO3+XO2=0.1000D+00*AACD+...
      LOSS(  AACD         ) =                 RXRAT( 101 )      ! AACD+OH=MEO2

      PROD(  MEPX         ) =                 RXRAT(  72 )      ! MEO2+HO2=MEPX
     &                      +                 RXRAT(  85 )      ! HCO3+HO2=MEPX
      LOSS(  MEPX         ) =                 RXRAT(  74 )      ! MEPX+OH=0.7000D+00*MEO2+...
     &                      +                 RXRAT(  75 )      ! MEPX=FORM+HO2+OH

      PROD(  MEOH         ) =    6.3000D-01 * RXRAT(  73 )      ! MEO2+MEO2=0.6300D+00*MEOH+...
      LOSS(  MEOH         ) =                 RXRAT(  76 )      ! MEOH+OH=FORM+HO2
     &                      +                 RXRAT( 203 )      ! MEOH+CL=HCL+HO2+FORM

      PROD(  HCO3         ) =                 RXRAT(  82 )      ! FORM+HO2=HCO3
      LOSS(  HCO3         ) =                 RXRAT(  83 )      ! HCO3=FORM+HO2
     &                      +                 RXRAT(  84 )      ! HCO3+NO=FACD+NO2+HO2
     &                      +                 RXRAT(  85 )      ! HCO3+HO2=MEPX

      PROD(  PACD         ) =    4.1000D-01 * RXRAT(  95 )      ! C2O3+HO2=0.4100D+00*PACD+...
     &                      +    4.1000D-01 * RXRAT( 111 )      ! CXO3+HO2=0.4100D+00*PACD+...
     &                      +    4.1000D-01 * RXRAT( 229 )      ! MACO3+HO2=0.4100D+00*PACD+...
      LOSS(  PACD         ) =                 RXRAT(  99 )      ! PACD+OH=C2O3
     &                      +                 RXRAT( 100 )      ! PACD=MEO2+OH

      PROD(  CXO3         ) =                 RXRAT( 102 )      ! ALDX+O=CXO3+OH
     &                      +                 RXRAT( 103 )      ! ALDX+OH=CXO3
     &                      +                 RXRAT( 104 )      ! ALDX+NO3=CXO3+HNO3
     &                      +                 RXRAT( 108 )      ! PANX=CXO3+NO2
     &                      +    6.0000D-01 * RXRAT( 109 )      ! PANX=0.6000D+00*CXO3+...
     &                      +    2.5000D-01 * RXRAT( 162 )      ! O+ISOP=0.2500D+00*CXO3+...
     &                      +    3.9000D-01 * RXRAT( 179 )      ! TERP+O3=0.3900D+00*CXO3+...
     &                      +                 RXRAT( 202 )      ! CL+ALDX=CXO3+HCL
      LOSS(  CXO3         ) =                 RXRAT( 106 )      ! CXO3+NO=ALD2+NO2+HO2+XO2
     &                      +                 RXRAT( 107 )      ! CXO3+NO2=PANX
     &                      +                 RXRAT( 111 )      ! CXO3+HO2=0.4100D+00*PACD+...
     &                      +                 RXRAT( 112 )      ! CXO3+MEO2=0.9000D+00*ALD2+...
     &                      +                 RXRAT( 113 )      ! CXO3+XO2=0.9000D+00*ALD2+...
     &                      +    2.0000D+00 * RXRAT( 114 )      ! CXO3+CXO3=0.2000D+01*ALD2+...
     &                      +                 RXRAT( 115 )      ! CXO3+C2O3=MEO2+XO2+HO2+ALD2
     &                      +                 RXRAT( 232 )      ! CXO3+MACO3=ALD2+XO2+HO2+...

      PROD(  PANX         ) =                 RXRAT( 107 )      ! CXO3+NO2=PANX
      LOSS(  PANX         ) =                 RXRAT( 108 )      ! PANX=CXO3+NO2
     &                      +                 RXRAT( 109 )      ! PANX=0.6000D+00*CXO3+...
     &                      +                 RXRAT( 110 )      ! PANX+OH=ALD2+NO2

      PROD(  ROR          ) =    7.6000D-01 * RXRAT( 116 )      ! PAR+OH=0.7600D+00*ROR+...
     &                      +    7.6000D-01 * RXRAT( 194 )      ! CL+PAR=0.7600D+00*ROR+...
      LOSS(  ROR          ) =    9.8000D-01 * RXRAT( 117 )      ! ROR=0.2000D-01*ROR+0.6000D+...
     &                      +                 RXRAT( 118 )      ! ROR=HO2
     &                      +                 RXRAT( 119 )      ! ROR+NO2=NTRALK

      PROD(  OLE          ) =    3.0000D-01 * RXRAT( 198 )      ! CL+IOLE=0.3000D+00*OLE+...
      LOSS(  OLE          ) =                 RXRAT( 120 )      ! OLE+O=0.2000D+00*ALD2+...
     &                      +                 RXRAT( 121 )      ! OLE+OH=0.8000D+00*FORM+...
     &                      +                 RXRAT( 122 )      ! OLE+O3=0.1800D+00*ALD2+...
     &                      +                 RXRAT( 123 )      ! OLE+NO3=NO2+FORM+0.9100D+...
     &                      +                 RXRAT( 197 )      ! OLE+CL=FMCL+0.3300D+...

      PROD(  ETH          ) =   0.0D0
      LOSS(  ETH          ) =                 RXRAT( 124 )      ! ETH+O=FORM+0.1700D+01*HO2+...
     &                      +                 RXRAT( 125 )      ! ETH+OH=XO2+0.1560D+01*FORM+...
     &                      +                 RXRAT( 126 )      ! ETH+O3=FORM+0.6300D+00*CO+...
     &                      +                 RXRAT( 127 )      ! ETH+NO3=NO2+XO2+0.2000D+...
     &                      +                 RXRAT( 196 )      ! ETH+CL=FMCL+0.2000D+01*XO2+...

      PROD(  TOL          ) =   0.0D0
      LOSS(  TOL          ) =                 RXRAT( 132 )      ! TOL+OH=0.2800D+00*HO2+...
     &                      +                 RXRAT( 206 )      ! TOL+CL=HCL+0.8800D+00*XO2+...

      PROD(  CRES         ) =    1.8000D-01 * RXRAT( 132 )      ! TOL+OH=0.1800D+00*CRES+...
     &                      +                 RXRAT( 138 )      ! CRO+HO2=CRES
     &                      +    2.0000D-01 * RXRAT( 158 )      ! OH+XYLMN=0.2000D+00*CRES+...
     &                      +    2.0000D-01 * RXRAT( 159 )      ! OH+NAPH=0.2000D+00*CRES+...
      LOSS(  CRES         ) =                 RXRAT( 135 )      ! CRES+OH=0.6000D-01*CRO+...
     &                      +                 RXRAT( 136 )      ! CRES+NO3=0.3000D+00*CRO+...

      PROD(  TO2          ) =    6.5000D-01 * RXRAT( 132 )      ! TOL+OH=0.6500D+00*TO2+...
     &                      +    3.0000D-01 * RXRAT( 158 )      ! OH+XYLMN=0.3000D+00*TO2+...
     &                      +    3.0000D-01 * RXRAT( 159 )      ! OH+NAPH=0.3000D+00*TO2+...
      LOSS(  TO2          ) =                 RXRAT( 133 )      ! TO2+NO=0.8600D+00*NO2+...
     &                      +                 RXRAT( 134 )      ! TO2+HO2=

      PROD(  TOLRO2       ) =                 RXRAT( 132 )      ! TOL+OH=TOLRO2+0.1000D+...
      LOSS(  TOLRO2       ) =                 RXRAT( 211 )      ! TOLRO2+NO=NO+TOLNRXN
     &                      +                 RXRAT( 212 )      ! TOLRO2+HO2=HO2+TOLHRXN

      PROD(  OPEN         ) =    8.6000D-01 * RXRAT( 133 )      ! TO2+NO=0.8600D+00*OPEN+...
     &                      +    1.3000D-01 * RXRAT( 135 )      ! OH+CRES=0.1300D+00*OPEN+...
     &                      +    1.2000D-01 * RXRAT( 136 )      ! CRES+NO3=0.1200D+00*OPEN+...
      LOSS(  OPEN         ) =                 RXRAT( 147 )      ! OPEN=OPO3+HO2+CO
     &                      +                 RXRAT( 148 )      ! OPEN+OH=0.6000D+00*OPO3+...
     &                      +                 RXRAT( 149 )      ! OPEN+O3=0.3000D-01*ALDX+...
     &                      +                 RXRAT( 150 )      ! OPEN+NO3=OPO3+HNO3

      PROD(  CRO          ) =    6.0000D-02 * RXRAT( 135 )      ! OH+CRES=0.6000D-01*CRO+...
     &                      +    3.0000D-01 * RXRAT( 136 )      ! CRES+NO3=0.3000D+00*CRO+...
     &                      +                 RXRAT( 152 )      ! CAT1+NO3=CRO+HNO3
      LOSS(  CRO          ) =                 RXRAT( 137 )      ! CRO+NO2=CRON
     &                      +                 RXRAT( 138 )      ! CRO+HO2=CRES

      PROD(  CAT1         ) =    7.3200D-01 * RXRAT( 135 )      ! OH+CRES=0.7320D+00*CAT1+...
      LOSS(  CAT1         ) =                 RXRAT( 151 )      ! CAT1+OH=CAO2
     &                      +                 RXRAT( 152 )      ! CAT1+NO3=CRO+HNO3

      PROD(  CRON         ) =                 RXRAT( 137 )      ! CRO+NO2=CRON
      LOSS(  CRON         ) =                 RXRAT( 139 )      ! CRON+OH=CRNO
     &                      +                 RXRAT( 140 )      ! CRON+NO3=CRNO+HNO3

      PROD(  CRNO         ) =                 RXRAT( 139 )      ! CRON+OH=CRNO
     &                      +                 RXRAT( 140 )      ! CRON+NO3=CRNO+HNO3
     &                      +                 RXRAT( 143 )      ! CRN2+NO=CRNO+NO2
     &                      +                 RXRAT( 145 )      ! CRPX=CRNO+OH
      LOSS(  CRNO         ) =                 RXRAT( 141 )      ! CRNO+NO2=0.2000D+01*NTROH
     &                      +                 RXRAT( 142 )      ! CRNO+O3=CRN2

      PROD(  CRN2         ) =                 RXRAT( 142 )      ! CRNO+O3=CRN2
     &                      +                 RXRAT( 146 )      ! CRPX+OH=CRN2
      LOSS(  CRN2         ) =                 RXRAT( 143 )      ! CRN2+NO=CRNO+NO2
     &                      +                 RXRAT( 144 )      ! CRN2+HO2=CRPX

      PROD(  CRPX         ) =                 RXRAT( 144 )      ! CRN2+HO2=CRPX
      LOSS(  CRPX         ) =                 RXRAT( 145 )      ! CRPX=CRNO+OH
     &                      +                 RXRAT( 146 )      ! CRPX+OH=CRN2

      PROD(  OPO3         ) =                 RXRAT( 147 )      ! OPEN=OPO3+HO2+CO
     &                      +    6.0000D-01 * RXRAT( 148 )      ! OPEN+OH=0.6000D+00*OPO3+...
     &                      +    6.2000D-01 * RXRAT( 149 )      ! OPEN+O3=0.6200D+00*OPO3+...
     &                      +                 RXRAT( 150 )      ! OPEN+NO3=OPO3+HNO3
     &                      +                 RXRAT( 157 )      ! OPAN=OPO3+NO2
      LOSS(  OPO3         ) =                 RXRAT( 155 )      ! OPO3+NO=NO2+XO2+HO2+ALDX
     &                      +                 RXRAT( 156 )      ! OPO3+NO2=OPAN

      PROD(  CAO2         ) =    4.0000D-01 * RXRAT( 148 )      ! OPEN+OH=0.4000D+00*CAO2+...
     &                      +                 RXRAT( 151 )      ! CAT1+OH=CAO2
      LOSS(  CAO2         ) =                 RXRAT( 153 )      ! CAO2+NO=0.8600D+00*NO2+...
     &                      +                 RXRAT( 154 )      ! CAO2+HO2=

      PROD(  OPAN         ) =                 RXRAT( 156 )      ! OPO3+NO2=OPAN
      LOSS(  OPAN         ) =                 RXRAT( 157 )      ! OPAN=OPO3+NO2

      PROD(  XYLMN        ) =   0.0D0
      LOSS(  XYLMN        ) =                 RXRAT( 158 )      ! XYLMN+OH=0.7000D+00*HO2+...
     &                      +                 RXRAT( 207 )      ! XYLMN+CL=HCL+0.8400D+...

      PROD(  XYLRO2       ) =                 RXRAT( 158 )      ! OH+XYLMN=XYLRO2+0.5000D+...
      LOSS(  XYLRO2       ) =                 RXRAT( 213 )      ! XYLRO2+NO=NO+XYLNRXN
     &                      +                 RXRAT( 214 )      ! XYLRO2+HO2=HO2+XYLHRXN

      PROD(  NAPH         ) =   0.0D0
      LOSS(  NAPH         ) =                 RXRAT( 159 )      ! NAPH+OH=0.7000D+00*HO2+...
     &                      +                 RXRAT( 208 )      ! NAPH+CL=HCL+0.8400D+00*XO2+...

      PROD(  PAHRO2       ) =                 RXRAT( 159 )      ! OH+NAPH=PAHRO2+0.5000D+...
      LOSS(  PAHRO2       ) =                 RXRAT( 221 )      ! PAHRO2+NO=NO+PAHNRXN
     &                      +                 RXRAT( 222 )      ! PAHRO2+HO2=HO2+PAHHRXN

      PROD(  ISOP         ) =   0.0D0
      LOSS(  ISOP         ) =                 RXRAT( 162 )      ! ISOP+O=0.7500D+00*ISPD+...
     &                      +                 RXRAT( 163 )      ! ISOP+OH=ISOPO2+ISOPRXN
     &                      +                 RXRAT( 167 )      ! ISOP+O3=0.6500D+00*ISPD+...
     &                      +                 RXRAT( 168 )      ! ISOP+NO3=0.2000D+00*ISPD+...
     &                      +                 RXRAT( 184 )      ! ISOP+NO2=0.2000D+00*ISPD+...
     &                      +                 RXRAT( 199 )      ! ISOP+CL=0.1500D+00*HCL+XO2+...

      PROD(  ISPD         ) =    7.5000D-01 * RXRAT( 162 )      ! O+ISOP=0.7500D+00*ISPD+...
     &                      +    9.0000D-01 * RXRAT( 164 )      ! ISOPO2+NO=0.9000D+00*ISPD+...
     &                      +                 RXRAT( 165 )      ! ISOPO2+C2O3=ISPD+0.5980D+...
     &                      +    6.5000D-01 * RXRAT( 167 )      ! O3+ISOP=0.6500D+00*ISPD+...
     &                      +    2.0000D-01 * RXRAT( 168 )      ! NO3+ISOP=0.2000D+00*ISPD+...
     &                      +    2.0000D-01 * RXRAT( 184 )      ! NO2+ISOP=0.2000D+00*ISPD+...
     &                      +                 RXRAT( 199 )      ! CL+ISOP=ISPD+XO2+HO2+...
      LOSS(  ISPD         ) =                 RXRAT( 169 )      ! ISPD+OH=0.1565D+01*PAR+...
     &                      +                 RXRAT( 170 )      ! ISPD+O3=0.1140D+00*C2O3+...
     &                      +                 RXRAT( 171 )      ! ISPD+NO3=0.3570D+00*ALDX+...
     &                      +                 RXRAT( 172 )      ! ISPD=0.3330D+00*CO+0.6700D-...

      PROD(  ISOPRXN      ) =                 RXRAT( 163 )      ! ISOP+OH=ISOPRXN+ISOPO2
     &                      +                 RXRAT( 168 )      ! NO3+ISOP=ISOPRXN+0.8000D+...
      LOSS(  ISOPRXN      ) =   0.0D0

      PROD(  NTRM         ) =    1.0000D-01 * RXRAT( 164 )      ! ISOPO2+NO=0.1000D+00*NTRM+...
     &                      +    8.0000D-01 * RXRAT( 168 )      ! NO3+ISOP=0.8000D+00*NTRM+...
     &                      +                 RXRAT( 175 )      ! XO2T+NO=NTRM
     &                      +    5.3000D-01 * RXRAT( 180 )      ! TERP+NO3=0.5300D+00*NTRM+...
      LOSS(  NTRM         ) =                 RXRAT( 247 )      ! NTRM+OH=NTRMO2
     &                      +                 RXRAT( 253 )      ! NTRM=NO2+HO2+ALD2+IOLE
     &                      +                 RXRAT( 265 )      ! NTRM=HNO3

      PROD(  MACO3        ) =    2.0000D-01 * RXRAT( 167 )      ! O3+ISOP=0.2000D+00*MACO3+...
     &                      +    1.3000D-01 * RXRAT( 169 )      ! OH+ISPD=0.1300D+00*MACO3+...
     &                      +    7.5000D-02 * RXRAT( 171 )      ! NO3+ISPD=0.7500D-01*MACO3+...
     &                      +    7.0000D-01 * RXRAT( 172 )      ! ISPD=0.7000D+00*MACO3+...
     &                      +                 RXRAT( 226 )      ! MAPAN=MACO3+NO2
     &                      +    6.0000D-01 * RXRAT( 227 )      ! MAPAN=0.6000D+00*MACO3+...
      LOSS(  MACO3        ) =                 RXRAT( 224 )      ! MACO3+NO=FORM+NO2+MEO2
     &                      +                 RXRAT( 225 )      ! MACO3+NO2=MAPAN
     &                      +                 RXRAT( 229 )      ! MACO3+HO2=0.1500D+00*C2O3+...
     &                      +                 RXRAT( 230 )      ! MACO3+MEO2=0.1900D+01*FORM+...
     &                      +                 RXRAT( 231 )      ! MACO3+XO2=ALD2+0.3000D+...
     &                      +                 RXRAT( 232 )      ! MACO3+CXO3=ALD2+XO2+HO2+...
     &                      +                 RXRAT( 233 )      ! MACO3+C2O3=0.1650D+01*MEO2+...

      PROD(  NTRI         ) =    8.5000D-01 * RXRAT( 171 )      ! NO3+ISPD=0.8500D+00*NTRI+...
     &                      +    1.1500D+00 * RXRAT( 248 )      ! NTRMO2+NO=0.1150D+01*NTRI+...
     &                      +                 RXRAT( 249 )      ! NTRMO2+HO2=NTRI
     &                      +    6.0000D-01 * RXRAT( 251 )      ! NTRIO2+NO=0.6000D+00*NTRI+...
     &                      +                 RXRAT( 252 )      ! NTRIO2+HO2=NTRI
      LOSS(  NTRI         ) =                 RXRAT( 250 )      ! NTRI+OH=NTRIO2
     &                      +                 RXRAT( 254 )      ! NTRI=NO2+HO2+0.3300D+...
     &                      +                 RXRAT( 266 )      ! NTRI=HNO3

      PROD(  TERP         ) =   0.0D0
      LOSS(  TERP         ) =                 RXRAT( 173 )      ! TERP+O=0.1500D+00*ALDX+...
     &                      +                 RXRAT( 174 )      ! TERP+OH=0.7500D+00*HO2+...
     &                      +                 RXRAT( 179 )      ! TERP+O3=0.5700D+00*OH+...
     &                      +                 RXRAT( 180 )      ! TERP+NO3=0.4700D+00*NO2+...

      PROD(  TRPRXN       ) =                 RXRAT( 173 )      ! TERP+O=TRPRXN+0.5120D+...
     &                      +                 RXRAT( 174 )      ! TERP+OH=TRPRXN+0.1250D+...
     &                      +                 RXRAT( 179 )      ! TERP+O3=TRPRXN+0.7000D-...
     &                      +                 RXRAT( 180 )      ! TERP+NO3=TRPRXN+0.2800D+...
      LOSS(  TRPRXN       ) =   0.0D0

      PROD(  XO2T         ) =    2.5000D-01 * RXRAT( 174 )      ! TERP+OH=0.2500D+00*XO2T+...
     &                      +    1.8000D-01 * RXRAT( 179 )      ! TERP+O3=0.1800D+00*XO2T+...
     &                      +    2.5000D-01 * RXRAT( 180 )      ! TERP+NO3=0.2500D+00*XO2T+...
      LOSS(  XO2T         ) =                 RXRAT( 175 )      ! XO2T+NO=NTRM
     &                      +                 RXRAT( 176 )      ! XO2T+HO2=ROOH
     &                      +    2.0000D+00 * RXRAT( 177 )      ! XO2T+XO2T=
     &                      +                 RXRAT( 178 )      ! XO2T+XO2=

      PROD(  SO2          ) =   0.0D0
      LOSS(  SO2          ) =                 RXRAT( 181 )      ! SO2+OH=SULF+HO2+SULRXN

      PROD(  SULF         ) =                 RXRAT( 181 )      ! SO2+OH=SULF+HO2+SULRXN
      LOSS(  SULF         ) =   0.0D0

      PROD(  SULRXN       ) =                 RXRAT( 181 )      ! SO2+OH=SULRXN+HO2+SULF
      LOSS(  SULRXN       ) =   0.0D0

      PROD(  ETOH         ) =   0.0D0
      LOSS(  ETOH         ) =                 RXRAT( 182 )      ! ETOH+OH=HO2+0.9500D+...
     &                      +                 RXRAT( 204 )      ! ETOH+CL=HCL+HO2+ALD2

      PROD(  ETHA         ) =   0.0D0
      LOSS(  ETHA         ) =                 RXRAT( 183 )      ! ETHA+OH=0.9910D+00*ALD2+...
     &                      +                 RXRAT( 195 )      ! ETHA+CL=HCL+0.9910D+...

      PROD(  CL2          ) =    3.0000D-01 * RXRAT( 188 )      ! CLO+CLO=0.3000D+00*CL2+...
      LOSS(  CL2          ) =                 RXRAT( 185 )      ! CL2=0.2000D+01*CL

      PROD(  CL           ) =    2.0000D+00 * RXRAT( 185 )      ! CL2=0.2000D+01*CL
     &                      +                 RXRAT( 186 )      ! HOCL=CL+OH
     &                      +    1.4000D+00 * RXRAT( 188 )      ! CLO+CLO=0.1400D+01*CL+...
     &                      +                 RXRAT( 189 )      ! CLO+NO=CL+NO2
     &                      +                 RXRAT( 191 )      ! OH+FMCL=CL+CO
     &                      +                 RXRAT( 192 )      ! FMCL=CL+CO+HO2
     &                      +                 RXRAT( 205 )      ! HCL+OH=CL
     &                      +                 RXRAT( 210 )      ! CLNO2=CL+NO2
      LOSS(  CL           ) =                 RXRAT( 187 )      ! CL+O3=CLO
     &                      +                 RXRAT( 193 )      ! CL=HCL+MEO2
     &                      +                 RXRAT( 194 )      ! CL+PAR=HCL+0.8700D+00*XO2+...
     &                      +                 RXRAT( 195 )      ! CL+ETHA=HCL+0.9910D+...
     &                      +                 RXRAT( 196 )      ! CL+ETH=FMCL+0.2000D+01*XO2+...
     &                      +                 RXRAT( 197 )      ! CL+OLE=FMCL+0.3300D+...
     &                      +                 RXRAT( 198 )      ! CL+IOLE=0.3000D+00*HCL+...
     &                      +                 RXRAT( 199 )      ! CL+ISOP=0.1500D+00*HCL+XO2+...
     &                      +                 RXRAT( 200 )      ! CL+FORM=HCL+HO2+CO
     &                      +                 RXRAT( 201 )      ! CL+ALD2=HCL+C2O3
     &                      +                 RXRAT( 202 )      ! CL+ALDX=HCL+CXO3
     &                      +                 RXRAT( 203 )      ! CL+MEOH=HCL+HO2+FORM
     &                      +                 RXRAT( 204 )      ! CL+ETOH=HCL+HO2+ALD2
     &                      +                 RXRAT( 206 )      ! CL+TOL=HCL+0.8800D+00*XO2+...
     &                      +                 RXRAT( 207 )      ! CL+XYLMN=HCL+0.8400D+...
     &                      +                 RXRAT( 208 )      ! CL+NAPH=HCL+0.8400D+00*XO2+...
     &                      +                 RXRAT( 209 )      ! CL+NO2=CLNO2

      PROD(  HOCL         ) =                 RXRAT( 190 )      ! CLO+HO2=HOCL
      LOSS(  HOCL         ) =                 RXRAT( 186 )      ! HOCL=OH+CL

      PROD(  CLO          ) =                 RXRAT( 187 )      ! CL+O3=CLO
      LOSS(  CLO          ) =    2.0000D+00 * RXRAT( 188 )      ! CLO+CLO=0.3000D+00*CL2+...
     &                      +                 RXRAT( 189 )      ! CLO+NO=CL+NO2
     &                      +                 RXRAT( 190 )      ! CLO+HO2=HOCL

      PROD(  FMCL         ) =                 RXRAT( 196 )      ! CL+ETH=FMCL+0.2000D+01*XO2+...
     &                      +                 RXRAT( 197 )      ! CL+OLE=FMCL+0.3300D+...
     &                      +    7.0000D-01 * RXRAT( 198 )      ! CL+IOLE=0.7000D+00*FMCL+...
     &                      +    8.5000D-01 * RXRAT( 199 )      ! CL+ISOP=0.8500D+00*FMCL+...
      LOSS(  FMCL         ) =                 RXRAT( 191 )      ! FMCL+OH=CL+CO
     &                      +                 RXRAT( 192 )      ! FMCL=CL+CO+HO2

      PROD(  HCL          ) =                 RXRAT( 193 )      ! CL=HCL+MEO2
     &                      +                 RXRAT( 194 )      ! CL+PAR=HCL+0.8700D+00*XO2+...
     &                      +                 RXRAT( 195 )      ! CL+ETHA=HCL+0.9910D+...
     &                      +    3.0000D-01 * RXRAT( 198 )      ! CL+IOLE=0.3000D+00*HCL+...
     &                      +    1.5000D-01 * RXRAT( 199 )      ! CL+ISOP=0.1500D+00*HCL+XO2+...
     &                      +                 RXRAT( 200 )      ! CL+FORM=HCL+HO2+CO
     &                      +                 RXRAT( 201 )      ! CL+ALD2=HCL+C2O3
     &                      +                 RXRAT( 202 )      ! CL+ALDX=HCL+CXO3
     &                      +                 RXRAT( 203 )      ! CL+MEOH=HCL+HO2+FORM
     &                      +                 RXRAT( 204 )      ! CL+ETOH=HCL+HO2+ALD2
     &                      +                 RXRAT( 206 )      ! CL+TOL=HCL+0.8800D+00*XO2+...
     &                      +                 RXRAT( 207 )      ! CL+XYLMN=HCL+0.8400D+...
     &                      +                 RXRAT( 208 )      ! CL+NAPH=HCL+0.8400D+00*XO2+...
      LOSS(  HCL          ) =                 RXRAT( 205 )      ! HCL+OH=CL

      PROD(  CLNO2        ) =                 RXRAT( 209 )      ! CL+NO2=CLNO2
     &                      +                 RXRAT( 271 )      ! H2NO3PIJ+ACLI=CLNO2
     &                      +                 RXRAT( 272 )      ! H2NO3PIJ+ACLJ=CLNO2
     &                      +                 RXRAT( 273 )      ! H2NO3PK+ACLK=CLNO2
      LOSS(  CLNO2        ) =                 RXRAT( 210 )      ! CLNO2=CL+NO2

      PROD(  TOLNRXN      ) =                 RXRAT( 211 )      ! TOLRO2+NO=TOLNRXN+NO
      LOSS(  TOLNRXN      ) =   0.0D0

      PROD(  TOLHRXN      ) =                 RXRAT( 212 )      ! TOLRO2+HO2=TOLHRXN+HO2
      LOSS(  TOLHRXN      ) =   0.0D0

      PROD(  XYLNRXN      ) =                 RXRAT( 213 )      ! XYLRO2+NO=XYLNRXN+NO
      LOSS(  XYLNRXN      ) =   0.0D0

      PROD(  XYLHRXN      ) =                 RXRAT( 214 )      ! XYLRO2+HO2=XYLHRXN+HO2
      LOSS(  XYLHRXN      ) =   0.0D0

      PROD(  BENZENE      ) =   0.0D0
      LOSS(  BENZENE      ) =                 RXRAT( 215 )      ! BENZENE+OH=OH+BENZRO2

      PROD(  BENZRO2      ) =                 RXRAT( 215 )      ! BENZENE+OH=BENZRO2+OH
      LOSS(  BENZRO2      ) =                 RXRAT( 216 )      ! BENZRO2+NO=NO+BNZNRXN
     &                      +                 RXRAT( 217 )      ! BENZRO2+HO2=HO2+BNZHRXN

      PROD(  BNZNRXN      ) =                 RXRAT( 216 )      ! BENZRO2+NO=BNZNRXN+NO
      LOSS(  BNZNRXN      ) =   0.0D0

      PROD(  BNZHRXN      ) =                 RXRAT( 217 )      ! BENZRO2+HO2=BNZHRXN+HO2
      LOSS(  BNZHRXN      ) =   0.0D0

      PROD(  SESQ         ) =   0.0D0
      LOSS(  SESQ         ) =                 RXRAT( 218 )      ! SESQ+O3=O3+SESQRXN
     &                      +                 RXRAT( 219 )      ! SESQ+OH=OH+SESQRXN
     &                      +                 RXRAT( 220 )      ! SESQ+NO3=NO3+SESQRXN

      PROD(  SESQRXN      ) =                 RXRAT( 218 )      ! SESQ+O3=SESQRXN+O3
     &                      +                 RXRAT( 219 )      ! SESQ+OH=SESQRXN+OH
     &                      +                 RXRAT( 220 )      ! SESQ+NO3=SESQRXN+NO3
      LOSS(  SESQRXN      ) =   0.0D0

      PROD(  PAHNRXN      ) =                 RXRAT( 221 )      ! PAHRO2+NO=PAHNRXN+NO
      LOSS(  PAHNRXN      ) =   0.0D0

      PROD(  PAHHRXN      ) =                 RXRAT( 222 )      ! PAHRO2+HO2=PAHHRXN+HO2
      LOSS(  PAHHRXN      ) =   0.0D0

      PROD(  SOAALK       ) =   0.0D0
      LOSS(  SOAALK       ) =                 RXRAT( 223 )      ! SOAALK+OH=OH+0.4700D+00*ALKRXN

      PROD(  ALKRXN       ) =    4.7000D-01 * RXRAT( 223 )      ! SOAALK+OH=0.4700D+00*ALKRXN+OH
      LOSS(  ALKRXN       ) =   0.0D0

      PROD(  MAPAN        ) =                 RXRAT( 225 )      ! MACO3+NO2=MAPAN
      LOSS(  MAPAN        ) =                 RXRAT( 226 )      ! MAPAN=MACO3+NO2
     &                      +                 RXRAT( 227 )      ! MAPAN=0.6000D+00*MACO3+...
     &                      +                 RXRAT( 228 )      ! MAPAN+OH=ALD2+CO+NO2

      PROD(  NALKO2       ) =                 RXRAT( 234 )      ! NTRALK+OH=NALKO2
      LOSS(  NALKO2       ) =                 RXRAT( 235 )      ! NALKO2+NO=0.1300D+01*NO2+...
     &                      +                 RXRAT( 236 )      ! NALKO2+HO2=NTRPX

      PROD(  NTRCN        ) =    1.5000D-01 * RXRAT( 235 )      ! NALKO2+NO=0.1500D+00*NTRCN+...
     &                      +    5.3000D-01 * RXRAT( 238 )      ! NOHO2+NO=0.5300D+00*NTRCN+...
     &                      +    2.1000D-01 * RXRAT( 241 )      ! NCNO2+NO=0.2100D+00*NTRCN+...
     &                      +    1.7000D-01 * RXRAT( 244 )      ! NCNOHO2+NO=0.1700D+...
     &                      +                 RXRAT( 246 )      ! NTRPX+OH=NTRCN+OH
      LOSS(  NTRCN        ) =                 RXRAT( 240 )      ! NTRCN+OH=NCNO2
     &                      +                 RXRAT( 257 )      ! NTRCN=NO2+HO2+0.3300D+...
     &                      +                 RXRAT( 262 )      ! NTRCN=HNO3

      PROD(  NTRCNOH      ) =    5.5000D-01 * RXRAT( 235 )      ! NALKO2+NO=0.5500D+...
     &                      +    2.5000D-01 * RXRAT( 238 )      ! NOHO2+NO=0.2500D+...
     &                      +    2.6000D-01 * RXRAT( 241 )      ! NCNO2+NO=0.2600D+...
     &                      +    5.9000D-01 * RXRAT( 244 )      ! NCNOHO2+NO=0.5900D+...
      LOSS(  NTRCNOH      ) =                 RXRAT( 243 )      ! NTRCNOH+OH=NCNOHO2
     &                      +                 RXRAT( 258 )      ! NTRCNOH=NO2+HO2+0.3300D+...
     &                      +                 RXRAT( 263 )      ! NTRCNOH=HNO3

      PROD(  NTRPX        ) =                 RXRAT( 236 )      ! NALKO2+HO2=NTRPX
     &                      +                 RXRAT( 239 )      ! NOHO2+HO2=NTRPX
     &                      +                 RXRAT( 242 )      ! NCNO2+HO2=NTRPX
     &                      +                 RXRAT( 245 )      ! NCNOHO2+HO2=NTRPX
      LOSS(  NTRPX        ) =                 RXRAT( 246 )      ! NTRPX+OH=NTRCN+OH
     &                      +                 RXRAT( 259 )      ! NTRPX=NO2+HO2+ROOH
     &                      +                 RXRAT( 264 )      ! NTRPX=HNO3

      PROD(  NOHO2        ) =                 RXRAT( 237 )      ! NTROH+OH=NOHO2
      LOSS(  NOHO2        ) =                 RXRAT( 238 )      ! NOHO2+NO=0.1220D+01*NO2+...
     &                      +                 RXRAT( 239 )      ! NOHO2+HO2=NTRPX

      PROD(  NCNO2        ) =                 RXRAT( 240 )      ! NTRCN+OH=NCNO2
      LOSS(  NCNO2        ) =                 RXRAT( 241 )      ! NCNO2+NO=0.1530D+01*NO2+...
     &                      +                 RXRAT( 242 )      ! NCNO2+HO2=NTRPX

      PROD(  NCNOHO2      ) =                 RXRAT( 243 )      ! NTRCNOH+OH=NCNOHO2
      LOSS(  NCNOHO2      ) =                 RXRAT( 244 )      ! NCNOHO2+NO=0.1240D+01*NO2+...
     &                      +                 RXRAT( 245 )      ! NCNOHO2+HO2=NTRPX

      PROD(  NTRMO2       ) =                 RXRAT( 247 )      ! NTRM+OH=NTRMO2
      LOSS(  NTRMO2       ) =                 RXRAT( 248 )      ! NTRMO2+NO=0.8700D+00*NO2+...
     &                      +                 RXRAT( 249 )      ! NTRMO2+HO2=NTRI

      PROD(  NTRIO2       ) =                 RXRAT( 250 )      ! NTRI+OH=NTRIO2
      LOSS(  NTRIO2       ) =                 RXRAT( 251 )      ! NTRIO2+NO=0.1400D+01*NO2+...
     &                      +                 RXRAT( 252 )      ! NTRIO2+HO2=NTRI

      PROD(  H2NO3PIJ     ) =                 RXRAT( 267 )      ! N2O5=H2NO3PIJ+HNO3
      LOSS(  H2NO3PIJ     ) =                 RXRAT( 269 )      ! H2NO3PIJ=HNO3
     &                      +                 RXRAT( 271 )      ! H2NO3PIJ+ACLI=CLNO2
     &                      +                 RXRAT( 272 )      ! H2NO3PIJ+ACLJ=CLNO2

      PROD(  H2NO3PK      ) =                 RXRAT( 268 )      ! N2O5=H2NO3PK+HNO3
      LOSS(  H2NO3PK      ) =                 RXRAT( 270 )      ! H2NO3PK=HNO3
     &                      +                 RXRAT( 273 )      ! H2NO3PK+ACLK=CLNO2

      PROD(  ACLI         ) =   0.0D0
      LOSS(  ACLI         ) =                 RXRAT( 271 )      ! ACLI+H2NO3PIJ=CLNO2

      PROD(  ACLJ         ) =   0.0D0
      LOSS(  ACLJ         ) =                 RXRAT( 272 )      ! ACLJ+H2NO3PIJ=CLNO2

      PROD(  ACLK         ) =   0.0D0
      LOSS(  ACLK         ) =                 RXRAT( 273 )      ! ACLK+H2NO3PK=CLNO2

      PROD(  AISO3J       ) =                 RXRAT( 276 )      ! IEPOX=AISO3J
      LOSS(  AISO3J       ) =   0.0D0

      PROD(  AXYL1J       ) =   0.0D0
      LOSS(  AXYL1J       ) =                 RXRAT( 277 )      ! AXYL1J=0.1143D+01*AOLGAJ

      PROD(  AOLGAJ       ) =    1.1428D+00 * RXRAT( 277 )      ! AXYL1J=0.1143D+01*AOLGAJ
     &                      +    1.1428D+00 * RXRAT( 278 )      ! AXYL2J=0.1143D+01*AOLGAJ
     &                      +                 RXRAT( 279 )      ! ATOL1J=AOLGAJ
     &                      +                 RXRAT( 280 )      ! ATOL2J=AOLGAJ
     &                      +    8.5714D-01 * RXRAT( 281 )      ! ABNZ1J=0.8571D+00*AOLGAJ
     &                      +    8.5714D-01 * RXRAT( 282 )      ! ABNZ2J=0.8571D+00*AOLGAJ
     &                      +    1.4286D+00 * RXRAT( 288 )      ! APAH1J=0.1429D+01*AOLGAJ
     &                      +    1.4286D+00 * RXRAT( 289 )      ! APAH2J=0.1429D+01*AOLGAJ
     &                      +    1.7143D+00 * RXRAT( 290 )      ! AALK1J=0.1714D+01*AOLGAJ
     &                      +    1.7143D+00 * RXRAT( 291 )      ! AALK2J=0.1714D+01*AOLGAJ
      LOSS(  AOLGAJ       ) =   0.0D0

      PROD(  AXYL2J       ) =   0.0D0
      LOSS(  AXYL2J       ) =                 RXRAT( 278 )      ! AXYL2J=0.1143D+01*AOLGAJ

      PROD(  ATOL1J       ) =   0.0D0
      LOSS(  ATOL1J       ) =                 RXRAT( 279 )      ! ATOL1J=AOLGAJ

      PROD(  ATOL2J       ) =   0.0D0
      LOSS(  ATOL2J       ) =                 RXRAT( 280 )      ! ATOL2J=AOLGAJ

      PROD(  ABNZ1J       ) =   0.0D0
      LOSS(  ABNZ1J       ) =                 RXRAT( 281 )      ! ABNZ1J=0.8571D+00*AOLGAJ

      PROD(  ABNZ2J       ) =   0.0D0
      LOSS(  ABNZ2J       ) =                 RXRAT( 282 )      ! ABNZ2J=0.8571D+00*AOLGAJ

      PROD(  ATRP1J       ) =   0.0D0
      LOSS(  ATRP1J       ) =                 RXRAT( 283 )      ! ATRP1J=AOLGBJ

      PROD(  AOLGBJ       ) =                 RXRAT( 283 )      ! ATRP1J=AOLGBJ
     &                      +                 RXRAT( 284 )      ! ATRP2J=AOLGBJ
     &                      +    5.0000D-01 * RXRAT( 285 )      ! AISO1J=0.5000D+00*AOLGBJ
     &                      +    5.0000D-01 * RXRAT( 286 )      ! AISO2J=0.5000D+00*AOLGBJ
     &                      +    1.5000D+00 * RXRAT( 287 )      ! ASQTJ=0.1500D+01*AOLGBJ
      LOSS(  AOLGBJ       ) =   0.0D0

      PROD(  ATRP2J       ) =   0.0D0
      LOSS(  ATRP2J       ) =                 RXRAT( 284 )      ! ATRP2J=AOLGBJ

      PROD(  AISO1J       ) =   0.0D0
      LOSS(  AISO1J       ) =                 RXRAT( 285 )      ! AISO1J=0.5000D+00*AOLGBJ

      PROD(  AISO2J       ) =   0.0D0
      LOSS(  AISO2J       ) =                 RXRAT( 286 )      ! AISO2J=0.5000D+00*AOLGBJ

      PROD(  ASQTJ        ) =   0.0D0
      LOSS(  ASQTJ        ) =                 RXRAT( 287 )      ! ASQTJ=0.1500D+01*AOLGBJ

      PROD(  APAH1J       ) =   0.0D0
      LOSS(  APAH1J       ) =                 RXRAT( 288 )      ! APAH1J=0.1429D+01*AOLGAJ

      PROD(  APAH2J       ) =   0.0D0
      LOSS(  APAH2J       ) =                 RXRAT( 289 )      ! APAH2J=0.1429D+01*AOLGAJ

      PROD(  AALK1J       ) =   0.0D0
      LOSS(  AALK1J       ) =                 RXRAT( 290 )      ! AALK1J=0.1714D+01*AOLGAJ

      PROD(  AALK2J       ) =   0.0D0
      LOSS(  AALK2J       ) =                 RXRAT( 291 )      ! AALK2J=0.1714D+01*AOLGAJ

      PROD(  PCVOC        ) =   0.0D0
      LOSS(  PCVOC        ) =                 RXRAT( 292 )      ! PCVOC+OH=OH+PCSOARXN

      PROD(  PCSOARXN     ) =                 RXRAT( 292 )      ! PCVOC+OH=PCSOARXN+OH
      LOSS(  PCSOARXN     ) =   0.0D0

      PROD(  VLVPO1       ) =    3.0030D-01 * RXRAT( 294 )      ! VSVPO1+OH=0.3003D+...
     &                      +    3.8560D-01 * RXRAT( 295 )      ! VSVPO2+OH=0.3856D+...
     &                      +    2.1810D-01 * RXRAT( 296 )      ! VSVPO3+OH=0.2181D+...
     &                      +    2.4120D-01 * RXRAT( 297 )      ! VIVPO1+OH=0.2412D+...
      LOSS(  VLVPO1       ) =    5.1430D-01 * RXRAT( 293 )      ! VLVPO1+OH=0.4857D+...

      PROD(  VSVPO1       ) =    6.2000D-03 * RXRAT( 293 )      ! VLVPO1+OH=0.6200D-...
     &                      +    9.5000D-02 * RXRAT( 295 )      ! VSVPO2+OH=0.9500D-...
     &                      +    3.0630D-01 * RXRAT( 296 )      ! VSVPO3+OH=0.3063D+...
     &                      +    2.0890D-01 * RXRAT( 297 )      ! VIVPO1+OH=0.2089D+...
      LOSS(  VSVPO1       ) =    7.1380D-01 * RXRAT( 294 )      ! VSVPO1+OH=0.2862D+...

      PROD(  VSVPO2       ) =    2.5000D-03 * RXRAT( 293 )      ! VLVPO1+OH=0.2500D-...
     &                      +    4.1000D-03 * RXRAT( 294 )      ! VSVPO1+OH=0.4100D-...
     &                      +    1.5300D-02 * RXRAT( 296 )      ! VSVPO3+OH=0.1530D-...
     &                      +    3.0000D-01 * RXRAT( 297 )      ! VIVPO1+OH=0.3000D+...
      LOSS(  VSVPO2       ) =    8.6270D-01 * RXRAT( 295 )      ! VSVPO2+OH=0.1373D+...

      PROD(  VSVPO3       ) =    2.6000D-03 * RXRAT( 293 )      ! VLVPO1+OH=0.2600D-...
     &                      +    3.5000D-03 * RXRAT( 294 )      ! VSVPO1+OH=0.3500D-...
     &                      +    5.0000D-04 * RXRAT( 295 )      ! VSVPO2+OH=0.5000D-...
      LOSS(  VSVPO3       ) =    8.9570D-01 * RXRAT( 296 )      ! VSVPO3+OH=0.1043D+...

      PROD(  VIVPO1       ) =    2.3000D-03 * RXRAT( 293 )      ! VLVPO1+OH=0.2300D-...
      LOSS(  VIVPO1       ) =                 RXRAT( 297 )      ! VIVPO1+OH=OH+0.2412D+...

      PROD(  VLVOO1       ) =    2.9440D-01 * RXRAT( 293 )      ! VLVPO1+OH=0.2944D+...
     &                      +    2.2390D-01 * RXRAT( 294 )      ! VSVPO1+OH=0.2239D+...
     &                      +    2.0510D-01 * RXRAT( 295 )      ! VSVPO2+OH=0.2051D+...
     &                      +    1.8930D-01 * RXRAT( 296 )      ! VSVPO3+OH=0.1893D+...
     &                      +    2.0280D-01 * RXRAT( 297 )      ! VIVPO1+OH=0.2028D+...
     &                      +    2.8580D-01 * RXRAT( 299 )      ! VLVOO2+OH=0.2858D+...
     &                      +    3.3030D-01 * RXRAT( 300 )      ! VSVOO1+OH=0.3303D+...
     &                      +    3.4440D-01 * RXRAT( 301 )      ! VSVOO2+OH=0.3444D+...
     &                      +    3.8860D-01 * RXRAT( 302 )      ! VSVOO3+OH=0.3886D+...
      LOSS(  VLVOO1       ) =    3.3360D-01 * RXRAT( 298 )      ! VLVOO1+OH=0.6664D+...

      PROD(  VLVOO2       ) =    2.0210D-01 * RXRAT( 293 )      ! VLVPO1+OH=0.2021D+...
     &                      +    1.8200D-01 * RXRAT( 294 )      ! VSVPO1+OH=0.1820D+...
     &                      +    1.7640D-01 * RXRAT( 295 )      ! VSVPO2+OH=0.1764D+...
     &                      +    1.6680D-01 * RXRAT( 296 )      ! VSVPO3+OH=0.1668D+...
     &                      +    4.7100D-02 * RXRAT( 297 )      ! VIVPO1+OH=0.4710D-...
     &                      +    1.4300D-02 * RXRAT( 298 )      ! VLVOO1+OH=0.1430D-...
     &                      +    2.2720D-01 * RXRAT( 300 )      ! VSVOO1+OH=0.2272D+...
     &                      +    2.7490D-01 * RXRAT( 301 )      ! VSVOO2+OH=0.2749D+...
     &                      +    2.4210D-01 * RXRAT( 302 )      ! VSVOO3+OH=0.2421D+...
      LOSS(  VLVOO2       ) =    6.0690D-01 * RXRAT( 299 )      ! VLVOO2+OH=0.3931D+...

      PROD(  VSVOO2       ) =    1.9000D-03 * RXRAT( 293 )      ! VLVPO1+OH=0.1900D-...
     &                      +    1.2390D-01 * RXRAT( 298 )      ! VLVOO1+OH=0.1239D+...
     &                      +    1.0270D-01 * RXRAT( 299 )      ! VLVOO2+OH=0.1027D+...
     &                      +    7.0200D-02 * RXRAT( 300 )      ! VSVOO1+OH=0.7020D-...
     &                      +    3.8500D-02 * RXRAT( 302 )      ! VSVOO3+OH=0.3850D-...
      LOSS(  VSVOO2       ) =    7.4230D-01 * RXRAT( 301 )      ! VSVOO2+OH=0.2577D+...

      PROD(  VSVOO3       ) =    2.3000D-03 * RXRAT( 293 )      ! VLVPO1+OH=0.2300D-...
     &                      +    1.8310D-01 * RXRAT( 298 )      ! VLVOO1+OH=0.1831D+...
     &                      +    2.0450D-01 * RXRAT( 299 )      ! VLVOO2+OH=0.2045D+...
     &                      +    1.1160D-01 * RXRAT( 300 )      ! VSVOO1+OH=0.1116D+...
     &                      +    7.3900D-02 * RXRAT( 301 )      ! VSVOO2+OH=0.7390D-...
      LOSS(  VSVOO3       ) =    7.3330D-01 * RXRAT( 302 )      ! VSVOO3+OH=0.2667D+...

      PROD(  VSVOO1       ) =    1.2300D-02 * RXRAT( 298 )      ! VLVOO1+OH=0.1230D-...
     &                      +    1.3900D-02 * RXRAT( 299 )      ! VLVOO2+OH=0.1390D-...
     &                      +    4.9100D-02 * RXRAT( 301 )      ! VSVOO2+OH=0.4910D-...
     &                      +    6.4000D-02 * RXRAT( 302 )      ! VSVOO3+OH=0.6400D-...
      LOSS(  VSVOO1       ) =    7.3930D-01 * RXRAT( 300 )      ! VSVOO1+OH=0.2607D+...

      PROD(  FORM_PRIMARY ) =   0.0D0
      LOSS(  FORM_PRIMARY ) =                 RXRAT( 303 )      ! FORM_PRIMARY+OH=OH
     &                      +                 RXRAT( 304 )      ! FORM_PRIMARY+NO3=NO3
     &                      +                 RXRAT( 305 )      ! FORM_PRIMARY+O=O
     &                      +                 RXRAT( 306 )      ! FORM_PRIMARY=
     &                      +                 RXRAT( 307 )      ! FORM_PRIMARY=
     &                      +                 RXRAT( 308 )      ! FORM_PRIMARY+CL=CL

      PROD(  ALD2_PRIMARY ) =   0.0D0
      LOSS(  ALD2_PRIMARY ) =                 RXRAT( 309 )      ! ALD2_PRIMARY+OH=OH
     &                      +                 RXRAT( 310 )      ! ALD2_PRIMARY+NO3=NO3
     &                      +                 RXRAT( 311 )      ! ALD2_PRIMARY+O=O
     &                      +                 RXRAT( 312 )      ! ALD2_PRIMARY=
     &                      +                 RXRAT( 313 )      ! ALD2_PRIMARY+CL=CL

      PROD(  BUTADIENE13  ) =   0.0D0
      LOSS(  BUTADIENE13  ) =                 RXRAT( 314 )      ! BUTADIENE13+OH=OH+0.5800D+...
     &                      +                 RXRAT( 315 )      ! BUTADIENE13+O3=O3+0.5200D+...
     &                      +                 RXRAT( 316 )      ! BUTADIENE13+NO3=NO3+...
     &                      +                 RXRAT( 317 )      ! BUTADIENE13+CL=CL+0.5800D+...

      PROD(  ACROLEIN     ) =    5.8000D-01 * RXRAT( 314 )      ! BUTADIENE13+OH=0.5800D+...
     &                      +    5.2000D-01 * RXRAT( 315 )      ! BUTADIENE13+O3=0.5200D+...
     &                      +    4.5000D-02 * RXRAT( 316 )      ! BUTADIENE13+NO3=0.4500D-...
     &                      +    5.8000D-01 * RXRAT( 317 )      ! BUTADIENE13+CL=0.5800D+...
      LOSS(  ACROLEIN     ) =                 RXRAT( 323 )      ! ACROLEIN+OH=OH
     &                      +                 RXRAT( 324 )      ! ACROLEIN+O3=O3
     &                      +                 RXRAT( 325 )      ! ACROLEIN+NO3=NO3
     &                      +                 RXRAT( 326 )      ! ACROLEIN=
     &                      +                 RXRAT( 327 )      ! ACROLEIN+CL=CL

      PROD(  ACRO_PRIMARY ) =   0.0D0
      LOSS(  ACRO_PRIMARY ) =                 RXRAT( 318 )      ! ACRO_PRIMARY+OH=OH
     &                      +                 RXRAT( 319 )      ! ACRO_PRIMARY+O3=O3
     &                      +                 RXRAT( 320 )      ! ACRO_PRIMARY+NO3=NO3
     &                      +                 RXRAT( 321 )      ! ACRO_PRIMARY=
     &                      +                 RXRAT( 322 )      ! ACRO_PRIMARY+CL=CL

      PROD(  TOLU         ) =   0.0D0
      LOSS(  TOLU         ) =                 RXRAT( 328 )      ! TOLU+OH=OH
     &                      +                 RXRAT( 329 )      ! TOLU+CL=CL

      PROD(  MXYL         ) =   0.0D0
      LOSS(  MXYL         ) =                 RXRAT( 330 )      ! MXYL+OH=OH
     &                      +                 RXRAT( 331 )      ! MXYL+CL=CL

      PROD(  OXYL         ) =   0.0D0
      LOSS(  OXYL         ) =                 RXRAT( 332 )      ! OXYL+OH=OH
     &                      +                 RXRAT( 333 )      ! OXYL+CL=CL

      PROD(  PXYL         ) =   0.0D0
      LOSS(  PXYL         ) =                 RXRAT( 334 )      ! PXYL+OH=OH
     &                      +                 RXRAT( 335 )      ! PXYL+CL=CL

      PROD(  APIN         ) =   0.0D0
      LOSS(  APIN         ) =                 RXRAT( 336 )      ! APIN+O=O
     &                      +                 RXRAT( 337 )      ! APIN+OH=OH
     &                      +                 RXRAT( 338 )      ! APIN+O3=O3
     &                      +                 RXRAT( 339 )      ! APIN+NO3=NO3
     &                      +                 RXRAT( 340 )      ! APIN+CL=CL

      PROD(  BPIN         ) =   0.0D0
      LOSS(  BPIN         ) =                 RXRAT( 341 )      ! BPIN+O=O
     &                      +                 RXRAT( 342 )      ! BPIN+OH=OH
     &                      +                 RXRAT( 343 )      ! BPIN+O3=O3
     &                      +                 RXRAT( 344 )      ! BPIN+NO3=NO3
     &                      +                 RXRAT( 345 )      ! BPIN+CL=CL

      PROD(  HG           ) =   0.0D0
      LOSS(  HG           ) =                 RXRAT( 346 )      ! HG+O3=0.5000D+00*HGIIAER+...
     &                      +                 RXRAT( 347 )      ! HG+CL2=HGIIGAS+CL2
     &                      +                 RXRAT( 348 )      ! HG+H2O2=HGIIGAS+H2O2
     &                      +                 RXRAT( 349 )      ! HG+OH=0.5000D+00*HGIIAER+...
     &                      +    5.0000D-01 * RXRAT( 350 )      ! HG+CL=0.5000D+00*HG+...

      PROD(  HGIIAER      ) =    5.0000D-01 * RXRAT( 346 )      ! HG+O3=0.5000D+00*HGIIAER+...
     &                      +    5.0000D-01 * RXRAT( 349 )      ! HG+OH=0.5000D+00*HGIIAER+...
      LOSS(  HGIIAER      ) =   0.0D0

      PROD(  HGIIGAS      ) =    5.0000D-01 * RXRAT( 346 )      ! HG+O3=0.5000D+00*HGIIGAS+...
     &                      +                 RXRAT( 347 )      ! HG+CL2=HGIIGAS+CL2
     &                      +                 RXRAT( 348 )      ! HG+H2O2=HGIIGAS+H2O2
     &                      +    5.0000D-01 * RXRAT( 349 )      ! HG+OH=0.5000D+00*HGIIGAS+...
     &                      +    5.0000D-01 * RXRAT( 350 )      ! HG+CL=0.5000D+00*HGIIGAS+...
      LOSS(  HGIIGAS      ) =   0.0D0

      PNEG( PAR ) =    2.1000D+00 * RXRAT( 117 )      ! ROR=-0.2100D+01*PAR+...
     &            +    7.0000D-01 * RXRAT( 121 )      ! OH+OLE=-0.7000D+00*PAR+...
     &            +                 RXRAT( 122 )      ! O3+OLE=-PAR+0.7400D+...
     &            +                 RXRAT( 123 )      ! NO3+OLE=-PAR+FORM+0.9100D+...
     &            +                 RXRAT( 197 )      ! CL+OLE=-PAR+0.3300D+...
     &            +    6.6000D-01 * RXRAT( 254 )      ! NTRI=-0.6600D+00*PAR+HO2+...
     &            +    6.6000D-01 * RXRAT( 255 )      ! NTRALK=-0.6600D+00*PAR+HO2+...
     &            +    6.6000D-01 * RXRAT( 256 )      ! NTROH=-0.6600D+00*PAR+HO2+...
     &            +    6.6000D-01 * RXRAT( 257 )      ! NTRCN=-0.6600D+00*PAR+HO2+...
     &            +    6.6000D-01 * RXRAT( 258 )      ! NTRCNOH=-0.6600D+00*PAR+...

      RETURN

      END
