
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!

C RCS file, release, date & time of last delta, author, state, [and locker]
C $Header$

C what(1) key, module and SID; SCCS file; date and time of last delta:
C %W% %P% %G% %U%

      SUBROUTINE HRPRODLOSS

C***********************************************************************
C
C  FUNCTION: To compute the production and loss rates for EBI species
C
C  PRECONDITIONS: For the CB05TUMP family of mechanisms
C
C  RETURN VALUES: None
C
C  KEY SUBROUTINES/FUNCTIONS CALLED: None
C
C  REVISION HISTORY: Created by EBI solver program, May 27, 2016
C
C   18 Jul 14 B.Hutzell: revised to use real(8) variables

C***********************************************************************
      USE HRDATA

      IMPLICIT NONE


C.....INCLUDES: NONE


C.....ARGUMENTS: NONE


C.....PARAMETERS: NONE


C.....EXTERNAL FUNCTIONS: NONE


C.....SAVED VARIABLES: NONE
!     CHARACTER( 16 ), SAVE  ::  PNAME = 'HRPRODLOSS'   ! Program name


C.....LOCAL VARIABLES:


C***********************************************************************


      PROD(  HNO3             ) =    2.0000D+00 * RXRAT(  19 )      ! N2O5=0.2000D+01*HNO3
     &                          +    2.0000D+00 * RXRAT(  20 )      ! N2O5=0.2000D+01*HNO3
     &                          +                 RXRAT(  28 )      ! NO2+OH=HNO3
     &                          +                 RXRAT(  48 )      ! NO3+HO2=HNO3
     &                          +                 RXRAT(  61 )      ! NTR+OH=HNO3+HO2+0.3300D+...
     &                          +                 RXRAT(  77 )      ! FORM+NO3=HNO3+HO2+CO
     &                          +                 RXRAT(  85 )      ! ALD2+NO3=HNO3+C2O3
     &                          +                 RXRAT( 100 )      ! ALDX+NO3=HNO3+CXO3
     &                          +                 RXRAT( 132 )      ! CRES+NO3=HNO3+0.3000D+...
     &                          +                 RXRAT( 136 )      ! CRON+NO3=HNO3+CRNO
     &                          +                 RXRAT( 146 )      ! OPEN+NO3=HNO3+OPO3
     &                          +                 RXRAT( 148 )      ! CAT1+NO3=HNO3+CRO
     &                          +    1.5000D-01 * RXRAT( 163 )      ! NO3+ISPD=0.1500D+00*HNO3+...
     &                          +                 RXRAT( 208 )      ! N2O5=HNO3+H2NO3PIJ
     &                          +                 RXRAT( 209 )      ! N2O5=HNO3+H2NO3PK
     &                          +                 RXRAT( 210 )      ! H2NO3PIJ=HNO3
     &                          +                 RXRAT( 211 )      ! H2NO3PK=HNO3
     &                          +    5.0000D-01 * RXRAT( 215 )      ! NO2=0.5000D+00*HNO3+...
      LOSS(  HNO3             ) =                 RXRAT(  29 )      ! HNO3+OH=NO3
     &                          +                 RXRAT(  52 )      ! HNO3=OH+NO2

      PROD(  H2O2             ) =                 RXRAT(  34 )      ! HO2+HO2=H2O2
     &                          +                 RXRAT(  35 )      ! HO2+HO2=H2O2
     &                          +                 RXRAT(  42 )      ! OH+OH=H2O2
      LOSS(  H2O2             ) =                 RXRAT(  36 )      ! H2O2=0.2000D+01*OH
     &                          +                 RXRAT(  37 )      ! H2O2+OH=HO2
     &                          +                 RXRAT(  45 )      ! H2O2+O=OH+HO2

      PROD(  XO2              ) =                 RXRAT(  63 )      ! ROOH+OH=XO2+0.5000D+...
     &                          +    3.0000D-01 * RXRAT(  70 )      ! MEPX+OH=0.3000D+00*XO2+...
     &                          +                 RXRAT( 102 )      ! CXO3+NO=XO2+NO2+HO2+ALD2
     &                          +    9.0000D-01 * RXRAT( 108 )      ! CXO3+MEO2=0.9000D+00*XO2+...
     &                          +    2.0000D+00 * RXRAT( 110 )      ! CXO3+CXO3=0.2000D+01*XO2+...
     &                          +                 RXRAT( 111 )      ! CXO3+C2O3=XO2+MEO2+HO2+ALD2
     &                          +    8.7000D-01 * RXRAT( 112 )      ! PAR+OH=0.8700D+00*XO2+...
     &                          +    9.6000D-01 * RXRAT( 113 )      ! ROR=0.9600D+00*XO2+0.6000D+...
     &                          +    2.0000D-01 * RXRAT( 116 )      ! O+OLE=0.2000D+00*XO2+...
     &                          +    8.0000D-01 * RXRAT( 117 )      ! OH+OLE=0.8000D+00*XO2+...
     &                          +    2.2000D-01 * RXRAT( 118 )      ! O3+OLE=0.2200D+00*XO2+...
     &                          +    9.1000D-01 * RXRAT( 119 )      ! NO3+OLE=0.9100D+00*XO2+...
     &                          +    7.0000D-01 * RXRAT( 120 )      ! O+ETH=0.7000D+00*XO2+...
     &                          +                 RXRAT( 121 )      ! OH+ETH=XO2+0.1560D+01*FORM+...
     &                          +                 RXRAT( 123 )      ! NO3+ETH=XO2+NO2+0.2000D+...
     &                          +    1.0000D-01 * RXRAT( 124 )      ! IOLE+O=0.1000D+00*XO2+...
     &                          +                 RXRAT( 125 )      ! IOLE+OH=XO2+0.7000D+...
     &                          +    1.0000D-01 * RXRAT( 128 )      ! TOL+OH=0.1000D+00*XO2+...
     &                          +    1.2000D-01 * RXRAT( 131 )      ! OH+CRES=0.1200D+00*XO2+...
     &                          +    6.0000D-01 * RXRAT( 132 )      ! CRES+NO3=0.6000D+00*XO2+...
     &                          +    3.0000D-02 * RXRAT( 145 )      ! OPEN+O3=0.3000D-01*XO2+...
     &                          +                 RXRAT( 151 )      ! OPO3+NO=XO2+NO2+HO2+ALDX
     &                          +    5.0000D-01 * RXRAT( 154 )      ! OH+XYL=0.5000D+00*XO2+...
     &                          +                 RXRAT( 155 )      ! OH+MGLY=XO2+C2O3
     &                          +    2.5000D-01 * RXRAT( 157 )      ! O+ISOP=0.2500D+00*XO2+...
     &                          +    9.9100D-01 * RXRAT( 158 )      ! OH+ISOP=0.9910D+00*XO2+...
     &                          +    2.0000D-01 * RXRAT( 159 )      ! O3+ISOP=0.2000D+00*XO2+...
     &                          +                 RXRAT( 160 )      ! NO3+ISOP=XO2+0.8000D+...
     &                          +    7.1300D-01 * RXRAT( 161 )      ! OH+ISPD=0.7130D+00*XO2+...
     &                          +    6.4000D-02 * RXRAT( 162 )      ! O3+ISPD=0.6400D-01*XO2+...
     &                          +    7.5000D-02 * RXRAT( 163 )      ! NO3+ISPD=0.7500D-01*XO2+...
     &                          +    7.0000D-01 * RXRAT( 164 )      ! ISPD=0.7000D+00*XO2+...
     &                          +    1.2500D+00 * RXRAT( 166 )      ! TERP+OH=0.1250D+01*XO2+...
     &                          +    7.6000D-01 * RXRAT( 167 )      ! TERP+O3=0.7600D+00*XO2+...
     &                          +    1.0300D+00 * RXRAT( 168 )      ! TERP+NO3=0.1030D+01*XO2+...
     &                          +    1.0000D-01 * RXRAT( 170 )      ! OH+ETOH=0.1000D+00*XO2+...
     &                          +    9.9100D-01 * RXRAT( 171 )      ! OH+ETHA=0.9910D+00*XO2+...
     &                          +                 RXRAT( 172 )      ! NO2+ISOP=XO2+0.8000D+...
     &                          +    8.7000D-01 * RXRAT( 182 )      ! CL+PAR=0.8700D+00*XO2+HCL+...
     &                          +    9.9100D-01 * RXRAT( 183 )      ! CL+ETHA=0.9910D+00*XO2+...
     &                          +    2.0000D+00 * RXRAT( 184 )      ! CL+ETH=0.2000D+01*XO2+FMCL+...
     &                          +    2.0000D+00 * RXRAT( 185 )      ! CL+OLE=0.2000D+01*XO2+...
     &                          +    1.7000D+00 * RXRAT( 186 )      ! CL+IOLE=0.1700D+01*XO2+...
     &                          +                 RXRAT( 187 )      ! CL+ISOP=XO2+0.1500D+00*HCL+...
     &                          +    8.8000D-01 * RXRAT( 194 )      ! CL+TOL=0.8800D+00*XO2+HCL+...
     &                          +    8.4000D-01 * RXRAT( 195 )      ! CL+XYL=0.8400D+00*XO2+HCL+...
      LOSS(  XO2              ) =                 RXRAT(  54 )      ! XO2+NO=NO2
     &                          +                 RXRAT(  56 )      ! XO2+HO2=ROOH
     &                          +    2.0000D+00 * RXRAT(  58 )      ! XO2+XO2=
     &                          +                 RXRAT(  60 )      ! XO2+XO2N=
     &                          +                 RXRAT(  93 )      ! XO2+C2O3=0.9000D+00*MEO2+...
     &                          +                 RXRAT( 109 )      ! XO2+CXO3=0.9000D+00*ALD2+...

      PROD(  XO2N             ) =    1.3000D-01 * RXRAT( 112 )      ! PAR+OH=0.1300D+00*XO2N+...
     &                          +    4.0000D-02 * RXRAT( 113 )      ! ROR=0.4000D-01*XO2N+...
     &                          +    1.0000D-02 * RXRAT( 116 )      ! O+OLE=0.1000D-01*XO2N+...
     &                          +    9.0000D-02 * RXRAT( 119 )      ! NO3+OLE=0.9000D-01*XO2N+...
     &                          +    6.0000D-02 * RXRAT( 131 )      ! OH+CRES=0.6000D-01*XO2N+...
     &                          +    1.0000D-01 * RXRAT( 132 )      ! CRES+NO3=0.1000D+00*XO2N+...
     &                          +    8.8000D-02 * RXRAT( 158 )      ! OH+ISOP=0.8800D-01*XO2N+...
     &                          +    2.5000D-01 * RXRAT( 166 )      ! TERP+OH=0.2500D+00*XO2N+...
     &                          +    1.8000D-01 * RXRAT( 167 )      ! TERP+O3=0.1800D+00*XO2N+...
     &                          +    2.5000D-01 * RXRAT( 168 )      ! TERP+NO3=0.2500D+00*XO2N+...
     &                          +    9.0000D-03 * RXRAT( 171 )      ! OH+ETHA=0.9000D-02*XO2N+...
     &                          +    1.3000D-01 * RXRAT( 182 )      ! CL+PAR=0.1300D+00*XO2N+...
     &                          +    9.0000D-03 * RXRAT( 183 )      ! CL+ETHA=0.9000D-02*XO2N+...
     &                          +    1.2000D-01 * RXRAT( 194 )      ! CL+TOL=0.1200D+00*XO2N+...
     &                          +    1.6000D-01 * RXRAT( 195 )      ! CL+XYL=0.1600D+00*XO2N+...
      LOSS(  XO2N             ) =                 RXRAT(  55 )      ! XO2N+NO=NTR
     &                          +                 RXRAT(  57 )      ! XO2N+HO2=ROOH
     &                          +    2.0000D+00 * RXRAT(  59 )      ! XO2N+XO2N=
     &                          +                 RXRAT(  60 )      ! XO2N+XO2=

      PROD(  NTR              ) =                 RXRAT(  55 )      ! XO2N+NO=NTR
     &                          +                 RXRAT( 115 )      ! ROR+NO2=NTR
     &                          +    1.4000D-01 * RXRAT( 129 )      ! TO2+NO=0.1400D+00*NTR+...
     &                          +    2.0000D+00 * RXRAT( 137 )      ! CRNO+NO2=0.2000D+01*NTR
     &                          +    1.4000D-01 * RXRAT( 149 )      ! CAO2+NO=0.1400D+00*NTR+...
     &                          +    8.0000D-01 * RXRAT( 160 )      ! NO3+ISOP=0.8000D+00*NTR+...
     &                          +    8.5000D-01 * RXRAT( 163 )      ! NO3+ISPD=0.8500D+00*NTR+...
     &                          +    5.3000D-01 * RXRAT( 168 )      ! TERP+NO3=0.5300D+00*NTR+...
     &                          +    8.0000D-01 * RXRAT( 172 )      ! NO2+ISOP=0.8000D+00*NTR+...
      LOSS(  NTR              ) =                 RXRAT(  61 )      ! NTR+OH=HNO3+HO2+0.3300D+...
     &                          +                 RXRAT(  62 )      ! NTR=NO2+HO2+0.3300D+...

      PROD(  ROOH             ) =                 RXRAT(  56 )      ! XO2+HO2=ROOH
     &                          +                 RXRAT(  57 )      ! XO2N+HO2=ROOH
      LOSS(  ROOH             ) =                 RXRAT(  63 )      ! ROOH+OH=XO2+0.5000D+...
     &                          +                 RXRAT(  64 )      ! ROOH=OH+HO2+0.5000D+...

      PROD(  FORM             ) =    3.3000D-01 * RXRAT(  61 )      ! NTR+OH=0.3300D+00*FORM+HO2+...
     &                          +    3.3000D-01 * RXRAT(  62 )      ! NTR=0.3300D+00*FORM+HO2+...
     &                          +                 RXRAT(  67 )      ! MEO2+NO=FORM+HO2+NO2
     &                          +    1.3700D+00 * RXRAT(  69 )      ! MEO2+MEO2=0.1370D+01*FORM+...
     &                          +                 RXRAT(  71 )      ! MEPX=FORM+HO2+OH
     &                          +                 RXRAT(  72 )      ! MEOH+OH=FORM+HO2
     &                          +                 RXRAT(  79 )      ! HCO3=FORM+HO2
     &                          +                 RXRAT(  92 )      ! C2O3+MEO2=FORM+0.9000D+...
     &                          +    1.0000D-01 * RXRAT( 108 )      ! CXO3+MEO2=0.1000D+00*FORM+...
     &                          +    2.0000D-01 * RXRAT( 116 )      ! O+OLE=0.2000D+00*FORM+...
     &                          +    8.0000D-01 * RXRAT( 117 )      ! OH+OLE=0.8000D+00*FORM+...
     &                          +    7.4000D-01 * RXRAT( 118 )      ! O3+OLE=0.7400D+00*FORM+...
     &                          +                 RXRAT( 119 )      ! NO3+OLE=FORM+NO2+0.9100D+...
     &                          +                 RXRAT( 120 )      ! O+ETH=FORM+0.1700D+01*HO2+...
     &                          +    1.5600D+00 * RXRAT( 121 )      ! OH+ETH=0.1560D+01*FORM+XO2+...
     &                          +                 RXRAT( 122 )      ! O3+ETH=FORM+0.6300D+00*CO+...
     &                          +    2.0000D+00 * RXRAT( 123 )      ! NO3+ETH=0.2000D+01*FORM+...
     &                          +    2.5000D-01 * RXRAT( 126 )      ! IOLE+O3=0.2500D+00*FORM+...
     &                          +    3.3600D-01 * RXRAT( 129 )      ! TO2+NO=0.3360D+00*FORM+...
     &                          +    6.0000D-02 * RXRAT( 131 )      ! OH+CRES=0.6000D-01*FORM+...
     &                          +    2.4000D-01 * RXRAT( 132 )      ! CRES+NO3=0.2400D+00*FORM+...
     &                          +    7.0000D-01 * RXRAT( 145 )      ! OPEN+O3=0.7000D+00*FORM+...
     &                          +    3.4400D-01 * RXRAT( 149 )      ! CAO2+NO=0.3440D+00*FORM+...
     &                          +    5.0000D-01 * RXRAT( 157 )      ! O+ISOP=0.5000D+00*FORM+...
     &                          +    6.2900D-01 * RXRAT( 158 )      ! OH+ISOP=0.6290D+00*FORM+...
     &                          +    6.0000D-01 * RXRAT( 159 )      ! O3+ISOP=0.6000D+00*FORM+...
     &                          +    1.6700D-01 * RXRAT( 161 )      ! OH+ISPD=0.1670D+00*FORM+...
     &                          +    1.5000D-01 * RXRAT( 162 )      ! O3+ISPD=0.1500D+00*FORM+...
     &                          +    2.8200D-01 * RXRAT( 163 )      ! NO3+ISPD=0.2820D+00*FORM+...
     &                          +    9.0000D-01 * RXRAT( 164 )      ! ISPD=0.9000D+00*FORM+...
     &                          +    2.8000D-01 * RXRAT( 166 )      ! TERP+OH=0.2800D+00*FORM+...
     &                          +    2.4000D-01 * RXRAT( 167 )      ! TERP+O3=0.2400D+00*FORM+...
     &                          +    1.0000D-01 * RXRAT( 170 )      ! OH+ETOH=0.1000D+00*FORM+...
     &                          +                 RXRAT( 184 )      ! CL+ETH=FORM+0.2000D+01*XO2+...
     &                          +                 RXRAT( 191 )      ! CL+MEOH=FORM+HO2+HCL
      LOSS(  FORM             ) =                 RXRAT(  73 )      ! FORM+OH=HO2+CO
     &                          +                 RXRAT(  74 )      ! FORM=0.2000D+01*HO2+CO
     &                          +                 RXRAT(  75 )      ! FORM=CO
     &                          +                 RXRAT(  76 )      ! FORM+O=OH+HO2+CO
     &                          +                 RXRAT(  77 )      ! FORM+NO3=HNO3+HO2+CO
     &                          +                 RXRAT(  78 )      ! FORM+HO2=HCO3
     &                          +                 RXRAT( 188 )      ! FORM+CL=HCL+HO2+CO

      PROD(  ALD2             ) =    3.3000D-01 * RXRAT(  61 )      ! NTR+OH=0.3300D+00*ALD2+HO2+...
     &                          +    3.3000D-01 * RXRAT(  62 )      ! NTR=0.3300D+00*ALD2+HO2+...
     &                          +    5.0000D-01 * RXRAT(  63 )      ! ROOH+OH=0.5000D+00*ALD2+...
     &                          +    5.0000D-01 * RXRAT(  64 )      ! ROOH=0.5000D+00*ALD2+HO2+...
     &                          +                 RXRAT( 102 )      ! CXO3+NO=ALD2+NO2+HO2+XO2
     &                          +                 RXRAT( 106 )      ! PANX+OH=ALD2+NO2
     &                          +    9.0000D-01 * RXRAT( 108 )      ! CXO3+MEO2=0.9000D+00*ALD2+...
     &                          +    9.0000D-01 * RXRAT( 109 )      ! CXO3+XO2=0.9000D+00*ALD2+...
     &                          +    2.0000D+00 * RXRAT( 110 )      ! CXO3+CXO3=0.2000D+01*ALD2+...
     &                          +                 RXRAT( 111 )      ! CXO3+C2O3=ALD2+XO2+HO2+MEO2
     &                          +    6.0000D-02 * RXRAT( 112 )      ! PAR+OH=0.6000D-01*ALD2+...
     &                          +    6.0000D-01 * RXRAT( 113 )      ! ROR=0.6000D+00*ALD2+...
     &                          +    2.0000D-01 * RXRAT( 116 )      ! O+OLE=0.2000D+00*ALD2+...
     &                          +    3.3000D-01 * RXRAT( 117 )      ! OH+OLE=0.3300D+00*ALD2+...
     &                          +    1.8000D-01 * RXRAT( 118 )      ! O3+OLE=0.1800D+00*ALD2+...
     &                          +    3.5000D-01 * RXRAT( 119 )      ! NO3+OLE=0.3500D+00*ALD2+...
     &                          +    1.2400D+00 * RXRAT( 124 )      ! IOLE+O=0.1240D+01*ALD2+...
     &                          +    1.3000D+00 * RXRAT( 125 )      ! IOLE+OH=0.1300D+01*ALD2+...
     &                          +    6.5000D-01 * RXRAT( 126 )      ! IOLE+O3=0.6500D+00*ALD2+...
     &                          +    1.1800D+00 * RXRAT( 127 )      ! IOLE+NO3=0.1180D+01*ALD2+...
     &                          +    2.5200D-01 * RXRAT( 161 )      ! OH+ISPD=0.2520D+00*ALD2+...
     &                          +    2.0000D-02 * RXRAT( 162 )      ! O3+ISPD=0.2000D-01*ALD2+...
     &                          +    6.7000D-02 * RXRAT( 164 )      ! ISPD=0.6700D-01*ALD2+...
     &                          +    9.0000D-01 * RXRAT( 170 )      ! OH+ETOH=0.9000D+00*ALD2+...
     &                          +    9.9100D-01 * RXRAT( 171 )      ! OH+ETHA=0.9910D+00*ALD2+...
     &                          +    6.0000D-02 * RXRAT( 182 )      ! CL+PAR=0.6000D-01*ALD2+...
     &                          +    9.9100D-01 * RXRAT( 183 )      ! CL+ETHA=0.9910D+00*ALD2+...
     &                          +    3.3000D-01 * RXRAT( 185 )      ! CL+OLE=0.3300D+00*ALD2+...
     &                          +    4.5000D-01 * RXRAT( 186 )      ! CL+IOLE=0.4500D+00*ALD2+...
     &                          +                 RXRAT( 192 )      ! CL+ETOH=ALD2+HO2+HCL
      LOSS(  ALD2             ) =                 RXRAT(  83 )      ! ALD2+O=C2O3+OH
     &                          +                 RXRAT(  84 )      ! ALD2+OH=C2O3
     &                          +                 RXRAT(  85 )      ! ALD2+NO3=C2O3+HNO3
     &                          +                 RXRAT(  86 )      ! ALD2=MEO2+CO+HO2
     &                          +                 RXRAT( 189 )      ! ALD2+CL=HCL+C2O3

      PROD(  ALDX             ) =    3.3000D-01 * RXRAT(  61 )      ! NTR+OH=0.3300D+00*ALDX+HO2+...
     &                          +    3.3000D-01 * RXRAT(  62 )      ! NTR=0.3300D+00*ALDX+HO2+...
     &                          +    5.0000D-01 * RXRAT(  63 )      ! ROOH+OH=0.5000D+00*ALDX+...
     &                          +    5.0000D-01 * RXRAT(  64 )      ! ROOH=0.5000D+00*ALDX+HO2+...
     &                          +    5.0000D-02 * RXRAT( 112 )      ! PAR+OH=0.5000D-01*ALDX+...
     &                          +    5.0000D-01 * RXRAT( 113 )      ! ROR=0.5000D+00*ALDX+...
     &                          +    3.0000D-01 * RXRAT( 116 )      ! O+OLE=0.3000D+00*ALDX+...
     &                          +    6.2000D-01 * RXRAT( 117 )      ! OH+OLE=0.6200D+00*ALDX+...
     &                          +    3.2000D-01 * RXRAT( 118 )      ! O3+OLE=0.3200D+00*ALDX+...
     &                          +    5.6000D-01 * RXRAT( 119 )      ! NO3+OLE=0.5600D+00*ALDX+...
     &                          +    2.2000D-01 * RXRAT( 121 )      ! OH+ETH=0.2200D+00*ALDX+...
     &                          +    6.6000D-01 * RXRAT( 124 )      ! IOLE+O=0.6600D+00*ALDX+...
     &                          +    7.0000D-01 * RXRAT( 125 )      ! IOLE+OH=0.7000D+00*ALDX+...
     &                          +    3.5000D-01 * RXRAT( 126 )      ! IOLE+O3=0.3500D+00*ALDX+...
     &                          +    6.4000D-01 * RXRAT( 127 )      ! IOLE+NO3=0.6400D+00*ALDX+...
     &                          +    4.8000D-01 * RXRAT( 132 )      ! CRES+NO3=0.4800D+00*ALDX+...
     &                          +    3.0000D-02 * RXRAT( 145 )      ! OPEN+O3=0.3000D-01*ALDX+...
     &                          +                 RXRAT( 151 )      ! OPO3+NO=ALDX+XO2+HO2+NO2
     &                          +    1.5000D-01 * RXRAT( 159 )      ! O3+ISOP=0.1500D+00*ALDX+...
     &                          +    8.0000D-01 * RXRAT( 160 )      ! NO3+ISOP=0.8000D+00*ALDX+...
     &                          +    1.2000D-01 * RXRAT( 161 )      ! OH+ISPD=0.1200D+00*ALDX+...
     &                          +    3.5700D-01 * RXRAT( 163 )      ! NO3+ISPD=0.3570D+00*ALDX+...
     &                          +    1.5000D-01 * RXRAT( 165 )      ! TERP+O=0.1500D+00*ALDX+...
     &                          +    4.7000D-01 * RXRAT( 166 )      ! TERP+OH=0.4700D+00*ALDX+...
     &                          +    2.1000D-01 * RXRAT( 167 )      ! TERP+O3=0.2100D+00*ALDX+...
     &                          +    4.7000D-01 * RXRAT( 168 )      ! TERP+NO3=0.4700D+00*ALDX+...
     &                          +    5.0000D-02 * RXRAT( 170 )      ! OH+ETOH=0.5000D-01*ALDX+...
     &                          +    8.0000D-01 * RXRAT( 172 )      ! NO2+ISOP=0.8000D+00*ALDX+...
     &                          +    5.0000D-02 * RXRAT( 182 )      ! CL+PAR=0.5000D-01*ALDX+...
     &                          +    6.7000D-01 * RXRAT( 185 )      ! CL+OLE=0.6700D+00*ALDX+...
     &                          +    5.5000D-01 * RXRAT( 186 )      ! CL+IOLE=0.5500D+00*ALDX+...
      LOSS(  ALDX             ) =                 RXRAT(  98 )      ! ALDX+O=CXO3+OH
     &                          +                 RXRAT(  99 )      ! ALDX+OH=CXO3
     &                          +                 RXRAT( 100 )      ! ALDX+NO3=CXO3+HNO3
     &                          +                 RXRAT( 101 )      ! ALDX=MEO2+CO+HO2
     &                          +                 RXRAT( 190 )      ! ALDX+CL=HCL+CXO3

      PROD(  PAR              ) =    2.0000D-01 * RXRAT( 116 )      ! O+OLE=0.2000D+00*PAR+...
     &                          +    1.0000D-01 * RXRAT( 124 )      ! IOLE+O=0.1000D+00*PAR+...
     &                          +    1.1000D+00 * RXRAT( 154 )      ! OH+XYL=0.1100D+01*PAR+...
     &                          +    2.5000D-01 * RXRAT( 157 )      ! O+ISOP=0.2500D+00*PAR+...
     &                          +    3.5000D-01 * RXRAT( 159 )      ! O3+ISOP=0.3500D+00*PAR+...
     &                          +    2.4000D+00 * RXRAT( 160 )      ! NO3+ISOP=0.2400D+01*PAR+...
     &                          +    1.5650D+00 * RXRAT( 161 )      ! OH+ISPD=0.1565D+01*PAR+...
     &                          +    3.6000D-01 * RXRAT( 162 )      ! O3+ISPD=0.3600D+00*PAR+...
     &                          +    1.2820D+00 * RXRAT( 163 )      ! NO3+ISPD=0.1282D+01*PAR+...
     &                          +    8.3200D-01 * RXRAT( 164 )      ! ISPD=0.8320D+00*PAR+...
     &                          +    5.1200D+00 * RXRAT( 165 )      ! TERP+O=0.5120D+01*PAR+...
     &                          +    1.6600D+00 * RXRAT( 166 )      ! TERP+OH=0.1660D+01*PAR+...
     &                          +    7.0000D+00 * RXRAT( 167 )      ! TERP+O3=0.7000D+01*PAR+...
     &                          +    2.4000D+00 * RXRAT( 172 )      ! NO2+ISOP=0.2400D+01*PAR+...
     &                          +    3.0000D-01 * RXRAT( 186 )      ! CL+IOLE=0.3000D+00*PAR+...
      LOSS(  PAR              ) =    6.6000D-01 * RXRAT(  61 )      ! NTR+OH=-0.6600D+00*PAR+HO2+...
     &                          +    6.6000D-01 * RXRAT(  62 )      ! NTR=-0.6600D+00*PAR+HO2+...
     &                          +    1.1100D+00 * RXRAT( 112 )      ! PAR+OH=-0.1100D+00*PAR+...
     &                          +    2.1000D+00 * RXRAT( 113 )      ! ROR=-0.2100D+01*PAR+...
     &                          +    7.0000D-01 * RXRAT( 117 )      ! OH+OLE=-0.7000D+00*PAR+...
     &                          +                 RXRAT( 118 )      ! O3+OLE=-PAR+0.7400D+...
     &                          +                 RXRAT( 119 )      ! NO3+OLE=-PAR+FORM+0.9100D+...
     &                          +    1.1100D+00 * RXRAT( 182 )      ! PAR+CL=-0.1100D+00*PAR+...
     &                          +                 RXRAT( 185 )      ! CL+OLE=-PAR+0.3300D+...

      PROD(  CO               ) =                 RXRAT(  73 )      ! FORM+OH=CO+HO2
     &                          +                 RXRAT(  74 )      ! FORM=CO+0.2000D+01*HO2
     &                          +                 RXRAT(  75 )      ! FORM=CO
     &                          +                 RXRAT(  76 )      ! FORM+O=CO+HO2+OH
     &                          +                 RXRAT(  77 )      ! FORM+NO3=CO+HO2+HNO3
     &                          +                 RXRAT(  86 )      ! ALD2=CO+MEO2+HO2
     &                          +                 RXRAT( 101 )      ! ALDX=CO+MEO2+HO2
     &                          +    2.0000D-01 * RXRAT( 116 )      ! O+OLE=0.2000D+00*CO+...
     &                          +    3.3000D-01 * RXRAT( 118 )      ! O3+OLE=0.3300D+00*CO+...
     &                          +                 RXRAT( 120 )      ! O+ETH=CO+0.1700D+01*HO2+...
     &                          +    6.3000D-01 * RXRAT( 122 )      ! O3+ETH=0.6300D+00*CO+FORM+...
     &                          +    1.0000D-01 * RXRAT( 124 )      ! IOLE+O=0.1000D+00*CO+...
     &                          +    2.5000D-01 * RXRAT( 126 )      ! IOLE+O3=0.2500D+00*CO+...
     &                          +    3.3600D-01 * RXRAT( 129 )      ! TO2+NO=0.3360D+00*CO+...
     &                          +    6.0000D-02 * RXRAT( 131 )      ! OH+CRES=0.6000D-01*CO+...
     &                          +    2.4000D-01 * RXRAT( 132 )      ! CRES+NO3=0.2400D+00*CO+...
     &                          +                 RXRAT( 143 )      ! OPEN=CO+HO2+OPO3
     &                          +    6.9000D-01 * RXRAT( 145 )      ! OPEN+O3=0.6900D+00*CO+...
     &                          +    3.4400D-01 * RXRAT( 149 )      ! CAO2+NO=0.3440D+00*CO+...
     &                          +                 RXRAT( 156 )      ! MGLY=CO+HO2+C2O3
     &                          +    6.6000D-02 * RXRAT( 159 )      ! O3+ISOP=0.6600D-01*CO+...
     &                          +    3.3400D-01 * RXRAT( 161 )      ! OH+ISPD=0.3340D+00*CO+...
     &                          +    2.2500D-01 * RXRAT( 162 )      ! O3+ISPD=0.2250D+00*CO+...
     &                          +    6.4300D-01 * RXRAT( 163 )      ! NO3+ISPD=0.6430D+00*CO+...
     &                          +    3.3300D-01 * RXRAT( 164 )      ! ISPD=0.3330D+00*CO+0.6700D-...
     &                          +    1.0000D-03 * RXRAT( 167 )      ! TERP+O3=0.1000D-02*CO+...
     &                          +                 RXRAT( 179 )      ! OH+FMCL=CO+CL
     &                          +                 RXRAT( 180 )      ! FMCL=CO+CL+HO2
     &                          +                 RXRAT( 188 )      ! CL+FORM=CO+HO2+HCL
      LOSS(  CO               ) =                 RXRAT(  65 )      ! CO+OH=HO2

      PROD(  MEO2             ) =                 RXRAT(  66 )      ! OH=MEO2
     &                          +    7.0000D-01 * RXRAT(  70 )      ! MEPX+OH=0.7000D+00*MEO2+...
     &                          +                 RXRAT(  86 )      ! ALD2=MEO2+CO+HO2
     &                          +                 RXRAT(  87 )      ! C2O3+NO=MEO2+NO2
     &                          +    9.0000D-01 * RXRAT(  93 )      ! C2O3+XO2=0.9000D+00*MEO2+...
     &                          +    2.0000D+00 * RXRAT(  94 )      ! C2O3+C2O3=0.2000D+01*MEO2
     &                          +                 RXRAT(  96 )      ! PACD=MEO2+OH
     &                          +                 RXRAT(  97 )      ! AACD+OH=MEO2
     &                          +                 RXRAT( 101 )      ! ALDX=MEO2+CO+HO2
     &                          +                 RXRAT( 111 )      ! CXO3+C2O3=MEO2+XO2+HO2+ALD2
     &                          +                 RXRAT( 181 )      ! CL=MEO2+HCL
      LOSS(  MEO2             ) =                 RXRAT(  67 )      ! MEO2+NO=FORM+HO2+NO2
     &                          +                 RXRAT(  68 )      ! MEO2+HO2=MEPX
     &                          +    2.0000D+00 * RXRAT(  69 )      ! MEO2+MEO2=0.1370D+01*FORM+...
     &                          +    1.0000D-01 * RXRAT(  92 )      ! MEO2+C2O3=0.9000D+00*MEO2+...
     &                          +                 RXRAT( 108 )      ! MEO2+CXO3=0.9000D+00*ALD2+...

      PROD(  MEPX             ) =                 RXRAT(  68 )      ! MEO2+HO2=MEPX
     &                          +                 RXRAT(  81 )      ! HCO3+HO2=MEPX
      LOSS(  MEPX             ) =                 RXRAT(  70 )      ! MEPX+OH=0.7000D+00*MEO2+...
     &                          +                 RXRAT(  71 )      ! MEPX=FORM+HO2+OH

      PROD(  MEOH             ) =    6.3000D-01 * RXRAT(  69 )      ! MEO2+MEO2=0.6300D+00*MEOH+...
      LOSS(  MEOH             ) =                 RXRAT(  72 )      ! MEOH+OH=FORM+HO2
     &                          +                 RXRAT( 191 )      ! MEOH+CL=HCL+HO2+FORM

      PROD(  HCO3             ) =                 RXRAT(  78 )      ! FORM+HO2=HCO3
      LOSS(  HCO3             ) =                 RXRAT(  79 )      ! HCO3=FORM+HO2
     &                          +                 RXRAT(  80 )      ! HCO3+NO=FACD+NO2+HO2
     &                          +                 RXRAT(  81 )      ! HCO3+HO2=MEPX

      PROD(  FACD             ) =                 RXRAT(  80 )      ! HCO3+NO=FACD+NO2+HO2
     &                          +    3.7000D-01 * RXRAT( 122 )      ! O3+ETH=0.3700D+00*FACD+...
      LOSS(  FACD             ) =                 RXRAT(  82 )      ! FACD+OH=HO2

      PROD(  PACD             ) =    8.0000D-01 * RXRAT(  91 )      ! C2O3+HO2=0.8000D+00*PACD+...
     &                          +    8.0000D-01 * RXRAT( 107 )      ! CXO3+HO2=0.8000D+00*PACD+...
      LOSS(  PACD             ) =                 RXRAT(  95 )      ! PACD+OH=C2O3
     &                          +                 RXRAT(  96 )      ! PACD=MEO2+OH

      PROD(  AACD             ) =    2.0000D-01 * RXRAT(  91 )      ! C2O3+HO2=0.2000D+00*AACD+...
     &                          +    1.0000D-01 * RXRAT(  92 )      ! C2O3+MEO2=0.1000D+00*AACD+...
     &                          +    1.0000D-01 * RXRAT(  93 )      ! C2O3+XO2=0.1000D+00*AACD+...
     &                          +    2.0000D-01 * RXRAT( 107 )      ! CXO3+HO2=0.2000D+00*AACD+...
     &                          +    1.0000D-01 * RXRAT( 108 )      ! CXO3+MEO2=0.1000D+00*AACD+...
     &                          +    1.0000D-01 * RXRAT( 109 )      ! CXO3+XO2=0.1000D+00*AACD+...
      LOSS(  AACD             ) =                 RXRAT(  97 )      ! AACD+OH=MEO2

      PROD(  CXO3             ) =                 RXRAT(  98 )      ! ALDX+O=CXO3+OH
     &                          +                 RXRAT(  99 )      ! ALDX+OH=CXO3
     &                          +                 RXRAT( 100 )      ! ALDX+NO3=CXO3+HNO3
     &                          +                 RXRAT( 104 )      ! PANX=CXO3+NO2
     &                          +                 RXRAT( 105 )      ! PANX=CXO3+NO2
     &                          +    2.5000D-01 * RXRAT( 157 )      ! O+ISOP=0.2500D+00*CXO3+...
     &                          +    2.0000D-01 * RXRAT( 159 )      ! O3+ISOP=0.2000D+00*CXO3+...
     &                          +    2.5000D-01 * RXRAT( 161 )      ! OH+ISPD=0.2500D+00*CXO3+...
     &                          +    7.5000D-02 * RXRAT( 163 )      ! NO3+ISPD=0.7500D-01*CXO3+...
     &                          +    3.9000D-01 * RXRAT( 167 )      ! TERP+O3=0.3900D+00*CXO3+...
     &                          +                 RXRAT( 190 )      ! CL+ALDX=CXO3+HCL
      LOSS(  CXO3             ) =                 RXRAT( 102 )      ! CXO3+NO=ALD2+NO2+HO2+XO2
     &                          +                 RXRAT( 103 )      ! CXO3+NO2=PANX
     &                          +                 RXRAT( 107 )      ! CXO3+HO2=0.8000D+00*PACD+...
     &                          +                 RXRAT( 108 )      ! CXO3+MEO2=0.9000D+00*ALD2+...
     &                          +                 RXRAT( 109 )      ! CXO3+XO2=0.9000D+00*ALD2+...
     &                          +    2.0000D+00 * RXRAT( 110 )      ! CXO3+CXO3=0.2000D+01*ALD2+...
     &                          +                 RXRAT( 111 )      ! CXO3+C2O3=MEO2+XO2+HO2+ALD2

      PROD(  PANX             ) =                 RXRAT( 103 )      ! CXO3+NO2=PANX
      LOSS(  PANX             ) =                 RXRAT( 104 )      ! PANX=CXO3+NO2
     &                          +                 RXRAT( 105 )      ! PANX=CXO3+NO2
     &                          +                 RXRAT( 106 )      ! PANX+OH=ALD2+NO2

      PROD(  ROR              ) =    7.6000D-01 * RXRAT( 112 )      ! PAR+OH=0.7600D+00*ROR+...
     &                          +    7.6000D-01 * RXRAT( 182 )      ! CL+PAR=0.7600D+00*ROR+...
      LOSS(  ROR              ) =    9.8000D-01 * RXRAT( 113 )      ! ROR=0.2000D-01*ROR+0.6000D+...
     &                          +                 RXRAT( 114 )      ! ROR=HO2
     &                          +                 RXRAT( 115 )      ! ROR+NO2=NTR

      PROD(  OLE              ) =    3.0000D-01 * RXRAT( 186 )      ! CL+IOLE=0.3000D+00*OLE+...
      LOSS(  OLE              ) =                 RXRAT( 116 )      ! OLE+O=0.2000D+00*ALD2+...
     &                          +                 RXRAT( 117 )      ! OLE+OH=0.8000D+00*FORM+...
     &                          +                 RXRAT( 118 )      ! OLE+O3=0.1800D+00*ALD2+...
     &                          +                 RXRAT( 119 )      ! OLE+NO3=NO2+FORM+0.9100D+...
     &                          +                 RXRAT( 185 )      ! OLE+CL=FMCL+0.3300D+...

      PROD(  ETH              ) =   0.0D0
      LOSS(  ETH              ) =                 RXRAT( 120 )      ! ETH+O=FORM+0.1700D+01*HO2+...
     &                          +                 RXRAT( 121 )      ! ETH+OH=XO2+0.1560D+01*FORM+...
     &                          +                 RXRAT( 122 )      ! ETH+O3=FORM+0.6300D+00*CO+...
     &                          +                 RXRAT( 123 )      ! ETH+NO3=NO2+XO2+0.2000D+...
     &                          +                 RXRAT( 184 )      ! ETH+CL=FMCL+0.2000D+01*XO2+...

      PROD(  IOLE             ) =   0.0D0
      LOSS(  IOLE             ) =                 RXRAT( 124 )      ! IOLE+O=0.1240D+01*ALD2+...
     &                          +                 RXRAT( 125 )      ! IOLE+OH=0.1300D+01*ALD2+...
     &                          +                 RXRAT( 126 )      ! IOLE+O3=0.6500D+00*ALD2+...
     &                          +                 RXRAT( 127 )      ! IOLE+NO3=0.1180D+01*ALD2+...
     &                          +                 RXRAT( 186 )      ! IOLE+CL=0.3000D+00*HCL+...

      PROD(  TOL              ) =   0.0D0
      LOSS(  TOL              ) =                 RXRAT( 128 )      ! TOL+OH=0.2800D+00*HO2+...
     &                          +                 RXRAT( 194 )      ! TOL+CL=HCL+0.8800D+00*XO2+...

      PROD(  CRES             ) =    1.8000D-01 * RXRAT( 128 )      ! TOL+OH=0.1800D+00*CRES+...
     &                          +                 RXRAT( 134 )      ! CRO+HO2=CRES
     &                          +    2.0000D-01 * RXRAT( 154 )      ! OH+XYL=0.2000D+00*CRES+...
      LOSS(  CRES             ) =                 RXRAT( 131 )      ! CRES+OH=0.6000D-01*CRO+...
     &                          +                 RXRAT( 132 )      ! CRES+NO3=0.3000D+00*CRO+...

      PROD(  TO2              ) =    6.5000D-01 * RXRAT( 128 )      ! TOL+OH=0.6500D+00*TO2+...
     &                          +    3.0000D-01 * RXRAT( 154 )      ! OH+XYL=0.3000D+00*TO2+...
      LOSS(  TO2              ) =                 RXRAT( 129 )      ! TO2+NO=0.8600D+00*NO2+...
     &                          +                 RXRAT( 130 )      ! TO2+HO2=

      PROD(  TOLRO2           ) =                 RXRAT( 128 )      ! TOL+OH=TOLRO2+0.1000D+...
      LOSS(  TOLRO2           ) =                 RXRAT( 198 )      ! TOLRO2+NO=NO+TOLNRXN
     &                          +                 RXRAT( 199 )      ! TOLRO2+HO2=HO2+TOLHRXN

      PROD(  OPEN             ) =    8.6000D-01 * RXRAT( 129 )      ! TO2+NO=0.8600D+00*OPEN+...
     &                          +    1.3000D-01 * RXRAT( 131 )      ! OH+CRES=0.1300D+00*OPEN+...
     &                          +    1.2000D-01 * RXRAT( 132 )      ! CRES+NO3=0.1200D+00*OPEN+...
      LOSS(  OPEN             ) =                 RXRAT( 143 )      ! OPEN=OPO3+HO2+CO
     &                          +                 RXRAT( 144 )      ! OPEN+OH=0.6000D+00*OPO3+...
     &                          +                 RXRAT( 145 )      ! OPEN+O3=0.3000D-01*ALDX+...
     &                          +                 RXRAT( 146 )      ! OPEN+NO3=OPO3+HNO3

      PROD(  MGLY             ) =    5.2000D-01 * RXRAT( 129 )      ! TO2+NO=0.5200D+00*MGLY+...
     &                          +    2.4000D-01 * RXRAT( 132 )      ! CRES+NO3=0.2400D+00*MGLY+...
     &                          +    2.0000D-01 * RXRAT( 145 )      ! OPEN+O3=0.2000D+00*MGLY+...
     &                          +    8.0000D-01 * RXRAT( 154 )      ! OH+XYL=0.8000D+00*MGLY+...
     &                          +    1.6800D-01 * RXRAT( 161 )      ! OH+ISPD=0.1680D+00*MGLY+...
     &                          +    8.5000D-01 * RXRAT( 162 )      ! O3+ISPD=0.8500D+00*MGLY+...
      LOSS(  MGLY             ) =                 RXRAT( 155 )      ! MGLY+OH=XO2+C2O3
     &                          +                 RXRAT( 156 )      ! MGLY=C2O3+HO2+CO

      PROD(  CRO              ) =    6.0000D-02 * RXRAT( 131 )      ! OH+CRES=0.6000D-01*CRO+...
     &                          +    3.0000D-01 * RXRAT( 132 )      ! CRES+NO3=0.3000D+00*CRO+...
     &                          +                 RXRAT( 148 )      ! CAT1+NO3=CRO+HNO3
      LOSS(  CRO              ) =                 RXRAT( 133 )      ! CRO+NO2=CRON
     &                          +                 RXRAT( 134 )      ! CRO+HO2=CRES

      PROD(  CAT1             ) =    7.3200D-01 * RXRAT( 131 )      ! OH+CRES=0.7320D+00*CAT1+...
      LOSS(  CAT1             ) =                 RXRAT( 147 )      ! CAT1+OH=CAO2
     &                          +                 RXRAT( 148 )      ! CAT1+NO3=CRO+HNO3

      PROD(  CRON             ) =                 RXRAT( 133 )      ! CRO+NO2=CRON
      LOSS(  CRON             ) =                 RXRAT( 135 )      ! CRON+OH=CRNO
     &                          +                 RXRAT( 136 )      ! CRON+NO3=CRNO+HNO3

      PROD(  CRNO             ) =                 RXRAT( 135 )      ! CRON+OH=CRNO
     &                          +                 RXRAT( 136 )      ! CRON+NO3=CRNO+HNO3
     &                          +                 RXRAT( 139 )      ! CRN2+NO=CRNO+NO2
     &                          +                 RXRAT( 141 )      ! CRPX=CRNO+OH
      LOSS(  CRNO             ) =                 RXRAT( 137 )      ! CRNO+NO2=0.2000D+01*NTR
     &                          +                 RXRAT( 138 )      ! CRNO+O3=CRN2

      PROD(  CRN2             ) =                 RXRAT( 138 )      ! CRNO+O3=CRN2
     &                          +                 RXRAT( 142 )      ! CRPX+OH=CRN2
      LOSS(  CRN2             ) =                 RXRAT( 139 )      ! CRN2+NO=CRNO+NO2
     &                          +                 RXRAT( 140 )      ! CRN2+HO2=CRPX

      PROD(  CRPX             ) =                 RXRAT( 140 )      ! CRN2+HO2=CRPX
      LOSS(  CRPX             ) =                 RXRAT( 141 )      ! CRPX=CRNO+OH
     &                          +                 RXRAT( 142 )      ! CRPX+OH=CRN2

      PROD(  OPO3             ) =                 RXRAT( 143 )      ! OPEN=OPO3+HO2+CO
     &                          +    6.0000D-01 * RXRAT( 144 )      ! OPEN+OH=0.6000D+00*OPO3+...
     &                          +    6.2000D-01 * RXRAT( 145 )      ! OPEN+O3=0.6200D+00*OPO3+...
     &                          +                 RXRAT( 146 )      ! OPEN+NO3=OPO3+HNO3
     &                          +                 RXRAT( 153 )      ! OPAN=OPO3+NO2
      LOSS(  OPO3             ) =                 RXRAT( 151 )      ! OPO3+NO=NO2+XO2+HO2+ALDX
     &                          +                 RXRAT( 152 )      ! OPO3+NO2=OPAN

      PROD(  CAO2             ) =    4.0000D-01 * RXRAT( 144 )      ! OPEN+OH=0.4000D+00*CAO2+...
     &                          +                 RXRAT( 147 )      ! CAT1+OH=CAO2
      LOSS(  CAO2             ) =                 RXRAT( 149 )      ! CAO2+NO=0.8600D+00*NO2+...
     &                          +                 RXRAT( 150 )      ! CAO2+HO2=

      PROD(  OPAN             ) =                 RXRAT( 152 )      ! OPO3+NO2=OPAN
      LOSS(  OPAN             ) =                 RXRAT( 153 )      ! OPAN=OPO3+NO2

      PROD(  XYL              ) =   0.0D0
      LOSS(  XYL              ) =                 RXRAT( 154 )      ! XYL+OH=0.7000D+00*HO2+...
     &                          +                 RXRAT( 195 )      ! XYL+CL=HCL+0.8400D+00*XO2+...

      PROD(  XYLRO2           ) =                 RXRAT( 154 )      ! OH+XYL=XYLRO2+0.5000D+...
      LOSS(  XYLRO2           ) =                 RXRAT( 200 )      ! XYLRO2+NO=NO+XYLNRXN
     &                          +                 RXRAT( 201 )      ! XYLRO2+HO2=HO2+XYLHRXN

      PROD(  ISOP             ) =   0.0D0
      LOSS(  ISOP             ) =                 RXRAT( 157 )      ! ISOP+O=0.7500D+00*ISPD+...
     &                          +                 RXRAT( 158 )      ! ISOP+OH=0.9120D+00*ISPD+...
     &                          +                 RXRAT( 159 )      ! ISOP+O3=0.6500D+00*ISPD+...
     &                          +                 RXRAT( 160 )      ! ISOP+NO3=0.2000D+00*ISPD+...
     &                          +                 RXRAT( 172 )      ! ISOP+NO2=0.2000D+00*ISPD+...
     &                          +                 RXRAT( 187 )      ! ISOP+CL=0.1500D+00*HCL+XO2+...

      PROD(  ISPD             ) =    7.5000D-01 * RXRAT( 157 )      ! O+ISOP=0.7500D+00*ISPD+...
     &                          +    9.1200D-01 * RXRAT( 158 )      ! OH+ISOP=0.9120D+00*ISPD+...
     &                          +    6.5000D-01 * RXRAT( 159 )      ! O3+ISOP=0.6500D+00*ISPD+...
     &                          +    2.0000D-01 * RXRAT( 160 )      ! NO3+ISOP=0.2000D+00*ISPD+...
     &                          +    2.0000D-01 * RXRAT( 172 )      ! NO2+ISOP=0.2000D+00*ISPD+...
     &                          +                 RXRAT( 187 )      ! CL+ISOP=ISPD+XO2+HO2+...
      LOSS(  ISPD             ) =                 RXRAT( 161 )      ! ISPD+OH=0.1565D+01*PAR+...
     &                          +                 RXRAT( 162 )      ! ISPD+O3=0.1140D+00*C2O3+...
     &                          +                 RXRAT( 163 )      ! ISPD+NO3=0.3570D+00*ALDX+...
     &                          +                 RXRAT( 164 )      ! ISPD=0.3330D+00*CO+0.6700D-...

      PROD(  ISOPRXN          ) =                 RXRAT( 158 )      ! OH+ISOP=ISOPRXN+0.6290D+...
      LOSS(  ISOPRXN          ) =   0.0D0

      PROD(  TERP             ) =   0.0D0
      LOSS(  TERP             ) =                 RXRAT( 165 )      ! TERP+O=0.1500D+00*ALDX+...
     &                          +                 RXRAT( 166 )      ! TERP+OH=0.7500D+00*HO2+...
     &                          +                 RXRAT( 167 )      ! TERP+O3=0.5700D+00*OH+...
     &                          +                 RXRAT( 168 )      ! TERP+NO3=0.4700D+00*NO2+...

      PROD(  TRPRXN           ) =                 RXRAT( 165 )      ! TERP+O=TRPRXN+0.5120D+...
     &                          +                 RXRAT( 166 )      ! TERP+OH=TRPRXN+0.1250D+...
     &                          +                 RXRAT( 167 )      ! TERP+O3=TRPRXN+0.7000D-...
     &                          +                 RXRAT( 168 )      ! TERP+NO3=TRPRXN+0.2800D+...
      LOSS(  TRPRXN           ) =   0.0D0

      PROD(  SO2              ) =   0.0D0
      LOSS(  SO2              ) =                 RXRAT( 169 )      ! SO2+OH=SULF+HO2+SULRXN

      PROD(  SULF             ) =                 RXRAT( 169 )      ! SO2+OH=SULF+HO2+SULRXN
      LOSS(  SULF             ) =   0.0D0

      PROD(  SULRXN           ) =                 RXRAT( 169 )      ! SO2+OH=SULRXN+HO2+SULF
      LOSS(  SULRXN           ) =   0.0D0

      PROD(  ETOH             ) =   0.0D0
      LOSS(  ETOH             ) =                 RXRAT( 170 )      ! ETOH+OH=HO2+0.9000D+...
     &                          +                 RXRAT( 192 )      ! ETOH+CL=HCL+HO2+ALD2

      PROD(  ETHA             ) =   0.0D0
      LOSS(  ETHA             ) =                 RXRAT( 171 )      ! ETHA+OH=0.9910D+00*ALD2+...
     &                          +                 RXRAT( 183 )      ! ETHA+CL=HCL+0.9910D+...

      PROD(  CL2              ) =    3.0000D-01 * RXRAT( 176 )      ! CLO+CLO=0.3000D+00*CL2+...
      LOSS(  CL2              ) =                 RXRAT( 173 )      ! CL2=0.2000D+01*CL

      PROD(  CL               ) =    2.0000D+00 * RXRAT( 173 )      ! CL2=0.2000D+01*CL
     &                          +                 RXRAT( 174 )      ! HOCL=CL+OH
     &                          +    1.4000D+00 * RXRAT( 176 )      ! CLO+CLO=0.1400D+01*CL+...
     &                          +                 RXRAT( 177 )      ! CLO+NO=CL+NO2
     &                          +                 RXRAT( 179 )      ! OH+FMCL=CL+CO
     &                          +                 RXRAT( 180 )      ! FMCL=CL+CO+HO2
     &                          +                 RXRAT( 193 )      ! HCL+OH=CL
     &                          +                 RXRAT( 197 )      ! CLNO2=CL+NO2
      LOSS(  CL               ) =                 RXRAT( 175 )      ! CL+O3=CLO
     &                          +                 RXRAT( 181 )      ! CL=HCL+MEO2
     &                          +                 RXRAT( 182 )      ! CL+PAR=HCL+0.8700D+00*XO2+...
     &                          +                 RXRAT( 183 )      ! CL+ETHA=HCL+0.9910D+...
     &                          +                 RXRAT( 184 )      ! CL+ETH=FMCL+0.2000D+01*XO2+...
     &                          +                 RXRAT( 185 )      ! CL+OLE=FMCL+0.3300D+...
     &                          +                 RXRAT( 186 )      ! CL+IOLE=0.3000D+00*HCL+...
     &                          +                 RXRAT( 187 )      ! CL+ISOP=0.1500D+00*HCL+XO2+...
     &                          +                 RXRAT( 188 )      ! CL+FORM=HCL+HO2+CO
     &                          +                 RXRAT( 189 )      ! CL+ALD2=HCL+C2O3
     &                          +                 RXRAT( 190 )      ! CL+ALDX=HCL+CXO3
     &                          +                 RXRAT( 191 )      ! CL+MEOH=HCL+HO2+FORM
     &                          +                 RXRAT( 192 )      ! CL+ETOH=HCL+HO2+ALD2
     &                          +                 RXRAT( 194 )      ! CL+TOL=HCL+0.8800D+00*XO2+...
     &                          +                 RXRAT( 195 )      ! CL+XYL=HCL+0.8400D+00*XO2+...
     &                          +                 RXRAT( 196 )      ! CL+NO2=CLNO2

      PROD(  HOCL             ) =                 RXRAT( 178 )      ! CLO+HO2=HOCL
      LOSS(  HOCL             ) =                 RXRAT( 174 )      ! HOCL=OH+CL

      PROD(  CLO              ) =                 RXRAT( 175 )      ! CL+O3=CLO
      LOSS(  CLO              ) =    2.0000D+00 * RXRAT( 176 )      ! CLO+CLO=0.3000D+00*CL2+...
     &                          +                 RXRAT( 177 )      ! CLO+NO=CL+NO2
     &                          +                 RXRAT( 178 )      ! CLO+HO2=HOCL

      PROD(  FMCL             ) =                 RXRAT( 184 )      ! CL+ETH=FMCL+0.2000D+01*XO2+...
     &                          +                 RXRAT( 185 )      ! CL+OLE=FMCL+0.3300D+...
     &                          +    7.0000D-01 * RXRAT( 186 )      ! CL+IOLE=0.7000D+00*FMCL+...
     &                          +    8.5000D-01 * RXRAT( 187 )      ! CL+ISOP=0.8500D+00*FMCL+...
      LOSS(  FMCL             ) =                 RXRAT( 179 )      ! FMCL+OH=CL+CO
     &                          +                 RXRAT( 180 )      ! FMCL=CL+CO+HO2

      PROD(  HCL              ) =                 RXRAT( 181 )      ! CL=HCL+MEO2
     &                          +                 RXRAT( 182 )      ! CL+PAR=HCL+0.8700D+00*XO2+...
     &                          +                 RXRAT( 183 )      ! CL+ETHA=HCL+0.9910D+...
     &                          +    3.0000D-01 * RXRAT( 186 )      ! CL+IOLE=0.3000D+00*HCL+...
     &                          +    1.5000D-01 * RXRAT( 187 )      ! CL+ISOP=0.1500D+00*HCL+XO2+...
     &                          +                 RXRAT( 188 )      ! CL+FORM=HCL+HO2+CO
     &                          +                 RXRAT( 189 )      ! CL+ALD2=HCL+C2O3
     &                          +                 RXRAT( 190 )      ! CL+ALDX=HCL+CXO3
     &                          +                 RXRAT( 191 )      ! CL+MEOH=HCL+HO2+FORM
     &                          +                 RXRAT( 192 )      ! CL+ETOH=HCL+HO2+ALD2
     &                          +                 RXRAT( 194 )      ! CL+TOL=HCL+0.8800D+00*XO2+...
     &                          +                 RXRAT( 195 )      ! CL+XYL=HCL+0.8400D+00*XO2+...
      LOSS(  HCL              ) =                 RXRAT( 193 )      ! HCL+OH=CL

      PROD(  CLNO2            ) =                 RXRAT( 196 )      ! CL+NO2=CLNO2
     &                          +                 RXRAT( 212 )      ! H2NO3PIJ+ACLI=CLNO2
     &                          +                 RXRAT( 213 )      ! H2NO3PIJ+ACLJ=CLNO2
     &                          +                 RXRAT( 214 )      ! H2NO3PK+ACLK=CLNO2
      LOSS(  CLNO2            ) =                 RXRAT( 197 )      ! CLNO2=CL+NO2

      PROD(  TOLNRXN          ) =                 RXRAT( 198 )      ! TOLRO2+NO=TOLNRXN+NO
      LOSS(  TOLNRXN          ) =   0.0D0

      PROD(  TOLHRXN          ) =                 RXRAT( 199 )      ! TOLRO2+HO2=TOLHRXN+HO2
      LOSS(  TOLHRXN          ) =   0.0D0

      PROD(  XYLNRXN          ) =                 RXRAT( 200 )      ! XYLRO2+NO=XYLNRXN+NO
      LOSS(  XYLNRXN          ) =   0.0D0

      PROD(  XYLHRXN          ) =                 RXRAT( 201 )      ! XYLRO2+HO2=XYLHRXN+HO2
      LOSS(  XYLHRXN          ) =   0.0D0

      PROD(  BENZENE          ) =   0.0D0
      LOSS(  BENZENE          ) =                 RXRAT( 202 )      ! BENZENE+OH=OH+BENZRO2

      PROD(  BENZRO2          ) =                 RXRAT( 202 )      ! BENZENE+OH=BENZRO2+OH
      LOSS(  BENZRO2          ) =                 RXRAT( 203 )      ! BENZRO2+NO=NO+BNZNRXN
     &                          +                 RXRAT( 204 )      ! BENZRO2+HO2=HO2+BNZHRXN

      PROD(  BNZNRXN          ) =                 RXRAT( 203 )      ! BENZRO2+NO=BNZNRXN+NO
      LOSS(  BNZNRXN          ) =   0.0D0

      PROD(  BNZHRXN          ) =                 RXRAT( 204 )      ! BENZRO2+HO2=BNZHRXN+HO2
      LOSS(  BNZHRXN          ) =   0.0D0

      PROD(  SESQ             ) =   0.0D0
      LOSS(  SESQ             ) =                 RXRAT( 205 )      ! SESQ+O3=O3+SESQRXN
     &                          +                 RXRAT( 206 )      ! SESQ+OH=OH+SESQRXN
     &                          +                 RXRAT( 207 )      ! SESQ+NO3=NO3+SESQRXN

      PROD(  SESQRXN          ) =                 RXRAT( 205 )      ! SESQ+O3=SESQRXN+O3
     &                          +                 RXRAT( 206 )      ! SESQ+OH=SESQRXN+OH
     &                          +                 RXRAT( 207 )      ! SESQ+NO3=SESQRXN+NO3
      LOSS(  SESQRXN          ) =   0.0D0

      PROD(  H2NO3PIJ         ) =                 RXRAT( 208 )      ! N2O5=H2NO3PIJ+HNO3
      LOSS(  H2NO3PIJ         ) =                 RXRAT( 210 )      ! H2NO3PIJ=HNO3
     &                          +                 RXRAT( 212 )      ! H2NO3PIJ+ACLI=CLNO2
     &                          +                 RXRAT( 213 )      ! H2NO3PIJ+ACLJ=CLNO2

      PROD(  H2NO3PK          ) =                 RXRAT( 209 )      ! N2O5=H2NO3PK+HNO3
      LOSS(  H2NO3PK          ) =                 RXRAT( 211 )      ! H2NO3PK=HNO3
     &                          +                 RXRAT( 214 )      ! H2NO3PK+ACLK=CLNO2

      PROD(  ACLI             ) =   0.0D0
      LOSS(  ACLI             ) =                 RXRAT( 212 )      ! ACLI+H2NO3PIJ=CLNO2

      PROD(  ACLJ             ) =   0.0D0
      LOSS(  ACLJ             ) =                 RXRAT( 213 )      ! ACLJ+H2NO3PIJ=CLNO2

      PROD(  ACLK             ) =   0.0D0
      LOSS(  ACLK             ) =                 RXRAT( 214 )      ! ACLK+H2NO3PK=CLNO2

      PROD(  AXYL1J           ) =   0.0D0
      LOSS(  AXYL1J           ) =                 RXRAT( 217 )      ! AXYL1J=0.1143D+01*AOLGAJ

      PROD(  AOLGAJ           ) =    1.1428D+00 * RXRAT( 217 )      ! AXYL1J=0.1143D+01*AOLGAJ
     &                          +    1.1428D+00 * RXRAT( 218 )      ! AXYL2J=0.1143D+01*AOLGAJ
     &                          +                 RXRAT( 219 )      ! ATOL1J=AOLGAJ
     &                          +                 RXRAT( 220 )      ! ATOL2J=AOLGAJ
     &                          +    8.5714D-01 * RXRAT( 221 )      ! ABNZ1J=0.8571D+00*AOLGAJ
     &                          +    8.5714D-01 * RXRAT( 222 )      ! ABNZ2J=0.8571D+00*AOLGAJ
     &                          +    1.4286D+00 * RXRAT( 228 )      ! APAH1J=0.1429D+01*AOLGAJ
     &                          +    1.4286D+00 * RXRAT( 229 )      ! APAH2J=0.1429D+01*AOLGAJ
     &                          +    1.7143D+00 * RXRAT( 230 )      ! AALK1J=0.1714D+01*AOLGAJ
     &                          +    1.7143D+00 * RXRAT( 231 )      ! AALK2J=0.1714D+01*AOLGAJ
      LOSS(  AOLGAJ           ) =   0.0D0

      PROD(  AXYL2J           ) =   0.0D0
      LOSS(  AXYL2J           ) =                 RXRAT( 218 )      ! AXYL2J=0.1143D+01*AOLGAJ

      PROD(  ATOL1J           ) =   0.0D0
      LOSS(  ATOL1J           ) =                 RXRAT( 219 )      ! ATOL1J=AOLGAJ

      PROD(  ATOL2J           ) =   0.0D0
      LOSS(  ATOL2J           ) =                 RXRAT( 220 )      ! ATOL2J=AOLGAJ

      PROD(  ABNZ1J           ) =   0.0D0
      LOSS(  ABNZ1J           ) =                 RXRAT( 221 )      ! ABNZ1J=0.8571D+00*AOLGAJ

      PROD(  ABNZ2J           ) =   0.0D0
      LOSS(  ABNZ2J           ) =                 RXRAT( 222 )      ! ABNZ2J=0.8571D+00*AOLGAJ

      PROD(  ATRP1J           ) =   0.0D0
      LOSS(  ATRP1J           ) =                 RXRAT( 223 )      ! ATRP1J=AOLGBJ

      PROD(  AOLGBJ           ) =                 RXRAT( 223 )      ! ATRP1J=AOLGBJ
     &                          +                 RXRAT( 224 )      ! ATRP2J=AOLGBJ
     &                          +    5.0000D-01 * RXRAT( 225 )      ! AISO1J=0.5000D+00*AOLGBJ
     &                          +    5.0000D-01 * RXRAT( 226 )      ! AISO2J=0.5000D+00*AOLGBJ
     &                          +    1.5000D+00 * RXRAT( 227 )      ! ASQTJ=0.1500D+01*AOLGBJ
      LOSS(  AOLGBJ           ) =   0.0D0

      PROD(  ATRP2J           ) =   0.0D0
      LOSS(  ATRP2J           ) =                 RXRAT( 224 )      ! ATRP2J=AOLGBJ

      PROD(  AISO1J           ) =   0.0D0
      LOSS(  AISO1J           ) =                 RXRAT( 225 )      ! AISO1J=0.5000D+00*AOLGBJ

      PROD(  AISO2J           ) =   0.0D0
      LOSS(  AISO2J           ) =                 RXRAT( 226 )      ! AISO2J=0.5000D+00*AOLGBJ

      PROD(  ASQTJ            ) =   0.0D0
      LOSS(  ASQTJ            ) =                 RXRAT( 227 )      ! ASQTJ=0.1500D+01*AOLGBJ

      PROD(  APAH1J           ) =   0.0D0
      LOSS(  APAH1J           ) =                 RXRAT( 228 )      ! APAH1J=0.1429D+01*AOLGAJ

      PROD(  APAH2J           ) =   0.0D0
      LOSS(  APAH2J           ) =                 RXRAT( 229 )      ! APAH2J=0.1429D+01*AOLGAJ

      PROD(  AALK1J           ) =   0.0D0
      LOSS(  AALK1J           ) =                 RXRAT( 230 )      ! AALK1J=0.1714D+01*AOLGAJ

      PROD(  AALK2J           ) =   0.0D0
      LOSS(  AALK2J           ) =                 RXRAT( 231 )      ! AALK2J=0.1714D+01*AOLGAJ

      PROD(  PCVOC            ) =   0.0D0
      LOSS(  PCVOC            ) =                 RXRAT( 232 )      ! PCVOC+OH=OH+PCSOARXN

      PROD(  PCSOARXN         ) =                 RXRAT( 232 )      ! PCVOC+OH=PCSOARXN+OH
      LOSS(  PCSOARXN         ) =   0.0D0

      PROD(  VLVPO1           ) =    3.0030D-01 * RXRAT( 234 )      ! VSVPO1+OH=0.3003D+...
     &                          +    3.8560D-01 * RXRAT( 235 )      ! VSVPO2+OH=0.3856D+...
     &                          +    2.1810D-01 * RXRAT( 236 )      ! VSVPO3+OH=0.2181D+...
     &                          +    2.4120D-01 * RXRAT( 237 )      ! VIVPO1+OH=0.2412D+...
      LOSS(  VLVPO1           ) =    5.1430D-01 * RXRAT( 233 )      ! VLVPO1+OH=0.4857D+...

      PROD(  VSVPO1           ) =    6.2000D-03 * RXRAT( 233 )      ! VLVPO1+OH=0.6200D-...
     &                          +    9.5000D-02 * RXRAT( 235 )      ! VSVPO2+OH=0.9500D-...
     &                          +    3.0630D-01 * RXRAT( 236 )      ! VSVPO3+OH=0.3063D+...
     &                          +    2.0890D-01 * RXRAT( 237 )      ! VIVPO1+OH=0.2089D+...
      LOSS(  VSVPO1           ) =    7.1380D-01 * RXRAT( 234 )      ! VSVPO1+OH=0.2862D+...

      PROD(  VSVPO2           ) =    2.5000D-03 * RXRAT( 233 )      ! VLVPO1+OH=0.2500D-...
     &                          +    4.1000D-03 * RXRAT( 234 )      ! VSVPO1+OH=0.4100D-...
     &                          +    1.5300D-02 * RXRAT( 236 )      ! VSVPO3+OH=0.1530D-...
     &                          +    3.0000D-01 * RXRAT( 237 )      ! VIVPO1+OH=0.3000D+...
      LOSS(  VSVPO2           ) =    8.6270D-01 * RXRAT( 235 )      ! VSVPO2+OH=0.1373D+...

      PROD(  VSVPO3           ) =    2.6000D-03 * RXRAT( 233 )      ! VLVPO1+OH=0.2600D-...
     &                          +    3.5000D-03 * RXRAT( 234 )      ! VSVPO1+OH=0.3500D-...
     &                          +    5.0000D-04 * RXRAT( 235 )      ! VSVPO2+OH=0.5000D-...
      LOSS(  VSVPO3           ) =    8.9570D-01 * RXRAT( 236 )      ! VSVPO3+OH=0.1043D+...

      PROD(  VIVPO1           ) =    2.3000D-03 * RXRAT( 233 )      ! VLVPO1+OH=0.2300D-...
      LOSS(  VIVPO1           ) =                 RXRAT( 237 )      ! VIVPO1+OH=OH+0.2412D+...

      PROD(  VLVOO1           ) =    2.9440D-01 * RXRAT( 233 )      ! VLVPO1+OH=0.2944D+...
     &                          +    2.2390D-01 * RXRAT( 234 )      ! VSVPO1+OH=0.2239D+...
     &                          +    2.0510D-01 * RXRAT( 235 )      ! VSVPO2+OH=0.2051D+...
     &                          +    1.8930D-01 * RXRAT( 236 )      ! VSVPO3+OH=0.1893D+...
     &                          +    2.0280D-01 * RXRAT( 237 )      ! VIVPO1+OH=0.2028D+...
     &                          +    2.8580D-01 * RXRAT( 239 )      ! VLVOO2+OH=0.2858D+...
     &                          +    3.3030D-01 * RXRAT( 240 )      ! VSVOO1+OH=0.3303D+...
     &                          +    3.4440D-01 * RXRAT( 241 )      ! VSVOO2+OH=0.3444D+...
     &                          +    3.8860D-01 * RXRAT( 242 )      ! VSVOO3+OH=0.3886D+...
      LOSS(  VLVOO1           ) =    3.3360D-01 * RXRAT( 238 )      ! VLVOO1+OH=0.6664D+...

      PROD(  VLVOO2           ) =    2.0210D-01 * RXRAT( 233 )      ! VLVPO1+OH=0.2021D+...
     &                          +    1.8200D-01 * RXRAT( 234 )      ! VSVPO1+OH=0.1820D+...
     &                          +    1.7640D-01 * RXRAT( 235 )      ! VSVPO2+OH=0.1764D+...
     &                          +    1.6680D-01 * RXRAT( 236 )      ! VSVPO3+OH=0.1668D+...
     &                          +    4.7100D-02 * RXRAT( 237 )      ! VIVPO1+OH=0.4710D-...
     &                          +    1.4300D-02 * RXRAT( 238 )      ! VLVOO1+OH=0.1430D-...
     &                          +    2.2720D-01 * RXRAT( 240 )      ! VSVOO1+OH=0.2272D+...
     &                          +    2.7490D-01 * RXRAT( 241 )      ! VSVOO2+OH=0.2749D+...
     &                          +    2.4210D-01 * RXRAT( 242 )      ! VSVOO3+OH=0.2421D+...
      LOSS(  VLVOO2           ) =    6.0690D-01 * RXRAT( 239 )      ! VLVOO2+OH=0.3931D+...

      PROD(  VSVOO2           ) =    1.9000D-03 * RXRAT( 233 )      ! VLVPO1+OH=0.1900D-...
     &                          +    1.2390D-01 * RXRAT( 238 )      ! VLVOO1+OH=0.1239D+...
     &                          +    1.0270D-01 * RXRAT( 239 )      ! VLVOO2+OH=0.1027D+...
     &                          +    7.0200D-02 * RXRAT( 240 )      ! VSVOO1+OH=0.7020D-...
     &                          +    3.8500D-02 * RXRAT( 242 )      ! VSVOO3+OH=0.3850D-...
      LOSS(  VSVOO2           ) =    7.4230D-01 * RXRAT( 241 )      ! VSVOO2+OH=0.2577D+...

      PROD(  VSVOO3           ) =    2.3000D-03 * RXRAT( 233 )      ! VLVPO1+OH=0.2300D-...
     &                          +    1.8310D-01 * RXRAT( 238 )      ! VLVOO1+OH=0.1831D+...
     &                          +    2.0450D-01 * RXRAT( 239 )      ! VLVOO2+OH=0.2045D+...
     &                          +    1.1160D-01 * RXRAT( 240 )      ! VSVOO1+OH=0.1116D+...
     &                          +    7.3900D-02 * RXRAT( 241 )      ! VSVOO2+OH=0.7390D-...
      LOSS(  VSVOO3           ) =    7.3330D-01 * RXRAT( 242 )      ! VSVOO3+OH=0.2667D+...

      PROD(  VSVOO1           ) =    1.2300D-02 * RXRAT( 238 )      ! VLVOO1+OH=0.1230D-...
     &                          +    1.3900D-02 * RXRAT( 239 )      ! VLVOO2+OH=0.1390D-...
     &                          +    4.9100D-02 * RXRAT( 241 )      ! VSVOO2+OH=0.4910D-...
     &                          +    6.4000D-02 * RXRAT( 242 )      ! VSVOO3+OH=0.6400D-...
      LOSS(  VSVOO1           ) =    7.3930D-01 * RXRAT( 240 )      ! VSVOO1+OH=0.2607D+...

      PROD(  FORM_PRIMARY     ) =   0.0D0
      LOSS(  FORM_PRIMARY     ) =                 RXRAT( 243 )      ! FORM_PRIMARY+OH=OH
     &                          +                 RXRAT( 244 )      ! FORM_PRIMARY+NO3=NO3
     &                          +                 RXRAT( 245 )      ! FORM_PRIMARY+O=O
     &                          +                 RXRAT( 246 )      ! FORM_PRIMARY=
     &                          +                 RXRAT( 247 )      ! FORM_PRIMARY=
     &                          +                 RXRAT( 248 )      ! FORM_PRIMARY+CL=CL

      PROD(  ALD2_PRIMARY     ) =   0.0D0
      LOSS(  ALD2_PRIMARY     ) =                 RXRAT( 249 )      ! ALD2_PRIMARY+OH=OH
     &                          +                 RXRAT( 250 )      ! ALD2_PRIMARY+NO3=NO3
     &                          +                 RXRAT( 251 )      ! ALD2_PRIMARY+O=O
     &                          +                 RXRAT( 252 )      ! ALD2_PRIMARY=
     &                          +                 RXRAT( 253 )      ! ALD2_PRIMARY+CL=CL

      PROD(  BUTADIENE13      ) =   0.0D0
      LOSS(  BUTADIENE13      ) =                 RXRAT( 254 )      ! BUTADIENE13+OH=OH+0.5800D+...
     &                          +                 RXRAT( 255 )      ! BUTADIENE13+O3=O3+0.5200D+...
     &                          +                 RXRAT( 256 )      ! BUTADIENE13+NO3=NO3+...
     &                          +                 RXRAT( 257 )      ! BUTADIENE13+CL=CL+0.5800D+...

      PROD(  ACROLEIN         ) =    5.8000D-01 * RXRAT( 254 )      ! BUTADIENE13+OH=0.5800D+...
     &                          +    5.2000D-01 * RXRAT( 255 )      ! BUTADIENE13+O3=0.5200D+...
     &                          +    4.5000D-02 * RXRAT( 256 )      ! BUTADIENE13+NO3=0.4500D-...
     &                          +    5.8000D-01 * RXRAT( 257 )      ! BUTADIENE13+CL=0.5800D+...
      LOSS(  ACROLEIN         ) =                 RXRAT( 263 )      ! ACROLEIN+OH=OH
     &                          +                 RXRAT( 264 )      ! ACROLEIN+O3=O3
     &                          +                 RXRAT( 265 )      ! ACROLEIN+NO3=NO3
     &                          +                 RXRAT( 266 )      ! ACROLEIN=
     &                          +                 RXRAT( 267 )      ! ACROLEIN+CL=CL

      PROD(  ACROLEIN_PRIMARY ) =   0.0D0
      LOSS(  ACROLEIN_PRIMARY ) =                 RXRAT( 258 )      ! ACROLEIN_PRIMARY+OH=OH
     &                          +                 RXRAT( 259 )      ! ACROLEIN_PRIMARY+O3=O3
     &                          +                 RXRAT( 260 )      ! ACROLEIN_PRIMARY+NO3=NO3
     &                          +                 RXRAT( 261 )      ! ACROLEIN_PRIMARY=
     &                          +                 RXRAT( 262 )      ! ACROLEIN_PRIMARY+CL=CL

      PROD(  TOLU             ) =   0.0D0
      LOSS(  TOLU             ) =                 RXRAT( 268 )      ! TOLU+OH=OH
     &                          +                 RXRAT( 269 )      ! TOLU+CL=CL

      PROD(  MXYL             ) =   0.0D0
      LOSS(  MXYL             ) =                 RXRAT( 270 )      ! MXYL+OH=OH
     &                          +                 RXRAT( 271 )      ! MXYL+CL=CL

      PROD(  OXYL             ) =   0.0D0
      LOSS(  OXYL             ) =                 RXRAT( 272 )      ! OXYL+OH=OH
     &                          +                 RXRAT( 273 )      ! OXYL+CL=CL

      PROD(  PXYL             ) =   0.0D0
      LOSS(  PXYL             ) =                 RXRAT( 274 )      ! PXYL+OH=OH
     &                          +                 RXRAT( 275 )      ! PXYL+CL=CL

      PROD(  APIN             ) =   0.0D0
      LOSS(  APIN             ) =                 RXRAT( 276 )      ! APIN+O=O
     &                          +                 RXRAT( 277 )      ! APIN+OH=OH
     &                          +                 RXRAT( 278 )      ! APIN+O3=O3
     &                          +                 RXRAT( 279 )      ! APIN+NO3=NO3
     &                          +                 RXRAT( 280 )      ! APIN+CL=CL

      PROD(  BPIN             ) =   0.0D0
      LOSS(  BPIN             ) =                 RXRAT( 281 )      ! BPIN+O=O
     &                          +                 RXRAT( 282 )      ! BPIN+OH=OH
     &                          +                 RXRAT( 283 )      ! BPIN+O3=O3
     &                          +                 RXRAT( 284 )      ! BPIN+NO3=NO3
     &                          +                 RXRAT( 285 )      ! BPIN+CL=CL

      PROD(  HG               ) =   0.0D0
      LOSS(  HG               ) =                 RXRAT( 286 )      ! HG+O3=0.5000D+00*HGIIAER+...
     &                          +                 RXRAT( 287 )      ! HG+CL2=HGIIGAS+CL2
     &                          +                 RXRAT( 288 )      ! HG+H2O2=HGIIGAS+H2O2
     &                          +                 RXRAT( 289 )      ! HG+OH=0.5000D+00*HGIIAER+...
     &                          +    5.0000D-01 * RXRAT( 290 )      ! HG+CL=0.5000D+00*HG+...

      PROD(  HGIIAER          ) =    5.0000D-01 * RXRAT( 286 )      ! HG+O3=0.5000D+00*HGIIAER+...
     &                          +    5.0000D-01 * RXRAT( 289 )      ! HG+OH=0.5000D+00*HGIIAER+...
      LOSS(  HGIIAER          ) =   0.0D0

      PROD(  HGIIGAS          ) =    5.0000D-01 * RXRAT( 286 )      ! HG+O3=0.5000D+00*HGIIGAS+...
     &                          +                 RXRAT( 287 )      ! HG+CL2=HGIIGAS+CL2
     &                          +                 RXRAT( 288 )      ! HG+H2O2=HGIIGAS+H2O2
     &                          +    5.0000D-01 * RXRAT( 289 )      ! HG+OH=0.5000D+00*HGIIGAS+...
     &                          +    5.0000D-01 * RXRAT( 290 )      ! HG+CL=0.5000D+00*HGIIGAS+...
      LOSS(  HGIIGAS          ) =   0.0D0

      PNEG( PAR ) =    6.6000D-01 * RXRAT(  61 )      ! NTR+OH=-0.6600D+00*PAR+HO2+...
     &            +    6.6000D-01 * RXRAT(  62 )      ! NTR=-0.6600D+00*PAR+HO2+...
     &            +    2.1000D+00 * RXRAT( 113 )      ! ROR=-0.2100D+01*PAR+...
     &            +    7.0000D-01 * RXRAT( 117 )      ! OH+OLE=-0.7000D+00*PAR+...
     &            +                 RXRAT( 118 )      ! O3+OLE=-PAR+0.7400D+...
     &            +                 RXRAT( 119 )      ! NO3+OLE=-PAR+FORM+0.9100D+...
     &            +                 RXRAT( 185 )      ! CL+OLE=-PAR+0.3300D+...

      RETURN

      END
