
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!

C RCS file, release, date & time of last delta, author, state, [and locker]
C $Header$

C what(1) key, module and SID; SCCS file; date and time of last delta:
C %W% %P% %G% %U%

      SUBROUTINE HRPRODLOSS

C***********************************************************************
C
C  FUNCTION: To compute the production and loss rates for EBI species
C
C  PRECONDITIONS: For the SAPRC07TB family of mechanisms
C
C  RETURN VALUES: None
C
C  KEY SUBROUTINES/FUNCTIONS CALLED: None
C
C  REVISION HISTORY: Created by EBI solver program, May 25, 2016
C
C   18 Jul 14 B.Hutzell: revised to use real(8) variables

C***********************************************************************
      USE HRDATA

      IMPLICIT NONE


C.....INCLUDES: NONE


C.....ARGUMENTS: NONE


C.....PARAMETERS: NONE


C.....EXTERNAL FUNCTIONS: NONE


C.....SAVED VARIABLES: NONE
!     CHARACTER( 16 ), SAVE  ::  PNAME = 'HRPRODLOSS'   ! Program name


C.....LOCAL VARIABLES:


C***********************************************************************


      PROD(  HNO3         ) =    2.0000D+00 * RXRAT(  13 )      ! N2O5=0.2000D+01*HNO3
     &                      +    2.0000D+00 * RXRAT(  14 )      ! N2O5=0.2000D+01*HNO3
     &                      +                 RXRAT(  25 )      ! OH+NO2=HNO3
     &                      +    2.0000D-01 * RXRAT(  39 )      ! NO3+HO2=0.2000D+00*HNO3+...
     &                      +                 RXRAT( 135 )      ! HCHO+NO3=HNO3+HO2+CO
     &                      +                 RXRAT( 138 )      ! CCHO+NO3=HNO3+MECO3
     &                      +                 RXRAT( 141 )      ! RCHO+NO3=HNO3+RCO3
     &                      +                 RXRAT( 161 )      ! GLY+NO3=HNO3+0.7000D+...
     &                      +                 RXRAT( 164 )      ! MGLY+NO3=HNO3+CO+MECO3
     &                      +                 RXRAT( 167 )      ! CRES+NO3=HNO3+BZO
     &                      +                 RXRAT( 173 )      ! BALD+NO3=HNO3+BZCO3
     &                      +    5.0000D-01 * RXRAT( 184 )      ! MACR+NO3=0.5000D+00*HNO3+...
     &                      +    1.5000D-01 * RXRAT( 193 )      ! IPRD+NO3=0.1500D+00*HNO3+...
     &                      +                 RXRAT( 201 )      ! HOCCHO+NO3=HNO3+MECO3
     &                      +    9.6700D-01 * RXRAT( 204 )      ! ACROLEIN+NO3=0.9670D+...
     &                      +    5.0000D-01 * RXRAT( 429 )      ! NO2=0.5000D+00*HNO3+...
     &                      +                 RXRAT( 430 )      ! N2O5=HNO3+H2NO3PIJ
     &                      +                 RXRAT( 431 )      ! N2O5=HNO3+H2NO3PK
     &                      +                 RXRAT( 432 )      ! H2NO3PIJ=HNO3
     &                      +                 RXRAT( 433 )      ! H2NO3PK=HNO3
      LOSS(  HNO3         ) =                 RXRAT(  27 )      ! HNO3+OH=NO3
     &                      +                 RXRAT(  28 )      ! HNO3=OH+NO2

      PROD(  CO           ) =                 RXRAT( 130 )      ! xCO=CO
     &                      +                 RXRAT( 132 )      ! HCHO=CO+0.2000D+01*HO2
     &                      +                 RXRAT( 133 )      ! HCHO=CO
     &                      +                 RXRAT( 134 )      ! HCHO+OH=CO+HO2
     &                      +                 RXRAT( 135 )      ! HCHO+NO3=CO+HO2+HNO3
     &                      +                 RXRAT( 137 )      ! CCHO=CO+HO2+MEO2
     &                      +                 RXRAT( 140 )      ! RCHO=CO+xHO2+yROOH+xCCHO+...
     &                      +    3.8000D-01 * RXRAT( 143 )      ! ACETONE=0.3800D+00*CO+...
     &                      +    2.0000D+00 * RXRAT( 158 )      ! GLY=0.2000D+01*CO+0.2000D+...
     &                      +                 RXRAT( 159 )      ! GLY=CO+HCHO
     &                      +    1.4000D+00 * RXRAT( 160 )      ! GLY+OH=0.1400D+01*CO+...
     &                      +    1.4000D+00 * RXRAT( 161 )      ! GLY+NO3=0.1400D+01*CO+...
     &                      +                 RXRAT( 162 )      ! MGLY=CO+HO2+MECO3
     &                      +                 RXRAT( 163 )      ! MGLY+OH=CO+MECO3
     &                      +                 RXRAT( 164 )      ! MGLY+NO3=CO+HNO3+MECO3
     &                      +    5.2200D-01 * RXRAT( 175 )      ! AFG1+O3=0.5220D+00*CO+...
     &                      +    6.9500D-01 * RXRAT( 176 )      ! AFG1=0.6950D+00*CO+0.1730D+...
     &                      +    5.2200D-01 * RXRAT( 178 )      ! AFG2+O3=0.5220D+00*CO+...
     &                      +    5.8000D-01 * RXRAT( 181 )      ! AFG3+O3=0.5800D+00*CO+...
     &                      +    4.5000D-01 * RXRAT( 183 )      ! MACR+O3=0.4500D+00*CO+...
     &                      +    6.7000D-01 * RXRAT( 186 )      ! MACR=0.6700D+00*CO+0.6700D+...
     &                      +    4.7500D-01 * RXRAT( 188 )      ! MVK+O3=0.4750D+00*CO+...
     &                      +    6.0000D-01 * RXRAT( 190 )      ! MVK=0.6000D+00*CO+0.4000D+...
     &                      +    4.9800D-01 * RXRAT( 192 )      ! IPRD+O3=0.4980D+00*CO+...
     &                      +    1.2330D+00 * RXRAT( 194 )      ! IPRD=0.1233D+01*CO+0.4670D+...
     &                      +                 RXRAT( 200 )      ! HOCCHO=CO+0.2000D+01*HO2+HCHO
     &                      +    1.0050D+00 * RXRAT( 203 )      ! ACROLEIN+O3=0.1005D+01*CO+...
     &                      +    1.1880D+00 * RXRAT( 206 )      ! ACROLEIN=0.1188D+01*CO+...
     &                      +                 RXRAT( 210 )      ! HCOCO3+NO=CO+HO2+CO2+NO2
     &                      +                 RXRAT( 211 )      ! HCOCO3+NO2=CO+HO2+CO2+NO3
     &                      +    4.4000D-01 * RXRAT( 212 )      ! HCOCO3+HO2=0.4400D+00*CO+...
     &                      +    5.1000D-01 * RXRAT( 268 )      ! ETHENE+O3=0.5100D+00*CO+...
     &                      +    5.1000D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.5100D+00*CO+...
     &                      +    5.2500D-01 * RXRAT( 272 )      ! PROPENE+O3=0.5250D+00*CO+...
     &                      +    2.5500D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.2550D+...
     &                      +    2.7500D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.2750D+00*CO+...
     &                      +    2.5100D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.2510D+00*CO+...
     &                      +    2.5100D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.2510D+00*CO+...
     &                      +    1.2600D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.1260D+00*CO+...
     &                      +    1.2600D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.1260D+00*CO+...
     &                      +    2.5100D-01 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.2510D+...
     &                      +    2.9000D-02 * RXRAT( 293 )      ! APIN+O3=0.2900D-01*CO+...
     &                      +    3.0000D-01 * RXRAT( 296 )      ! ACETYLENE+OH=0.3000D+00*CO+...
     &                      +    1.5000D+00 * RXRAT( 297 )      ! ACETYLENE+O3=0.1500D+01*CO+...
     &                      +    3.0300D-01 * RXRAT( 312 )      ! OLE1+O3=0.3030D+00*CO+...
     &                      +    2.9900D-01 * RXRAT( 316 )      ! OLE2+O3=0.2990D+00*CO+...
     &                      +    2.4900D-01 * RXRAT( 323 )      ! TERP+O3=0.2490D+00*CO+...
     &                      +    2.4900D-01 * RXRAT( 327 )      ! SESQ+O3=0.2490D+00*CO+...
     &                      +                 RXRAT( 352 )      ! HCHO+CL=CO+HO2+HCL
     &                      +    1.2600D+00 * RXRAT( 360 )      ! GLY+CL=0.1260D+01*CO+...
     &                      +                 RXRAT( 361 )      ! MGLY+CL=CO+HCL+MECO3
     &                      +                 RXRAT( 371 )      ! CLCCHO=CO+HO2+RO2C+xCL+...
     &                      +                 RXRAT( 387 )      ! ACETYLENE+CL=CO+HO2
      LOSS(  CO           ) =                 RXRAT(  29 )      ! CO+OH=HO2+CO2

      PROD(  CO2          ) =                 RXRAT(  29 )      ! OH+CO=CO2+HO2
     &                      +    4.0000D-01 * RXRAT(  65 )      ! PAN=0.4000D+00*CO2+0.6000D+...
     &                      +                 RXRAT(  66 )      ! MECO3+NO=CO2+MEO2+NO2
     &                      +    4.4000D-01 * RXRAT(  67 )      ! MECO3+HO2=0.4400D+00*CO2+...
     &                      +                 RXRAT(  68 )      ! MECO3+NO3=CO2+MEO2+NO2
     &                      +    9.0000D-01 * RXRAT(  69 )      ! MECO3+MEO2=0.9000D+00*CO2+...
     &                      +                 RXRAT(  70 )      ! MECO3+RO2C=CO2+MEO2
     &                      +                 RXRAT(  71 )      ! MECO3+RO2XC=CO2+MEO2
     &                      +    2.0000D+00 * RXRAT(  72 )      ! MECO3+MECO3=0.2000D+01*CO2+...
     &                      +    4.0000D-01 * RXRAT(  75 )      ! PAN2=0.4000D+00*CO2+...
     &                      +                 RXRAT(  76 )      ! RCO3+NO=CO2+RO2C+xHO2+...
     &                      +    4.4000D-01 * RXRAT(  77 )      ! RCO3+HO2=0.4400D+00*CO2+...
     &                      +                 RXRAT(  78 )      ! RCO3+NO3=CO2+RO2C+xHO2+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=CO2+HO2+RO2C+...
     &                      +                 RXRAT(  80 )      ! RCO3+RO2C=CO2+xHO2+xCCHO+...
     &                      +                 RXRAT(  81 )      ! RCO3+RO2XC=CO2+xHO2+xCCHO+...
     &                      +    2.0000D+00 * RXRAT(  82 )      ! RCO3+MECO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT(  83 )      ! RCO3+RCO3=0.2000D+01*CO2+...
     &                      +    4.0000D-01 * RXRAT(  86 )      ! PBZN=0.4000D+00*CO2+...
     &                      +                 RXRAT(  87 )      ! BZCO3+NO=CO2+NO2+BZO+RO2C
     &                      +    4.4000D-01 * RXRAT(  88 )      ! BZCO3+HO2=0.4400D+00*CO2+...
     &                      +                 RXRAT(  89 )      ! BZCO3+NO3=CO2+NO2+BZO+RO2C
     &                      +                 RXRAT(  90 )      ! BZCO3+MEO2=CO2+HO2+RO2C+...
     &                      +                 RXRAT(  91 )      ! BZCO3+RO2C=CO2+BZO+RO2C
     &                      +                 RXRAT(  92 )      ! BZCO3+RO2XC=CO2+BZO+RO2C
     &                      +    2.0000D+00 * RXRAT(  93 )      ! BZCO3+MECO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT(  94 )      ! BZCO3+RCO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT(  95 )      ! BZCO3+BZCO3=0.2000D+01*CO2+...
     &                      +    4.0000D-01 * RXRAT(  98 )      ! MAPAN=0.4000D+00*CO2+...
     &                      +                 RXRAT(  99 )      ! MACO3+NO=CO2+NO2+HCHO+MECO3
     &                      +    4.4000D-01 * RXRAT( 100 )      ! MACO3+HO2=0.4400D+00*CO2+...
     &                      +                 RXRAT( 101 )      ! MACO3+NO3=CO2+NO2+HCHO+MECO3
     &                      +                 RXRAT( 102 )      ! MACO3+MEO2=CO2+HO2+0.2000D+...
     &                      +                 RXRAT( 103 )      ! MACO3+RO2C=CO2+HCHO+MECO3
     &                      +                 RXRAT( 104 )      ! MACO3+RO2XC=CO2+HCHO+MECO3
     &                      +    2.0000D+00 * RXRAT( 105 )      ! MACO3+MECO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT( 106 )      ! MACO3+RCO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT( 107 )      ! MACO3+BZCO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT( 108 )      ! MACO3+MACO3=0.2000D+01*CO2+...
     &                      +                 RXRAT( 147 )      ! HCOOH+OH=CO2+HO2
     &                      +    5.0900D-01 * RXRAT( 148 )      ! CCOOH+OH=0.5090D+00*CO2+...
     &                      +    1.4300D-01 * RXRAT( 149 )      ! RCOOH+OH=0.1430D+00*CO2+...
     &                      +    1.7400D-01 * RXRAT( 175 )      ! AFG1+O3=0.1740D+00*CO2+...
     &                      +    1.7400D-01 * RXRAT( 178 )      ! AFG2+O3=0.1740D+00*CO2+...
     &                      +    1.9000D-01 * RXRAT( 181 )      ! AFG3+O3=0.1900D+00*CO2+...
     &                      +    1.1700D-01 * RXRAT( 183 )      ! MACR+O3=0.1170D+00*CO2+...
     &                      +    1.2400D-01 * RXRAT( 188 )      ! MVK+O3=0.1240D+00*CO2+...
     &                      +    1.4000D-01 * RXRAT( 192 )      ! IPRD+O3=0.1400D+00*CO2+...
     &                      +    3.1000D-01 * RXRAT( 203 )      ! ACROLEIN+O3=0.3100D+00*CO2+...
     &                      +    1.0200D-01 * RXRAT( 206 )      ! ACROLEIN=0.1020D+00*CO2+...
     &                      +    2.0000D-02 * RXRAT( 207 )      ! CCOOOH+OH=0.2000D-01*CO2+...
     &                      +                 RXRAT( 208 )      ! CCOOOH=CO2+MEO2+OH
     &                      +    1.1000D-01 * RXRAT( 209 )      ! RCOOOH+OH=0.1100D+00*CO2+...
     &                      +                 RXRAT( 210 )      ! HCOCO3+NO=CO2+CO+HO2+NO2
     &                      +                 RXRAT( 211 )      ! HCOCO3+NO2=CO2+CO+HO2+NO3
     &                      +    4.4000D-01 * RXRAT( 212 )      ! HCOCO3+HO2=0.4400D+00*CO2+...
     &                      +    1.2000D-01 * RXRAT( 268 )      ! ETHENE+O3=0.1200D+00*CO2+...
     &                      +    2.1500D-01 * RXRAT( 272 )      ! PROPENE+O3=0.2150D+00*CO2+...
     &                      +    1.8500D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.1850D+...
     &                      +    1.2200D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1220D+00*CO2+...
     &                      +    2.0000D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.2000D+00*CO2+...
     &                      +    2.0000D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.2000D+00*CO2+...
     &                      +    1.0000D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.1000D+...
     &                      +    1.0000D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.1000D+...
     &                      +    1.2000D+00 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.1200D+...
     &                      +    1.7000D-02 * RXRAT( 293 )      ! APIN+O3=0.1700D-01*CO2+...
     &                      +    5.0000D-01 * RXRAT( 297 )      ! ACETYLENE+O3=0.5000D+...
     &                      +    8.8000D-02 * RXRAT( 312 )      ! OLE1+O3=0.8800D-01*CO2+...
     &                      +    1.6100D-01 * RXRAT( 316 )      ! OLE2+O3=0.1610D+00*CO2+...
     &                      +    6.3000D-02 * RXRAT( 323 )      ! TERP+O3=0.6300D-01*CO2+...
     &                      +    6.3000D-02 * RXRAT( 327 )      ! SESQ+O3=0.6300D-01*CO2+...
      LOSS(  CO2          ) =   0.0D0

      PROD(  HO2H         ) =                 RXRAT(  37 )      ! HO2+HO2=HO2H
     &                      +                 RXRAT(  38 )      ! HO2+HO2=HO2H
      LOSS(  HO2H         ) =                 RXRAT(  41 )      ! HO2H=0.2000D+01*OH
     &                      +                 RXRAT(  42 )      ! HO2H+OH=HO2

      PROD(  SO2          ) =   0.0D0
      LOSS(  SO2          ) =                 RXRAT(  44 )      ! SO2+OH=HO2+SULF+SULRXN

      PROD(  SULF         ) =                 RXRAT(  44 )      ! OH+SO2=SULF+HO2+SULRXN
      LOSS(  SULF         ) =   0.0D0

      PROD(  SULRXN       ) =                 RXRAT(  44 )      ! OH+SO2=SULRXN+SULF+HO2
      LOSS(  SULRXN       ) =   0.0D0

      PROD(  MEO2         ) =    4.0000D-01 * RXRAT(  65 )      ! PAN=0.4000D+00*MEO2+...
     &                      +                 RXRAT(  66 )      ! MECO3+NO=MEO2+CO2+NO2
     &                      +    4.4000D-01 * RXRAT(  67 )      ! MECO3+HO2=0.4400D+00*MEO2+...
     &                      +                 RXRAT(  68 )      ! MECO3+NO3=MEO2+CO2+NO2
     &                      +                 RXRAT(  70 )      ! MECO3+RO2C=MEO2+CO2
     &                      +                 RXRAT(  71 )      ! MECO3+RO2XC=MEO2+CO2
     &                      +    2.0000D+00 * RXRAT(  72 )      ! MECO3+MECO3=0.2000D+...
     &                      +                 RXRAT(  82 )      ! RCO3+MECO3=MEO2+0.2000D+...
     &                      +                 RXRAT(  93 )      ! BZCO3+MECO3=MEO2+0.2000D+...
     &                      +                 RXRAT( 105 )      ! MACO3+MECO3=MEO2+0.2000D+...
     &                      +                 RXRAT( 110 )      ! TBUO=MEO2+ACETONE
     &                      +                 RXRAT( 120 )      ! xMEO2=MEO2
     &                      +                 RXRAT( 137 )      ! CCHO=MEO2+HO2+CO
     &                      +    1.3800D+00 * RXRAT( 143 )      ! ACETONE=0.1380D+01*MEO2+...
     &                      +    5.0900D-01 * RXRAT( 148 )      ! CCOOH+OH=0.5090D+00*MEO2+...
     &                      +    7.0000D-01 * RXRAT( 150 )      ! COOH+OH=0.7000D+00*MEO2+...
     &                      +    1.7300D-01 * RXRAT( 176 )      ! AFG1=0.1730D+00*MEO2+...
     &                      +    4.0000D-01 * RXRAT( 190 )      ! MVK=0.4000D+00*MEO2+...
     &                      +    2.3400D-01 * RXRAT( 206 )      ! ACROLEIN=0.2340D+00*MEO2+...
     &                      +                 RXRAT( 208 )      ! CCOOOH=MEO2+CO2+OH
     &                      +                 RXRAT( 266 )      ! OH=MEO2
     &                      +    5.1000D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.5100D+00*MEO2+...
     &                      +    3.5500D-01 * RXRAT( 272 )      ! PROPENE+O3=0.3550D+00*MEO2+...
     &                      +    2.5000D-01 * RXRAT( 282 )      ! ISOPRENE+O3P=0.2500D+...
     &                      +                 RXRAT( 291 )      ! IEPOXOO+MECO3=MEO2+0.2750D+...
     &                      +    3.0700D-01 * RXRAT( 316 )      ! OLE2+O3=0.3070D+00*MEO2+...
     &                      +                 RXRAT( 381 )      ! CL=MEO2+HCL
      LOSS(  MEO2         ) =                 RXRAT(  46 )      ! MEO2+NO=NO2+HCHO+HO2
     &                      +                 RXRAT(  47 )      ! MEO2+HO2=COOH
     &                      +                 RXRAT(  48 )      ! MEO2+HO2=HCHO
     &                      +                 RXRAT(  49 )      ! MEO2+NO3=HCHO+HO2+NO2
     &                      +    2.0000D+00 * RXRAT(  50 )      ! MEO2+MEO2=MEOH+HCHO
     &                      +    2.0000D+00 * RXRAT(  51 )      ! MEO2+MEO2=0.2000D+01*HCHO+...
     &                      +                 RXRAT(  55 )      ! MEO2+RO2C=0.5000D+00*HO2+...
     &                      +                 RXRAT(  60 )      ! MEO2+RO2XC=0.5000D+00*HO2+...
     &                      +    1.0000D-01 * RXRAT(  69 )      ! MEO2+MECO3=0.9000D+00*MEO2+...
     &                      +                 RXRAT(  79 )      ! MEO2+RCO3=HCHO+HO2+RO2C+...
     &                      +                 RXRAT(  90 )      ! MEO2+BZCO3=HCHO+HO2+RO2C+...
     &                      +                 RXRAT( 102 )      ! MEO2+MACO3=0.2000D+01*HCHO+...
     &                      +                 RXRAT( 289 )      ! MEO2+IEPOXOO=0.3630D+...

      PROD(  HCHO         ) =                 RXRAT(  46 )      ! MEO2+NO=HCHO+NO2+HO2
     &                      +                 RXRAT(  48 )      ! MEO2+HO2=HCHO
     &                      +                 RXRAT(  49 )      ! MEO2+NO3=HCHO+HO2+NO2
     &                      +                 RXRAT(  50 )      ! MEO2+MEO2=HCHO+MEOH
     &                      +    2.0000D+00 * RXRAT(  51 )      ! MEO2+MEO2=0.2000D+01*HCHO+...
     &                      +    7.5000D-01 * RXRAT(  55 )      ! RO2C+MEO2=0.7500D+00*HCHO+...
     &                      +    7.5000D-01 * RXRAT(  60 )      ! RO2XC+MEO2=0.7500D+00*HCHO+...
     &                      +                 RXRAT(  69 )      ! MECO3+MEO2=HCHO+0.1000D+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=HCHO+HO2+RO2C+...
     &                      +                 RXRAT(  90 )      ! BZCO3+MEO2=HCHO+HO2+RO2C+...
     &                      +    4.0000D-01 * RXRAT(  98 )      ! MAPAN=0.4000D+00*HCHO+...
     &                      +                 RXRAT(  99 )      ! MACO3+NO=HCHO+CO2+NO2+MECO3
     &                      +    4.4000D-01 * RXRAT( 100 )      ! MACO3+HO2=0.4400D+00*HCHO+...
     &                      +                 RXRAT( 101 )      ! MACO3+NO3=HCHO+CO2+NO2+MECO3
     &                      +    2.0000D+00 * RXRAT( 102 )      ! MACO3+MEO2=0.2000D+01*HCHO+...
     &                      +                 RXRAT( 103 )      ! MACO3+RO2C=HCHO+CO2+MECO3
     &                      +                 RXRAT( 104 )      ! MACO3+RO2XC=HCHO+CO2+MECO3
     &                      +                 RXRAT( 105 )      ! MACO3+MECO3=HCHO+MEO2+...
     &                      +                 RXRAT( 106 )      ! MACO3+RCO3=HCHO+MECO3+RO2C+...
     &                      +                 RXRAT( 107 )      ! MACO3+BZCO3=HCHO+MECO3+BZO+...
     &                      +    2.0000D+00 * RXRAT( 108 )      ! MACO3+MACO3=0.2000D+...
     &                      +                 RXRAT( 146 )      ! MEOH+OH=HCHO+HO2
     &                      +    3.0000D-01 * RXRAT( 150 )      ! COOH+OH=0.3000D+00*HCHO+...
     &                      +                 RXRAT( 151 )      ! COOH=HCHO+HO2+OH
     &                      +                 RXRAT( 159 )      ! GLY=HCHO+CO
     &                      +    1.0000D-01 * RXRAT( 183 )      ! MACR+O3=0.1000D+00*HCHO+...
     &                      +    3.4000D-01 * RXRAT( 186 )      ! MACR=0.3400D+00*HCHO+...
     &                      +    5.0000D-02 * RXRAT( 188 )      ! MVK+O3=0.5000D-01*HCHO+...
     &                      +    1.2400D-01 * RXRAT( 192 )      ! IPRD+O3=0.1240D+00*HCHO+...
     &                      +    3.0000D-01 * RXRAT( 194 )      ! IPRD=0.3000D+00*HCHO+...
     &                      +    2.0000D-03 * RXRAT( 195 )      ! PRD2+OH=0.2000D-02*HCHO+...
     &                      +    7.4000D-02 * RXRAT( 198 )      ! RNO3=0.7400D-01*HCHO+...
     &                      +                 RXRAT( 200 )      ! HOCCHO=HCHO+0.2000D+01*HO2+CO
     &                      +    5.0000D-01 * RXRAT( 203 )      ! ACROLEIN+O3=0.5000D+...
     &                      +    3.4000D-01 * RXRAT( 206 )      ! ACROLEIN=0.3400D+00*HCHO+...
     &                      +                 RXRAT( 213 )      ! xHCHO=HCHO
     &                      +                 RXRAT( 268 )      ! ETHENE+O3=HCHO+0.1600D+...
     &                      +    5.0000D-01 * RXRAT( 272 )      ! PROPENE+O3=0.5000D+00*HCHO+...
     &                      +    5.0000D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.5000D+...
     &                      +    4.0000D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.4000D+...
     &                      +    7.5000D-01 * RXRAT( 285 )      ! ISOPOOH=0.7500D+00*HCHO+...
     &                      +    3.7500D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.3750D+...
     &                      +    3.7500D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.3750D+00*HCHO+...
     &                      +    9.3800D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.9380D+...
     &                      +    1.8800D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.1880D+...
     &                      +    3.7500D-01 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.3750D+...
     &                      +    5.0000D-01 * RXRAT( 312 )      ! OLE1+O3=0.5000D+00*HCHO+...
     &                      +    1.3100D-01 * RXRAT( 316 )      ! OLE2+O3=0.1310D+00*HCHO+...
     &                      +    1.2700D-01 * RXRAT( 323 )      ! TERP+O3=0.1270D+00*HCHO+...
     &                      +    1.2700D-01 * RXRAT( 327 )      ! SESQ+O3=0.1270D+00*HCHO+...
     &                      +                 RXRAT( 354 )      ! MEOH+CL=HCHO+HCL+HO2
      LOSS(  HCHO         ) =                 RXRAT( 132 )      ! HCHO=0.2000D+01*HO2+CO
     &                      +                 RXRAT( 133 )      ! HCHO=CO
     &                      +                 RXRAT( 134 )      ! HCHO+OH=HO2+CO
     &                      +                 RXRAT( 135 )      ! HCHO+NO3=HNO3+HO2+CO
     &                      +                 RXRAT( 352 )      ! HCHO+CL=HCL+HO2+CO

      PROD(  COOH         ) =                 RXRAT(  47 )      ! MEO2+HO2=COOH
      LOSS(  COOH         ) =                 RXRAT( 150 )      ! COOH+OH=0.3000D+00*HCHO+...
     &                      +                 RXRAT( 151 )      ! COOH=HCHO+HO2+OH

      PROD(  MEOH         ) =                 RXRAT(  50 )      ! MEO2+MEO2=MEOH+HCHO
     &                      +    2.5000D-01 * RXRAT(  55 )      ! RO2C+MEO2=0.2500D+00*MEOH+...
     &                      +    2.5000D-01 * RXRAT(  60 )      ! RO2XC+MEO2=0.2500D+00*MEOH+...
     &                      +    2.5000D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.2500D+...
      LOSS(  MEOH         ) =                 RXRAT( 146 )      ! MEOH+OH=HCHO+HO2
     &                      +                 RXRAT( 354 )      ! MEOH+CL=HCL+HCHO+HO2

      PROD(  RO2C         ) =    4.0000D-01 * RXRAT(  75 )      ! PAN2=0.4000D+00*RO2C+...
     &                      +                 RXRAT(  76 )      ! RCO3+NO=RO2C+NO2+xHO2+...
     &                      +    4.4000D-01 * RXRAT(  77 )      ! RCO3+HO2=0.4400D+00*RO2C+...
     &                      +                 RXRAT(  78 )      ! RCO3+NO3=RO2C+NO2+xHO2+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=RO2C+HO2+HCHO+...
     &                      +                 RXRAT(  81 )      ! RCO3+RO2XC=RO2C+xHO2+xCCHO+...
     &                      +                 RXRAT(  82 )      ! RCO3+MECO3=RO2C+MEO2+...
     &                      +    2.0000D+00 * RXRAT(  83 )      ! RCO3+RCO3=0.2000D+01*RO2C+...
     &                      +    4.0000D-01 * RXRAT(  86 )      ! PBZN=0.4000D+00*RO2C+...
     &                      +                 RXRAT(  87 )      ! BZCO3+NO=RO2C+CO2+BZO+NO2
     &                      +    4.4000D-01 * RXRAT(  88 )      ! BZCO3+HO2=0.4400D+00*RO2C+...
     &                      +                 RXRAT(  89 )      ! BZCO3+NO3=RO2C+CO2+BZO+NO2
     &                      +                 RXRAT(  90 )      ! BZCO3+MEO2=RO2C+HO2+HCHO+...
     &                      +                 RXRAT(  92 )      ! BZCO3+RO2XC=RO2C+BZO+CO2
     &                      +                 RXRAT(  93 )      ! BZCO3+MECO3=RO2C+MEO2+BZO+...
     &                      +    2.0000D+00 * RXRAT(  94 )      ! BZCO3+RCO3=0.2000D+01*RO2C+...
     &                      +    2.0000D+00 * RXRAT(  95 )      ! BZCO3+BZCO3=0.2000D+...
     &                      +                 RXRAT( 106 )      ! MACO3+RCO3=RO2C+MECO3+HCHO+...
     &                      +                 RXRAT( 107 )      ! MACO3+BZCO3=RO2C+MECO3+BZO+...
     &                      +                 RXRAT( 113 )      ! BZO=RO2C+CRES+xHO2
     &                      +    3.5000D-02 * RXRAT( 139 )      ! RCHO+OH=0.3500D-01*RO2C+...
     &                      +                 RXRAT( 140 )      ! RCHO=RO2C+xHO2+yROOH+xCCHO+...
     &                      +                 RXRAT( 142 )      ! ACETONE+OH=RO2C+xMECO3+...
     &                      +    9.6700D-01 * RXRAT( 144 )      ! MEK+OH=0.9670D+00*RO2C+...
     &                      +                 RXRAT( 145 )      ! MEK=RO2C+MECO3+xHO2+xCCHO+...
     &                      +    4.9100D-01 * RXRAT( 148 )      ! CCOOH+OH=0.4910D+00*RO2C+...
     &                      +                 RXRAT( 149 )      ! RCOOH+OH=RO2C+xHO2+0.1430D+...
     &                      +    2.5100D-01 * RXRAT( 152 )      ! ROOH+OH=0.2510D+00*RO2C+...
     &                      +    2.2200D-01 * RXRAT( 154 )      ! R6OOH+OH=0.2220D+00*RO2C+...
     &                      +    7.8200D-01 * RXRAT( 155 )      ! R6OOH=0.7820D+00*RO2C+...
     &                      +    5.8900D-01 * RXRAT( 156 )      ! RAOOH+OH=0.5890D+00*RO2C+...
     &                      +    8.0000D-01 * RXRAT( 166 )      ! CRES+OH=0.8000D+00*RO2C+...
     &                      +    7.2300D-01 * RXRAT( 174 )      ! AFG1+OH=0.7230D+00*RO2C+...
     &                      +    6.5200D-01 * RXRAT( 175 )      ! AFG1+O3=0.6520D+00*RO2C+...
     &                      +    7.2300D-01 * RXRAT( 177 )      ! AFG2+OH=0.7230D+00*RO2C+...
     &                      +    6.5200D-01 * RXRAT( 178 )      ! AFG2+O3=0.6520D+00*RO2C+...
     &                      +    7.3300D-01 * RXRAT( 180 )      ! AFG3+OH=0.7330D+00*RO2C+...
     &                      +    2.5800D-01 * RXRAT( 181 )      ! AFG3+O3=0.2580D+00*RO2C+...
     &                      +    5.0000D-01 * RXRAT( 182 )      ! MACR+OH=0.5000D+00*RO2C+...
     &                      +    1.0000D-01 * RXRAT( 183 )      ! MACR+O3=0.1000D+00*RO2C+...
     &                      +    5.0000D-01 * RXRAT( 184 )      ! MACR+NO3=0.5000D+00*RO2C+...
     &                      +    3.3000D-01 * RXRAT( 186 )      ! MACR=0.3300D+00*RO2C+...
     &                      +    9.7500D-01 * RXRAT( 187 )      ! MVK+OH=0.9750D+00*RO2C+...
     &                      +    5.0000D-02 * RXRAT( 188 )      ! MVK+O3=0.5000D-01*RO2C+...
     &                      +    6.7000D-01 * RXRAT( 191 )      ! IPRD+OH=0.6700D+00*RO2C+...
     &                      +    4.8000D-02 * RXRAT( 192 )      ! IPRD+O3=0.4800D-01*RO2C+...
     &                      +    7.9900D-01 * RXRAT( 193 )      ! IPRD+NO3=0.7990D+00*RO2C+...
     &                      +    4.7300D-01 * RXRAT( 195 )      ! PRD2+OH=0.4730D+00*RO2C+...
     &                      +    1.5900D+00 * RXRAT( 196 )      ! PRD2=0.1590D+01*RO2C+...
     &                      +    9.7600D-01 * RXRAT( 197 )      ! RNO3+OH=0.9760D+00*RO2C+...
     &                      +    7.2100D-01 * RXRAT( 198 )      ! RNO3=0.7210D+00*RO2C+...
     &                      +    2.5000D-01 * RXRAT( 202 )      ! ACROLEIN+OH=0.2500D+...
     &                      +    3.1000D-02 * RXRAT( 204 )      ! ACROLEIN+NO3=0.3100D-...
     &                      +    2.0000D-02 * RXRAT( 207 )      ! CCOOOH+OH=0.2000D-01*RO2C+...
     &                      +    1.9400D-01 * RXRAT( 209 )      ! RCOOOH+OH=0.1940D+00*RO2C+...
     &                      +                 RXRAT( 267 )      ! ETHENE+OH=RO2C+xHO2+...
     &                      +                 RXRAT( 269 )      ! ETHENE+NO3=RO2C+xHO2+xRCHO+...
     &                      +    2.9000D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.2900D+00*RO2C+...
     &                      +    9.8400D-01 * RXRAT( 271 )      ! PROPENE+OH=0.9840D+00*RO2C+...
     &                      +    9.4900D-01 * RXRAT( 273 )      ! PROPENE+NO3=0.9490D+...
     &                      +    1.1890D+00 * RXRAT( 275 )      ! BUTADIENE13+OH=0.1189D+...
     &                      +    1.0550D+00 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.1055D+...
     &                      +    2.3500D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.2350D+...
     &                      +    9.8600D-01 * RXRAT( 279 )      ! ISOPRENE+OH=0.9860D+...
     &                      +    1.9200D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1920D+...
     &                      +    9.3600D-01 * RXRAT( 281 )      ! ISOPRENE+NO3=0.9360D+...
     &                      +    2.4000D-01 * RXRAT( 282 )      ! ISOPRENE+O3P=0.2400D+...
     &                      +    3.5000D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.3500D+00*RO2C+...
     &                      +    9.0000D-02 * RXRAT( 285 )      ! ISOPOOH=0.9000D-01*RO2C+...
     &                      +    1.0420D+00 * RXRAT( 292 )      ! APIN+OH=0.1042D+01*RO2C+...
     &                      +    1.5110D+00 * RXRAT( 293 )      ! APIN+O3=0.1511D+01*RO2C+...
     &                      +    1.0500D+00 * RXRAT( 294 )      ! APIN+NO3=0.1050D+01*RO2C+...
     &                      +    2.9000D-01 * RXRAT( 298 )      ! BENZENE+OH=0.2900D+00*RO2C+...
     &                      +    4.5400D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.4540D+00*RO2C+...
     &                      +    5.2000D-01 * RXRAT( 300 )      ! MXYL+OH=0.5200D+00*RO2C+...
     &                      +    5.5400D-01 * RXRAT( 301 )      ! OXYL+OH=0.5540D+00*RO2C+...
     &                      +    4.8700D-01 * RXRAT( 302 )      ! PXYL+OH=0.4870D+00*RO2C+...
     &                      +    6.2700D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.6270D+...
     &                      +    5.0000D-02 * RXRAT( 304 )      ! ETOH+OH=0.5000D-01*RO2C+...
     &                      +                 RXRAT( 305 )      ! ALK1+OH=RO2C+xHO2+xCCHO+yROOH
     &                      +    9.6500D-01 * RXRAT( 306 )      ! ALK2+OH=0.9650D+00*RO2C+...
     &                      +    1.2530D+00 * RXRAT( 307 )      ! ALK3+OH=0.1253D+01*RO2C+...
     &                      +    1.7630D+00 * RXRAT( 308 )      ! ALK4+OH=0.1763D+01*RO2C+...
     &                      +    1.6050D+00 * RXRAT( 309 )      ! ALK5+OH=0.1605D+01*RO2C+...
     &                      +    1.2020D+00 * RXRAT( 311 )      ! OLE1+OH=0.1202D+01*RO2C+...
     &                      +    9.0000D-02 * RXRAT( 312 )      ! OLE1+O3=0.9000D-01*RO2C+...
     &                      +    1.4630D+00 * RXRAT( 313 )      ! OLE1+NO3=0.1463D+01*RO2C+...
     &                      +    9.5300D-01 * RXRAT( 315 )      ! OLE2+OH=0.9530D+00*RO2C+...
     &                      +    2.1200D-01 * RXRAT( 316 )      ! OLE2+O3=0.2120D+00*RO2C+...
     &                      +    1.1930D+00 * RXRAT( 317 )      ! OLE2+NO3=0.1193D+01*RO2C+...
     &                      +    5.6600D-01 * RXRAT( 319 )      ! ARO1+OH=0.5660D+00*RO2C+...
     &                      +    6.1700D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.6170D+00*RO2C+...
     &                      +    6.1700D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.6170D+...
     &                      +    1.2110D+00 * RXRAT( 322 )      ! TERP+OH=0.1211D+01*RO2C+...
     &                      +    4.9000D-01 * RXRAT( 323 )      ! TERP+O3=0.4900D+00*RO2C+...
     &                      +    1.7860D+00 * RXRAT( 324 )      ! TERP+NO3=0.1786D+01*RO2C+...
     &                      +    1.2110D+00 * RXRAT( 326 )      ! SESQ+OH=0.1211D+01*RO2C+...
     &                      +    4.9000D-01 * RXRAT( 327 )      ! SESQ+O3=0.4900D+00*RO2C+...
     &                      +    1.7860D+00 * RXRAT( 328 )      ! SESQ+NO3=0.1786D+01*RO2C+...
     &                      +    1.0000D-01 * RXRAT( 355 )      ! RCHO+CL=0.1000D+00*RO2C+...
     &                      +                 RXRAT( 356 )      ! ACETONE+CL=RO2C+HCL+xHCHO+...
     &                      +    9.7500D-01 * RXRAT( 357 )      ! MEK+CL=0.9750D+00*RO2C+HCL+...
     &                      +    1.2820D+00 * RXRAT( 358 )      ! RNO3+CL=0.1282D+01*RO2C+...
     &                      +    6.8000D-01 * RXRAT( 359 )      ! PRD2+CL=0.6800D+00*RO2C+...
     &                      +    5.8800D-01 * RXRAT( 364 )      ! ROOH+CL=0.5880D+00*RO2C+...
     &                      +    1.0780D+00 * RXRAT( 365 )      ! R6OOH+CL=0.1078D+01*RO2C+...
     &                      +    5.8900D-01 * RXRAT( 366 )      ! RAOOH+CL=0.5890D+00*RO2C+...
     &                      +    1.0320D+00 * RXRAT( 367 )      ! ACROLEIN+CL=0.1032D+...
     &                      +    8.0200D-01 * RXRAT( 368 )      ! MACR+CL=0.8020D+00*RO2C+...
     &                      +    1.2830D+00 * RXRAT( 369 )      ! MVK+CL=0.1283D+01*RO2C+...
     &                      +    7.3000D-01 * RXRAT( 370 )      ! IPRD+CL=0.7300D+00*RO2C+...
     &                      +                 RXRAT( 371 )      ! CLCCHO=RO2C+CO+HO2+xCL+...
     &                      +                 RXRAT( 374 )      ! CLACET=RO2C+MECO3+xCL+...
     &                      +    2.0000D+00 * RXRAT( 382 )      ! ETHENE+CL=0.2000D+01*RO2C+...
     &                      +    9.7100D-01 * RXRAT( 383 )      ! PROPENE+CL=0.9710D+00*RO2C+...
     &                      +    1.8840D+00 * RXRAT( 384 )      ! BUTADIENE13+CL=0.1884D+...
     &                      +    1.1680D+00 * RXRAT( 385 )      ! ISOPRENE+CL=0.1168D+...
     &                      +    2.2580D+00 * RXRAT( 386 )      ! APIN+CL=0.2258D+01*RO2C+...
     &                      +    8.9400D-01 * RXRAT( 388 )      ! TOLUENE+CL=0.8940D+00*RO2C+...
     &                      +    8.6400D-01 * RXRAT( 389 )      ! MXYL+CL=0.8640D+00*RO2C+...
     &                      +    8.6400D-01 * RXRAT( 390 )      ! OXYL+CL=0.8640D+00*RO2C+...
     &                      +    8.6400D-01 * RXRAT( 391 )      ! PXYL+CL=0.8640D+00*RO2C+...
     &                      +    8.3800D-01 * RXRAT( 392 )      ! TMBENZ124+CL=0.8380D+...
     &                      +    3.1200D-01 * RXRAT( 393 )      ! ETOH+CL=0.3120D+00*RO2C+...
     &                      +                 RXRAT( 394 )      ! ALK1+CL=RO2C+xHO2+HCL+...
     &                      +    9.7000D-01 * RXRAT( 395 )      ! ALK2+CL=0.9700D+00*RO2C+...
     &                      +    1.3610D+00 * RXRAT( 396 )      ! ALK3+CL=0.1361D+01*RO2C+...
     &                      +    1.7370D+00 * RXRAT( 397 )      ! ALK4+CL=0.1737D+01*RO2C+...
     &                      +    1.5410D+00 * RXRAT( 398 )      ! ALK5+CL=0.1541D+01*RO2C+...
     &                      +    1.6080D+00 * RXRAT( 399 )      ! OLE1+CL=0.1608D+01*RO2C+...
     &                      +    1.4920D+00 * RXRAT( 400 )      ! OLE2+CL=0.1492D+01*RO2C+...
     &                      +    8.4000D-01 * RXRAT( 401 )      ! ARO1+CL=0.8400D+00*RO2C+...
     &                      +    8.2800D-01 * RXRAT( 402 )      ! ARO2MN+CL=0.8280D+00*RO2C+...
     &                      +    8.2800D-01 * RXRAT( 403 )      ! NAPHTHAL+CL=0.8280D+...
     &                      +    2.2580D+00 * RXRAT( 404 )      ! TERP+CL=0.2258D+01*RO2C+...
     &                      +    2.2580D+00 * RXRAT( 405 )      ! SESQ+CL=0.2258D+01*RO2C+...
      LOSS(  RO2C         ) =                 RXRAT(  52 )      ! RO2C+NO=NO2
     &                      +                 RXRAT(  53 )      ! RO2C+HO2=
     &                      +                 RXRAT(  54 )      ! RO2C+NO3=NO2
     &                      +                 RXRAT(  55 )      ! RO2C+MEO2=0.5000D+00*HO2+...
     &                      +    2.0000D+00 * RXRAT(  56 )      ! RO2C+RO2C=
     &                      +                 RXRAT(  61 )      ! RO2C+RO2XC=
     &                      +                 RXRAT(  70 )      ! RO2C+MECO3=MEO2+CO2
     &                      +                 RXRAT( 103 )      ! RO2C+MACO3=CO2+HCHO+MECO3
     &                      +                 RXRAT( 290 )      ! RO2C+IEPOXOO=0.3630D+...

      PROD(  RO2XC        ) =    3.9000D-02 * RXRAT( 144 )      ! MEK+OH=0.3900D-01*RO2XC+...
     &                      +    4.0000D-03 * RXRAT( 152 )      ! ROOH+OH=0.4000D-02*RO2XC+...
     &                      +    2.9000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.2900D-01*RO2XC+...
     &                      +    7.7000D-02 * RXRAT( 155 )      ! R6OOH=0.7700D-01*RO2XC+...
     &                      +    1.2400D-01 * RXRAT( 156 )      ! RAOOH+OH=0.1240D+00*RO2XC+...
     &                      +    6.0000D-02 * RXRAT( 174 )      ! AFG1+OH=0.6000D-01*RO2XC+...
     &                      +    6.0000D-02 * RXRAT( 177 )      ! AFG2+OH=0.6000D-01*RO2XC+...
     &                      +    1.1700D-01 * RXRAT( 180 )      ! AFG3+OH=0.1170D+00*RO2XC+...
     &                      +    7.0000D-03 * RXRAT( 181 )      ! AFG3+O3=0.7000D-02*RO2XC+...
     &                      +    2.5000D-02 * RXRAT( 187 )      ! MVK+OH=0.2500D-01*RO2XC+...
     &                      +    4.1000D-02 * RXRAT( 191 )      ! IPRD+OH=0.4100D-01*RO2XC+...
     &                      +    5.1000D-02 * RXRAT( 193 )      ! IPRD+NO3=0.5100D-01*RO2XC+...
     &                      +    7.1000D-02 * RXRAT( 195 )      ! PRD2+OH=0.7100D-01*RO2XC+...
     &                      +    8.7000D-02 * RXRAT( 196 )      ! PRD2=0.8700D-01*RO2XC+...
     &                      +    1.7500D-01 * RXRAT( 197 )      ! RNO3+OH=0.1750D+00*RO2XC+...
     &                      +    1.0200D-01 * RXRAT( 198 )      ! RNO3=0.1020D+00*RO2XC+...
     &                      +    2.0000D-03 * RXRAT( 204 )      ! ACROLEIN+NO3=0.2000D-...
     &                      +    1.6000D-02 * RXRAT( 271 )      ! PROPENE+OH=0.1600D-...
     &                      +    5.1000D-02 * RXRAT( 273 )      ! PROPENE+NO3=0.5100D-...
     &                      +    4.9000D-02 * RXRAT( 275 )      ! BUTADIENE13+OH=0.4900D-...
     &                      +    6.5000D-02 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.6500D-...
     &                      +    1.5000D-02 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1500D-...
     &                      +    9.3000D-02 * RXRAT( 279 )      ! ISOPRENE+OH=0.9300D-...
     &                      +    8.0000D-03 * RXRAT( 280 )      ! ISOPRENE+O3=0.8000D-...
     &                      +    6.4000D-02 * RXRAT( 281 )      ! ISOPRENE+NO3=0.6400D-...
     &                      +    1.0000D-02 * RXRAT( 282 )      ! ISOPRENE+O3P=0.1000D-...
     &                      +    1.9700D-01 * RXRAT( 292 )      ! APIN+OH=0.1970D+00*RO2XC+...
     &                      +    3.3700D-01 * RXRAT( 293 )      ! APIN+O3=0.3370D+00*RO2XC+...
     &                      +    2.9300D-01 * RXRAT( 294 )      ! APIN+NO3=0.2930D+00*RO2XC+...
     &                      +    2.4000D-02 * RXRAT( 298 )      ! BENZENE+OH=0.2400D-...
     &                      +    5.4000D-02 * RXRAT( 299 )      ! TOLUENE+OH=0.5400D-...
     &                      +    8.2000D-02 * RXRAT( 300 )      ! MXYL+OH=0.8200D-01*RO2XC+...
     &                      +    8.7000D-02 * RXRAT( 301 )      ! OXYL+OH=0.8700D-01*RO2XC+...
     &                      +    7.6000D-02 * RXRAT( 302 )      ! PXYL+OH=0.7600D-01*RO2XC+...
     &                      +    1.2100D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.1210D+...
     &                      +    3.5000D-02 * RXRAT( 306 )      ! ALK2+OH=0.3500D-01*RO2XC+...
     &                      +    7.0000D-02 * RXRAT( 307 )      ! ALK3+OH=0.7000D-01*RO2XC+...
     &                      +    1.4900D-01 * RXRAT( 308 )      ! ALK4+OH=0.1490D+00*RO2XC+...
     &                      +    3.5300D-01 * RXRAT( 309 )      ! ALK5+OH=0.3530D+00*RO2XC+...
     &                      +    1.2800D-01 * RXRAT( 311 )      ! OLE1+OH=0.1280D+00*RO2XC+...
     &                      +    5.0000D-03 * RXRAT( 312 )      ! OLE1+O3=0.5000D-02*RO2XC+...
     &                      +    2.2800D-01 * RXRAT( 313 )      ! OLE1+NO3=0.2280D+00*RO2XC+...
     &                      +    8.8000D-02 * RXRAT( 315 )      ! OLE2+OH=0.8800D-01*RO2XC+...
     &                      +    3.0000D-03 * RXRAT( 316 )      ! OLE2+O3=0.3000D-02*RO2XC+...
     &                      +    1.4000D-01 * RXRAT( 317 )      ! OLE2+NO3=0.1400D+00*RO2XC+...
     &                      +    1.1000D-01 * RXRAT( 319 )      ! ARO1+OH=0.1100D+00*RO2XC+...
     &                      +    1.2800D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.1280D+00*RO2XC+...
     &                      +    1.2800D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.1280D+...
     &                      +    2.0100D-01 * RXRAT( 322 )      ! TERP+OH=0.2010D+00*RO2XC+...
     &                      +    1.2100D-01 * RXRAT( 323 )      ! TERP+O3=0.1210D+00*RO2XC+...
     &                      +    4.6000D-01 * RXRAT( 324 )      ! TERP+NO3=0.4600D+00*RO2XC+...
     &                      +    2.0100D-01 * RXRAT( 326 )      ! SESQ+OH=0.2010D+00*RO2XC+...
     &                      +    1.2100D-01 * RXRAT( 327 )      ! SESQ+O3=0.1210D+00*RO2XC+...
     &                      +    4.6000D-01 * RXRAT( 328 )      ! SESQ+NO3=0.4600D+00*RO2XC+...
     &                      +    3.9000D-02 * RXRAT( 357 )      ! MEK+CL=0.3900D-01*RO2XC+...
     &                      +    2.0200D-01 * RXRAT( 358 )      ! RNO3+CL=0.2020D+00*RO2XC+...
     &                      +    1.1600D-01 * RXRAT( 359 )      ! PRD2+CL=0.1160D+00*RO2XC+...
     &                      +    1.1700D-01 * RXRAT( 365 )      ! R6OOH+CL=0.1170D+00*RO2XC+...
     &                      +    1.2400D-01 * RXRAT( 366 )      ! RAOOH+CL=0.1240D+00*RO2XC+...
     &                      +    2.6000D-02 * RXRAT( 367 )      ! ACROLEIN+CL=0.2600D-...
     &                      +    3.3000D-02 * RXRAT( 368 )      ! MACR+CL=0.3300D-01*RO2XC+...
     &                      +    5.3000D-02 * RXRAT( 369 )      ! MVK+CL=0.5300D-01*RO2XC+...
     &                      +    5.1000D-02 * RXRAT( 370 )      ! IPRD+CL=0.5100D-01*RO2XC+...
     &                      +    2.9000D-02 * RXRAT( 383 )      ! PROPENE+CL=0.2900D-...
     &                      +    6.9000D-02 * RXRAT( 384 )      ! BUTADIENE13+CL=0.6900D-...
     &                      +    8.5000D-02 * RXRAT( 385 )      ! ISOPRENE+CL=0.8500D-...
     &                      +    5.8200D-01 * RXRAT( 386 )      ! APIN+CL=0.5820D+00*RO2XC+...
     &                      +    1.0600D-01 * RXRAT( 388 )      ! TOLUENE+CL=0.1060D+...
     &                      +    1.3600D-01 * RXRAT( 389 )      ! MXYL+CL=0.1360D+00*RO2XC+...
     &                      +    1.3600D-01 * RXRAT( 390 )      ! OXYL+CL=0.1360D+00*RO2XC+...
     &                      +    1.3600D-01 * RXRAT( 391 )      ! PXYL+CL=0.1360D+00*RO2XC+...
     &                      +    1.6200D-01 * RXRAT( 392 )      ! TMBENZ124+CL=0.1620D+...
     &                      +    3.0000D-02 * RXRAT( 395 )      ! ALK2+CL=0.3000D-01*RO2XC+...
     &                      +    7.0000D-02 * RXRAT( 396 )      ! ALK3+CL=0.7000D-01*RO2XC+...
     &                      +    1.6500D-01 * RXRAT( 397 )      ! ALK4+CL=0.1650D+00*RO2XC+...
     &                      +    3.5200D-01 * RXRAT( 398 )      ! ALK5+CL=0.3520D+00*RO2XC+...
     &                      +    1.2700D-01 * RXRAT( 399 )      ! OLE1+CL=0.1270D+00*RO2XC+...
     &                      +    1.0600D-01 * RXRAT( 400 )      ! OLE2+CL=0.1060D+00*RO2XC+...
     &                      +    1.6000D-01 * RXRAT( 401 )      ! ARO1+CL=0.1600D+00*RO2XC+...
     &                      +    1.7200D-01 * RXRAT( 402 )      ! ARO2MN+CL=0.1720D+00*RO2XC+...
     &                      +    1.7200D-01 * RXRAT( 403 )      ! NAPHTHAL+CL=0.1720D+...
     &                      +    5.8200D-01 * RXRAT( 404 )      ! TERP+CL=0.5820D+00*RO2XC+...
     &                      +    5.8200D-01 * RXRAT( 405 )      ! SESQ+CL=0.5820D+00*RO2XC+...
      LOSS(  RO2XC        ) =                 RXRAT(  57 )      ! RO2XC+NO=
     &                      +                 RXRAT(  58 )      ! RO2XC+HO2=
     &                      +                 RXRAT(  59 )      ! RO2XC+NO3=NO2
     &                      +                 RXRAT(  60 )      ! RO2XC+MEO2=0.5000D+00*HO2+...
     &                      +                 RXRAT(  61 )      ! RO2XC+RO2C=
     &                      +    2.0000D+00 * RXRAT(  62 )      ! RO2XC+RO2XC=
     &                      +                 RXRAT(  71 )      ! RO2XC+MECO3=MEO2+CO2
     &                      +                 RXRAT(  81 )      ! RO2XC+RCO3=RO2C+xHO2+xCCHO+...
     &                      +                 RXRAT(  92 )      ! RO2XC+BZCO3=RO2C+BZO+CO2
     &                      +                 RXRAT( 104 )      ! RO2XC+MACO3=CO2+HCHO+MECO3

      PROD(  CCOOOH       ) =    1.0500D-01 * RXRAT(  67 )      ! MECO3+HO2=0.1050D+...
      LOSS(  CCOOOH       ) =                 RXRAT( 207 )      ! CCOOOH+OH=0.9800D+00*MECO3+...
     &                      +                 RXRAT( 208 )      ! CCOOOH=MEO2+CO2+OH

      PROD(  CCOOH        ) =    4.5000D-02 * RXRAT(  67 )      ! MECO3+HO2=0.4500D-01*CCOOH+...
     &                      +    1.0000D-01 * RXRAT(  69 )      ! MECO3+MEO2=0.1000D+...
     &                      +    5.0000D-02 * RXRAT( 206 )      ! ACROLEIN=0.5000D-01*CCOOH+...
     &                      +    7.5000D-02 * RXRAT( 272 )      ! PROPENE+O3=0.7500D-...
     &                      +    6.5000D-02 * RXRAT( 316 )      ! OLE2+O3=0.6500D-01*CCOOH+...
      LOSS(  CCOOH        ) =                 RXRAT( 148 )      ! CCOOH+OH=0.5090D+00*MEO2+...

      PROD(  RCO3         ) =                 RXRAT(  74 )      ! PAN2=RCO3+NO2
     &                      +    6.0000D-01 * RXRAT(  75 )      ! PAN2=0.6000D+00*RCO3+...
     &                      +                 RXRAT( 124 )      ! xRCO3=RCO3
     &                      +    9.6500D-01 * RXRAT( 139 )      ! RCHO+OH=0.9650D+00*RCO3+...
     &                      +                 RXRAT( 141 )      ! RCHO+NO3=RCO3+HNO3
     &                      +    3.0000D-01 * RXRAT( 194 )      ! IPRD=0.3000D+00*RCO3+...
     &                      +    6.0000D-01 * RXRAT( 196 )      ! PRD2=0.6000D+00*RCO3+...
     &                      +    8.0600D-01 * RXRAT( 209 )      ! RCOOOH+OH=0.8060D+00*RCO3+...
     &                      +    9.0000D-01 * RXRAT( 355 )      ! RCHO+CL=0.9000D+00*RCO3+...
     &                      +    3.7000D-01 * RXRAT( 360 )      ! GLY+CL=0.3700D+00*RCO3+...
     &                      +                 RXRAT( 372 )      ! CLCCHO+OH=RCO3
     &                      +                 RXRAT( 373 )      ! CLCCHO+CL=RCO3+HCL
      LOSS(  RCO3         ) =                 RXRAT(  73 )      ! RCO3+NO2=PAN2
     &                      +                 RXRAT(  76 )      ! RCO3+NO=NO2+RO2C+xHO2+...
     &                      +                 RXRAT(  77 )      ! RCO3+HO2=0.3075D+00*RCOOOH+...
     &                      +                 RXRAT(  78 )      ! RCO3+NO3=NO2+RO2C+xHO2+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=HCHO+HO2+RO2C+...
     &                      +                 RXRAT(  80 )      ! RCO3+RO2C=RO2C+xHO2+xCCHO+...
     &                      +                 RXRAT(  81 )      ! RCO3+RO2XC=RO2C+xHO2+xCCHO+...
     &                      +                 RXRAT(  82 )      ! RCO3+MECO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT(  83 )      ! RCO3+RCO3=0.2000D+01*RO2C+...
     &                      +                 RXRAT(  94 )      ! RCO3+BZCO3=0.2000D+01*CO2+...
     &                      +                 RXRAT( 106 )      ! RCO3+MACO3=HCHO+MECO3+RO2C+...

      PROD(  PAN2         ) =                 RXRAT(  73 )      ! RCO3+NO2=PAN2
      LOSS(  PAN2         ) =                 RXRAT(  74 )      ! PAN2=RCO3+NO2
     &                      +                 RXRAT(  75 )      ! PAN2=0.6000D+00*RCO3+...

      PROD(  xHO2         ) =    4.0000D-01 * RXRAT(  75 )      ! PAN2=0.4000D+00*xHO2+...
     &                      +                 RXRAT(  76 )      ! RCO3+NO=xHO2+RO2C+NO2+...
     &                      +    4.4000D-01 * RXRAT(  77 )      ! RCO3+HO2=0.4400D+00*xHO2+...
     &                      +                 RXRAT(  78 )      ! RCO3+NO3=xHO2+RO2C+NO2+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=xHO2+HO2+RO2C+...
     &                      +                 RXRAT(  80 )      ! RCO3+RO2C=xHO2+RO2C+xCCHO+...
     &                      +                 RXRAT(  81 )      ! RCO3+RO2XC=xHO2+RO2C+xCCHO+...
     &                      +                 RXRAT(  82 )      ! RCO3+MECO3=xHO2+MEO2+RO2C+...
     &                      +    2.0000D+00 * RXRAT(  83 )      ! RCO3+RCO3=0.2000D+01*xHO2+...
     &                      +                 RXRAT(  94 )      ! BZCO3+RCO3=xHO2+0.2000D+...
     &                      +                 RXRAT( 106 )      ! MACO3+RCO3=xHO2+MECO3+RO2C+...
     &                      +                 RXRAT( 113 )      ! BZO=xHO2+RO2C+CRES
     &                      +    3.5000D-02 * RXRAT( 139 )      ! RCHO+OH=0.3500D-01*xHO2+...
     &                      +                 RXRAT( 140 )      ! RCHO=xHO2+RO2C+yROOH+xCCHO+...
     &                      +    3.7600D-01 * RXRAT( 144 )      ! MEK+OH=0.3760D+00*xHO2+...
     &                      +                 RXRAT( 145 )      ! MEK=xHO2+RO2C+MECO3+xCCHO+...
     &                      +    4.9100D-01 * RXRAT( 148 )      ! CCOOH+OH=0.4910D+00*xHO2+...
     &                      +                 RXRAT( 149 )      ! RCOOH+OH=xHO2+RO2C+0.1430D+...
     &                      +    2.3900D-01 * RXRAT( 152 )      ! ROOH+OH=0.2390D+00*xHO2+...
     &                      +    9.0000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.9000D-01*xHO2+...
     &                      +    7.8200D-01 * RXRAT( 155 )      ! R6OOH=0.7820D+00*xHO2+...
     &                      +    5.6500D-01 * RXRAT( 156 )      ! RAOOH+OH=0.5650D+00*xHO2+...
     &                      +    8.0000D-01 * RXRAT( 166 )      ! CRES+OH=0.8000D+00*xHO2+...
     &                      +    5.2100D-01 * RXRAT( 174 )      ! AFG1+OH=0.5210D+00*xHO2+...
     &                      +    5.2100D-01 * RXRAT( 177 )      ! AFG2+OH=0.5210D+00*xHO2+...
     &                      +    5.6100D-01 * RXRAT( 180 )      ! AFG3+OH=0.5610D+00*xHO2+...
     &                      +    9.5000D-02 * RXRAT( 181 )      ! AFG3+O3=0.9500D-01*xHO2+...
     &                      +    5.0000D-01 * RXRAT( 182 )      ! MACR+OH=0.5000D+00*xHO2+...
     &                      +    5.0000D-01 * RXRAT( 184 )      ! MACR+NO3=0.5000D+00*xHO2+...
     &                      +    3.0000D-01 * RXRAT( 187 )      ! MVK+OH=0.3000D+00*xHO2+...
     &                      +    5.0000D-02 * RXRAT( 188 )      ! MVK+O3=0.5000D-01*xHO2+...
     &                      +    6.7000D-01 * RXRAT( 191 )      ! IPRD+OH=0.6700D+00*xHO2+...
     &                      +    7.9900D-01 * RXRAT( 193 )      ! IPRD+NO3=0.7990D+00*xHO2+...
     &                      +    3.7900D-01 * RXRAT( 195 )      ! PRD2+OH=0.3790D+00*xHO2+...
     &                      +    9.1300D-01 * RXRAT( 196 )      ! PRD2=0.9130D+00*xHO2+...
     &                      +    3.0500D-01 * RXRAT( 197 )      ! RNO3+OH=0.3050D+00*xHO2+...
     &                      +    5.5400D-01 * RXRAT( 198 )      ! RNO3=0.5540D+00*xHO2+...
     &                      +    2.5000D-01 * RXRAT( 202 )      ! ACROLEIN+OH=0.2500D+...
     &                      +    3.1000D-02 * RXRAT( 204 )      ! ACROLEIN+NO3=0.3100D-...
     &                      +    8.4000D-02 * RXRAT( 209 )      ! RCOOOH+OH=0.8400D-01*xHO2+...
     &                      +                 RXRAT( 267 )      ! ETHENE+OH=xHO2+RO2C+...
     &                      +                 RXRAT( 269 )      ! ETHENE+NO3=xHO2+RO2C+xRCHO+...
     &                      +    2.9000D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.2900D+00*xHO2+...
     &                      +    9.8400D-01 * RXRAT( 271 )      ! PROPENE+OH=0.9840D+00*xHO2+...
     &                      +    9.4900D-01 * RXRAT( 273 )      ! PROPENE+NO3=0.9490D+...
     &                      +    9.5100D-01 * RXRAT( 275 )      ! BUTADIENE13+OH=0.9510D+...
     &                      +    8.1500D-01 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.8150D+...
     &                      +    1.1700D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1170D+...
     &                      +    9.0700D-01 * RXRAT( 279 )      ! ISOPRENE+OH=0.9070D+...
     &                      +    7.4900D-01 * RXRAT( 281 )      ! ISOPRENE+NO3=0.7490D+...
     &                      +    3.1000D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.3100D+00*xHO2+...
     &                      +    7.9900D-01 * RXRAT( 292 )      ! APIN+OH=0.7990D+00*xHO2+...
     &                      +    1.0200D-01 * RXRAT( 293 )      ! APIN+O3=0.1020D+00*xHO2+...
     &                      +    5.6000D-02 * RXRAT( 294 )      ! APIN+NO3=0.5600D-01*xHO2+...
     &                      +    2.9000D-01 * RXRAT( 298 )      ! BENZENE+OH=0.2900D+00*xHO2+...
     &                      +    4.5400D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.4540D+00*xHO2+...
     &                      +    5.2000D-01 * RXRAT( 300 )      ! MXYL+OH=0.5200D+00*xHO2+...
     &                      +    5.5400D-01 * RXRAT( 301 )      ! OXYL+OH=0.5540D+00*xHO2+...
     &                      +    4.8700D-01 * RXRAT( 302 )      ! PXYL+OH=0.4870D+00*xHO2+...
     &                      +    6.2700D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.6270D+...
     &                      +    5.0000D-02 * RXRAT( 304 )      ! ETOH+OH=0.5000D-01*xHO2+...
     &                      +                 RXRAT( 305 )      ! ALK1+OH=xHO2+RO2C+xCCHO+yROOH
     &                      +    9.6500D-01 * RXRAT( 306 )      ! ALK2+OH=0.9650D+00*xHO2+...
     &                      +    6.9500D-01 * RXRAT( 307 )      ! ALK3+OH=0.6950D+00*xHO2+...
     &                      +    8.3000D-01 * RXRAT( 308 )      ! ALK4+OH=0.8300D+00*xHO2+...
     &                      +    6.4700D-01 * RXRAT( 309 )      ! ALK5+OH=0.6470D+00*xHO2+...
     &                      +    8.7100D-01 * RXRAT( 311 )      ! OLE1+OH=0.8710D+00*xHO2+...
     &                      +    5.7000D-02 * RXRAT( 312 )      ! OLE1+O3=0.5700D-01*xHO2+...
     &                      +    7.7200D-01 * RXRAT( 313 )      ! OLE1+NO3=0.7720D+00*xHO2+...
     &                      +    9.1200D-01 * RXRAT( 315 )      ! OLE2+OH=0.9120D+00*xHO2+...
     &                      +    4.1000D-02 * RXRAT( 316 )      ! OLE2+O3=0.4100D-01*xHO2+...
     &                      +    4.0000D-01 * RXRAT( 317 )      ! OLE2+NO3=0.4000D+00*xHO2+...
     &                      +    5.6600D-01 * RXRAT( 319 )      ! ARO1+OH=0.5660D+00*xHO2+...
     &                      +    6.1700D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.6170D+00*xHO2+...
     &                      +    6.1700D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.6170D+...
     &                      +    7.3400D-01 * RXRAT( 322 )      ! TERP+OH=0.7340D+00*xHO2+...
     &                      +    4.6000D-02 * RXRAT( 323 )      ! TERP+O3=0.4600D-01*xHO2+...
     &                      +    2.2700D-01 * RXRAT( 324 )      ! TERP+NO3=0.2270D+00*xHO2+...
     &                      +    7.3400D-01 * RXRAT( 326 )      ! SESQ+OH=0.7340D+00*xHO2+...
     &                      +    4.6000D-02 * RXRAT( 327 )      ! SESQ+O3=0.4600D-01*xHO2+...
     &                      +    2.2700D-01 * RXRAT( 328 )      ! SESQ+NO3=0.2270D+00*xHO2+...
     &                      +    1.0000D-01 * RXRAT( 355 )      ! RCHO+CL=0.1000D+00*xHO2+...
     &                      +    8.4000D-01 * RXRAT( 357 )      ! MEK+CL=0.8400D+00*xHO2+...
     &                      +    5.4700D-01 * RXRAT( 358 )      ! RNO3+CL=0.5470D+00*xHO2+...
     &                      +    5.4100D-01 * RXRAT( 359 )      ! PRD2+CL=0.5410D+00*xHO2+...
     &                      +                 RXRAT( 362 )      ! CRES+CL=xHO2+HCL+xBALD+yR6OOH
     &                      +    4.8200D-01 * RXRAT( 364 )      ! ROOH+CL=0.4820D+00*xHO2+...
     &                      +    2.3700D-01 * RXRAT( 365 )      ! R6OOH+CL=0.2370D+00*xHO2+...
     &                      +    5.6500D-01 * RXRAT( 366 )      ! RAOOH+CL=0.5650D+00*xHO2+...
     &                      +    4.8400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.4840D+...
     &                      +    8.0200D-01 * RXRAT( 368 )      ! MACR+CL=0.8020D+00*xHO2+...
     &                      +    3.2200D-01 * RXRAT( 369 )      ! MVK+CL=0.3220D+00*xHO2+...
     &                      +    7.1200D-01 * RXRAT( 370 )      ! IPRD+CL=0.7120D+00*xHO2+...
     &                      +                 RXRAT( 382 )      ! ETHENE+CL=xHO2+0.2000D+...
     &                      +    9.7100D-01 * RXRAT( 383 )      ! PROPENE+CL=0.9710D+00*xHO2+...
     &                      +    3.9000D-01 * RXRAT( 384 )      ! BUTADIENE13+CL=0.3900D+...
     &                      +    7.3800D-01 * RXRAT( 385 )      ! ISOPRENE+CL=0.7380D+...
     &                      +    2.5200D-01 * RXRAT( 386 )      ! APIN+CL=0.2520D+00*xHO2+...
     &                      +    8.9400D-01 * RXRAT( 388 )      ! TOLUENE+CL=0.8940D+00*xHO2+...
     &                      +    8.6400D-01 * RXRAT( 389 )      ! MXYL+CL=0.8640D+00*xHO2+...
     &                      +    8.6400D-01 * RXRAT( 390 )      ! OXYL+CL=0.8640D+00*xHO2+...
     &                      +    8.6400D-01 * RXRAT( 391 )      ! PXYL+CL=0.8640D+00*xHO2+...
     &                      +    8.3800D-01 * RXRAT( 392 )      ! TMBENZ124+CL=0.8380D+...
     &                      +    3.1200D-01 * RXRAT( 393 )      ! ETOH+CL=0.3120D+00*xHO2+...
     &                      +                 RXRAT( 394 )      ! ALK1+CL=xHO2+HCL+RO2C+...
     &                      +    9.7000D-01 * RXRAT( 395 )      ! ALK2+CL=0.9700D+00*xHO2+...
     &                      +    8.3500D-01 * RXRAT( 396 )      ! ALK3+CL=0.8350D+00*xHO2+...
     &                      +    8.2700D-01 * RXRAT( 397 )      ! ALK4+CL=0.8270D+00*xHO2+...
     &                      +    6.4700D-01 * RXRAT( 398 )      ! ALK5+CL=0.6470D+00*xHO2+...
     &                      +    8.7300D-01 * RXRAT( 399 )      ! OLE1+CL=0.8730D+00*xHO2+...
     &                      +    4.5000D-01 * RXRAT( 400 )      ! OLE2+CL=0.4500D+00*xHO2+...
     &                      +    8.4000D-01 * RXRAT( 401 )      ! ARO1+CL=0.8400D+00*xHO2+...
     &                      +    8.2800D-01 * RXRAT( 402 )      ! ARO2MN+CL=0.8280D+00*xHO2+...
     &                      +    8.2800D-01 * RXRAT( 403 )      ! NAPHTHAL+CL=0.8280D+...
     &                      +    2.5200D-01 * RXRAT( 404 )      ! TERP+CL=0.2520D+00*xHO2+...
     &                      +    2.5200D-01 * RXRAT( 405 )      ! SESQ+CL=0.2520D+00*xHO2+...
      LOSS(  xHO2         ) =                 RXRAT( 114 )      ! xHO2=HO2
     &                      +                 RXRAT( 115 )      ! xHO2=

      PROD(  yROOH        ) =    4.0000D-01 * RXRAT(  75 )      ! PAN2=0.4000D+00*yROOH+...
     &                      +                 RXRAT(  76 )      ! RCO3+NO=yROOH+RO2C+xHO2+...
     &                      +    4.4000D-01 * RXRAT(  77 )      ! RCO3+HO2=0.4400D+00*yROOH+...
     &                      +                 RXRAT(  78 )      ! RCO3+NO3=yROOH+RO2C+xHO2+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=yROOH+HO2+RO2C+...
     &                      +                 RXRAT(  80 )      ! RCO3+RO2C=yROOH+xHO2+xCCHO+...
     &                      +                 RXRAT(  81 )      ! RCO3+RO2XC=yROOH+xHO2+...
     &                      +                 RXRAT(  82 )      ! RCO3+MECO3=yROOH+MEO2+RO2C+...
     &                      +    2.0000D+00 * RXRAT(  83 )      ! RCO3+RCO3=0.2000D+01*yROOH+...
     &                      +                 RXRAT(  94 )      ! BZCO3+RCO3=yROOH+0.2000D+...
     &                      +                 RXRAT( 106 )      ! MACO3+RCO3=yROOH+MECO3+...
     &                      +    3.5000D-02 * RXRAT( 139 )      ! RCHO+OH=0.3500D-01*yROOH+...
     &                      +                 RXRAT( 140 )      ! RCHO=yROOH+xHO2+RO2C+xCCHO+...
     &                      +                 RXRAT( 142 )      ! ACETONE+OH=yROOH+xMECO3+...
     &                      +                 RXRAT( 144 )      ! MEK+OH=yROOH+0.3900D-...
     &                      +                 RXRAT( 145 )      ! MEK=yROOH+RO2C+xHO2+xCCHO+...
     &                      +    4.9100D-01 * RXRAT( 148 )      ! CCOOH+OH=0.4910D+00*yROOH+...
     &                      +                 RXRAT( 149 )      ! RCOOH+OH=yROOH+xHO2+...
     &                      +    2.5600D-01 * RXRAT( 152 )      ! ROOH+OH=0.2560D+00*yROOH+...
     &                      +    1.6000D-01 * RXRAT( 154 )      ! R6OOH+OH=0.1600D+00*yROOH+...
     &                      +    5.0000D-01 * RXRAT( 182 )      ! MACR+OH=0.5000D+00*yROOH+...
     &                      +    1.0000D-01 * RXRAT( 183 )      ! MACR+O3=0.1000D+00*yROOH+...
     &                      +    5.0000D-01 * RXRAT( 184 )      ! MACR+NO3=0.5000D+00*yROOH+...
     &                      +    3.3000D-01 * RXRAT( 186 )      ! MACR=0.3300D+00*yROOH+...
     &                      +                 RXRAT( 187 )      ! MVK+OH=yROOH+0.2500D-...
     &                      +    5.0000D-02 * RXRAT( 188 )      ! MVK+O3=0.5000D-01*yROOH+...
     &                      +    1.5700D-01 * RXRAT( 197 )      ! RNO3+OH=0.1570D+00*yROOH+...
     &                      +    6.6000D-02 * RXRAT( 198 )      ! RNO3=0.6600D-01*yROOH+...
     &                      +    2.5000D-01 * RXRAT( 202 )      ! ACROLEIN+OH=0.2500D+...
     &                      +    3.3000D-02 * RXRAT( 204 )      ! ACROLEIN+NO3=0.3300D-...
     &                      +    2.0000D-02 * RXRAT( 207 )      ! CCOOOH+OH=0.2000D-01*yROOH+...
     &                      +    1.9400D-01 * RXRAT( 209 )      ! RCOOOH+OH=0.1940D+00*yROOH+...
     &                      +                 RXRAT( 267 )      ! ETHENE+OH=yROOH+RO2C+...
     &                      +                 RXRAT( 269 )      ! ETHENE+NO3=yROOH+RO2C+...
     &                      +    2.9000D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.2900D+...
     &                      +                 RXRAT( 271 )      ! PROPENE+OH=yROOH+0.9840D+...
     &                      +                 RXRAT( 273 )      ! PROPENE+NO3=yROOH+0.9490D+...
     &                      +                 RXRAT( 275 )      ! BUTADIENE13+OH=yROOH+...
     &                      +                 RXRAT( 277 )      ! BUTADIENE13+NO3=yROOH+...
     &                      +    2.5000D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.2500D+...
     &                      +    5.0000D-02 * RXRAT( 304 )      ! ETOH+OH=0.5000D-01*yROOH+...
     &                      +                 RXRAT( 305 )      ! ALK1+OH=yROOH+RO2C+xCCHO+xHO2
     &                      +                 RXRAT( 306 )      ! ALK2+OH=yROOH+0.9650D+...
     &                      +    9.8300D-01 * RXRAT( 307 )      ! ALK3+OH=0.9830D+00*yROOH+...
     &                      +    1.6900D-01 * RXRAT( 311 )      ! OLE1+OH=0.1690D+00*yROOH+...
     &                      +    1.1000D-02 * RXRAT( 312 )      ! OLE1+O3=0.1100D-01*yROOH+...
     &                      +    1.6900D-01 * RXRAT( 313 )      ! OLE1+NO3=0.1690D+00*yROOH+...
     &                      +    3.1900D-01 * RXRAT( 315 )      ! OLE2+OH=0.3190D+00*yROOH+...
     &                      +    7.3000D-02 * RXRAT( 316 )      ! OLE2+O3=0.7300D-01*yROOH+...
     &                      +    3.1900D-01 * RXRAT( 317 )      ! OLE2+NO3=0.3190D+00*yROOH+...
     &                      +    1.0000D-01 * RXRAT( 355 )      ! RCHO+CL=0.1000D+00*yROOH+...
     &                      +                 RXRAT( 356 )      ! ACETONE+CL=yROOH+RO2C+...
     &                      +                 RXRAT( 357 )      ! MEK+CL=yROOH+0.9750D+...
     &                      +    5.8600D-01 * RXRAT( 364 )      ! ROOH+CL=0.5860D+00*yROOH+...
     &                      +    7.8400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.7840D+...
     &                      +    8.3500D-01 * RXRAT( 368 )      ! MACR+CL=0.8350D+00*yROOH+...
     &                      +                 RXRAT( 369 )      ! MVK+CL=yROOH+0.5300D-...
     &                      +                 RXRAT( 371 )      ! CLCCHO=yROOH+CO+RO2C+xCL+...
     &                      +                 RXRAT( 374 )      ! CLACET=yROOH+RO2C+xCL+...
     &                      +                 RXRAT( 383 )      ! PROPENE+CL=yROOH+0.9710D+...
     &                      +                 RXRAT( 384 )      ! BUTADIENE13+CL=yROOH+...
     &                      +    3.1200D-01 * RXRAT( 393 )      ! ETOH+CL=0.3120D+00*yROOH+...
     &                      +                 RXRAT( 394 )      ! ALK1+CL=yROOH+xHO2+RO2C+...
     &                      +                 RXRAT( 395 )      ! ALK2+CL=yROOH+0.9700D+...
     &                      +    9.8300D-01 * RXRAT( 396 )      ! ALK3+CL=0.9830D+00*yROOH+...
     &                      +    1.6900D-01 * RXRAT( 399 )      ! OLE1+CL=0.1690D+00*yROOH+...
     &                      +    3.1900D-01 * RXRAT( 400 )      ! OLE2+CL=0.3190D+00*yROOH+...
      LOSS(  yROOH        ) =                 RXRAT( 250 )      ! yROOH=ROOH
     &                      +                 RXRAT( 251 )      ! yROOH=MEK
     &                      +                 RXRAT( 252 )      ! yROOH=

      PROD(  xCCHO        ) =    4.0000D-01 * RXRAT(  75 )      ! PAN2=0.4000D+00*xCCHO+...
     &                      +                 RXRAT(  76 )      ! RCO3+NO=xCCHO+RO2C+xHO2+...
     &                      +    4.4000D-01 * RXRAT(  77 )      ! RCO3+HO2=0.4400D+00*xCCHO+...
     &                      +                 RXRAT(  78 )      ! RCO3+NO3=xCCHO+RO2C+xHO2+...
     &                      +                 RXRAT(  79 )      ! RCO3+MEO2=xCCHO+HO2+RO2C+...
     &                      +                 RXRAT(  80 )      ! RCO3+RO2C=xCCHO+xHO2+RO2C+...
     &                      +                 RXRAT(  81 )      ! RCO3+RO2XC=xCCHO+xHO2+RO2C+...
     &                      +                 RXRAT(  82 )      ! RCO3+MECO3=xCCHO+MEO2+RO2C+...
     &                      +    2.0000D+00 * RXRAT(  83 )      ! RCO3+RCO3=0.2000D+01*xCCHO+...
     &                      +                 RXRAT(  94 )      ! BZCO3+RCO3=xCCHO+0.2000D+...
     &                      +                 RXRAT( 106 )      ! MACO3+RCO3=xCCHO+MECO3+...
     &                      +    3.5000D-02 * RXRAT( 139 )      ! RCHO+OH=0.3500D-01*xCCHO+...
     &                      +                 RXRAT( 140 )      ! RCHO=xCCHO+xHO2+yROOH+RO2C+...
     &                      +    5.0400D-01 * RXRAT( 144 )      ! MEK+OH=0.5040D+00*xCCHO+...
     &                      +                 RXRAT( 145 )      ! MEK=xCCHO+RO2C+xHO2+MECO3+...
     &                      +    1.4200D-01 * RXRAT( 149 )      ! RCOOH+OH=0.1420D+00*xCCHO+...
     &                      +    1.2000D-02 * RXRAT( 152 )      ! ROOH+OH=0.1200D-01*xCCHO+...
     &                      +    2.0000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.2000D-01*xCCHO+...
     &                      +    2.6000D-02 * RXRAT( 155 )      ! R6OOH=0.2600D-01*xCCHO+...
     &                      +    8.3000D-02 * RXRAT( 195 )      ! PRD2+OH=0.8300D-01*xCCHO+...
     &                      +    1.6300D-01 * RXRAT( 196 )      ! PRD2=0.1630D+00*xCCHO+...
     &                      +    4.2900D-01 * RXRAT( 197 )      ! RNO3+OH=0.4290D+00*xCCHO+...
     &                      +    2.3000D-01 * RXRAT( 198 )      ! RNO3=0.2300D+00*xCCHO+...
     &                      +    1.6700D-01 * RXRAT( 202 )      ! ACROLEIN+OH=0.1670D+...
     &                      +    1.1000D-01 * RXRAT( 209 )      ! RCOOOH+OH=0.1100D+00*xCCHO+...
     &                      +    9.8400D-01 * RXRAT( 271 )      ! PROPENE+OH=0.9840D+...
     &                      +                 RXRAT( 305 )      ! ALK1+OH=xCCHO+RO2C+xHO2+yROOH
     &                      +    4.4500D-01 * RXRAT( 307 )      ! ALK3+OH=0.4450D+00*xCCHO+...
     &                      +    4.3800D-01 * RXRAT( 308 )      ! ALK4+OH=0.4380D+00*xCCHO+...
     &                      +    1.0600D-01 * RXRAT( 309 )      ! ALK5+OH=0.1060D+00*xCCHO+...
     &                      +    1.0000D-02 * RXRAT( 311 )      ! OLE1+OH=0.1000D-01*xCCHO+...
     &                      +    1.1000D-02 * RXRAT( 312 )      ! OLE1+O3=0.1100D-01*xCCHO+...
     &                      +    1.3000D-02 * RXRAT( 313 )      ! OLE1+NO3=0.1300D-01*xCCHO+...
     &                      +    8.3500D-01 * RXRAT( 315 )      ! OLE2+OH=0.8350D+00*xCCHO+...
     &                      +    7.1000D-02 * RXRAT( 316 )      ! OLE2+O3=0.7100D-01*xCCHO+...
     &                      +    5.7900D-01 * RXRAT( 317 )      ! OLE2+NO3=0.5790D+00*xCCHO+...
     &                      +    2.0000D-03 * RXRAT( 328 )      ! SESQ+NO3=0.2000D-02*xCCHO+...
     &                      +    1.0000D-01 * RXRAT( 355 )      ! RCHO+CL=0.1000D+00*xCCHO+...
     &                      +    7.0000D-02 * RXRAT( 357 )      ! MEK+CL=0.7000D-01*xCCHO+...
     &                      +    3.0000D-01 * RXRAT( 358 )      ! RNO3+CL=0.3000D+00*xCCHO+...
     &                      +    1.0900D-01 * RXRAT( 359 )      ! PRD2+CL=0.1090D+00*xCCHO+...
     &                      +    1.0400D-01 * RXRAT( 364 )      ! ROOH+CL=0.1040D+00*xCCHO+...
     &                      +    1.8600D-01 * RXRAT( 365 )      ! R6OOH+CL=0.1860D+00*xCCHO+...
     &                      +                 RXRAT( 394 )      ! ALK1+CL=xCCHO+xHO2+RO2C+...
     &                      +    3.4000D-01 * RXRAT( 396 )      ! ALK3+CL=0.3400D+00*xCCHO+...
     &                      +    2.8700D-01 * RXRAT( 397 )      ! ALK4+CL=0.2870D+00*xCCHO+...
     &                      +    8.0000D-02 * RXRAT( 398 )      ! ALK5+CL=0.8000D-01*xCCHO+...
     &                      +    2.0600D-01 * RXRAT( 399 )      ! OLE1+CL=0.2060D+00*xCCHO+...
     &                      +    3.8300D-01 * RXRAT( 400 )      ! OLE2+CL=0.3830D+00*xCCHO+...
      LOSS(  xCCHO        ) =                 RXRAT( 215 )      ! xCCHO=CCHO
     &                      +                 RXRAT( 216 )      ! xCCHO=

      PROD(  RCOOOH       ) =    3.0750D-01 * RXRAT(  77 )      ! RCO3+HO2=0.3075D+00*RCOOOH+...
     &                      +    3.0750D-01 * RXRAT(  88 )      ! BZCO3+HO2=0.3075D+...
     &                      +    3.0750D-01 * RXRAT( 100 )      ! MACO3+HO2=0.3075D+...
      LOSS(  RCOOOH       ) =                 RXRAT( 209 )      ! RCOOOH+OH=0.8060D+00*RCO3+...

      PROD(  RCOOH        ) =    1.0250D-01 * RXRAT(  77 )      ! RCO3+HO2=0.1025D+00*RCOOH+...
     &                      +    1.0250D-01 * RXRAT(  88 )      ! BZCO3+HO2=0.1025D+00*RCOOH+...
     &                      +    1.0250D-01 * RXRAT( 100 )      ! MACO3+HO2=0.1025D+00*RCOOH+...
     &                      +    3.7200D-01 * RXRAT( 192 )      ! IPRD+O3=0.3720D+00*RCOOH+...
     &                      +    1.5900D-01 * RXRAT( 312 )      ! OLE1+O3=0.1590D+00*RCOOH+...
     &                      +    2.3500D-01 * RXRAT( 316 )      ! OLE2+O3=0.2350D+00*RCOOH+...
     &                      +    6.8000D-02 * RXRAT( 323 )      ! TERP+O3=0.6800D-01*RCOOH+...
     &                      +    6.8000D-02 * RXRAT( 327 )      ! SESQ+O3=0.6800D-01*RCOOH+...
      LOSS(  RCOOH        ) =                 RXRAT( 149 )      ! RCOOH+OH=RO2C+xHO2+0.1430D+...

      PROD(  BZCO3        ) =                 RXRAT(  85 )      ! PBZN=BZCO3+NO2
     &                      +    6.0000D-01 * RXRAT(  86 )      ! PBZN=0.6000D+00*BZCO3+...
     &                      +                 RXRAT( 171 )      ! BALD+OH=BZCO3
     &                      +                 RXRAT( 173 )      ! BALD+NO3=BZCO3+HNO3
     &                      +                 RXRAT( 363 )      ! BALD+CL=BZCO3+HCL
      LOSS(  BZCO3        ) =                 RXRAT(  84 )      ! BZCO3+NO2=PBZN
     &                      +                 RXRAT(  87 )      ! BZCO3+NO=NO2+CO2+BZO+RO2C
     &                      +                 RXRAT(  88 )      ! BZCO3+HO2=0.3075D+...
     &                      +                 RXRAT(  89 )      ! BZCO3+NO3=NO2+CO2+BZO+RO2C
     &                      +                 RXRAT(  90 )      ! BZCO3+MEO2=HCHO+HO2+RO2C+...
     &                      +                 RXRAT(  91 )      ! BZCO3+RO2C=RO2C+BZO+CO2
     &                      +                 RXRAT(  92 )      ! BZCO3+RO2XC=RO2C+BZO+CO2
     &                      +                 RXRAT(  93 )      ! BZCO3+MECO3=0.2000D+01*CO2+...
     &                      +                 RXRAT(  94 )      ! BZCO3+RCO3=0.2000D+01*CO2+...
     &                      +    2.0000D+00 * RXRAT(  95 )      ! BZCO3+BZCO3=0.2000D+01*BZO+...
     &                      +                 RXRAT( 107 )      ! BZCO3+MACO3=HCHO+MECO3+BZO+...

      PROD(  PBZN         ) =                 RXRAT(  84 )      ! BZCO3+NO2=PBZN
      LOSS(  PBZN         ) =                 RXRAT(  85 )      ! PBZN=BZCO3+NO2
     &                      +                 RXRAT(  86 )      ! PBZN=0.6000D+00*BZCO3+...

      PROD(  BZO          ) =    4.0000D-01 * RXRAT(  86 )      ! PBZN=0.4000D+00*BZO+...
     &                      +                 RXRAT(  87 )      ! BZCO3+NO=BZO+CO2+NO2+RO2C
     &                      +    4.4000D-01 * RXRAT(  88 )      ! BZCO3+HO2=0.4400D+00*BZO+...
     &                      +                 RXRAT(  89 )      ! BZCO3+NO3=BZO+CO2+NO2+RO2C
     &                      +                 RXRAT(  90 )      ! BZCO3+MEO2=BZO+HO2+RO2C+...
     &                      +                 RXRAT(  91 )      ! BZCO3+RO2C=BZO+RO2C+CO2
     &                      +                 RXRAT(  92 )      ! BZCO3+RO2XC=BZO+RO2C+CO2
     &                      +                 RXRAT(  93 )      ! BZCO3+MECO3=BZO+MEO2+...
     &                      +                 RXRAT(  94 )      ! BZCO3+RCO3=BZO+0.2000D+...
     &                      +    2.0000D+00 * RXRAT(  95 )      ! BZCO3+BZCO3=0.2000D+01*BZO+...
     &                      +                 RXRAT( 107 )      ! MACO3+BZCO3=BZO+MECO3+HCHO+...
     &                      +    2.0000D-01 * RXRAT( 166 )      ! CRES+OH=0.2000D+00*BZO+...
     &                      +                 RXRAT( 167 )      ! CRES+NO3=BZO+HNO3
     &                      +                 RXRAT( 168 )      ! NPHE+OH=BZO
      LOSS(  BZO          ) =                 RXRAT( 111 )      ! BZO+NO2=NPHE
     &                      +                 RXRAT( 112 )      ! BZO+HO2=CRES
     &                      +                 RXRAT( 113 )      ! BZO=CRES+RO2C+xHO2

      PROD(  MACO3        ) =                 RXRAT(  97 )      ! MAPAN=MACO3+NO2
     &                      +    6.0000D-01 * RXRAT(  98 )      ! MAPAN=0.6000D+00*MACO3+...
     &                      +                 RXRAT( 126 )      ! xMACO3=MACO3
     &                      +    2.1700D-01 * RXRAT( 174 )      ! AFG1+OH=0.2170D+00*MACO3+...
     &                      +    5.0000D-01 * RXRAT( 176 )      ! AFG1=0.5000D+00*MACO3+...
     &                      +    2.1700D-01 * RXRAT( 177 )      ! AFG2+OH=0.2170D+00*MACO3+...
     &                      +    2.0600D-01 * RXRAT( 180 )      ! AFG3+OH=0.2060D+00*MACO3+...
     &                      +    5.0000D-01 * RXRAT( 182 )      ! MACR+OH=0.5000D+00*MACO3+...
     &                      +    5.0000D-01 * RXRAT( 184 )      ! MACR+NO3=0.5000D+00*MACO3+...
     &                      +    3.3000D-01 * RXRAT( 186 )      ! MACR=0.3300D+00*MACO3+...
     &                      +    4.0000D-01 * RXRAT( 190 )      ! MVK=0.4000D+00*MACO3+...
     &                      +    2.8900D-01 * RXRAT( 191 )      ! IPRD+OH=0.2890D+00*MACO3+...
     &                      +    1.5000D-01 * RXRAT( 193 )      ! IPRD+NO3=0.1500D+00*MACO3+...
     &                      +    7.5000D-01 * RXRAT( 202 )      ! ACROLEIN+OH=0.7500D+...
     &                      +    9.6700D-01 * RXRAT( 204 )      ! ACROLEIN+NO3=0.9670D+...
     &                      +    3.3000D-01 * RXRAT( 206 )      ! ACROLEIN=0.3300D+00*MACO3+...
     &                      +    2.1600D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.2160D+...
     &                      +    1.6500D-01 * RXRAT( 368 )      ! MACR+CL=0.1650D+00*MACO3+...
     &                      +    1.5400D-01 * RXRAT( 370 )      ! IPRD+CL=0.1540D+00*MACO3+...
      LOSS(  MACO3        ) =                 RXRAT(  96 )      ! MACO3+NO2=MAPAN
     &                      +                 RXRAT(  99 )      ! MACO3+NO=NO2+CO2+HCHO+MECO3
     &                      +                 RXRAT( 100 )      ! MACO3+HO2=0.3075D+...
     &                      +                 RXRAT( 101 )      ! MACO3+NO3=NO2+CO2+HCHO+MECO3
     &                      +                 RXRAT( 102 )      ! MACO3+MEO2=0.2000D+01*HCHO+...
     &                      +                 RXRAT( 103 )      ! MACO3+RO2C=CO2+HCHO+MECO3
     &                      +                 RXRAT( 104 )      ! MACO3+RO2XC=CO2+HCHO+MECO3
     &                      +                 RXRAT( 105 )      ! MACO3+MECO3=0.2000D+01*CO2+...
     &                      +                 RXRAT( 106 )      ! MACO3+RCO3=HCHO+MECO3+RO2C+...
     &                      +                 RXRAT( 107 )      ! MACO3+BZCO3=HCHO+MECO3+BZO+...
     &                      +    2.0000D+00 * RXRAT( 108 )      ! MACO3+MACO3=0.2000D+...

      PROD(  MAPAN        ) =                 RXRAT(  96 )      ! MACO3+NO2=MAPAN
      LOSS(  MAPAN        ) =                 RXRAT(  97 )      ! MAPAN=MACO3+NO2
     &                      +                 RXRAT(  98 )      ! MAPAN=0.6000D+00*MACO3+...

      PROD(  TBUO         ) =                 RXRAT( 128 )      ! xTBUO=TBUO
      LOSS(  TBUO         ) =                 RXRAT( 109 )      ! TBUO+NO2=RNO3
     &                      +                 RXRAT( 110 )      ! TBUO=ACETONE+MEO2

      PROD(  RNO3         ) =                 RXRAT( 109 )      ! TBUO+NO2=RNO3
     &                      +                 RXRAT( 245 )      ! xRNO3=RNO3
     &                      +                 RXRAT( 247 )      ! zRNO3=RNO3
      LOSS(  RNO3         ) =    8.1100D-01 * RXRAT( 197 )      ! RNO3+OH=0.1890D+00*RNO3+...
     &                      +                 RXRAT( 198 )      ! RNO3=0.3440D+00*HO2+...
     &                      +    9.4500D-01 * RXRAT( 358 )      ! RNO3+CL=0.5500D-01*RNO3+...

      PROD(  ACETONE      ) =                 RXRAT( 110 )      ! TBUO=ACETONE+MEO2
     &                      +                 RXRAT( 219 )      ! xACETONE=ACETONE
     &                      +    5.1000D-02 * RXRAT( 316 )      ! OLE2+O3=0.5100D-01*ACETONE+...
      LOSS(  ACETONE      ) =                 RXRAT( 142 )      ! ACETONE+OH=RO2C+xMECO3+...
     &                      +                 RXRAT( 143 )      ! ACETONE=0.6200D+00*MECO3+...
     &                      +                 RXRAT( 356 )      ! ACETONE+CL=HCL+RO2C+xHCHO+...

      PROD(  NPHE         ) =                 RXRAT( 111 )      ! BZO+NO2=NPHE
      LOSS(  NPHE         ) =                 RXRAT( 168 )      ! NPHE+OH=BZO
     &                      +                 RXRAT( 169 )      ! NPHE=HONO
     &                      +                 RXRAT( 170 )      ! NPHE=

      PROD(  CRES         ) =                 RXRAT( 112 )      ! BZO+HO2=CRES
     &                      +                 RXRAT( 113 )      ! BZO=CRES+RO2C+xHO2
     &                      +    5.7000D-01 * RXRAT( 298 )      ! BENZENE+OH=0.5700D+00*CRES+...
     &                      +    1.8100D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.1810D+00*CRES+...
     &                      +    1.5900D-01 * RXRAT( 300 )      ! MXYL+OH=0.1590D+00*CRES+...
     &                      +    1.6100D-01 * RXRAT( 301 )      ! OXYL+OH=0.1610D+00*CRES+...
     &                      +    1.5900D-01 * RXRAT( 302 )      ! PXYL+OH=0.1590D+00*CRES+...
     &                      +    2.2000D-02 * RXRAT( 303 )      ! TMBENZ124+OH=0.2200D-...
     &                      +    1.2300D-01 * RXRAT( 319 )      ! ARO1+OH=0.1230D+00*CRES+...
     &                      +    7.7000D-02 * RXRAT( 320 )      ! ARO2MN+OH=0.7700D-01*CRES+...
     &                      +    7.7000D-02 * RXRAT( 321 )      ! NAPHTHAL+OH=0.7700D-...
      LOSS(  CRES         ) =                 RXRAT( 166 )      ! CRES+OH=0.2000D+00*BZO+...
     &                      +                 RXRAT( 167 )      ! CRES+NO3=HNO3+BZO
     &                      +                 RXRAT( 362 )      ! CRES+CL=HCL+xHO2+xBALD+yR6OOH

      PROD(  xOH          ) =    1.2000D-02 * RXRAT( 152 )      ! ROOH+OH=0.1200D-01*xOH+...
     &                      +    4.1000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.4100D-01*xOH+...
     &                      +    2.4000D-02 * RXRAT( 156 )      ! RAOOH+OH=0.2400D-01*xOH+...
     &                      +    2.0000D-02 * RXRAT( 207 )      ! CCOOOH+OH=0.2000D-01*xOH+...
     &                      +    1.1000D-01 * RXRAT( 209 )      ! RCOOOH+OH=0.1100D+00*xOH+...
     &                      +    1.0400D-01 * RXRAT( 364 )      ! ROOH+CL=0.1040D+00*xOH+...
     &                      +    5.0200D-01 * RXRAT( 365 )      ! R6OOH+CL=0.5020D+00*xOH+...
     &                      +    2.4000D-02 * RXRAT( 366 )      ! RAOOH+CL=0.2400D-01*xOH+...
      LOSS(  xOH          ) =                 RXRAT( 116 )      ! xOH=OH
     &                      +                 RXRAT( 117 )      ! xOH=

      PROD(  xNO2         ) =    3.1300D-01 * RXRAT( 197 )      ! RNO3+OH=0.3130D+00*xNO2+...
     &                      +    1.2000D-01 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.1200D+...
     &                      +    1.8700D-01 * RXRAT( 281 )      ! ISOPRENE+NO3=0.1870D+...
     &                      +    6.4300D-01 * RXRAT( 294 )      ! APIN+NO3=0.6430D+00*xNO2+...
     &                      +    4.2600D-01 * RXRAT( 317 )      ! OLE2+NO3=0.4260D+00*xNO2+...
     &                      +    2.8700D-01 * RXRAT( 324 )      ! TERP+NO3=0.2870D+00*xNO2+...
     &                      +    2.8700D-01 * RXRAT( 328 )      ! SESQ+NO3=0.2870D+00*xNO2+...
     &                      +    1.5900D-01 * RXRAT( 358 )      ! RNO3+CL=0.1590D+00*xNO2+...
      LOSS(  xNO2         ) =                 RXRAT( 118 )      ! xNO2=NO2
     &                      +                 RXRAT( 119 )      ! xNO2=

      PROD(  xMEO2        ) =    1.0000D-02 * RXRAT( 308 )      ! ALK4+OH=0.1000D-01*xMEO2+...
     &                      +    1.0000D-03 * RXRAT( 311 )      ! OLE1+OH=0.1000D-02*xMEO2+...
     &                      +    3.5000D-02 * RXRAT( 317 )      ! OLE2+NO3=0.3500D-01*xMEO2+...
     &                      +    3.0000D-03 * RXRAT( 397 )      ! ALK4+CL=0.3000D-02*xMEO2+...
     &                      +    1.0000D-03 * RXRAT( 400 )      ! OLE2+CL=0.1000D-02*xMEO2+...
      LOSS(  xMEO2        ) =                 RXRAT( 120 )      ! xMEO2=MEO2
     &                      +                 RXRAT( 121 )      ! xMEO2=

      PROD(  xMECO3       ) =                 RXRAT( 142 )      ! ACETONE+OH=xMECO3+RO2C+...
     &                      +    5.1000D-01 * RXRAT( 144 )      ! MEK+OH=0.5100D+00*xMECO3+...
     &                      +    2.0100D-01 * RXRAT( 174 )      ! AFG1+OH=0.2010D+00*xMECO3+...
     &                      +    2.0100D-01 * RXRAT( 177 )      ! AFG2+OH=0.2010D+00*xMECO3+...
     &                      +    1.1700D-01 * RXRAT( 180 )      ! AFG3+OH=0.1170D+00*xMECO3+...
     &                      +    3.3000D-01 * RXRAT( 186 )      ! MACR=0.3300D+00*xMECO3+...
     &                      +    6.7500D-01 * RXRAT( 187 )      ! MVK+OH=0.6750D+00*xMECO3+...
     &                      +    2.9000D-02 * RXRAT( 195 )      ! PRD2+OH=0.2900D-01*xMECO3+...
     &                      +    1.0000D-03 * RXRAT( 293 )      ! APIN+O3=0.1000D-02*xMECO3+...
     &                      +    1.1000D-02 * RXRAT( 308 )      ! ALK4+OH=0.1100D-01*xMECO3+...
     &                      +    1.5600D-01 * RXRAT( 316 )      ! OLE2+O3=0.1560D+00*xMECO3+...
     &                      +    2.0200D-01 * RXRAT( 323 )      ! TERP+O3=0.2020D+00*xMECO3+...
     &                      +    2.0200D-01 * RXRAT( 327 )      ! SESQ+O3=0.2020D+00*xMECO3+...
     &                      +                 RXRAT( 356 )      ! ACETONE+CL=xMECO3+RO2C+...
     &                      +    8.5000D-02 * RXRAT( 357 )      ! MEK+CL=0.8500D-01*xMECO3+...
     &                      +    7.0000D-03 * RXRAT( 359 )      ! PRD2+CL=0.7000D-02*xMECO3+...
     &                      +    6.2500D-01 * RXRAT( 369 )      ! MVK+CL=0.6250D+00*xMECO3+...
     &                      +    3.4000D-02 * RXRAT( 386 )      ! APIN+CL=0.3400D-01*xMECO3+...
     &                      +    4.0000D-03 * RXRAT( 397 )      ! ALK4+CL=0.4000D-02*xMECO3+...
     &                      +    3.4000D-02 * RXRAT( 404 )      ! TERP+CL=0.3400D-01*xMECO3+...
     &                      +    3.4000D-02 * RXRAT( 405 )      ! SESQ+CL=0.3400D-01*xMECO3+...
      LOSS(  xMECO3       ) =                 RXRAT( 122 )      ! xMECO3=MECO3
     &                      +                 RXRAT( 123 )      ! xMECO3=

      PROD(  xRCO3        ) =    7.4000D-02 * RXRAT( 144 )      ! MEK+OH=0.7400D-01*xRCO3+...
     &                      +    6.5200D-01 * RXRAT( 175 )      ! AFG1+O3=0.6520D+00*xRCO3+...
     &                      +    6.5200D-01 * RXRAT( 178 )      ! AFG2+O3=0.6520D+00*xRCO3+...
     &                      +    1.6300D-01 * RXRAT( 181 )      ! AFG3+O3=0.1630D+00*xRCO3+...
     &                      +    1.0000D-01 * RXRAT( 183 )      ! MACR+O3=0.1000D+00*xRCO3+...
     &                      +    5.0000D-02 * RXRAT( 188 )      ! MVK+O3=0.5000D-01*xRCO3+...
     &                      +    4.8000D-02 * RXRAT( 192 )      ! IPRD+O3=0.4800D-01*xRCO3+...
     &                      +    4.9000D-02 * RXRAT( 195 )      ! PRD2+OH=0.4900D-01*xRCO3+...
     &                      +    4.0000D-03 * RXRAT( 292 )      ! APIN+OH=0.4000D-02*xRCO3+...
     &                      +    2.9700D-01 * RXRAT( 293 )      ! APIN+O3=0.2970D+00*xRCO3+...
     &                      +    7.0000D-03 * RXRAT( 294 )      ! APIN+NO3=0.7000D-02*xRCO3+...
     &                      +    8.0000D-03 * RXRAT( 316 )      ! OLE2+O3=0.8000D-02*xRCO3+...
     &                      +    6.4000D-02 * RXRAT( 322 )      ! TERP+OH=0.6400D-01*xRCO3+...
     &                      +    5.9000D-02 * RXRAT( 323 )      ! TERP+O3=0.5900D-01*xRCO3+...
     &                      +    2.6000D-02 * RXRAT( 324 )      ! TERP+NO3=0.2600D-01*xRCO3+...
     &                      +    6.4000D-02 * RXRAT( 326 )      ! SESQ+OH=0.6400D-01*xRCO3+...
     &                      +    5.9000D-02 * RXRAT( 327 )      ! SESQ+O3=0.5900D-01*xRCO3+...
     &                      +    2.6000D-02 * RXRAT( 328 )      ! SESQ+NO3=0.2600D-01*xRCO3+...
     &                      +    3.6000D-02 * RXRAT( 357 )      ! MEK+CL=0.3600D-01*xRCO3+...
     &                      +    2.2000D-02 * RXRAT( 359 )      ! PRD2+CL=0.2200D-01*xRCO3+...
     &                      +    5.0000D-02 * RXRAT( 386 )      ! APIN+CL=0.5000D-01*xRCO3+...
     &                      +    5.0000D-02 * RXRAT( 404 )      ! TERP+CL=0.5000D-01*xRCO3+...
     &                      +    5.0000D-02 * RXRAT( 405 )      ! SESQ+CL=0.5000D-01*xRCO3+...
      LOSS(  xRCO3        ) =                 RXRAT( 124 )      ! xRCO3=RCO3
     &                      +                 RXRAT( 125 )      ! xRCO3=

      PROD(  xMACO3       ) =    1.1800D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1180D+...
     &                      +    1.9200D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1920D+...
     &                      +    2.4000D-01 * RXRAT( 282 )      ! ISOPRENE+O3P=0.2400D+...
     &                      +    1.6000D-02 * RXRAT( 386 )      ! APIN+CL=0.1600D-01*xMACO3+...
     &                      +    1.6000D-02 * RXRAT( 404 )      ! TERP+CL=0.1600D-01*xMACO3+...
     &                      +    1.6000D-02 * RXRAT( 405 )      ! SESQ+CL=0.1600D-01*xMACO3+...
      LOSS(  xMACO3       ) =                 RXRAT( 126 )      ! xMACO3=MACO3
     &                      +                 RXRAT( 127 )      ! xMACO3=

      PROD(  xTBUO        ) =    2.3600D-01 * RXRAT( 307 )      ! ALK3+OH=0.2360D+00*xTBUO+...
     &                      +    9.4000D-02 * RXRAT( 396 )      ! ALK3+CL=0.9400D-01*xTBUO+...
      LOSS(  xTBUO        ) =                 RXRAT( 128 )      ! xTBUO=TBUO
     &                      +                 RXRAT( 129 )      ! xTBUO=

      PROD(  xCO          ) =    3.5000D-02 * RXRAT( 139 )      ! RCHO+OH=0.3500D-01*xCO+...
     &                      +    3.3400D-01 * RXRAT( 174 )      ! AFG1+OH=0.3340D+00*xCO+...
     &                      +    3.3400D-01 * RXRAT( 177 )      ! AFG2+OH=0.3340D+00*xCO+...
     &                      +    1.1400D-01 * RXRAT( 180 )      ! AFG3+OH=0.1140D+00*xCO+...
     &                      +    4.1600D-01 * RXRAT( 182 )      ! MACR+OH=0.4160D+00*xCO+...
     &                      +    5.0000D-01 * RXRAT( 184 )      ! MACR+NO3=0.5000D+00*xCO+...
     &                      +    3.3600D-01 * RXRAT( 191 )      ! IPRD+OH=0.3360D+00*xCO+...
     &                      +    5.7200D-01 * RXRAT( 193 )      ! IPRD+NO3=0.5720D+00*xCO+...
     &                      +    1.6700D-01 * RXRAT( 202 )      ! ACROLEIN+OH=0.1670D+00*xCO+...
     &                      +    3.1000D-02 * RXRAT( 204 )      ! ACROLEIN+NO3=0.3100D-...
     &                      +    2.7800D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.2780D+00*xCO+...
     &                      +    1.1500D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1150D+...
     &                      +    2.0000D-03 * RXRAT( 292 )      ! APIN+OH=0.2000D-02*xCO+...
     &                      +    5.1000D-02 * RXRAT( 293 )      ! APIN+O3=0.5100D-01*xCO+...
     &                      +    5.0000D-03 * RXRAT( 294 )      ! APIN+NO3=0.5000D-02*xCO+...
     &                      +    2.0000D-03 * RXRAT( 308 )      ! ALK4+OH=0.2000D-02*xCO+...
     &                      +    1.0000D-03 * RXRAT( 322 )      ! TERP+OH=0.1000D-02*xCO+...
     &                      +    1.2000D-02 * RXRAT( 324 )      ! TERP+NO3=0.1200D-01*xCO+...
     &                      +    1.0000D-03 * RXRAT( 326 )      ! SESQ+OH=0.1000D-02*xCO+...
     &                      +    1.2000D-02 * RXRAT( 328 )      ! SESQ+NO3=0.1200D-01*xCO+...
     &                      +    1.0000D-01 * RXRAT( 355 )      ! RCHO+CL=0.1000D+00*xCO+...
     &                      +    4.8400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.4840D+00*xCO+...
     &                      +    5.4100D-01 * RXRAT( 368 )      ! MACR+CL=0.5410D+00*xCO+...
     &                      +    4.9800D-01 * RXRAT( 370 )      ! IPRD+CL=0.4980D+00*xCO+...
     &                      +    3.5000D-02 * RXRAT( 386 )      ! APIN+CL=0.3500D-01*xCO+...
     &                      +    3.0000D-03 * RXRAT( 397 )      ! ALK4+CL=0.3000D-02*xCO+...
     &                      +    3.5000D-02 * RXRAT( 404 )      ! TERP+CL=0.3500D-01*xCO+...
     &                      +    3.5000D-02 * RXRAT( 405 )      ! SESQ+CL=0.3500D-01*xCO+...
      LOSS(  xCO          ) =                 RXRAT( 130 )      ! xCO=CO
     &                      +                 RXRAT( 131 )      ! xCO=

      PROD(  CCHO         ) =    1.0000D-03 * RXRAT( 195 )      ! PRD2+OH=0.1000D-02*CCHO+...
     &                      +    2.1400D-01 * RXRAT( 198 )      ! RNO3=0.2140D+00*CCHO+...
     &                      +                 RXRAT( 215 )      ! xCCHO=CCHO
     &                      +    1.0000D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.1000D+00*CCHO+...
     &                      +    5.0000D-01 * RXRAT( 272 )      ! PROPENE+O3=0.5000D+00*CCHO+...
     &                      +    9.5000D-01 * RXRAT( 304 )      ! ETOH+OH=0.9500D+00*CCHO+...
     &                      +    4.5300D-01 * RXRAT( 316 )      ! OLE2+O3=0.4530D+00*CCHO+...
     &                      +    6.8800D-01 * RXRAT( 393 )      ! ETOH+CL=0.6880D+00*CCHO+...
      LOSS(  CCHO         ) =                 RXRAT( 136 )      ! CCHO+OH=MECO3
     &                      +                 RXRAT( 137 )      ! CCHO=CO+HO2+MEO2
     &                      +                 RXRAT( 138 )      ! CCHO+NO3=HNO3+MECO3
     &                      +                 RXRAT( 353 )      ! CCHO+CL=HCL+MECO3

      PROD(  RCHO         ) =    7.4400D-01 * RXRAT( 152 )      ! ROOH+OH=0.7440D+00*RCHO+...
     &                      +                 RXRAT( 153 )      ! ROOH=RCHO+HO2+OH
     &                      +    8.5000D-02 * RXRAT( 155 )      ! R6OOH=0.8500D-01*RCHO+...
     &                      +                 RXRAT( 185 )      ! MACR+O3P=RCHO
     &                      +    4.5000D-01 * RXRAT( 189 )      ! MVK+O3P=0.4500D+00*RCHO+...
     &                      +    1.4300D-01 * RXRAT( 195 )      ! PRD2+OH=0.1430D+00*RCHO+...
     &                      +    1.0000D-03 * RXRAT( 197 )      ! RNO3+OH=0.1000D-02*RCHO+...
     &                      +    7.4000D-02 * RXRAT( 198 )      ! RNO3=0.7400D-01*RCHO+...
     &                      +                 RXRAT( 205 )      ! ACROLEIN+O3P=RCHO
     &                      +                 RXRAT( 217 )      ! xRCHO=RCHO
     &                      +    4.5000D-01 * RXRAT( 274 )      ! PROPENE+O3P=0.4500D+...
     &                      +    6.1000D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.6100D+00*RCHO+...
     &                      +    1.1000D-01 * RXRAT( 285 )      ! ISOPOOH=0.1100D+00*RCHO+...
     &                      +    5.0000D-01 * RXRAT( 312 )      ! OLE1+O3=0.5000D+00*RCHO+...
     &                      +    4.5000D-01 * RXRAT( 314 )      ! OLE1+O3P=0.4500D+00*RCHO+...
     &                      +    3.3300D-01 * RXRAT( 316 )      ! OLE2+O3=0.3330D+00*RCHO+...
     &                      +    7.9000D-02 * RXRAT( 318 )      ! OLE2+O3P=0.7900D-01*RCHO+...
     &                      +    2.3700D-01 * RXRAT( 325 )      ! TERP+O3P=0.2370D+00*RCHO+...
     &                      +    2.3700D-01 * RXRAT( 329 )      ! SESQ+O3P=0.2370D+00*RCHO+...
     &                      +    9.0000D-03 * RXRAT( 358 )      ! RNO3+CL=0.9000D-02*RCHO+...
     &                      +    1.9800D-01 * RXRAT( 359 )      ! PRD2+CL=0.1980D+00*RCHO+...
     &                      +    4.1400D-01 * RXRAT( 364 )      ! ROOH+CL=0.4140D+00*RCHO+...
      LOSS(  RCHO         ) =                 RXRAT( 139 )      ! RCHO+OH=0.9650D+00*RCO3+...
     &                      +                 RXRAT( 140 )      ! RCHO=RO2C+xHO2+yROOH+xCCHO+...
     &                      +                 RXRAT( 141 )      ! RCHO+NO3=HNO3+RCO3
     &                      +                 RXRAT( 355 )      ! RCHO+CL=HCL+0.9000D+...

      PROD(  xHCHO        ) =                 RXRAT( 142 )      ! ACETONE+OH=xHCHO+xMECO3+...
     &                      +    8.8000D-02 * RXRAT( 144 )      ! MEK+OH=0.8800D-01*xHCHO+...
     &                      +    1.2000D-02 * RXRAT( 152 )      ! ROOH+OH=0.1200D-01*xHCHO+...
     &                      +    6.5200D-01 * RXRAT( 175 )      ! AFG1+O3=0.6520D+00*xHCHO+...
     &                      +    6.5200D-01 * RXRAT( 178 )      ! AFG2+O3=0.6520D+00*xHCHO+...
     &                      +    1.6300D-01 * RXRAT( 181 )      ! AFG3+O3=0.1630D+00*xHCHO+...
     &                      +    8.4000D-02 * RXRAT( 182 )      ! MACR+OH=0.8400D-01*xHCHO+...
     &                      +    1.0000D-01 * RXRAT( 183 )      ! MACR+O3=0.1000D+00*xHCHO+...
     &                      +    3.3000D-01 * RXRAT( 186 )      ! MACR=0.3300D+00*xHCHO+...
     &                      +    3.0000D-01 * RXRAT( 187 )      ! MVK+OH=0.3000D+00*xHCHO+...
     &                      +    5.0000D-02 * RXRAT( 188 )      ! MVK+O3=0.5000D-01*xHCHO+...
     &                      +    5.5000D-02 * RXRAT( 191 )      ! IPRD+OH=0.5500D-01*xHCHO+...
     &                      +    1.0000D-03 * RXRAT( 192 )      ! IPRD+O3=0.1000D-02*xHCHO+...
     &                      +    2.2700D-01 * RXRAT( 193 )      ! IPRD+NO3=0.2270D+00*xHCHO+...
     &                      +    2.1100D-01 * RXRAT( 195 )      ! PRD2+OH=0.2110D+00*xHCHO+...
     &                      +    3.0300D-01 * RXRAT( 196 )      ! PRD2=0.3030D+00*xHCHO+...
     &                      +    1.1000D-02 * RXRAT( 197 )      ! RNO3+OH=0.1100D-01*xHCHO+...
     &                      +    6.1000D-02 * RXRAT( 198 )      ! RNO3=0.6100D-01*xHCHO+...
     &                      +    8.3000D-02 * RXRAT( 202 )      ! ACROLEIN+OH=0.8300D-...
     &                      +    2.0000D-02 * RXRAT( 207 )      ! CCOOOH+OH=0.2000D-01*xHCHO+...
     &                      +    1.6100D+00 * RXRAT( 267 )      ! ETHENE+OH=0.1610D+01*xHCHO+...
     &                      +    2.7800D-01 * RXRAT( 270 )      ! ETHENE+O3P=0.2780D+...
     &                      +    9.8400D-01 * RXRAT( 271 )      ! PROPENE+OH=0.9840D+...
     &                      +    7.0800D-01 * RXRAT( 275 )      ! BUTADIENE13+OH=0.7080D+...
     &                      +    1.1500D-01 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.1150D+...
     &                      +    6.2400D-01 * RXRAT( 279 )      ! ISOPRENE+OH=0.6240D+...
     &                      +    1.9200D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1920D+...
     &                      +    2.4000D-01 * RXRAT( 282 )      ! ISOPRENE+O3P=0.2400D+...
     &                      +    2.6000D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.2600D+...
     &                      +    2.2000D-02 * RXRAT( 292 )      ! APIN+OH=0.2200D-01*xHCHO+...
     &                      +    3.4400D-01 * RXRAT( 293 )      ! APIN+O3=0.3440D+00*xHCHO+...
     &                      +    7.0000D-03 * RXRAT( 294 )      ! APIN+NO3=0.7000D-02*xHCHO+...
     &                      +    8.1000D-02 * RXRAT( 304 )      ! ETOH+OH=0.8100D-01*xHCHO+...
     &                      +    2.6000D-02 * RXRAT( 307 )      ! ALK3+OH=0.2600D-01*xHCHO+...
     &                      +    2.9000D-02 * RXRAT( 308 )      ! ALK4+OH=0.2900D-01*xHCHO+...
     &                      +    4.0000D-02 * RXRAT( 309 )      ! ALK5+OH=0.4000D-01*xHCHO+...
     &                      +    5.8200D-01 * RXRAT( 311 )      ! OLE1+OH=0.5820D+00*xHCHO+...
     &                      +    1.7900D-01 * RXRAT( 315 )      ! OLE2+OH=0.1790D+00*xHCHO+...
     &                      +    1.1400D-01 * RXRAT( 316 )      ! OLE2+O3=0.1140D+00*xHCHO+...
     &                      +    7.2000D-02 * RXRAT( 317 )      ! OLE2+NO3=0.7200D-01*xHCHO+...
     &                      +    4.1100D-01 * RXRAT( 322 )      ! TERP+OH=0.4110D+00*xHCHO+...
     &                      +    3.3000D-02 * RXRAT( 323 )      ! TERP+O3=0.3300D-01*xHCHO+...
     &                      +    2.3000D-02 * RXRAT( 324 )      ! TERP+NO3=0.2300D-01*xHCHO+...
     &                      +    4.1100D-01 * RXRAT( 326 )      ! SESQ+OH=0.4110D+00*xHCHO+...
     &                      +    3.3000D-02 * RXRAT( 327 )      ! SESQ+O3=0.3300D-01*xHCHO+...
     &                      +    2.3000D-02 * RXRAT( 328 )      ! SESQ+NO3=0.2300D-01*xHCHO+...
     &                      +                 RXRAT( 356 )      ! ACETONE+CL=xHCHO+RO2C+HCL+...
     &                      +    6.5000D-02 * RXRAT( 357 )      ! MEK+CL=0.6500D-01*xHCHO+...
     &                      +    4.5000D-02 * RXRAT( 358 )      ! RNO3+CL=0.4500D-01*xHCHO+...
     &                      +    2.3700D-01 * RXRAT( 359 )      ! PRD2+CL=0.2370D+00*xHCHO+...
     &                      +    1.0600D-01 * RXRAT( 364 )      ! ROOH+CL=0.1060D+00*xHCHO+...
     &                      +    2.7400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.2740D+...
     &                      +    1.9500D-01 * RXRAT( 370 )      ! IPRD+CL=0.1950D+00*xHCHO+...
     &                      +                 RXRAT( 371 )      ! CLCCHO=xHCHO+CO+RO2C+xCL+...
     &                      +                 RXRAT( 374 )      ! CLACET=xHCHO+RO2C+xCL+...
     &                      +                 RXRAT( 382 )      ! ETHENE+CL=xHCHO+0.2000D+...
     &                      +    8.6300D-01 * RXRAT( 384 )      ! BUTADIENE13+CL=0.8630D+...
     &                      +    2.7500D-01 * RXRAT( 385 )      ! ISOPRENE+CL=0.2750D+...
     &                      +    1.5800D-01 * RXRAT( 386 )      ! APIN+CL=0.1580D+00*xHCHO+...
     &                      +    5.0300D-01 * RXRAT( 393 )      ! ETOH+CL=0.5030D+00*xHCHO+...
     &                      +    7.8000D-02 * RXRAT( 396 )      ! ALK3+CL=0.7800D-01*xHCHO+...
     &                      +    3.4000D-02 * RXRAT( 397 )      ! ALK4+CL=0.3400D-01*xHCHO+...
     &                      +    2.2000D-02 * RXRAT( 398 )      ! ALK5+CL=0.2200D-01*xHCHO+...
     &                      +    3.6000D-02 * RXRAT( 399 )      ! OLE1+CL=0.3600D-01*xHCHO+...
     &                      +    1.9000D-01 * RXRAT( 400 )      ! OLE2+CL=0.1900D+00*xHCHO+...
     &                      +    1.5800D-01 * RXRAT( 404 )      ! TERP+CL=0.1580D+00*xHCHO+...
     &                      +    1.5800D-01 * RXRAT( 405 )      ! SESQ+CL=0.1580D+00*xHCHO+...
      LOSS(  xHCHO        ) =                 RXRAT( 213 )      ! xHCHO=HCHO
     &                      +                 RXRAT( 214 )      ! xHCHO=

      PROD(  MEK          ) =    5.5000D-01 * RXRAT( 189 )      ! MVK+O3P=0.5500D+00*MEK+...
     &                      +    2.1000D-01 * RXRAT( 192 )      ! IPRD+O3=0.2100D+00*MEK+...
     &                      +    2.3300D-01 * RXRAT( 194 )      ! IPRD=0.2330D+00*MEK+...
     &                      +    1.0000D-02 * RXRAT( 197 )      ! RNO3+OH=0.1000D-01*MEK+...
     &                      +    1.2400D-01 * RXRAT( 198 )      ! RNO3=0.1240D+00*MEK+...
     &                      +                 RXRAT( 221 )      ! xMEK=MEK
     &                      +                 RXRAT( 251 )      ! yROOH=MEK
     &                      +    5.5000D-01 * RXRAT( 274 )      ! PROPENE+O3P=0.5500D+00*MEK+...
     &                      +    7.2500D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.7250D+00*MEK+...
     &                      +    7.2500D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.7250D+00*MEK+...
     &                      +    3.6300D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.3630D+...
     &                      +    3.6300D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.3630D+...
     &                      +    7.2500D-01 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.7250D+...
     &                      +    8.0000D-03 * RXRAT( 293 )      ! APIN+O3=0.8000D-02*MEK+...
     &                      +    9.0000D-03 * RXRAT( 312 )      ! OLE1+O3=0.9000D-02*MEK+...
     &                      +    3.9000D-01 * RXRAT( 314 )      ! OLE1+O3P=0.3900D+00*MEK+...
     &                      +    3.3000D-02 * RXRAT( 316 )      ! OLE2+O3=0.3300D-01*MEK+...
     &                      +    7.5100D-01 * RXRAT( 318 )      ! OLE2+O3P=0.7510D+00*MEK+...
     &                      +    2.0000D-03 * RXRAT( 323 )      ! TERP+O3=0.2000D-02*MEK+...
     &                      +    2.0000D-03 * RXRAT( 327 )      ! SESQ+O3=0.2000D-02*MEK+...
     &                      +    1.8000D-02 * RXRAT( 358 )      ! RNO3+CL=0.1800D-01*MEK+...
      LOSS(  MEK          ) =                 RXRAT( 144 )      ! MEK+OH=0.9670D+00*RO2C+...
     &                      +                 RXRAT( 145 )      ! MEK=MECO3+RO2C+xHO2+xCCHO+...
     &                      +                 RXRAT( 357 )      ! MEK+CL=HCL+0.9750D+00*RO2C+...

      PROD(  zRNO3        ) =    3.9000D-02 * RXRAT( 144 )      ! MEK+OH=0.3900D-01*zRNO3+...
     &                      +    4.0000D-03 * RXRAT( 152 )      ! ROOH+OH=0.4000D-02*zRNO3+...
     &                      +    2.9000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.2900D-01*zRNO3+...
     &                      +    7.7000D-02 * RXRAT( 155 )      ! R6OOH=0.7700D-01*zRNO3+...
     &                      +    1.2400D-01 * RXRAT( 156 )      ! RAOOH+OH=0.1240D+00*zRNO3+...
     &                      +    6.0000D-02 * RXRAT( 174 )      ! AFG1+OH=0.6000D-01*zRNO3+...
     &                      +    6.0000D-02 * RXRAT( 177 )      ! AFG2+OH=0.6000D-01*zRNO3+...
     &                      +    1.1700D-01 * RXRAT( 180 )      ! AFG3+OH=0.1170D+00*zRNO3+...
     &                      +    7.0000D-03 * RXRAT( 181 )      ! AFG3+O3=0.7000D-02*zRNO3+...
     &                      +    2.5000D-02 * RXRAT( 187 )      ! MVK+OH=0.2500D-01*zRNO3+...
     &                      +    4.1000D-02 * RXRAT( 191 )      ! IPRD+OH=0.4100D-01*zRNO3+...
     &                      +    5.1000D-02 * RXRAT( 193 )      ! IPRD+NO3=0.5100D-01*zRNO3+...
     &                      +    7.1000D-02 * RXRAT( 195 )      ! PRD2+OH=0.7100D-01*zRNO3+...
     &                      +    8.7000D-02 * RXRAT( 196 )      ! PRD2=0.8700D-01*zRNO3+...
     &                      +    1.7500D-01 * RXRAT( 197 )      ! RNO3+OH=0.1750D+00*zRNO3+...
     &                      +    1.0200D-01 * RXRAT( 198 )      ! RNO3=0.1020D+00*zRNO3+...
     &                      +    2.0000D-03 * RXRAT( 204 )      ! ACROLEIN+NO3=0.2000D-...
     &                      +    1.6000D-02 * RXRAT( 271 )      ! PROPENE+OH=0.1600D-...
     &                      +    5.1000D-02 * RXRAT( 273 )      ! PROPENE+NO3=0.5100D-...
     &                      +    4.9000D-02 * RXRAT( 275 )      ! BUTADIENE13+OH=0.4900D-...
     &                      +    6.5000D-02 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.6500D-...
     &                      +    1.5000D-02 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1500D-...
     &                      +    9.3000D-02 * RXRAT( 279 )      ! ISOPRENE+OH=0.9300D-...
     &                      +    8.0000D-03 * RXRAT( 280 )      ! ISOPRENE+O3=0.8000D-...
     &                      +    6.4000D-02 * RXRAT( 281 )      ! ISOPRENE+NO3=0.6400D-...
     &                      +    1.0000D-02 * RXRAT( 282 )      ! ISOPRENE+O3P=0.1000D-...
     &                      +    1.9700D-01 * RXRAT( 292 )      ! APIN+OH=0.1970D+00*zRNO3+...
     &                      +    3.3700D-01 * RXRAT( 293 )      ! APIN+O3=0.3370D+00*zRNO3+...
     &                      +    2.9300D-01 * RXRAT( 294 )      ! APIN+NO3=0.2930D+00*zRNO3+...
     &                      +    2.4000D-02 * RXRAT( 298 )      ! BENZENE+OH=0.2400D-...
     &                      +    5.4000D-02 * RXRAT( 299 )      ! TOLUENE+OH=0.5400D-...
     &                      +    8.2000D-02 * RXRAT( 300 )      ! MXYL+OH=0.8200D-01*zRNO3+...
     &                      +    8.7000D-02 * RXRAT( 301 )      ! OXYL+OH=0.8700D-01*zRNO3+...
     &                      +    7.6000D-02 * RXRAT( 302 )      ! PXYL+OH=0.7600D-01*zRNO3+...
     &                      +    1.2100D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.1210D+...
     &                      +    3.5000D-02 * RXRAT( 306 )      ! ALK2+OH=0.3500D-01*zRNO3+...
     &                      +    7.0000D-02 * RXRAT( 307 )      ! ALK3+OH=0.7000D-01*zRNO3+...
     &                      +    1.4900D-01 * RXRAT( 308 )      ! ALK4+OH=0.1490D+00*zRNO3+...
     &                      +    3.5300D-01 * RXRAT( 309 )      ! ALK5+OH=0.3530D+00*zRNO3+...
     &                      +    1.2800D-01 * RXRAT( 311 )      ! OLE1+OH=0.1280D+00*zRNO3+...
     &                      +    5.0000D-03 * RXRAT( 312 )      ! OLE1+O3=0.5000D-02*zRNO3+...
     &                      +    2.2800D-01 * RXRAT( 313 )      ! OLE1+NO3=0.2280D+00*zRNO3+...
     &                      +    8.8000D-02 * RXRAT( 315 )      ! OLE2+OH=0.8800D-01*zRNO3+...
     &                      +    3.0000D-03 * RXRAT( 316 )      ! OLE2+O3=0.3000D-02*zRNO3+...
     &                      +    1.4000D-01 * RXRAT( 317 )      ! OLE2+NO3=0.1400D+00*zRNO3+...
     &                      +    1.1000D-01 * RXRAT( 319 )      ! ARO1+OH=0.1100D+00*zRNO3+...
     &                      +    1.2800D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.1280D+00*zRNO3+...
     &                      +    1.2800D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.1280D+...
     &                      +    2.0100D-01 * RXRAT( 322 )      ! TERP+OH=0.2010D+00*zRNO3+...
     &                      +    1.2100D-01 * RXRAT( 323 )      ! TERP+O3=0.1210D+00*zRNO3+...
     &                      +    4.6000D-01 * RXRAT( 324 )      ! TERP+NO3=0.4600D+00*zRNO3+...
     &                      +    2.0100D-01 * RXRAT( 326 )      ! SESQ+OH=0.2010D+00*zRNO3+...
     &                      +    1.2100D-01 * RXRAT( 327 )      ! SESQ+O3=0.1210D+00*zRNO3+...
     &                      +    4.6000D-01 * RXRAT( 328 )      ! SESQ+NO3=0.4600D+00*zRNO3+...
     &                      +    3.9000D-02 * RXRAT( 357 )      ! MEK+CL=0.3900D-01*zRNO3+...
     &                      +    2.0200D-01 * RXRAT( 358 )      ! RNO3+CL=0.2020D+00*zRNO3+...
     &                      +    1.1600D-01 * RXRAT( 359 )      ! PRD2+CL=0.1160D+00*zRNO3+...
     &                      +    1.1700D-01 * RXRAT( 365 )      ! R6OOH+CL=0.1170D+00*zRNO3+...
     &                      +    1.2400D-01 * RXRAT( 366 )      ! RAOOH+CL=0.1240D+00*zRNO3+...
     &                      +    2.6000D-02 * RXRAT( 367 )      ! ACROLEIN+CL=0.2600D-...
     &                      +    3.3000D-02 * RXRAT( 368 )      ! MACR+CL=0.3300D-01*zRNO3+...
     &                      +    5.3000D-02 * RXRAT( 369 )      ! MVK+CL=0.5300D-01*zRNO3+...
     &                      +    5.1000D-02 * RXRAT( 370 )      ! IPRD+CL=0.5100D-01*zRNO3+...
     &                      +    2.9000D-02 * RXRAT( 383 )      ! PROPENE+CL=0.2900D-...
     &                      +    6.9000D-02 * RXRAT( 384 )      ! BUTADIENE13+CL=0.6900D-...
     &                      +    8.5000D-02 * RXRAT( 385 )      ! ISOPRENE+CL=0.8500D-...
     &                      +    5.8200D-01 * RXRAT( 386 )      ! APIN+CL=0.5820D+00*zRNO3+...
     &                      +    1.0600D-01 * RXRAT( 388 )      ! TOLUENE+CL=0.1060D+...
     &                      +    1.3600D-01 * RXRAT( 389 )      ! MXYL+CL=0.1360D+00*zRNO3+...
     &                      +    1.3600D-01 * RXRAT( 390 )      ! OXYL+CL=0.1360D+00*zRNO3+...
     &                      +    1.3600D-01 * RXRAT( 391 )      ! PXYL+CL=0.1360D+00*zRNO3+...
     &                      +    1.6200D-01 * RXRAT( 392 )      ! TMBENZ124+CL=0.1620D+...
     &                      +    3.0000D-02 * RXRAT( 395 )      ! ALK2+CL=0.3000D-01*zRNO3+...
     &                      +    7.0000D-02 * RXRAT( 396 )      ! ALK3+CL=0.7000D-01*zRNO3+...
     &                      +    1.6500D-01 * RXRAT( 397 )      ! ALK4+CL=0.1650D+00*zRNO3+...
     &                      +    3.5200D-01 * RXRAT( 398 )      ! ALK5+CL=0.3520D+00*zRNO3+...
     &                      +    1.2700D-01 * RXRAT( 399 )      ! OLE1+CL=0.1270D+00*zRNO3+...
     &                      +    1.0600D-01 * RXRAT( 400 )      ! OLE2+CL=0.1060D+00*zRNO3+...
     &                      +    1.6000D-01 * RXRAT( 401 )      ! ARO1+CL=0.1600D+00*zRNO3+...
     &                      +    1.7200D-01 * RXRAT( 402 )      ! ARO2MN+CL=0.1720D+00*zRNO3+...
     &                      +    1.7200D-01 * RXRAT( 403 )      ! NAPHTHAL+CL=0.1720D+...
     &                      +    5.8200D-01 * RXRAT( 404 )      ! TERP+CL=0.5820D+00*zRNO3+...
     &                      +    5.8200D-01 * RXRAT( 405 )      ! SESQ+CL=0.5820D+00*zRNO3+...
      LOSS(  zRNO3        ) =                 RXRAT( 247 )      ! zRNO3=RNO3
     &                      +                 RXRAT( 248 )      ! zRNO3=PRD2+HO2
     &                      +                 RXRAT( 249 )      ! zRNO3=

      PROD(  xRCHO        ) =    3.7600D-01 * RXRAT( 144 )      ! MEK+OH=0.3760D+00*xRCHO+...
     &                      +    4.0000D-01 * RXRAT( 149 )      ! RCOOH+OH=0.4000D+00*xRCHO+...
     &                      +    2.0500D-01 * RXRAT( 152 )      ! ROOH+OH=0.2050D+00*xRCHO+...
     &                      +    7.5000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.7500D-01*xRCHO+...
     &                      +    5.8000D-02 * RXRAT( 155 )      ! R6OOH=0.5800D-01*xRCHO+...
     &                      +    4.4800D-01 * RXRAT( 156 )      ! RAOOH+OH=0.4480D+00*xRCHO+...
     &                      +    4.0700D-01 * RXRAT( 174 )      ! AFG1+OH=0.4070D+00*xRCHO+...
     &                      +    4.0700D-01 * RXRAT( 177 )      ! AFG2+OH=0.4070D+00*xRCHO+...
     &                      +    1.3000D-02 * RXRAT( 191 )      ! IPRD+OH=0.1300D-01*xRCHO+...
     &                      +    2.1800D-01 * RXRAT( 193 )      ! IPRD+NO3=0.2180D+00*xRCHO+...
     &                      +    4.0200D-01 * RXRAT( 195 )      ! PRD2+OH=0.4020D+00*xRCHO+...
     &                      +    7.8000D-01 * RXRAT( 196 )      ! PRD2=0.7800D+00*xRCHO+...
     &                      +    3.6000D-02 * RXRAT( 197 )      ! RNO3+OH=0.3600D-01*xRCHO+...
     &                      +    6.3000D-02 * RXRAT( 198 )      ! RNO3=0.6300D-01*xRCHO+...
     &                      +    8.4000D-02 * RXRAT( 209 )      ! RCOOOH+OH=0.8400D-01*xRCHO+...
     &                      +                 RXRAT( 269 )      ! ETHENE+NO3=xRCHO+RO2C+xHO2+...
     &                      +    4.0000D-02 * RXRAT( 284 )      ! ISOPOOH+OH=0.4000D-...
     &                      +    7.7600D-01 * RXRAT( 292 )      ! APIN+OH=0.7760D+00*xRCHO+...
     &                      +    2.4000D-01 * RXRAT( 293 )      ! APIN+O3=0.2400D+00*xRCHO+...
     &                      +    6.8400D-01 * RXRAT( 294 )      ! APIN+NO3=0.6840D+00*xRCHO+...
     &                      +    2.6100D-01 * RXRAT( 306 )      ! ALK2+OH=0.2610D+00*xRCHO+...
     &                      +    1.2200D-01 * RXRAT( 307 )      ! ALK3+OH=0.1220D+00*xRCHO+...
     &                      +    2.3600D-01 * RXRAT( 308 )      ! ALK4+OH=0.2360D+00*xRCHO+...
     &                      +    2.0900D-01 * RXRAT( 309 )      ! ALK5+OH=0.2090D+00*xRCHO+...
     &                      +    6.6600D-01 * RXRAT( 311 )      ! OLE1+OH=0.6660D+00*xRCHO+...
     &                      +    4.4000D-02 * RXRAT( 312 )      ! OLE1+O3=0.4400D-01*xRCHO+...
     &                      +    3.0000D-03 * RXRAT( 313 )      ! OLE1+NO3=0.3000D-02*xRCHO+...
     &                      +    5.1000D-01 * RXRAT( 315 )      ! OLE2+OH=0.5100D+00*xRCHO+...
     &                      +    1.9000D-02 * RXRAT( 316 )      ! OLE2+O3=0.1900D-01*xRCHO+...
     &                      +    1.6300D-01 * RXRAT( 317 )      ! OLE2+NO3=0.1630D+00*xRCHO+...
     &                      +    3.8500D-01 * RXRAT( 322 )      ! TERP+OH=0.3850D+00*xRCHO+...
     &                      +    2.0800D-01 * RXRAT( 323 )      ! TERP+O3=0.2080D+00*xRCHO+...
     &                      +    4.0300D-01 * RXRAT( 324 )      ! TERP+NO3=0.4030D+00*xRCHO+...
     &                      +    3.8500D-01 * RXRAT( 326 )      ! SESQ+OH=0.3850D+00*xRCHO+...
     &                      +    2.0800D-01 * RXRAT( 327 )      ! SESQ+O3=0.2080D+00*xRCHO+...
     &                      +    4.0300D-01 * RXRAT( 328 )      ! SESQ+NO3=0.4030D+00*xRCHO+...
     &                      +    8.4000D-01 * RXRAT( 357 )      ! MEK+CL=0.8400D+00*xRCHO+...
     &                      +    2.0000D-02 * RXRAT( 358 )      ! RNO3+CL=0.2000D-01*xRCHO+...
     &                      +    5.9100D-01 * RXRAT( 359 )      ! PRD2+CL=0.5910D+00*xRCHO+...
     &                      +    1.9700D-01 * RXRAT( 364 )      ! ROOH+CL=0.1970D+00*xRCHO+...
     &                      +    6.7600D-01 * RXRAT( 365 )      ! R6OOH+CL=0.6760D+00*xRCHO+...
     &                      +    4.4800D-01 * RXRAT( 366 )      ! RAOOH+CL=0.4480D+00*xRCHO+...
     &                      +    1.8500D-01 * RXRAT( 386 )      ! APIN+CL=0.1850D+00*xRCHO+...
     &                      +    4.8200D-01 * RXRAT( 395 )      ! ALK2+CL=0.4820D+00*xRCHO+...
     &                      +    3.4300D-01 * RXRAT( 396 )      ! ALK3+CL=0.3430D+00*xRCHO+...
     &                      +    4.1200D-01 * RXRAT( 397 )      ! ALK4+CL=0.4120D+00*xRCHO+...
     &                      +    2.5800D-01 * RXRAT( 398 )      ! ALK5+CL=0.2580D+00*xRCHO+...
     &                      +    7.2000D-02 * RXRAT( 399 )      ! OLE1+CL=0.7200D-01*xRCHO+...
     &                      +    3.1700D-01 * RXRAT( 400 )      ! OLE2+CL=0.3170D+00*xRCHO+...
     &                      +    1.8500D-01 * RXRAT( 404 )      ! TERP+CL=0.1850D+00*xRCHO+...
     &                      +    1.8500D-01 * RXRAT( 405 )      ! SESQ+CL=0.1850D+00*xRCHO+...
      LOSS(  xRCHO        ) =                 RXRAT( 217 )      ! xRCHO=RCHO
     &                      +                 RXRAT( 218 )      ! xRCHO=

      PROD(  HCOOH        ) =    3.3300D-01 * RXRAT( 183 )      ! MACR+O3=0.3330D+00*HCOOH+...
     &                      +    3.5100D-01 * RXRAT( 188 )      ! MVK+O3=0.3510D+00*HCOOH+...
     &                      +    1.0000D-01 * RXRAT( 192 )      ! IPRD+O3=0.1000D+00*HCOOH+...
     &                      +    1.8500D-01 * RXRAT( 203 )      ! ACROLEIN+O3=0.1850D+...
     &                      +    3.7000D-01 * RXRAT( 268 )      ! ETHENE+O3=0.3700D+00*HCOOH+...
     &                      +    1.8500D-01 * RXRAT( 272 )      ! PROPENE+O3=0.1850D+...
     &                      +    1.8500D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.1850D+...
     &                      +    2.0400D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.2040D+...
     &                      +    7.4000D-02 * RXRAT( 287 )      ! IEPOXOO+HO2=0.7400D-...
     &                      +    7.4000D-02 * RXRAT( 288 )      ! IEPOXOO+NO=0.7400D-...
     &                      +    3.7000D-02 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.3700D-...
     &                      +    3.7000D-02 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.3700D-...
     &                      +    7.4000D-02 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.7400D-...
     &                      +    3.0000D-01 * RXRAT( 296 )      ! ACETYLENE+OH=0.3000D+...
     &                      +    1.8500D-01 * RXRAT( 312 )      ! OLE1+O3=0.1850D+00*HCOOH+...
     &                      +    2.4000D-02 * RXRAT( 316 )      ! OLE2+O3=0.2400D-01*HCOOH+...
     &                      +    1.7200D-01 * RXRAT( 323 )      ! TERP+O3=0.1720D+00*HCOOH+...
     &                      +    1.7200D-01 * RXRAT( 327 )      ! SESQ+O3=0.1720D+00*HCOOH+...
      LOSS(  HCOOH        ) =                 RXRAT( 147 )      ! HCOOH+OH=HO2+CO2

      PROD(  xMGLY        ) =    4.9100D-01 * RXRAT( 148 )      ! CCOOH+OH=0.4910D+00*xMGLY+...
     &                      +    2.5200D-01 * RXRAT( 156 )      ! RAOOH+OH=0.2520D+00*xMGLY+...
     &                      +    2.5000D-01 * RXRAT( 166 )      ! CRES+OH=0.2500D+00*xMGLY+...
     &                      +    2.6700D-01 * RXRAT( 174 )      ! AFG1+OH=0.2670D+00*xMGLY+...
     &                      +    2.6700D-01 * RXRAT( 177 )      ! AFG2+OH=0.2670D+00*xMGLY+...
     &                      +    1.5300D-01 * RXRAT( 180 )      ! AFG3+OH=0.1530D+00*xMGLY+...
     &                      +    9.5000D-02 * RXRAT( 181 )      ! AFG3+O3=0.9500D-01*xMGLY+...
     &                      +    8.4000D-02 * RXRAT( 182 )      ! MACR+OH=0.8400D-01*xMGLY+...
     &                      +    3.0000D-01 * RXRAT( 187 )      ! MVK+OH=0.3000D+00*xMGLY+...
     &                      +    1.7400D-01 * RXRAT( 191 )      ! IPRD+OH=0.1740D+00*xMGLY+...
     &                      +    8.0000D-03 * RXRAT( 193 )      ! IPRD+NO3=0.8000D-02*xMGLY+...
     &                      +    2.0000D-02 * RXRAT( 292 )      ! APIN+OH=0.2000D-01*xMGLY+...
     &                      +    2.0000D-03 * RXRAT( 294 )      ! APIN+NO3=0.2000D-02*xMGLY+...
     &                      +    1.5100D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.1510D+...
     &                      +    3.8000D-01 * RXRAT( 300 )      ! MXYL+OH=0.3800D+00*xMGLY+...
     &                      +    2.3800D-01 * RXRAT( 301 )      ! OXYL+OH=0.2380D+00*xMGLY+...
     &                      +    1.1200D-01 * RXRAT( 302 )      ! PXYL+OH=0.1120D+00*xMGLY+...
     &                      +    4.0500D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.4050D+...
     &                      +    1.0000D-01 * RXRAT( 319 )      ! ARO1+OH=0.1000D+00*xMGLY+...
     &                      +    3.1200D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.3120D+00*xMGLY+...
     &                      +    3.1200D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.3120D+...
     &                      +    3.0000D-03 * RXRAT( 322 )      ! TERP+OH=0.3000D-02*xMGLY+...
     &                      +    3.0000D-03 * RXRAT( 323 )      ! TERP+O3=0.3000D-02*xMGLY+...
     &                      +    3.0000D-03 * RXRAT( 326 )      ! SESQ+OH=0.3000D-02*xMGLY+...
     &                      +    3.0000D-03 * RXRAT( 327 )      ! SESQ+O3=0.3000D-02*xMGLY+...
     &                      +    2.5200D-01 * RXRAT( 366 )      ! RAOOH+CL=0.2520D+00*xMGLY+...
     &                      +    1.7000D-02 * RXRAT( 370 )      ! IPRD+CL=0.1700D-01*xMGLY+...
      LOSS(  xMGLY        ) =                 RXRAT( 227 )      ! xMGLY=MGLY
     &                      +                 RXRAT( 228 )      ! xMGLY=

      PROD(  xBACL        ) =    4.5700D-01 * RXRAT( 149 )      ! RCOOH+OH=0.4570D+00*xBACL+...
     &                      +    1.9000D-02 * RXRAT( 180 )      ! AFG3+OH=0.1900D-01*xBACL+...
     &                      +    2.3000D-02 * RXRAT( 292 )      ! APIN+OH=0.2300D-01*xBACL+...
     &                      +    8.1000D-02 * RXRAT( 293 )      ! APIN+O3=0.8100D-01*xBACL+...
     &                      +    1.8500D-01 * RXRAT( 301 )      ! OXYL+OH=0.1850D+00*xBACL+...
     &                      +    1.1200D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.1120D+...
     &                      +    1.3400D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.1340D+00*xBACL+...
     &                      +    1.3400D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.1340D+...
     &                      +    9.0000D-03 * RXRAT( 322 )      ! TERP+OH=0.9000D-02*xBACL+...
     &                      +    3.9000D-02 * RXRAT( 323 )      ! TERP+O3=0.3900D-01*xBACL+...
     &                      +    9.0000D-03 * RXRAT( 326 )      ! SESQ+OH=0.9000D-02*xBACL+...
     &                      +    3.9000D-02 * RXRAT( 327 )      ! SESQ+O3=0.3900D-01*xBACL+...
     &                      +    3.0000D-03 * RXRAT( 386 )      ! APIN+CL=0.3000D-02*xBACL+...
     &                      +    3.0000D-03 * RXRAT( 404 )      ! TERP+CL=0.3000D-02*xBACL+...
     &                      +    3.0000D-03 * RXRAT( 405 )      ! SESQ+CL=0.3000D-02*xBACL+...
      LOSS(  xBACL        ) =                 RXRAT( 229 )      ! xBACL=BACL
     &                      +                 RXRAT( 230 )      ! xBACL=

      PROD(  ROOH         ) =                 RXRAT( 250 )      ! yROOH=ROOH
      LOSS(  ROOH         ) =                 RXRAT( 152 )      ! ROOH+OH=0.7440D+00*OH+...
     &                      +                 RXRAT( 153 )      ! ROOH=RCHO+HO2+OH
     &                      +                 RXRAT( 364 )      ! ROOH+CL=HCL+0.4140D+00*OH+...

      PROD(  xPROD2       ) =    3.4000D-02 * RXRAT( 152 )      ! ROOH+OH=0.3400D-01*xPROD2+...
     &                      +    8.4000D-02 * RXRAT( 154 )      ! R6OOH+OH=0.8400D-01*xPROD2+...
     &                      +    6.9800D-01 * RXRAT( 155 )      ! R6OOH=0.6980D+00*xPROD2+...
     &                      +    3.3200D-01 * RXRAT( 191 )      ! IPRD+OH=0.3320D+00*xPROD2+...
     &                      +    7.0000D-03 * RXRAT( 195 )      ! PRD2+OH=0.7000D-02*xPROD2+...
     &                      +    3.1000D-02 * RXRAT( 197 )      ! RNO3+OH=0.3100D-01*xPROD2+...
     &                      +    2.6100D-01 * RXRAT( 198 )      ! RNO3=0.2610D+00*xPROD2+...
     &                      +    1.4600D-01 * RXRAT( 308 )      ! ALK4+OH=0.1460D+00*xPROD2+...
     &                      +    4.0700D-01 * RXRAT( 309 )      ! ALK5+OH=0.4070D+00*xPROD2+...
     &                      +    1.6800D-01 * RXRAT( 311 )      ! OLE1+OH=0.1680D+00*xPROD2+...
     &                      +    2.3000D-02 * RXRAT( 315 )      ! OLE2+OH=0.2300D-01*xPROD2+...
     &                      +    3.0900D-01 * RXRAT( 319 )      ! ARO1+OH=0.3090D+00*xPROD2+...
     &                      +    5.7000D-02 * RXRAT( 320 )      ! ARO2MN+OH=0.5700D-...
     &                      +    5.7000D-02 * RXRAT( 321 )      ! NAPHTHAL+OH=0.5700D-...
     &                      +    4.0900D-01 * RXRAT( 322 )      ! TERP+OH=0.4090D+00*xPROD2+...
     &                      +    4.0900D-01 * RXRAT( 326 )      ! SESQ+OH=0.4090D+00*xPROD2+...
     &                      +    4.6000D-02 * RXRAT( 358 )      ! RNO3+CL=0.4600D-01*xPROD2+...
     &                      +    4.0000D-02 * RXRAT( 359 )      ! PRD2+CL=0.4000D-01*xPROD2+...
     &                      +    2.8000D-01 * RXRAT( 365 )      ! R6OOH+CL=0.2800D+00*xPROD2+...
     &                      +    1.3000D-01 * RXRAT( 397 )      ! ALK4+CL=0.1300D+00*xPROD2+...
     &                      +    3.7800D-01 * RXRAT( 398 )      ! ALK5+CL=0.3780D+00*xPROD2+...
     &                      +    8.4000D-01 * RXRAT( 401 )      ! ARO1+CL=0.8400D+00*xPROD2+...
     &                      +    3.5900D-01 * RXRAT( 402 )      ! ARO2MN+CL=0.3590D+...
     &                      +    3.5900D-01 * RXRAT( 403 )      ! NAPHTHAL+CL=0.3590D+...
      LOSS(  xPROD2       ) =                 RXRAT( 223 )      ! xPROD2=PRD2
     &                      +                 RXRAT( 224 )      ! xPROD2=

      PROD(  R6OOH        ) =                 RXRAT( 253 )      ! yR6OOH=R6OOH
      LOSS(  R6OOH        ) =                 RXRAT( 154 )      ! R6OOH+OH=0.8400D+00*OH+...
     &                      +                 RXRAT( 155 )      ! R6OOH=OH+0.1420D+00*HO2+...
     &                      +                 RXRAT( 365 )      ! R6OOH+CL=HCL+0.1450D+00*OH+...

      PROD(  PRD2         ) =    8.4000D-01 * RXRAT( 154 )      ! R6OOH+OH=0.8400D+00*PRD2+...
     &                      +    1.4200D-01 * RXRAT( 155 )      ! R6OOH=0.1420D+00*PRD2+...
     &                      +    7.4000D-02 * RXRAT( 156 )      ! RAOOH+OH=0.7400D-01*PRD2+...
     &                      +                 RXRAT( 179 )      ! AFG2=PRD2
     &                      +    6.0000D-01 * RXRAT( 190 )      ! MVK=0.6000D+00*PRD2+...
     &                      +    8.0000D-03 * RXRAT( 197 )      ! RNO3+OH=0.8000D-02*PRD2+...
     &                      +    1.9000D-01 * RXRAT( 198 )      ! RNO3=0.1900D+00*PRD2+...
     &                      +                 RXRAT( 223 )      ! xPROD2=PRD2
     &                      +                 RXRAT( 248 )      ! zRNO3=PRD2+HO2
     &                      +                 RXRAT( 254 )      ! yR6OOH=PRD2
     &                      +                 RXRAT( 257 )      ! yISOPOOH=PRD2
     &                      +                 RXRAT( 260 )      ! yRAOOH=PRD2
     &                      +    1.2500D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.1250D+...
     &                      +    7.5000D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.7500D+...
     &                      +    1.0000D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1000D+...
     &                      +    7.5000D-01 * RXRAT( 282 )      ! ISOPRENE+O3P=0.7500D+...
     &                      +    5.0000D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.5000D+...
     &                      +    5.0000D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.5000D+...
     &                      +    2.5500D-01 * RXRAT( 293 )      ! APIN+O3=0.2550D+00*PRD2+...
     &                      +                 RXRAT( 295 )      ! APIN+O3P=PRD2+TRPRXN
     &                      +    2.6800D-01 * RXRAT( 312 )      ! OLE1+O3=0.2680D+00*PRD2+...
     &                      +    1.6000D-01 * RXRAT( 314 )      ! OLE1+O3P=0.1600D+00*PRD2+...
     &                      +    3.7000D-02 * RXRAT( 316 )      ! OLE2+O3=0.3700D-01*PRD2+...
     &                      +    1.7000D-01 * RXRAT( 318 )      ! OLE2+O3P=0.1700D+00*PRD2+...
     &                      +    5.0200D-01 * RXRAT( 323 )      ! TERP+O3=0.5020D+00*PRD2+...
     &                      +    7.6300D-01 * RXRAT( 325 )      ! TERP+O3P=0.7630D+00*PRD2+...
     &                      +    5.0200D-01 * RXRAT( 327 )      ! SESQ+O3=0.5020D+00*PRD2+...
     &                      +    7.6300D-01 * RXRAT( 329 )      ! SESQ+O3P=0.7630D+00*PRD2+...
     &                      +    1.2000D-02 * RXRAT( 358 )      ! RNO3+CL=0.1200D-01*PRD2+...
     &                      +    1.4500D-01 * RXRAT( 365 )      ! R6OOH+CL=0.1450D+00*PRD2+...
     &                      +    7.4000D-02 * RXRAT( 366 )      ! RAOOH+CL=0.7400D-01*PRD2+...
      LOSS(  PRD2         ) =    6.7100D-01 * RXRAT( 195 )      ! PRD2+OH=0.3290D+00*PRD2+...
     &                      +                 RXRAT( 196 )      ! PRD2=0.9130D+00*xHO2+...
     &                      +    8.8400D-01 * RXRAT( 359 )      ! PRD2+CL=0.1160D+00*PRD2+...

      PROD(  yR6OOH       ) =    8.5800D-01 * RXRAT( 155 )      ! R6OOH=0.8580D+00*yR6OOH+...
     &                      +    7.1300D-01 * RXRAT( 156 )      ! RAOOH+OH=0.7130D+00*yR6OOH+...
     &                      +    8.0000D-01 * RXRAT( 166 )      ! CRES+OH=0.8000D+00*yR6OOH+...
     &                      +    7.8300D-01 * RXRAT( 174 )      ! AFG1+OH=0.7830D+00*yR6OOH+...
     &                      +    6.5200D-01 * RXRAT( 175 )      ! AFG1+O3=0.6520D+00*yR6OOH+...
     &                      +    7.8300D-01 * RXRAT( 177 )      ! AFG2+OH=0.7830D+00*yR6OOH+...
     &                      +    6.5200D-01 * RXRAT( 178 )      ! AFG2+O3=0.6520D+00*yR6OOH+...
     &                      +    7.9400D-01 * RXRAT( 180 )      ! AFG3+OH=0.7940D+00*yR6OOH+...
     &                      +    2.6400D-01 * RXRAT( 181 )      ! AFG3+O3=0.2640D+00*yR6OOH+...
     &                      +    7.1100D-01 * RXRAT( 191 )      ! IPRD+OH=0.7110D+00*yR6OOH+...
     &                      +    4.8000D-02 * RXRAT( 192 )      ! IPRD+O3=0.4800D-01*yR6OOH+...
     &                      +    8.5000D-01 * RXRAT( 193 )      ! IPRD+NO3=0.8500D+00*yR6OOH+...
     &                      +    5.2800D-01 * RXRAT( 195 )      ! PRD2+OH=0.5280D+00*yR6OOH+...
     &                      +                 RXRAT( 196 )      ! PRD2=yR6OOH+0.4000D+...
     &                      +    6.3600D-01 * RXRAT( 197 )      ! RNO3+OH=0.6360D+00*yR6OOH+...
     &                      +    5.9100D-01 * RXRAT( 198 )      ! RNO3=0.5910D+00*yR6OOH+...
     &                      +    2.0000D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.2000D+...
     &                      +                 RXRAT( 281 )      ! ISOPRENE+NO3=yR6OOH+...
     &                      +    2.5000D-01 * RXRAT( 282 )      ! ISOPRENE+O3P=0.2500D+...
     &                      +                 RXRAT( 292 )      ! APIN+OH=yR6OOH+0.4000D-...
     &                      +    7.3700D-01 * RXRAT( 293 )      ! APIN+O3=0.7370D+00*yR6OOH+...
     &                      +                 RXRAT( 294 )      ! APIN+NO3=yR6OOH+0.6430D+...
     &                      +    7.3000D-02 * RXRAT( 299 )      ! TOLUENE+OH=0.7300D-...
     &                      +    4.7000D-02 * RXRAT( 300 )      ! MXYL+OH=0.4700D-01*yR6OOH+...
     &                      +    5.5000D-02 * RXRAT( 301 )      ! OXYL+OH=0.5500D-01*yR6OOH+...
     &                      +    1.0200D-01 * RXRAT( 302 )      ! PXYL+OH=0.1020D+00*yR6OOH+...
     &                      +    4.3000D-02 * RXRAT( 303 )      ! TMBENZ124+OH=0.4300D-...
     &                      +    1.7000D-02 * RXRAT( 307 )      ! ALK3+OH=0.1700D-01*yR6OOH+...
     &                      +                 RXRAT( 308 )      ! ALK4+OH=yR6OOH+0.1000D-...
     &                      +                 RXRAT( 309 )      ! ALK5+OH=yR6OOH+0.1605D+...
     &                      +    8.3100D-01 * RXRAT( 311 )      ! OLE1+OH=0.8310D+00*yR6OOH+...
     &                      +    5.2000D-02 * RXRAT( 312 )      ! OLE1+O3=0.5200D-01*yR6OOH+...
     &                      +    8.3100D-01 * RXRAT( 313 )      ! OLE1+NO3=0.8310D+00*yR6OOH+...
     &                      +    6.8100D-01 * RXRAT( 315 )      ! OLE2+OH=0.6810D+00*yR6OOH+...
     &                      +    1.3600D-01 * RXRAT( 316 )      ! OLE2+O3=0.1360D+00*yR6OOH+...
     &                      +    6.8100D-01 * RXRAT( 317 )      ! OLE2+NO3=0.6810D+00*yR6OOH+...
     &                      +    3.6900D-01 * RXRAT( 319 )      ! ARO1+OH=0.3690D+00*yR6OOH+...
     &                      +    1.0100D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.1010D+...
     &                      +    1.0100D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.1010D+...
     &                      +                 RXRAT( 322 )      ! TERP+OH=yR6OOH+0.6400D-...
     &                      +    4.2800D-01 * RXRAT( 323 )      ! TERP+O3=0.4280D+00*yR6OOH+...
     &                      +                 RXRAT( 324 )      ! TERP+NO3=yR6OOH+0.2870D+...
     &                      +                 RXRAT( 326 )      ! SESQ+OH=yR6OOH+0.6400D-...
     &                      +    4.2800D-01 * RXRAT( 327 )      ! SESQ+O3=0.4280D+00*yR6OOH+...
     &                      +                 RXRAT( 328 )      ! SESQ+NO3=yR6OOH+0.2870D+...
     &                      +    9.0800D-01 * RXRAT( 358 )      ! RNO3+CL=0.9080D+00*yR6OOH+...
     &                      +    6.8600D-01 * RXRAT( 359 )      ! PRD2+CL=0.6860D+00*yR6OOH+...
     &                      +                 RXRAT( 362 )      ! CRES+CL=yR6OOH+xHO2+xBALD+HCL
     &                      +    8.5500D-01 * RXRAT( 365 )      ! R6OOH+CL=0.8550D+00*yR6OOH+...
     &                      +    7.1300D-01 * RXRAT( 366 )      ! RAOOH+CL=0.7130D+00*yR6OOH+...
     &                      +    7.6200D-01 * RXRAT( 370 )      ! IPRD+CL=0.7620D+00*yR6OOH+...
     &                      +                 RXRAT( 385 )      ! ISOPRENE+CL=yR6OOH+0.7380D+...
     &                      +                 RXRAT( 386 )      ! APIN+CL=yR6OOH+0.2520D+...
     &                      +    1.7000D-02 * RXRAT( 396 )      ! ALK3+CL=0.1700D-01*yR6OOH+...
     &                      +                 RXRAT( 397 )      ! ALK4+CL=yR6OOH+0.8270D+...
     &                      +                 RXRAT( 398 )      ! ALK5+CL=yR6OOH+0.6470D+...
     &                      +    8.3100D-01 * RXRAT( 399 )      ! OLE1+CL=0.8310D+00*yR6OOH+...
     &                      +    6.8100D-01 * RXRAT( 400 )      ! OLE2+CL=0.6810D+00*yR6OOH+...
     &                      +                 RXRAT( 404 )      ! TERP+CL=yR6OOH+0.2520D+...
     &                      +                 RXRAT( 405 )      ! SESQ+CL=yR6OOH+0.6800D-...
      LOSS(  yR6OOH       ) =                 RXRAT( 253 )      ! yR6OOH=R6OOH
     &                      +                 RXRAT( 254 )      ! yR6OOH=PRD2
     &                      +                 RXRAT( 255 )      ! yR6OOH=

      PROD(  RAOOH        ) =                 RXRAT( 259 )      ! yRAOOH=RAOOH
      LOSS(  RAOOH        ) =                 RXRAT( 156 )      ! RAOOH+OH=0.1390D+00*OH+...
     &                      +                 RXRAT( 157 )      ! RAOOH=OH+HO2+0.5000D+...
     &                      +                 RXRAT( 366 )      ! RAOOH+CL=0.4040D+00*HCL+...

      PROD(  MGLY         ) =    1.4700D-01 * RXRAT( 156 )      ! RAOOH+OH=0.1470D+00*MGLY+...
     &                      +    5.0000D-01 * RXRAT( 157 )      ! RAOOH=0.5000D+00*MGLY+HO2+...
     &                      +    5.6800D-01 * RXRAT( 175 )      ! AFG1+O3=0.5680D+00*MGLY+...
     &                      +    3.0500D-01 * RXRAT( 176 )      ! AFG1=0.3050D+00*MGLY+...
     &                      +    5.6800D-01 * RXRAT( 178 )      ! AFG2+O3=0.5680D+00*MGLY+...
     &                      +    1.8400D-01 * RXRAT( 181 )      ! AFG3+O3=0.1840D+00*MGLY+...
     &                      +    9.0000D-01 * RXRAT( 183 )      ! MACR+O3=0.9000D+00*MGLY+...
     &                      +    9.5000D-01 * RXRAT( 188 )      ! MVK+O3=0.9500D+00*MGLY+...
     &                      +    7.4200D-01 * RXRAT( 192 )      ! IPRD+O3=0.7420D+00*MGLY+...
     &                      +                 RXRAT( 227 )      ! xMGLY=MGLY
     &                      +    2.7500D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.2750D+...
     &                      +    2.7500D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.2750D+00*MGLY+...
     &                      +    1.3800D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.1380D+...
     &                      +    1.3800D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.1380D+...
     &                      +    2.7500D-01 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.2750D+...
     &                      +    1.4700D-01 * RXRAT( 366 )      ! RAOOH+CL=0.1470D+00*MGLY+...
      LOSS(  MGLY         ) =                 RXRAT( 162 )      ! MGLY=HO2+CO+MECO3
     &                      +                 RXRAT( 163 )      ! MGLY+OH=CO+MECO3
     &                      +                 RXRAT( 164 )      ! MGLY+NO3=HNO3+CO+MECO3
     &                      +                 RXRAT( 361 )      ! MGLY+CL=HCL+CO+MECO3

      PROD(  IPRD         ) =    1.3900D-01 * RXRAT( 156 )      ! RAOOH+OH=0.1390D+00*IPRD+...
     &                      +    3.0000D-03 * RXRAT( 181 )      ! AFG3+O3=0.3000D-02*IPRD+...
     &                      +                 RXRAT( 243 )      ! xIPRD=IPRD
     &                      +    1.5000D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1500D+...
     &                      +    1.3900D-01 * RXRAT( 366 )      ! RAOOH+CL=0.1390D+00*IPRD+...
      LOSS(  IPRD         ) =                 RXRAT( 191 )      ! IPRD+OH=0.2890D+00*MACO3+...
     &                      +                 RXRAT( 192 )      ! IPRD+O3=0.2850D+00*OH+...
     &                      +                 RXRAT( 193 )      ! IPRD+NO3=0.1500D+00*MACO3+...
     &                      +                 RXRAT( 194 )      ! IPRD=0.1233D+01*HO2+...
     &                      +                 RXRAT( 370 )      ! IPRD+CL=0.4010D+00*HCL+...

      PROD(  xGLY         ) =    2.6000D-02 * RXRAT( 156 )      ! RAOOH+OH=0.2600D-01*xGLY+...
     &                      +    1.0700D-01 * RXRAT( 174 )      ! AFG1+OH=0.1070D+00*xGLY+...
     &                      +    1.0700D-01 * RXRAT( 177 )      ! AFG2+OH=0.1070D+00*xGLY+...
     &                      +    2.7400D-01 * RXRAT( 180 )      ! AFG3+OH=0.2740D+00*xGLY+...
     &                      +    1.5000D-01 * RXRAT( 191 )      ! IPRD+OH=0.1500D+00*xGLY+...
     &                      +    8.3000D-02 * RXRAT( 202 )      ! ACROLEIN+OH=0.8300D-...
     &                      +    1.2000D-02 * RXRAT( 270 )      ! ETHENE+O3P=0.1200D-01*xGLY+...
     &                      +    2.0000D-03 * RXRAT( 293 )      ! APIN+O3=0.2000D-02*xGLY+...
     &                      +    2.9000D-01 * RXRAT( 298 )      ! BENZENE+OH=0.2900D+00*xGLY+...
     &                      +    2.3800D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.2380D+00*xGLY+...
     &                      +    1.0000D-01 * RXRAT( 300 )      ! MXYL+OH=0.1000D+00*xGLY+...
     &                      +    8.4000D-02 * RXRAT( 301 )      ! OXYL+OH=0.8400D-01*xGLY+...
     &                      +    2.8600D-01 * RXRAT( 302 )      ! PXYL+OH=0.2860D+00*xGLY+...
     &                      +    7.4000D-02 * RXRAT( 303 )      ! TMBENZ124+OH=0.7400D-...
     &                      +    1.5800D-01 * RXRAT( 319 )      ! ARO1+OH=0.1580D+00*xGLY+...
     &                      +    8.8000D-02 * RXRAT( 320 )      ! ARO2MN+OH=0.8800D-01*xGLY+...
     &                      +    8.8000D-02 * RXRAT( 321 )      ! NAPHTHAL+OH=0.8800D-...
     &                      +    2.6000D-02 * RXRAT( 366 )      ! RAOOH+CL=0.2600D-01*xGLY+...
     &                      +    2.7400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.2740D+...
     &                      +    7.0000D-03 * RXRAT( 386 )      ! APIN+CL=0.7000D-02*xGLY+...
     &                      +    7.0000D-03 * RXRAT( 404 )      ! TERP+CL=0.7000D-02*xGLY+...
     &                      +    7.0000D-03 * RXRAT( 405 )      ! SESQ+CL=0.7000D-02*xGLY+...
      LOSS(  xGLY         ) =                 RXRAT( 225 )      ! xGLY=GLY
     &                      +                 RXRAT( 226 )      ! xGLY=

      PROD(  xMEK         ) =    3.0000D-02 * RXRAT( 156 )      ! RAOOH+OH=0.3000D-01*xMEK+...
     &                      +    1.2900D-01 * RXRAT( 174 )      ! AFG1+OH=0.1290D+00*xMEK+...
     &                      +    1.2900D-01 * RXRAT( 177 )      ! AFG2+OH=0.1290D+00*xMEK+...
     &                      +    4.1600D-01 * RXRAT( 182 )      ! MACR+OH=0.4160D+00*xMEK+...
     &                      +    1.5000D-01 * RXRAT( 191 )      ! IPRD+OH=0.1500D+00*xMEK+...
     &                      +    1.1500D-01 * RXRAT( 195 )      ! PRD2+OH=0.1150D+00*xMEK+...
     &                      +    1.7000D-01 * RXRAT( 197 )      ! RNO3+OH=0.1700D+00*xMEK+...
     &                      +    8.3000D-02 * RXRAT( 198 )      ! RNO3=0.8300D-01*xMEK+...
     &                      +    3.3200D-01 * RXRAT( 307 )      ! ALK3+OH=0.3320D+00*xMEK+...
     &                      +    1.0600D-01 * RXRAT( 308 )      ! ALK4+OH=0.1060D+00*xMEK+...
     &                      +    8.6000D-02 * RXRAT( 309 )      ! ALK5+OH=0.8600D-01*xMEK+...
     &                      +    8.0000D-02 * RXRAT( 315 )      ! OLE2+OH=0.8000D-01*xMEK+...
     &                      +    1.0000D-03 * RXRAT( 316 )      ! OLE2+O3=0.1000D-02*xMEK+...
     &                      +    2.0000D-03 * RXRAT( 317 )      ! OLE2+NO3=0.2000D-02*xMEK+...
     &                      +    7.0000D-03 * RXRAT( 322 )      ! TERP+OH=0.7000D-02*xMEK+...
     &                      +    7.0000D-03 * RXRAT( 326 )      ! SESQ+OH=0.7000D-02*xMEK+...
     &                      +    4.1000D-02 * RXRAT( 358 )      ! RNO3+CL=0.4100D-01*xMEK+...
     &                      +    5.1000D-02 * RXRAT( 359 )      ! PRD2+CL=0.5100D-01*xMEK+...
     &                      +    2.8500D-01 * RXRAT( 364 )      ! ROOH+CL=0.2850D+00*xMEK+...
     &                      +    3.0000D-02 * RXRAT( 366 )      ! RAOOH+CL=0.3000D-01*xMEK+...
     &                      +    2.5300D-01 * RXRAT( 396 )      ! ALK3+CL=0.2530D+00*xMEK+...
     &                      +    7.6000D-02 * RXRAT( 397 )      ! ALK4+CL=0.7600D-01*xMEK+...
     &                      +    4.1000D-02 * RXRAT( 398 )      ! ALK5+CL=0.4100D-01*xMEK+...
     &                      +    4.2000D-02 * RXRAT( 400 )      ! OLE2+CL=0.4200D-01*xMEK+...
      LOSS(  xMEK         ) =                 RXRAT( 221 )      ! xMEK=MEK
     &                      +                 RXRAT( 222 )      ! xMEK=

      PROD(  xAFG1        ) =    7.3000D-02 * RXRAT( 156 )      ! RAOOH+OH=0.7300D-01*xAFG1+...
     &                      +    1.9500D-01 * RXRAT( 180 )      ! AFG3+OH=0.1950D+00*xAFG1+...
     &                      +    1.0000D-03 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1000D-...
     &                      +    2.9000D-02 * RXRAT( 298 )      ! BENZENE+OH=0.2900D-...
     &                      +    1.9500D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.1950D+...
     &                      +    3.3600D-01 * RXRAT( 300 )      ! MXYL+OH=0.3360D+00*xAFG1+...
     &                      +    2.5300D-01 * RXRAT( 301 )      ! OXYL+OH=0.2530D+00*xAFG1+...
     &                      +    4.5000D-02 * RXRAT( 302 )      ! PXYL+OH=0.4500D-01*xAFG1+...
     &                      +    8.8000D-02 * RXRAT( 303 )      ! TMBENZ124+OH=0.8800D-...
     &                      +    7.2000D-02 * RXRAT( 319 )      ! ARO1+OH=0.7200D-01*xAFG1+...
     &                      +    2.2100D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.2210D+00*xAFG1+...
     &                      +    2.2100D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.2210D+...
     &                      +    7.3000D-02 * RXRAT( 366 )      ! RAOOH+CL=0.7300D-01*xAFG1+...
     &                      +    9.0000D-03 * RXRAT( 370 )      ! IPRD+CL=0.9000D-02*xAFG1+...
     &                      +    6.0000D-03 * RXRAT( 386 )      ! APIN+CL=0.6000D-02*xAFG1+...
     &                      +    6.0000D-03 * RXRAT( 404 )      ! TERP+CL=0.6000D-02*xAFG1+...
     &                      +    6.0000D-03 * RXRAT( 405 )      ! SESQ+CL=0.6000D-02*xAFG1+...
      LOSS(  xAFG1        ) =                 RXRAT( 233 )      ! xAFG1=AFG1
     &                      +                 RXRAT( 234 )      ! xAFG1=

      PROD(  xAFG2        ) =    7.3000D-02 * RXRAT( 156 )      ! RAOOH+OH=0.7300D-01*xAFG2+...
     &                      +    1.9500D-01 * RXRAT( 180 )      ! AFG3+OH=0.1950D+00*xAFG2+...
     &                      +    1.0000D-03 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1000D-...
     &                      +    2.6100D-01 * RXRAT( 298 )      ! BENZENE+OH=0.2610D+...
     &                      +    1.9500D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.1950D+...
     &                      +    1.4400D-01 * RXRAT( 300 )      ! MXYL+OH=0.1440D+00*xAFG2+...
     &                      +    2.5300D-01 * RXRAT( 301 )      ! OXYL+OH=0.2530D+00*xAFG2+...
     &                      +    6.7000D-02 * RXRAT( 302 )      ! PXYL+OH=0.6700D-01*xAFG2+...
     &                      +    3.5200D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.3520D+...
     &                      +    1.8500D-01 * RXRAT( 319 )      ! ARO1+OH=0.1850D+00*xAFG2+...
     &                      +    2.4700D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.2470D+00*xAFG2+...
     &                      +    2.4700D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.2470D+...
     &                      +    7.3000D-02 * RXRAT( 366 )      ! RAOOH+CL=0.7300D-01*xAFG2+...
     &                      +    9.0000D-03 * RXRAT( 370 )      ! IPRD+CL=0.9000D-02*xAFG2+...
     &                      +    6.0000D-03 * RXRAT( 386 )      ! APIN+CL=0.6000D-02*xAFG2+...
     &                      +    6.0000D-03 * RXRAT( 404 )      ! TERP+CL=0.6000D-02*xAFG2+...
     &                      +    6.0000D-03 * RXRAT( 405 )      ! SESQ+CL=0.6000D-02*xAFG2+...
      LOSS(  xAFG2        ) =                 RXRAT( 235 )      ! xAFG2=AFG2
     &                      +                 RXRAT( 236 )      ! xAFG2=

      PROD(  GLY          ) =    5.0000D-01 * RXRAT( 157 )      ! RAOOH=0.5000D+00*GLY+HO2+...
     &                      +    4.3200D-01 * RXRAT( 175 )      ! AFG1+O3=0.4320D+00*GLY+...
     &                      +    1.9500D-01 * RXRAT( 176 )      ! AFG1=0.1950D+00*GLY+...
     &                      +    4.3200D-01 * RXRAT( 178 )      ! AFG2+O3=0.4320D+00*GLY+...
     &                      +    3.6600D-01 * RXRAT( 181 )      ! AFG3+O3=0.3660D+00*GLY+...
     &                      +    2.3000D-02 * RXRAT( 192 )      ! IPRD+O3=0.2300D-01*GLY+...
     &                      +    5.0000D-01 * RXRAT( 203 )      ! ACROLEIN+O3=0.5000D+00*GLY+...
     &                      +    5.6000D-01 * RXRAT( 212 )      ! HCOCO3+HO2=0.5600D+00*GLY+...
     &                      +                 RXRAT( 225 )      ! xGLY=GLY
     &                      +    2.7500D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.2750D+00*GLY+...
     &                      +    2.7500D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.2750D+00*GLY+...
     &                      +    1.3800D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.1380D+...
     &                      +    1.3800D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.1380D+...
     &                      +    2.7500D-01 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.2750D+...
     &                      +    7.0000D-01 * RXRAT( 296 )      ! ACETYLENE+OH=0.7000D+...
      LOSS(  GLY          ) =                 RXRAT( 158 )      ! GLY=0.2000D+01*CO+0.2000D+...
     &                      +                 RXRAT( 159 )      ! GLY=HCHO+CO
     &                      +                 RXRAT( 160 )      ! GLY+OH=0.7000D+00*HO2+...
     &                      +                 RXRAT( 161 )      ! GLY+NO3=HNO3+0.7000D+...
     &                      +                 RXRAT( 360 )      ! GLY+CL=HCL+0.6300D+00*HO2+...

      PROD(  AFG1         ) =    5.0000D-01 * RXRAT( 157 )      ! RAOOH=0.5000D+00*AFG1+HO2+...
     &                      +    3.5000D-01 * RXRAT( 181 )      ! AFG3+O3=0.3500D+00*AFG1+...
     &                      +                 RXRAT( 233 )      ! xAFG1=AFG1
     &                      +    4.2000D-02 * RXRAT( 370 )      ! IPRD+CL=0.4200D-01*AFG1+...
      LOSS(  AFG1         ) =                 RXRAT( 174 )      ! AFG1+OH=0.2170D+00*MACO3+...
     &                      +                 RXRAT( 175 )      ! AFG1+O3=0.8260D+00*OH+...
     &                      +                 RXRAT( 176 )      ! AFG1=0.1023D+01*HO2+...

      PROD(  AFG2         ) =    5.0000D-01 * RXRAT( 157 )      ! RAOOH=0.5000D+00*AFG2+HO2+...
     &                      +    3.5000D-01 * RXRAT( 181 )      ! AFG3+O3=0.3500D+00*AFG2+...
     &                      +                 RXRAT( 235 )      ! xAFG2=AFG2
     &                      +    4.2000D-02 * RXRAT( 370 )      ! IPRD+CL=0.4200D-01*AFG2+...
      LOSS(  AFG2         ) =                 RXRAT( 177 )      ! AFG2+OH=0.2170D+00*MACO3+...
     &                      +                 RXRAT( 178 )      ! AFG2+O3=0.8260D+00*OH+...
     &                      +                 RXRAT( 179 )      ! AFG2=PRD2

      PROD(  HCOCO3       ) =    3.0000D-01 * RXRAT( 160 )      ! GLY+OH=0.3000D+00*HCOCO3+...
     &                      +    3.0000D-01 * RXRAT( 161 )      ! GLY+NO3=0.3000D+00*HCOCO3+...
      LOSS(  HCOCO3       ) =                 RXRAT( 210 )      ! HCOCO3+NO=HO2+CO+CO2+NO2
     &                      +                 RXRAT( 211 )      ! HCOCO3+NO2=HO2+CO+CO2+NO3
     &                      +                 RXRAT( 212 )      ! HCOCO3+HO2=0.4400D+00*OH+...

      PROD(  BACL         ) =                 RXRAT( 229 )      ! xBACL=BACL
      LOSS(  BACL         ) =                 RXRAT( 165 )      ! BACL=0.2000D+01*MECO3

      PROD(  BALD         ) =                 RXRAT( 231 )      ! xBALD=BALD
      LOSS(  BALD         ) =                 RXRAT( 171 )      ! BALD+OH=BZCO3
     &                      +                 RXRAT( 172 )      ! BALD=
     &                      +                 RXRAT( 173 )      ! BALD+NO3=HNO3+BZCO3
     &                      +                 RXRAT( 363 )      ! BALD+CL=HCL+BZCO3

      PROD(  AFG3         ) =                 RXRAT( 237 )      ! xAFG3=AFG3
     &                      +    1.1600D-01 * RXRAT( 298 )      ! BENZENE+OH=0.1160D+00*AFG3+...
     &                      +    3.1200D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.3120D+00*AFG3+...
     &                      +    2.3900D-01 * RXRAT( 300 )      ! MXYL+OH=0.2390D+00*AFG3+...
     &                      +    1.9800D-01 * RXRAT( 301 )      ! OXYL+OH=0.1980D+00*AFG3+...
     &                      +    2.7800D-01 * RXRAT( 302 )      ! PXYL+OH=0.2780D+00*AFG3+...
     &                      +    2.3000D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.2300D+...
     &                      +    2.0200D-01 * RXRAT( 319 )      ! ARO1+OH=0.2020D+00*AFG3+...
     &                      +    1.7800D-01 * RXRAT( 320 )      ! ARO2MN+OH=0.1780D+00*AFG3+...
     &                      +    1.7800D-01 * RXRAT( 321 )      ! NAPHTHAL+OH=0.1780D+...
      LOSS(  AFG3         ) =                 RXRAT( 180 )      ! AFG3+OH=0.2060D+00*MACO3+...
     &                      +    8.6100D-01 * RXRAT( 181 )      ! AFG3+O3=0.1390D+00*AFG3+...

      PROD(  xIPRD        ) =    2.3100D-01 * RXRAT( 180 )      ! AFG3+OH=0.2310D+00*xIPRD+...
     &                      +    4.7100D-01 * RXRAT( 275 )      ! BUTADIENE13+OH=0.4710D+...
     &                      +    1.2000D-01 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.1200D+...
     &                      +    3.5700D-01 * RXRAT( 279 )      ! ISOPRENE+OH=0.3570D+...
     &                      +    9.3600D-01 * RXRAT( 281 )      ! ISOPRENE+NO3=0.9360D+...
     &                      +    9.0000D-03 * RXRAT( 311 )      ! OLE1+OH=0.9000D-02*xIPRD+...
     &                      +    1.2000D-02 * RXRAT( 315 )      ! OLE2+OH=0.1200D-01*xIPRD+...
     &                      +    2.0000D-03 * RXRAT( 322 )      ! TERP+OH=0.2000D-02*xIPRD+...
     &                      +    1.0000D-03 * RXRAT( 323 )      ! TERP+O3=0.1000D-02*xIPRD+...
     &                      +    4.0000D-03 * RXRAT( 324 )      ! TERP+NO3=0.4000D-02*xIPRD+...
     &                      +    2.0000D-03 * RXRAT( 326 )      ! SESQ+OH=0.2000D-02*xIPRD+...
     &                      +    1.0000D-03 * RXRAT( 327 )      ! SESQ+O3=0.1000D-02*xIPRD+...
     &                      +    4.0000D-03 * RXRAT( 328 )      ! SESQ+NO3=0.4000D-02*xIPRD+...
     &                      +    8.2000D-02 * RXRAT( 368 )      ! MACR+CL=0.8200D-01*xIPRD+...
     &                      +    1.1500D-01 * RXRAT( 370 )      ! IPRD+CL=0.1150D+00*xIPRD+...
     &                      +    4.7300D-01 * RXRAT( 384 )      ! BUTADIENE13+CL=0.4730D+...
     &                      +    6.7100D-01 * RXRAT( 385 )      ! ISOPRENE+CL=0.6710D+...
     &                      +    1.5800D-01 * RXRAT( 386 )      ! APIN+CL=0.1580D+00*xIPRD+...
     &                      +    3.8000D-02 * RXRAT( 399 )      ! OLE1+CL=0.3800D-01*xIPRD+...
     &                      +    1.6100D-01 * RXRAT( 400 )      ! OLE2+CL=0.1610D+00*xIPRD+...
     &                      +    1.5800D-01 * RXRAT( 404 )      ! TERP+CL=0.1580D+00*xIPRD+...
     &                      +    1.5800D-01 * RXRAT( 405 )      ! SESQ+CL=0.1580D+00*xIPRD+...
      LOSS(  xIPRD        ) =                 RXRAT( 243 )      ! xIPRD=IPRD
     &                      +                 RXRAT( 244 )      ! xIPRD=

      PROD(  MACR         ) =    3.0000D-03 * RXRAT( 181 )      ! AFG3+O3=0.3000D-02*MACR+...
     &                      +                 RXRAT( 239 )      ! xMACR=MACR
     &                      +    3.9000D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.3900D+...
     &                      +    2.9000D-01 * RXRAT( 285 )      ! ISOPOOH=0.2900D+00*MACR+...
      LOSS(  MACR         ) =                 RXRAT( 182 )      ! MACR+OH=0.5000D+00*MACO3+...
     &                      +                 RXRAT( 183 )      ! MACR+O3=0.2080D+00*OH+...
     &                      +                 RXRAT( 184 )      ! MACR+NO3=0.5000D+00*MACO3+...
     &                      +                 RXRAT( 185 )      ! MACR+O3P=RCHO
     &                      +                 RXRAT( 186 )      ! MACR=0.3300D+00*OH+0.6700D+...
     &                      +                 RXRAT( 368 )      ! MACR+CL=0.2500D+00*HCL+...

      PROD(  MVK          ) =    4.0000D-03 * RXRAT( 181 )      ! AFG3+O3=0.4000D-02*MVK+...
     &                      +                 RXRAT( 241 )      ! xMVK=MVK
     &                      +    3.7500D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.3750D+...
     &                      +    1.6000D-01 * RXRAT( 280 )      ! ISOPRENE+O3=0.1600D+00*MVK+...
     &                      +    4.5000D-01 * RXRAT( 285 )      ! ISOPOOH=0.4500D+00*MVK+...
      LOSS(  MVK          ) =                 RXRAT( 187 )      ! MVK+OH=0.9750D+00*RO2C+...
     &                      +                 RXRAT( 188 )      ! MVK+O3=0.1640D+00*OH+...
     &                      +                 RXRAT( 189 )      ! MVK+O3P=0.4500D+00*RCHO+...
     &                      +                 RXRAT( 190 )      ! MVK=0.4000D+00*MEO2+...
     &                      +                 RXRAT( 369 )      ! MVK+CL=0.1283D+01*RO2C+...

      PROD(  xHOCCHO      ) =    6.7500D-01 * RXRAT( 187 )      ! MVK+OH=0.6750D+00*xHOCCHO+...
     &                      +    1.2900D-01 * RXRAT( 191 )      ! IPRD+OH=0.1290D+00*xHOCCHO+...
     &                      +    4.7000D-02 * RXRAT( 192 )      ! IPRD+O3=0.4700D-01*xHOCCHO+...
     &                      +    1.9500D-01 * RXRAT( 267 )      ! ETHENE+OH=0.1950D+...
     &                      +    1.0000D-02 * RXRAT( 304 )      ! ETOH+OH=0.1000D-01*xHOCCHO+...
     &                      +    7.0000D-03 * RXRAT( 311 )      ! OLE1+OH=0.7000D-02*xHOCCHO+...
     &                      +    2.0000D-03 * RXRAT( 324 )      ! TERP+NO3=0.2000D-...
     &                      +    6.1000D-02 * RXRAT( 393 )      ! ETOH+CL=0.6100D-01*xHOCCHO+...
      LOSS(  xHOCCHO      ) =                 RXRAT( 262 )      ! xHOCCHO=HOCCHO
     &                      +                 RXRAT( 263 )      ! xHOCCHO=

      PROD(  xRNO3        ) =    5.7200D-01 * RXRAT( 193 )      ! IPRD+NO3=0.5720D+00*xRNO3+...
     &                      +    3.0500D-01 * RXRAT( 197 )      ! RNO3+OH=0.3050D+00*xRNO3+...
     &                      +    3.1000D-02 * RXRAT( 204 )      ! ACROLEIN+NO3=0.3100D-...
     &                      +    3.5500D-01 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.3550D+...
     &                      +    5.0000D-02 * RXRAT( 284 )      ! ISOPOOH+OH=0.5000D-...
     &                      +    5.6000D-02 * RXRAT( 294 )      ! APIN+NO3=0.5600D-01*xRNO3+...
     &                      +    7.7400D-01 * RXRAT( 313 )      ! OLE1+NO3=0.7740D+00*xRNO3+...
     &                      +    3.2000D-01 * RXRAT( 317 )      ! OLE2+NO3=0.3200D+00*xRNO3+...
     &                      +    2.2800D-01 * RXRAT( 324 )      ! TERP+NO3=0.2280D+00*xRNO3+...
     &                      +    2.2800D-01 * RXRAT( 328 )      ! SESQ+NO3=0.2280D+00*xRNO3+...
     &                      +    5.4700D-01 * RXRAT( 358 )      ! RNO3+CL=0.5470D+00*xRNO3+...
      LOSS(  xRNO3        ) =                 RXRAT( 245 )      ! xRNO3=RNO3
     &                      +                 RXRAT( 246 )      ! xRNO3=

      PROD(  HOCCHO       ) =    4.6700D-01 * RXRAT( 194 )      ! IPRD=0.4670D+00*HOCCHO+...
     &                      +                 RXRAT( 262 )      ! xHOCCHO=HOCCHO
     &                      +    2.7500D-01 * RXRAT( 287 )      ! IEPOXOO+HO2=0.2750D+...
     &                      +    2.7500D-01 * RXRAT( 288 )      ! IEPOXOO+NO=0.2750D+...
     &                      +    1.3800D-01 * RXRAT( 289 )      ! IEPOXOO+MEO2=0.1380D+...
     &                      +    1.3800D-01 * RXRAT( 290 )      ! IEPOXOO+RO2C=0.1380D+...
     &                      +    2.7500D-01 * RXRAT( 291 )      ! IEPOXOO+MECO3=0.2750D+...
      LOSS(  HOCCHO       ) =                 RXRAT( 199 )      ! HOCCHO+OH=MECO3
     &                      +                 RXRAT( 200 )      ! HOCCHO=CO+0.2000D+01*HO2+HCHO
     &                      +                 RXRAT( 201 )      ! HOCCHO+NO3=HNO3+MECO3

      PROD(  xACETONE     ) =    4.0000D-03 * RXRAT( 197 )      ! RNO3+OH=0.4000D-...
     &                      +    8.0000D-03 * RXRAT( 198 )      ! RNO3=0.8000D-02*xACETONE+...
     &                      +    3.4000D-02 * RXRAT( 292 )      ! APIN+OH=0.3400D-...
     &                      +    3.4500D-01 * RXRAT( 293 )      ! APIN+O3=0.3450D+...
     &                      +    6.9000D-02 * RXRAT( 294 )      ! APIN+NO3=0.6900D-...
     &                      +    7.0400D-01 * RXRAT( 306 )      ! ALK2+OH=0.7040D+...
     &                      +    2.4000D-02 * RXRAT( 307 )      ! ALK3+OH=0.2400D-...
     &                      +    4.2600D-01 * RXRAT( 308 )      ! ALK4+OH=0.4260D+...
     &                      +    7.1000D-02 * RXRAT( 309 )      ! ALK5+OH=0.7100D-...
     &                      +    7.0000D-03 * RXRAT( 311 )      ! OLE1+OH=0.7000D-...
     &                      +    3.0000D-03 * RXRAT( 312 )      ! OLE1+O3=0.3000D-...
     &                      +    3.4000D-02 * RXRAT( 313 )      ! OLE1+NO3=0.3400D-...
     &                      +    1.4400D-01 * RXRAT( 315 )      ! OLE2+OH=0.1440D+...
     &                      +    1.1600D-01 * RXRAT( 317 )      ! OLE2+NO3=0.1160D+...
     &                      +    3.7000D-02 * RXRAT( 322 )      ! TERP+OH=0.3700D-...
     &                      +    5.7000D-02 * RXRAT( 323 )      ! TERP+O3=0.5700D-...
     &                      +    2.3900D-01 * RXRAT( 324 )      ! TERP+NO3=0.2390D+...
     &                      +    3.7000D-02 * RXRAT( 326 )      ! SESQ+OH=0.3700D-...
     &                      +    5.7000D-02 * RXRAT( 327 )      ! SESQ+O3=0.5700D-...
     &                      +    2.3900D-01 * RXRAT( 328 )      ! SESQ+NO3=0.2390D+...
     &                      +    3.0000D-03 * RXRAT( 358 )      ! RNO3+CL=0.3000D-...
     &                      +    2.7400D-01 * RXRAT( 386 )      ! APIN+CL=0.2740D+...
     &                      +    4.8800D-01 * RXRAT( 395 )      ! ALK2+CL=0.4880D+...
     &                      +    7.5000D-02 * RXRAT( 396 )      ! ALK3+CL=0.7500D-...
     &                      +    2.4700D-01 * RXRAT( 397 )      ! ALK4+CL=0.2470D+...
     &                      +    4.4000D-02 * RXRAT( 398 )      ! ALK5+CL=0.4400D-...
     &                      +    8.6000D-02 * RXRAT( 400 )      ! OLE2+CL=0.8600D-...
     &                      +    2.7400D-01 * RXRAT( 404 )      ! TERP+CL=0.2740D+...
     &                      +    2.7400D-01 * RXRAT( 405 )      ! SESQ+CL=0.2740D+...
      LOSS(  xACETONE     ) =                 RXRAT( 219 )      ! xACETONE=ACETONE
     &                      +                 RXRAT( 220 )      ! xACETONE=

      PROD(  ACROLEIN     ) =                 RXRAT( 264 )      ! xACROLEIN=ACROLEIN
     &                      +    5.0000D-01 * RXRAT( 276 )      ! BUTADIENE13+O3=0.5000D+...
      LOSS(  ACROLEIN     ) =                 RXRAT( 202 )      ! ACROLEIN+OH=0.2500D+...
     &                      +                 RXRAT( 203 )      ! ACROLEIN+O3=0.8300D+00*HO2+...
     &                      +                 RXRAT( 204 )      ! ACROLEIN+NO3=0.3100D-...
     &                      +                 RXRAT( 205 )      ! ACROLEIN+O3P=RCHO
     &                      +                 RXRAT( 206 )      ! ACROLEIN=0.1066D+01*HO2+...
     &                      +                 RXRAT( 367 )      ! ACROLEIN+CL=0.4840D+...

      PROD(  xBALD        ) =    6.5000D-02 * RXRAT( 299 )      ! TOLUENE+OH=0.6500D-...
     &                      +    4.1000D-02 * RXRAT( 300 )      ! MXYL+OH=0.4100D-01*xBALD+...
     &                      +    4.7000D-02 * RXRAT( 301 )      ! OXYL+OH=0.4700D-01*xBALD+...
     &                      +    8.8000D-02 * RXRAT( 302 )      ! PXYL+OH=0.8800D-01*xBALD+...
     &                      +    3.6000D-02 * RXRAT( 303 )      ! TMBENZ124+OH=0.3600D-...
     &                      +    2.6000D-02 * RXRAT( 320 )      ! ARO2MN+OH=0.2600D-01*xBALD+...
     &                      +    2.6000D-02 * RXRAT( 321 )      ! NAPHTHAL+OH=0.2600D-...
     &                      +                 RXRAT( 362 )      ! CRES+CL=xBALD+xHO2+HCL+yR6OOH
     &                      +    8.9400D-01 * RXRAT( 388 )      ! TOLUENE+CL=0.8940D+...
     &                      +    8.6400D-01 * RXRAT( 389 )      ! MXYL+CL=0.8640D+00*xBALD+...
     &                      +    8.6400D-01 * RXRAT( 390 )      ! OXYL+CL=0.8640D+00*xBALD+...
     &                      +    8.6400D-01 * RXRAT( 391 )      ! PXYL+CL=0.8640D+00*xBALD+...
     &                      +    8.3800D-01 * RXRAT( 392 )      ! TMBENZ124+CL=0.8380D+...
     &                      +    4.6900D-01 * RXRAT( 402 )      ! ARO2MN+CL=0.4690D+00*xBALD+...
     &                      +    4.6900D-01 * RXRAT( 403 )      ! NAPHTHAL+CL=0.4690D+...
      LOSS(  xBALD        ) =                 RXRAT( 231 )      ! xBALD=BALD
     &                      +                 RXRAT( 232 )      ! xBALD=

      PROD(  xAFG3        ) =    2.8600D-01 * RXRAT( 302 )      ! PXYL+OH=0.2860D+00*xAFG3+...
     &                      +    1.5100D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.1510D+...
     &                      +    6.8000D-02 * RXRAT( 320 )      ! ARO2MN+OH=0.6800D-01*xAFG3+...
     &                      +    6.8000D-02 * RXRAT( 321 )      ! NAPHTHAL+OH=0.6800D-...
     &                      +    1.0000D-03 * RXRAT( 386 )      ! APIN+CL=0.1000D-02*xAFG3+...
     &                      +    1.0000D-03 * RXRAT( 404 )      ! TERP+CL=0.1000D-02*xAFG3+...
     &                      +    1.0000D-03 * RXRAT( 405 )      ! SESQ+CL=0.1000D-02*xAFG3+...
      LOSS(  xAFG3        ) =                 RXRAT( 237 )      ! xAFG3=AFG3
     &                      +                 RXRAT( 238 )      ! xAFG3=

      PROD(  xMACR        ) =    2.3000D-01 * RXRAT( 279 )      ! ISOPRENE+OH=0.2300D+...
     &                      +    1.0000D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.1000D+...
     &                      +    1.0000D-03 * RXRAT( 311 )      ! OLE1+OH=0.1000D-02*xMACR+...
     &                      +    2.0000D-03 * RXRAT( 323 )      ! TERP+O3=0.2000D-02*xMACR+...
     &                      +    5.0000D-03 * RXRAT( 324 )      ! TERP+NO3=0.5000D-02*xMACR+...
     &                      +    2.0000D-03 * RXRAT( 327 )      ! SESQ+O3=0.2000D-02*xMACR+...
     &                      +    5.0000D-03 * RXRAT( 328 )      ! SESQ+NO3=0.5000D-02*xMACR+...
     &                      +    2.5000D-02 * RXRAT( 400 )      ! OLE2+CL=0.2500D-01*xMACR+...
      LOSS(  xMACR        ) =                 RXRAT( 239 )      ! xMACR=MACR
     &                      +                 RXRAT( 240 )      ! xMACR=

      PROD(  xMVK         ) =    4.6000D-01 * RXRAT( 277 )      ! BUTADIENE13+NO3=0.4600D+...
     &                      +    3.2000D-01 * RXRAT( 279 )      ! ISOPRENE+OH=0.3200D+...
     &                      +    1.6000D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.1600D+00*xMVK+...
     &                      +    1.2000D-02 * RXRAT( 311 )      ! OLE1+OH=0.1200D-01*xMVK+...
     &                      +    2.0000D-03 * RXRAT( 315 )      ! OLE2+OH=0.2000D-02*xMVK+...
     &                      +    3.0000D-03 * RXRAT( 322 )      ! TERP+OH=0.3000D-02*xMVK+...
     &                      +    1.0000D-03 * RXRAT( 324 )      ! TERP+NO3=0.1000D-02*xMVK+...
     &                      +    3.0000D-03 * RXRAT( 326 )      ! SESQ+OH=0.3000D-02*xMVK+...
     &                      +    1.0000D-03 * RXRAT( 328 )      ! SESQ+NO3=0.1000D-02*xMVK+...
     &                      +    1.7700D-01 * RXRAT( 385 )      ! ISOPRENE+CL=0.1770D+...
     &                      +    3.0000D-03 * RXRAT( 386 )      ! APIN+CL=0.3000D-02*xMVK+...
     &                      +    1.9000D-02 * RXRAT( 399 )      ! OLE1+CL=0.1900D-01*xMVK+...
     &                      +    5.8000D-02 * RXRAT( 400 )      ! OLE2+CL=0.5800D-01*xMVK+...
     &                      +    3.0000D-03 * RXRAT( 404 )      ! TERP+CL=0.3000D-02*xMVK+...
     &                      +    3.0000D-03 * RXRAT( 405 )      ! SESQ+CL=0.3000D-02*xMVK+...
      LOSS(  xMVK         ) =                 RXRAT( 241 )      ! xMVK=MVK
     &                      +                 RXRAT( 242 )      ! xMVK=

      PROD(  yISOPOOH     ) =                 RXRAT( 279 )      ! ISOPRENE+OH=yISOPOOH+...
     &                      +    3.8700D-01 * RXRAT( 284 )      ! ISOPOOH+OH=0.3870D+...
      LOSS(  yISOPOOH     ) =                 RXRAT( 256 )      ! yISOPOOH=ISOPOOH
     &                      +                 RXRAT( 257 )      ! yISOPOOH=PRD2
     &                      +                 RXRAT( 258 )      ! yISOPOOH=

      PROD(  ISOPOOH      ) =                 RXRAT( 256 )      ! yISOPOOH=ISOPOOH
      LOSS(  ISOPOOH      ) =                 RXRAT( 283 )      ! ISOPOOH+OH=IEPOX+OH
     &                      +                 RXRAT( 284 )      ! ISOPOOH+OH=0.1600D+00*xMVK+...
     &                      +                 RXRAT( 285 )      ! ISOPOOH=OH+0.9100D+00*HO2+...

      PROD(  yRAOOH       ) =    3.1400D-01 * RXRAT( 298 )      ! BENZENE+OH=0.3140D+...
     &                      +    4.3500D-01 * RXRAT( 299 )      ! TOLUENE+OH=0.4350D+...
     &                      +    5.5500D-01 * RXRAT( 300 )      ! MXYL+OH=0.5550D+00*yRAOOH+...
     &                      +    5.8600D-01 * RXRAT( 301 )      ! OXYL+OH=0.5860D+00*yRAOOH+...
     &                      +    4.6100D-01 * RXRAT( 302 )      ! PXYL+OH=0.4610D+00*yRAOOH+...
     &                      +    7.0500D-01 * RXRAT( 303 )      ! TMBENZ124+OH=0.7050D+...
      LOSS(  yRAOOH       ) =                 RXRAT( 259 )      ! yRAOOH=RAOOH
     &                      +                 RXRAT( 260 )      ! yRAOOH=PRD2
     &                      +                 RXRAT( 261 )      ! yRAOOH=

      PROD(  xACROLEIN    ) =    4.8000D-01 * RXRAT( 275 )      ! BUTADIENE13+OH=0.4800D+...
     &                      +    1.1500D-01 * RXRAT( 278 )      ! BUTADIENE13+O3P=0.1150D+...
     &                      +    3.6000D-02 * RXRAT( 311 )      ! OLE1+OH=0.3600D-...
     &                      +    1.2400D-01 * RXRAT( 383 )      ! PROPENE+CL=0.1240D+...
     &                      +    4.5700D-01 * RXRAT( 384 )      ! BUTADIENE13+CL=0.4570D+...
     &                      +    2.1500D-01 * RXRAT( 399 )      ! OLE1+CL=0.2150D+...
      LOSS(  xACROLEIN    ) =                 RXRAT( 264 )      ! xACROLEIN=ACROLEIN
     &                      +                 RXRAT( 265 )      ! xACROLEIN=

      PROD(  ETHENE       ) =   0.0D0
      LOSS(  ETHENE       ) =                 RXRAT( 267 )      ! ETHENE+OH=xHO2+RO2C+...
     &                      +                 RXRAT( 268 )      ! ETHENE+O3=0.1600D+00*HO2+...
     &                      +                 RXRAT( 269 )      ! ETHENE+NO3=xHO2+RO2C+xRCHO+...
     &                      +                 RXRAT( 270 )      ! ETHENE+O3P=0.8000D+00*HO2+...
     &                      +                 RXRAT( 382 )      ! ETHENE+CL=xHO2+0.2000D+...

      PROD(  PROPENE      ) =   0.0D0
      LOSS(  PROPENE      ) =                 RXRAT( 271 )      ! PROPENE+OH=0.9840D+00*xHO2+...
     &                      +                 RXRAT( 272 )      ! PROPENE+O3=0.1650D+00*HO2+...
     &                      +                 RXRAT( 273 )      ! PROPENE+NO3=0.9490D+...
     &                      +                 RXRAT( 274 )      ! PROPENE+O3P=0.4500D+...
     &                      +                 RXRAT( 383 )      ! PROPENE+CL=0.1240D+00*HCL+...

      PROD(  BUTADIENE13  ) =   0.0D0
      LOSS(  BUTADIENE13  ) =                 RXRAT( 275 )      ! BUTADIENE13+OH=0.9510D+...
     &                      +                 RXRAT( 276 )      ! BUTADIENE13+O3=0.8000D-...
     &                      +                 RXRAT( 277 )      ! BUTADIENE13+NO3=0.8150D+...
     &                      +                 RXRAT( 278 )      ! BUTADIENE13+O3P=0.2500D+...
     &                      +                 RXRAT( 384 )      ! BUTADIENE13+CL=0.3900D+...

      PROD(  ISOPRENE     ) =   0.0D0
      LOSS(  ISOPRENE     ) =                 RXRAT( 279 )      ! ISOPRENE+OH=0.9070D+...
     &                      +                 RXRAT( 280 )      ! ISOPRENE+O3=0.6600D-01*HO2+...
     &                      +                 RXRAT( 281 )      ! ISOPRENE+NO3=0.7490D+...
     &                      +                 RXRAT( 282 )      ! ISOPRENE+O3P=0.2500D+...
     &                      +                 RXRAT( 385 )      ! ISOPRENE+CL=0.1500D+00*HCL+...

      PROD(  ISOPRXN      ) =                 RXRAT( 279 )      ! ISOPRENE+OH=ISOPRXN+...
      LOSS(  ISOPRXN      ) =   0.0D0

      PROD(  IEPOX        ) =                 RXRAT( 283 )      ! ISOPOOH+OH=IEPOX+OH
      LOSS(  IEPOX        ) =                 RXRAT( 286 )      ! IEPOX+OH=IEPOXOO
     &                      +                 RXRAT( 464 )      ! IEPOX=AISO3J

      PROD(  ARO2MN       ) =    2.0000D-02 * RXRAT( 284 )      ! ISOPOOH+OH=0.2000D-...
     &                      +    5.0000D-02 * RXRAT( 285 )      ! ISOPOOH=0.5000D-01*ARO2MN+...
      LOSS(  ARO2MN       ) =                 RXRAT( 320 )      ! ARO2MN+OH=0.7700D-01*HO2+...
     &                      +                 RXRAT( 402 )      ! ARO2MN+CL=0.8280D+00*xHO2+...

      PROD(  IEPOXOO      ) =                 RXRAT( 286 )      ! IEPOX+OH=IEPOXOO
      LOSS(  IEPOXOO      ) =                 RXRAT( 287 )      ! IEPOXOO+HO2=0.7250D+00*MEK+...
     &                      +                 RXRAT( 288 )      ! IEPOXOO+NO=0.7250D+00*MEK+...
     &                      +                 RXRAT( 289 )      ! IEPOXOO+MEO2=0.3630D+...
     &                      +                 RXRAT( 290 )      ! IEPOXOO+RO2C=0.3630D+...
     &                      +                 RXRAT( 291 )      ! IEPOXOO+MECO3=0.7250D+...

      PROD(  APIN         ) =   0.0D0
      LOSS(  APIN         ) =                 RXRAT( 292 )      ! APIN+OH=0.7990D+00*xHO2+...
     &                      +                 RXRAT( 293 )      ! APIN+O3=0.9000D-02*HO2+...
     &                      +                 RXRAT( 294 )      ! APIN+NO3=0.5600D-01*xHO2+...
     &                      +                 RXRAT( 295 )      ! APIN+O3P=PRD2+TRPRXN
     &                      +                 RXRAT( 386 )      ! APIN+CL=0.5480D+00*HCL+...

      PROD(  TRPRXN       ) =                 RXRAT( 292 )      ! APIN+OH=TRPRXN+0.4000D-...
     &                      +                 RXRAT( 293 )      ! APIN+O3=TRPRXN+0.1020D+...
     &                      +                 RXRAT( 294 )      ! APIN+NO3=TRPRXN+0.6430D+...
     &                      +                 RXRAT( 295 )      ! APIN+O3P=TRPRXN+PRD2
     &                      +                 RXRAT( 322 )      ! TERP+OH=TRPRXN+0.6400D-...
     &                      +                 RXRAT( 323 )      ! TERP+O3=TRPRXN+0.4600D-...
     &                      +                 RXRAT( 324 )      ! TERP+NO3=TRPRXN+0.2870D+...
     &                      +                 RXRAT( 325 )      ! TERP+O3P=TRPRXN+0.7630D+...
      LOSS(  TRPRXN       ) =   0.0D0

      PROD(  ACETYLENE    ) =   0.0D0
      LOSS(  ACETYLENE    ) =                 RXRAT( 296 )      ! ACETYLENE+OH=0.3000D+...
     &                      +                 RXRAT( 297 )      ! ACETYLENE+O3=0.1500D+...
     &                      +                 RXRAT( 387 )      ! ACETYLENE+CL=HO2+CO

      PROD(  BENZENE      ) =   0.0D0
      LOSS(  BENZENE      ) =                 RXRAT( 298 )      ! BENZENE+OH=0.5700D+00*HO2+...

      PROD(  BENZRO2      ) =                 RXRAT( 298 )      ! BENZENE+OH=BENZRO2+0.2900D+...
      LOSS(  BENZRO2      ) =                 RXRAT( 406 )      ! BENZRO2+NO=NO+BNZNRXN
     &                      +                 RXRAT( 407 )      ! BENZRO2+HO2=HO2+BNZHRXN

      PROD(  TOLUENE      ) =   0.0D0
      LOSS(  TOLUENE      ) =                 RXRAT( 299 )      ! TOLUENE+OH=0.1810D+00*HO2+...
     &                      +                 RXRAT( 388 )      ! TOLUENE+CL=0.8940D+00*xHO2+...

      PROD(  TOLRO2       ) =                 RXRAT( 299 )      ! TOLUENE+OH=TOLRO2+0.4540D+...
     &                      +                 RXRAT( 319 )      ! ARO1+OH=TOLRO2+0.5660D+...
      LOSS(  TOLRO2       ) =                 RXRAT( 410 )      ! TOLRO2+NO=NO+TOLNRXN
     &                      +                 RXRAT( 411 )      ! TOLRO2+HO2=HO2+TOLHRXN

      PROD(  MXYL         ) =   0.0D0
      LOSS(  MXYL         ) =                 RXRAT( 300 )      ! MXYL+OH=0.1590D+00*HO2+...
     &                      +                 RXRAT( 389 )      ! MXYL+CL=0.8640D+00*xHO2+...

      PROD(  XYLRO2       ) =                 RXRAT( 300 )      ! MXYL+OH=XYLRO2+0.5200D+...
     &                      +                 RXRAT( 301 )      ! OXYL+OH=XYLRO2+0.5540D+...
     &                      +                 RXRAT( 302 )      ! PXYL+OH=XYLRO2+0.4870D+...
     &                      +                 RXRAT( 303 )      ! TMBENZ124+OH=XYLRO2+...
     &                      +                 RXRAT( 320 )      ! ARO2MN+OH=XYLRO2+0.6170D+...
      LOSS(  XYLRO2       ) =                 RXRAT( 408 )      ! XYLRO2+NO=NO+XYLNRXN
     &                      +                 RXRAT( 409 )      ! XYLRO2+HO2=HO2+XYLHRXN

      PROD(  OXYL         ) =   0.0D0
      LOSS(  OXYL         ) =                 RXRAT( 301 )      ! OXYL+OH=0.1610D+00*HO2+...
     &                      +                 RXRAT( 390 )      ! OXYL+CL=0.8640D+00*xHO2+...

      PROD(  PXYL         ) =   0.0D0
      LOSS(  PXYL         ) =                 RXRAT( 302 )      ! PXYL+OH=0.1590D+00*HO2+...
     &                      +                 RXRAT( 391 )      ! PXYL+CL=0.8640D+00*xHO2+...

      PROD(  TMBENZ124    ) =   0.0D0
      LOSS(  TMBENZ124    ) =                 RXRAT( 303 )      ! TMBENZ124+OH=0.2200D-...
     &                      +                 RXRAT( 392 )      ! TMBENZ124+CL=0.8380D+...

      PROD(  ETOH         ) =   0.0D0
      LOSS(  ETOH         ) =                 RXRAT( 304 )      ! ETOH+OH=0.9500D+00*HO2+...
     &                      +                 RXRAT( 393 )      ! ETOH+CL=HCL+0.6880D+00*HO2+...

      PROD(  ALK1         ) =   0.0D0
      LOSS(  ALK1         ) =                 RXRAT( 305 )      ! ALK1+OH=xHO2+RO2C+xCCHO+yROOH
     &                      +                 RXRAT( 394 )      ! ALK1+CL=HCL+xHO2+RO2C+...

      PROD(  ALK2         ) =   0.0D0
      LOSS(  ALK2         ) =                 RXRAT( 306 )      ! ALK2+OH=0.9650D+00*xHO2+...
     &                      +                 RXRAT( 395 )      ! ALK2+CL=HCL+0.9700D+...

      PROD(  ALK3         ) =   0.0D0
      LOSS(  ALK3         ) =                 RXRAT( 307 )      ! ALK3+OH=0.6950D+00*xHO2+...
     &                      +                 RXRAT( 396 )      ! ALK3+CL=HCL+0.8350D+...

      PROD(  ALK4         ) =   0.0D0
      LOSS(  ALK4         ) =                 RXRAT( 308 )      ! ALK4+OH=0.8300D+00*xHO2+...
     &                      +                 RXRAT( 397 )      ! ALK4+CL=HCL+0.8270D+...

      PROD(  ALK5         ) =   0.0D0
      LOSS(  ALK5         ) =                 RXRAT( 309 )      ! ALK5+OH=0.6470D+00*xHO2+...
     &                      +                 RXRAT( 398 )      ! ALK5+CL=HCL+0.6470D+...

      PROD(  SOAALK       ) =   0.0D0
      LOSS(  SOAALK       ) =                 RXRAT( 310 )      ! SOAALK+OH=OH+0.4700D+00*ALKRXN

      PROD(  ALKRXN       ) =    4.7000D-01 * RXRAT( 310 )      ! SOAALK+OH=0.4700D+00*ALKRXN+OH
      LOSS(  ALKRXN       ) =   0.0D0

      PROD(  OLE1         ) =   0.0D0
      LOSS(  OLE1         ) =                 RXRAT( 311 )      ! OLE1+OH=0.8710D+00*xHO2+...
     &                      +                 RXRAT( 312 )      ! OLE1+O3=0.9500D-01*HO2+...
     &                      +                 RXRAT( 313 )      ! OLE1+NO3=0.7720D+00*xHO2+...
     &                      +                 RXRAT( 314 )      ! OLE1+O3P=0.4500D+00*RCHO+...
     &                      +                 RXRAT( 399 )      ! OLE1+CL=0.3840D+00*HCL+...

      PROD(  OLE2         ) =   0.0D0
      LOSS(  OLE2         ) =                 RXRAT( 315 )      ! OLE2+OH=0.9120D+00*xHO2+...
     &                      +                 RXRAT( 316 )      ! OLE2+O3=0.9400D-01*HO2+...
     &                      +                 RXRAT( 317 )      ! OLE2+NO3=0.4000D+00*xHO2+...
     &                      +                 RXRAT( 318 )      ! OLE2+O3P=0.7900D-01*RCHO+...
     &                      +                 RXRAT( 400 )      ! OLE2+CL=0.2790D+00*HCL+...

      PROD(  ARO1         ) =   0.0D0
      LOSS(  ARO1         ) =                 RXRAT( 319 )      ! ARO1+OH=0.1230D+00*HO2+...
     &                      +                 RXRAT( 401 )      ! ARO1+CL=0.8400D+00*xHO2+...

      PROD(  NAPHTHAL     ) =   0.0D0
      LOSS(  NAPHTHAL     ) =                 RXRAT( 321 )      ! NAPHTHAL+OH=0.7700D-01*HO2+...
     &                      +                 RXRAT( 403 )      ! NAPHTHAL+CL=0.8280D+...

      PROD(  PAHRO2       ) =                 RXRAT( 321 )      ! NAPHTHAL+OH=PAHRO2+0.6170D+...
      LOSS(  PAHRO2       ) =                 RXRAT( 412 )      ! PAHRO2+NO=NO+PAHNRXN
     &                      +                 RXRAT( 413 )      ! PAHRO2+HO2=HO2+PAHHRXN

      PROD(  TERP         ) =   0.0D0
      LOSS(  TERP         ) =                 RXRAT( 322 )      ! TERP+OH=0.7340D+00*xHO2+...
     &                      +                 RXRAT( 323 )      ! TERP+O3=0.7800D-01*HO2+...
     &                      +                 RXRAT( 324 )      ! TERP+NO3=0.2270D+00*xHO2+...
     &                      +                 RXRAT( 325 )      ! TERP+O3P=0.2370D+00*RCHO+...
     &                      +                 RXRAT( 404 )      ! TERP+CL=0.5480D+00*HCL+...

      PROD(  SESQ         ) =   0.0D0
      LOSS(  SESQ         ) =                 RXRAT( 326 )      ! SESQ+OH=0.7340D+00*xHO2+...
     &                      +                 RXRAT( 327 )      ! SESQ+O3=0.7800D-01*HO2+...
     &                      +                 RXRAT( 328 )      ! SESQ+NO3=0.2270D+00*xHO2+...
     &                      +                 RXRAT( 329 )      ! SESQ+O3P=0.2370D+00*RCHO+...
     &                      +                 RXRAT( 405 )      ! SESQ+CL=0.2520D+00*xHO2+...

      PROD(  SESQRXN      ) =                 RXRAT( 326 )      ! SESQ+OH=SESQRXN+0.6400D-...
     &                      +                 RXRAT( 327 )      ! SESQ+O3=SESQRXN+0.4600D-...
     &                      +                 RXRAT( 328 )      ! SESQ+NO3=SESQRXN+0.2870D+...
     &                      +                 RXRAT( 329 )      ! SESQ+O3P=SESQRXN+0.7630D+...
      LOSS(  SESQRXN      ) =   0.0D0

      PROD(  CL2          ) =                 RXRAT( 346 )      ! CL+CLONO2=CL2+NO3
     &                      +    2.9000D-01 * RXRAT( 349 )      ! CLO+CLO=0.2900D+00*CL2+...
      LOSS(  CL2          ) =                 RXRAT( 330 )      ! CL2=0.2000D+01*CL

      PROD(  CL           ) =    2.0000D+00 * RXRAT( 330 )      ! CL2=0.2000D+01*CL
     &                      +                 RXRAT( 332 )      ! CLNO=CL+NO
     &                      +                 RXRAT( 335 )      ! CLONO=CL+NO2
     &                      +                 RXRAT( 336 )      ! CLNO2=CL+NO2
     &                      +                 RXRAT( 341 )      ! CLO+NO=CL+NO2
     &                      +                 RXRAT( 344 )      ! CLONO2=CL+NO3
     &                      +                 RXRAT( 348 )      ! HOCL=CL+OH
     &                      +    1.4200D+00 * RXRAT( 349 )      ! CLO+CLO=0.1420D+01*CL+...
     &                      +                 RXRAT( 350 )      ! OH+HCL=CL
     &                      +                 RXRAT( 375 )      ! xCL=CL
      LOSS(  CL           ) =                 RXRAT( 331 )      ! CL+NO=CLNO
     &                      +                 RXRAT( 333 )      ! CL+NO2=CLONO
     &                      +                 RXRAT( 334 )      ! CL+NO2=CLNO2
     &                      +                 RXRAT( 337 )      ! CL+HO2=HCL
     &                      +                 RXRAT( 338 )      ! CL+HO2=CLO+OH
     &                      +                 RXRAT( 339 )      ! CL+O3=CLO
     &                      +                 RXRAT( 340 )      ! CL+NO3=CLO+NO2
     &                      +                 RXRAT( 346 )      ! CL+CLONO2=CL2+NO3
     &                      +                 RXRAT( 351 )      ! CL=HCL+HO2
     &                      +                 RXRAT( 352 )      ! CL+HCHO=HCL+HO2+CO
     &                      +                 RXRAT( 353 )      ! CL+CCHO=HCL+MECO3
     &                      +                 RXRAT( 354 )      ! CL+MEOH=HCL+HCHO+HO2
     &                      +                 RXRAT( 355 )      ! CL+RCHO=HCL+0.9000D+...
     &                      +                 RXRAT( 356 )      ! CL+ACETONE=HCL+RO2C+xHCHO+...
     &                      +                 RXRAT( 357 )      ! CL+MEK=HCL+0.9750D+00*RO2C+...
     &                      +                 RXRAT( 358 )      ! CL+RNO3=HCL+0.3800D-01*NO2+...
     &                      +                 RXRAT( 359 )      ! CL+PRD2=HCL+0.3140D+00*HO2+...
     &                      +                 RXRAT( 360 )      ! CL+GLY=HCL+0.6300D+00*HO2+...
     &                      +                 RXRAT( 361 )      ! CL+MGLY=HCL+CO+MECO3
     &                      +                 RXRAT( 362 )      ! CL+CRES=HCL+xHO2+xBALD+yR6OOH
     &                      +                 RXRAT( 363 )      ! CL+BALD=HCL+BZCO3
     &                      +                 RXRAT( 364 )      ! CL+ROOH=HCL+0.4140D+00*OH+...
     &                      +                 RXRAT( 365 )      ! CL+R6OOH=HCL+0.1450D+00*OH+...
     &                      +                 RXRAT( 366 )      ! CL+RAOOH=0.4040D+00*HCL+...
     &                      +                 RXRAT( 367 )      ! CL+ACROLEIN=0.4840D+...
     &                      +                 RXRAT( 368 )      ! CL+MACR=0.2500D+00*HCL+...
     &                      +                 RXRAT( 369 )      ! CL+MVK=0.1283D+01*RO2C+...
     &                      +                 RXRAT( 370 )      ! CL+IPRD=0.4010D+00*HCL+...
     &                      +                 RXRAT( 373 )      ! CL+CLCCHO=HCL+RCO3
     &                      +                 RXRAT( 381 )      ! CL=HCL+MEO2
     &                      +                 RXRAT( 382 )      ! CL+ETHENE=xHO2+0.2000D+...
     &                      +                 RXRAT( 383 )      ! CL+PROPENE=0.1240D+00*HCL+...
     &                      +                 RXRAT( 384 )      ! CL+BUTADIENE13=0.3900D+...
     &                      +                 RXRAT( 385 )      ! CL+ISOPRENE=0.1500D+00*HCL+...
     &                      +                 RXRAT( 386 )      ! CL+APIN=0.5480D+00*HCL+...
     &                      +                 RXRAT( 387 )      ! CL+ACETYLENE=HO2+CO
     &                      +                 RXRAT( 388 )      ! CL+TOLUENE=0.8940D+00*xHO2+...
     &                      +                 RXRAT( 389 )      ! CL+MXYL=0.8640D+00*xHO2+...
     &                      +                 RXRAT( 390 )      ! CL+OXYL=0.8640D+00*xHO2+...
     &                      +                 RXRAT( 391 )      ! CL+PXYL=0.8640D+00*xHO2+...
     &                      +                 RXRAT( 392 )      ! CL+TMBENZ124=0.8380D+...
     &                      +                 RXRAT( 393 )      ! CL+ETOH=HCL+0.6880D+00*HO2+...
     &                      +                 RXRAT( 394 )      ! CL+ALK1=HCL+xHO2+RO2C+...
     &                      +                 RXRAT( 395 )      ! CL+ALK2=HCL+0.9700D+...
     &                      +                 RXRAT( 396 )      ! CL+ALK3=HCL+0.8350D+...
     &                      +                 RXRAT( 397 )      ! CL+ALK4=HCL+0.8270D+...
     &                      +                 RXRAT( 398 )      ! CL+ALK5=HCL+0.6470D+...
     &                      +                 RXRAT( 399 )      ! CL+OLE1=0.3840D+00*HCL+...
     &                      +                 RXRAT( 400 )      ! CL+OLE2=0.2790D+00*HCL+...
     &                      +                 RXRAT( 401 )      ! CL+ARO1=0.8400D+00*xHO2+...
     &                      +                 RXRAT( 402 )      ! CL+ARO2MN=0.8280D+00*xHO2+...
     &                      +                 RXRAT( 403 )      ! CL+NAPHTHAL=0.8280D+...
     &                      +                 RXRAT( 404 )      ! CL+TERP=0.5480D+00*HCL+...
     &                      +                 RXRAT( 405 )      ! CL+SESQ=0.2520D+00*xHO2+...

      PROD(  CLNO         ) =                 RXRAT( 331 )      ! CL+NO=CLNO
      LOSS(  CLNO         ) =                 RXRAT( 332 )      ! CLNO=CL+NO

      PROD(  CLONO        ) =                 RXRAT( 333 )      ! CL+NO2=CLONO
      LOSS(  CLONO        ) =                 RXRAT( 335 )      ! CLONO=CL+NO2

      PROD(  CLNO2        ) =                 RXRAT( 334 )      ! CL+NO2=CLNO2
     &                      +                 RXRAT( 434 )      ! H2NO3PIJ+ACLI=CLNO2
     &                      +                 RXRAT( 435 )      ! H2NO3PIJ+ACLJ=CLNO2
     &                      +                 RXRAT( 436 )      ! H2NO3PK+ACLK=CLNO2
      LOSS(  CLNO2        ) =                 RXRAT( 336 )      ! CLNO2=CL+NO2

      PROD(  HCL          ) =                 RXRAT( 337 )      ! CL+HO2=HCL
     &                      +                 RXRAT( 351 )      ! CL=HCL+HO2
     &                      +                 RXRAT( 352 )      ! HCHO+CL=HCL+HO2+CO
     &                      +                 RXRAT( 353 )      ! CCHO+CL=HCL+MECO3
     &                      +                 RXRAT( 354 )      ! MEOH+CL=HCL+HCHO+HO2
     &                      +                 RXRAT( 355 )      ! RCHO+CL=HCL+0.9000D+...
     &                      +                 RXRAT( 356 )      ! ACETONE+CL=HCL+RO2C+xHCHO+...
     &                      +                 RXRAT( 357 )      ! MEK+CL=HCL+0.9750D+00*RO2C+...
     &                      +                 RXRAT( 358 )      ! RNO3+CL=HCL+0.3800D-01*NO2+...
     &                      +                 RXRAT( 359 )      ! PRD2+CL=HCL+0.3140D+00*HO2+...
     &                      +                 RXRAT( 360 )      ! GLY+CL=HCL+0.6300D+00*HO2+...
     &                      +                 RXRAT( 361 )      ! MGLY+CL=HCL+CO+MECO3
     &                      +                 RXRAT( 362 )      ! CRES+CL=HCL+xHO2+xBALD+yR6OOH
     &                      +                 RXRAT( 363 )      ! BALD+CL=HCL+BZCO3
     &                      +                 RXRAT( 364 )      ! ROOH+CL=HCL+0.4140D+00*OH+...
     &                      +                 RXRAT( 365 )      ! R6OOH+CL=HCL+0.1450D+00*OH+...
     &                      +    4.0400D-01 * RXRAT( 366 )      ! RAOOH+CL=0.4040D+00*HCL+...
     &                      +    2.1600D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.2160D+00*HCL+...
     &                      +    2.5000D-01 * RXRAT( 368 )      ! MACR+CL=0.2500D+00*HCL+...
     &                      +    4.0100D-01 * RXRAT( 370 )      ! IPRD+CL=0.4010D+00*HCL+...
     &                      +                 RXRAT( 373 )      ! CLCCHO+CL=HCL+RCO3
     &                      +                 RXRAT( 381 )      ! CL=HCL+MEO2
     &                      +    1.2400D-01 * RXRAT( 383 )      ! PROPENE+CL=0.1240D+00*HCL+...
     &                      +    1.5000D-01 * RXRAT( 385 )      ! ISOPRENE+CL=0.1500D+00*HCL+...
     &                      +    5.4800D-01 * RXRAT( 386 )      ! APIN+CL=0.5480D+00*HCL+...
     &                      +                 RXRAT( 393 )      ! ETOH+CL=HCL+0.6880D+00*HO2+...
     &                      +                 RXRAT( 394 )      ! ALK1+CL=HCL+xHO2+RO2C+...
     &                      +                 RXRAT( 395 )      ! ALK2+CL=HCL+0.9700D+...
     &                      +                 RXRAT( 396 )      ! ALK3+CL=HCL+0.8350D+...
     &                      +                 RXRAT( 397 )      ! ALK4+CL=HCL+0.8270D+...
     &                      +                 RXRAT( 398 )      ! ALK5+CL=HCL+0.6470D+...
     &                      +    3.8400D-01 * RXRAT( 399 )      ! OLE1+CL=0.3840D+00*HCL+...
     &                      +    2.7900D-01 * RXRAT( 400 )      ! OLE2+CL=0.2790D+00*HCL+...
     &                      +    5.4800D-01 * RXRAT( 404 )      ! TERP+CL=0.5480D+00*HCL+...
     &                      +    5.4800D-01 * RXRAT( 405 )      ! SESQ+CL=0.5480D+00*HCL+...
      LOSS(  HCL          ) =                 RXRAT( 350 )      ! HCL+OH=CL

      PROD(  CLO          ) =                 RXRAT( 338 )      ! CL+HO2=CLO+OH
     &                      +                 RXRAT( 339 )      ! CL+O3=CLO
     &                      +                 RXRAT( 340 )      ! CL+NO3=CLO+NO2
     &                      +                 RXRAT( 343 )      ! CLONO2=CLO+NO2
     &                      +                 RXRAT( 345 )      ! CLONO2=CLO+NO2
      LOSS(  CLO          ) =                 RXRAT( 341 )      ! CLO+NO=CL+NO2
     &                      +                 RXRAT( 342 )      ! CLO+NO2=CLONO2
     &                      +                 RXRAT( 347 )      ! CLO+HO2=HOCL
     &                      +    2.0000D+00 * RXRAT( 349 )      ! CLO+CLO=0.2900D+00*CL2+...

      PROD(  CLONO2       ) =                 RXRAT( 342 )      ! CLO+NO2=CLONO2
      LOSS(  CLONO2       ) =                 RXRAT( 343 )      ! CLONO2=CLO+NO2
     &                      +                 RXRAT( 344 )      ! CLONO2=CL+NO3
     &                      +                 RXRAT( 345 )      ! CLONO2=CLO+NO2
     &                      +                 RXRAT( 346 )      ! CLONO2+CL=CL2+NO3

      PROD(  HOCL         ) =                 RXRAT( 347 )      ! CLO+HO2=HOCL
      LOSS(  HOCL         ) =                 RXRAT( 348 )      ! HOCL=OH+CL

      PROD(  xCL          ) =    2.7400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.2740D+00*xCL+...
     &                      +                 RXRAT( 371 )      ! CLCCHO=xCL+CO+RO2C+HO2+...
     &                      +                 RXRAT( 374 )      ! CLACET=xCL+RO2C+MECO3+...
     &                      +    5.4100D-01 * RXRAT( 384 )      ! BUTADIENE13+CL=0.5410D+...
     &                      +    1.7700D-01 * RXRAT( 385 )      ! ISOPRENE+CL=0.1770D+00*xCL+...
     &                      +    6.8000D-02 * RXRAT( 386 )      ! APIN+CL=0.6800D-01*xCL+...
     &                      +    4.4200D-01 * RXRAT( 400 )      ! OLE2+CL=0.4420D+00*xCL+...
     &                      +    6.8000D-02 * RXRAT( 404 )      ! TERP+CL=0.6800D-01*xCL+...
     &                      +    6.8000D-02 * RXRAT( 405 )      ! SESQ+CL=0.6800D-01*xCL+...
      LOSS(  xCL          ) =                 RXRAT( 375 )      ! xCL=CL
     &                      +                 RXRAT( 376 )      ! xCL=

      PROD(  xCLCCHO      ) =    4.8400D-01 * RXRAT( 367 )      ! ACROLEIN+CL=0.4840D+...
     &                      +    1.8000D-01 * RXRAT( 368 )      ! MACR+CL=0.1800D+00*xCLCCHO+...
     &                      +    9.4700D-01 * RXRAT( 369 )      ! MVK+CL=0.9470D+00*xCLCCHO+...
     &                      +    1.4000D-01 * RXRAT( 370 )      ! IPRD+CL=0.1400D+00*xCLCCHO+...
     &                      +    3.0600D-01 * RXRAT( 383 )      ! PROPENE+CL=0.3060D+...
     &                      +    6.7000D-02 * RXRAT( 385 )      ! ISOPRENE+CL=0.6700D-...
     &                      +    1.0900D-01 * RXRAT( 386 )      ! APIN+CL=0.1090D+00*xCLCCHO+...
     &                      +    1.9200D-01 * RXRAT( 399 )      ! OLE1+CL=0.1920D+00*xCLCCHO+...
     &                      +    1.3000D-02 * RXRAT( 400 )      ! OLE2+CL=0.1300D-01*xCLCCHO+...
     &                      +    1.0900D-01 * RXRAT( 404 )      ! TERP+CL=0.1090D+00*xCLCCHO+...
     &                      +    1.0900D-01 * RXRAT( 405 )      ! SESQ+CL=0.1090D+00*xCLCCHO+...
      LOSS(  xCLCCHO      ) =                 RXRAT( 377 )      ! xCLCCHO=CLCCHO
     &                      +                 RXRAT( 378 )      ! xCLCCHO=

      PROD(  xCLACET      ) =    5.4100D-01 * RXRAT( 368 )      ! MACR+CL=0.5410D+00*xCLACET+...
     &                      +    4.2000D-01 * RXRAT( 370 )      ! IPRD+CL=0.4200D+00*xCLACET+...
     &                      +    5.4000D-01 * RXRAT( 383 )      ! PROPENE+CL=0.5400D+...
     &                      +    3.3700D-01 * RXRAT( 399 )      ! OLE1+CL=0.3370D+00*xCLACET+...
     &                      +    1.9100D-01 * RXRAT( 400 )      ! OLE2+CL=0.1910D+00*xCLACET+...
      LOSS(  xCLACET      ) =                 RXRAT( 379 )      ! xCLACET=CLACET
     &                      +                 RXRAT( 380 )      ! xCLACET=

      PROD(  CLCCHO       ) =                 RXRAT( 377 )      ! xCLCCHO=CLCCHO
      LOSS(  CLCCHO       ) =                 RXRAT( 371 )      ! CLCCHO=HO2+CO+RO2C+xCL+...
     &                      +                 RXRAT( 372 )      ! CLCCHO+OH=RCO3
     &                      +                 RXRAT( 373 )      ! CLCCHO+CL=HCL+RCO3

      PROD(  CLACET       ) =                 RXRAT( 379 )      ! xCLACET=CLACET
      LOSS(  CLACET       ) =                 RXRAT( 374 )      ! CLACET=MECO3+RO2C+xCL+...

      PROD(  CLCHO        ) =                 RXRAT( 382 )      ! ETHENE+CL=CLCHO+0.2000D+...
      LOSS(  CLCHO        ) =   0.0D0

      PROD(  BNZNRXN      ) =                 RXRAT( 406 )      ! BENZRO2+NO=BNZNRXN+NO
      LOSS(  BNZNRXN      ) =   0.0D0

      PROD(  BNZHRXN      ) =                 RXRAT( 407 )      ! BENZRO2+HO2=BNZHRXN+HO2
      LOSS(  BNZHRXN      ) =   0.0D0

      PROD(  XYLNRXN      ) =                 RXRAT( 408 )      ! XYLRO2+NO=XYLNRXN+NO
      LOSS(  XYLNRXN      ) =   0.0D0

      PROD(  XYLHRXN      ) =                 RXRAT( 409 )      ! XYLRO2+HO2=XYLHRXN+HO2
      LOSS(  XYLHRXN      ) =   0.0D0

      PROD(  TOLNRXN      ) =                 RXRAT( 410 )      ! TOLRO2+NO=TOLNRXN+NO
      LOSS(  TOLNRXN      ) =   0.0D0

      PROD(  TOLHRXN      ) =                 RXRAT( 411 )      ! TOLRO2+HO2=TOLHRXN+HO2
      LOSS(  TOLHRXN      ) =   0.0D0

      PROD(  PAHNRXN      ) =                 RXRAT( 412 )      ! PAHRO2+NO=PAHNRXN+NO
      LOSS(  PAHNRXN      ) =   0.0D0

      PROD(  PAHHRXN      ) =                 RXRAT( 413 )      ! PAHRO2+HO2=PAHHRXN+HO2
      LOSS(  PAHHRXN      ) =   0.0D0

      PROD(  HCHO_PRIMARY ) =   0.0D0
      LOSS(  HCHO_PRIMARY ) =                 RXRAT( 414 )      ! HCHO_PRIMARY=
     &                      +                 RXRAT( 415 )      ! HCHO_PRIMARY=
     &                      +                 RXRAT( 416 )      ! HCHO_PRIMARY+OH=OH
     &                      +                 RXRAT( 417 )      ! HCHO_PRIMARY+NO3=NO3
     &                      +                 RXRAT( 418 )      ! HCHO_PRIMARY+CL=CL

      PROD(  CCHO_PRIMARY ) =   0.0D0
      LOSS(  CCHO_PRIMARY ) =                 RXRAT( 419 )      ! CCHO_PRIMARY+OH=OH
     &                      +                 RXRAT( 420 )      ! CCHO_PRIMARY=
     &                      +                 RXRAT( 421 )      ! CCHO_PRIMARY+NO3=NO3
     &                      +                 RXRAT( 422 )      ! CCHO_PRIMARY+CL=CL

      PROD(  ACRO_PRIMARY ) =   0.0D0
      LOSS(  ACRO_PRIMARY ) =                 RXRAT( 423 )      ! ACRO_PRIMARY+OH=OH
     &                      +                 RXRAT( 424 )      ! ACRO_PRIMARY+O3=O3
     &                      +                 RXRAT( 425 )      ! ACRO_PRIMARY+NO3=NO3
     &                      +                 RXRAT( 426 )      ! ACRO_PRIMARY+O3P=O3P
     &                      +                 RXRAT( 427 )      ! ACRO_PRIMARY=
     &                      +                 RXRAT( 428 )      ! ACRO_PRIMARY+CL=CL

      PROD(  H2NO3PIJ     ) =                 RXRAT( 430 )      ! N2O5=H2NO3PIJ+HNO3
      LOSS(  H2NO3PIJ     ) =                 RXRAT( 432 )      ! H2NO3PIJ=HNO3
     &                      +                 RXRAT( 434 )      ! H2NO3PIJ+ACLI=CLNO2
     &                      +                 RXRAT( 435 )      ! H2NO3PIJ+ACLJ=CLNO2

      PROD(  H2NO3PK      ) =                 RXRAT( 431 )      ! N2O5=H2NO3PK+HNO3
      LOSS(  H2NO3PK      ) =                 RXRAT( 433 )      ! H2NO3PK=HNO3
     &                      +                 RXRAT( 436 )      ! H2NO3PK+ACLK=CLNO2

      PROD(  ACLI         ) =   0.0D0
      LOSS(  ACLI         ) =                 RXRAT( 434 )      ! ACLI+H2NO3PIJ=CLNO2

      PROD(  ACLJ         ) =   0.0D0
      LOSS(  ACLJ         ) =                 RXRAT( 435 )      ! ACLJ+H2NO3PIJ=CLNO2

      PROD(  ACLK         ) =   0.0D0
      LOSS(  ACLK         ) =                 RXRAT( 436 )      ! ACLK+H2NO3PK=CLNO2

      PROD(  AXYL1J       ) =   0.0D0
      LOSS(  AXYL1J       ) =                 RXRAT( 438 )      ! AXYL1J=0.1143D+01*AOLGAJ

      PROD(  AOLGAJ       ) =    1.1428D+00 * RXRAT( 438 )      ! AXYL1J=0.1143D+01*AOLGAJ
     &                      +    1.1428D+00 * RXRAT( 439 )      ! AXYL2J=0.1143D+01*AOLGAJ
     &                      +                 RXRAT( 440 )      ! ATOL1J=AOLGAJ
     &                      +                 RXRAT( 441 )      ! ATOL2J=AOLGAJ
     &                      +    8.5714D-01 * RXRAT( 442 )      ! ABNZ1J=0.8571D+00*AOLGAJ
     &                      +    8.5714D-01 * RXRAT( 443 )      ! ABNZ2J=0.8571D+00*AOLGAJ
     &                      +    1.4286D+00 * RXRAT( 449 )      ! APAH1J=0.1429D+01*AOLGAJ
     &                      +    1.4286D+00 * RXRAT( 450 )      ! APAH2J=0.1429D+01*AOLGAJ
     &                      +    1.7143D+00 * RXRAT( 451 )      ! AALK1J=0.1714D+01*AOLGAJ
     &                      +    1.7143D+00 * RXRAT( 452 )      ! AALK2J=0.1714D+01*AOLGAJ
      LOSS(  AOLGAJ       ) =   0.0D0

      PROD(  AXYL2J       ) =   0.0D0
      LOSS(  AXYL2J       ) =                 RXRAT( 439 )      ! AXYL2J=0.1143D+01*AOLGAJ

      PROD(  ATOL1J       ) =   0.0D0
      LOSS(  ATOL1J       ) =                 RXRAT( 440 )      ! ATOL1J=AOLGAJ

      PROD(  ATOL2J       ) =   0.0D0
      LOSS(  ATOL2J       ) =                 RXRAT( 441 )      ! ATOL2J=AOLGAJ

      PROD(  ABNZ1J       ) =   0.0D0
      LOSS(  ABNZ1J       ) =                 RXRAT( 442 )      ! ABNZ1J=0.8571D+00*AOLGAJ

      PROD(  ABNZ2J       ) =   0.0D0
      LOSS(  ABNZ2J       ) =                 RXRAT( 443 )      ! ABNZ2J=0.8571D+00*AOLGAJ

      PROD(  ATRP1J       ) =   0.0D0
      LOSS(  ATRP1J       ) =                 RXRAT( 444 )      ! ATRP1J=AOLGBJ

      PROD(  AOLGBJ       ) =                 RXRAT( 444 )      ! ATRP1J=AOLGBJ
     &                      +                 RXRAT( 445 )      ! ATRP2J=AOLGBJ
     &                      +    5.0000D-01 * RXRAT( 446 )      ! AISO1J=0.5000D+00*AOLGBJ
     &                      +    5.0000D-01 * RXRAT( 447 )      ! AISO2J=0.5000D+00*AOLGBJ
     &                      +    1.5000D+00 * RXRAT( 448 )      ! ASQTJ=0.1500D+01*AOLGBJ
      LOSS(  AOLGBJ       ) =   0.0D0

      PROD(  ATRP2J       ) =   0.0D0
      LOSS(  ATRP2J       ) =                 RXRAT( 445 )      ! ATRP2J=AOLGBJ

      PROD(  AISO1J       ) =   0.0D0
      LOSS(  AISO1J       ) =                 RXRAT( 446 )      ! AISO1J=0.5000D+00*AOLGBJ

      PROD(  AISO2J       ) =   0.0D0
      LOSS(  AISO2J       ) =                 RXRAT( 447 )      ! AISO2J=0.5000D+00*AOLGBJ

      PROD(  ASQTJ        ) =   0.0D0
      LOSS(  ASQTJ        ) =                 RXRAT( 448 )      ! ASQTJ=0.1500D+01*AOLGBJ

      PROD(  APAH1J       ) =   0.0D0
      LOSS(  APAH1J       ) =                 RXRAT( 449 )      ! APAH1J=0.1429D+01*AOLGAJ

      PROD(  APAH2J       ) =   0.0D0
      LOSS(  APAH2J       ) =                 RXRAT( 450 )      ! APAH2J=0.1429D+01*AOLGAJ

      PROD(  AALK1J       ) =   0.0D0
      LOSS(  AALK1J       ) =                 RXRAT( 451 )      ! AALK1J=0.1714D+01*AOLGAJ

      PROD(  AALK2J       ) =   0.0D0
      LOSS(  AALK2J       ) =                 RXRAT( 452 )      ! AALK2J=0.1714D+01*AOLGAJ

      PROD(  PCVOC        ) =   0.0D0
      LOSS(  PCVOC        ) =                 RXRAT( 453 )      ! PCVOC+OH=OH+PCSOARXN

      PROD(  PCSOARXN     ) =                 RXRAT( 453 )      ! PCVOC+OH=PCSOARXN+OH
      LOSS(  PCSOARXN     ) =   0.0D0

      PROD(  VLVPO1       ) =    3.0030D-01 * RXRAT( 455 )      ! VSVPO1+OH=0.3003D+...
     &                      +    3.8560D-01 * RXRAT( 456 )      ! VSVPO2+OH=0.3856D+...
     &                      +    2.1810D-01 * RXRAT( 457 )      ! VSVPO3+OH=0.2181D+...
     &                      +    2.4120D-01 * RXRAT( 458 )      ! VIVPO1+OH=0.2412D+...
      LOSS(  VLVPO1       ) =    5.1430D-01 * RXRAT( 454 )      ! VLVPO1+OH=0.4857D+...

      PROD(  VSVPO1       ) =    6.2000D-03 * RXRAT( 454 )      ! VLVPO1+OH=0.6200D-...
     &                      +    9.5000D-02 * RXRAT( 456 )      ! VSVPO2+OH=0.9500D-...
     &                      +    3.0630D-01 * RXRAT( 457 )      ! VSVPO3+OH=0.3063D+...
     &                      +    2.0890D-01 * RXRAT( 458 )      ! VIVPO1+OH=0.2089D+...
      LOSS(  VSVPO1       ) =    7.1380D-01 * RXRAT( 455 )      ! VSVPO1+OH=0.2862D+...

      PROD(  VSVPO2       ) =    2.5000D-03 * RXRAT( 454 )      ! VLVPO1+OH=0.2500D-...
     &                      +    4.1000D-03 * RXRAT( 455 )      ! VSVPO1+OH=0.4100D-...
     &                      +    1.5300D-02 * RXRAT( 457 )      ! VSVPO3+OH=0.1530D-...
     &                      +    3.0000D-01 * RXRAT( 458 )      ! VIVPO1+OH=0.3000D+...
      LOSS(  VSVPO2       ) =    8.6270D-01 * RXRAT( 456 )      ! VSVPO2+OH=0.1373D+...

      PROD(  VSVPO3       ) =    2.6000D-03 * RXRAT( 454 )      ! VLVPO1+OH=0.2600D-...
     &                      +    3.5000D-03 * RXRAT( 455 )      ! VSVPO1+OH=0.3500D-...
     &                      +    5.0000D-04 * RXRAT( 456 )      ! VSVPO2+OH=0.5000D-...
      LOSS(  VSVPO3       ) =    8.9570D-01 * RXRAT( 457 )      ! VSVPO3+OH=0.1043D+...

      PROD(  VIVPO1       ) =    2.3000D-03 * RXRAT( 454 )      ! VLVPO1+OH=0.2300D-...
      LOSS(  VIVPO1       ) =                 RXRAT( 458 )      ! VIVPO1+OH=OH+0.2412D+...

      PROD(  VLVOO1       ) =    2.9440D-01 * RXRAT( 454 )      ! VLVPO1+OH=0.2944D+...
     &                      +    2.2390D-01 * RXRAT( 455 )      ! VSVPO1+OH=0.2239D+...
     &                      +    2.0510D-01 * RXRAT( 456 )      ! VSVPO2+OH=0.2051D+...
     &                      +    1.8930D-01 * RXRAT( 457 )      ! VSVPO3+OH=0.1893D+...
     &                      +    2.0280D-01 * RXRAT( 458 )      ! VIVPO1+OH=0.2028D+...
     &                      +    2.8580D-01 * RXRAT( 460 )      ! VLVOO2+OH=0.2858D+...
     &                      +    3.3030D-01 * RXRAT( 461 )      ! VSVOO1+OH=0.3303D+...
     &                      +    3.4440D-01 * RXRAT( 462 )      ! VSVOO2+OH=0.3444D+...
     &                      +    3.8860D-01 * RXRAT( 463 )      ! VSVOO3+OH=0.3886D+...
      LOSS(  VLVOO1       ) =    3.3360D-01 * RXRAT( 459 )      ! VLVOO1+OH=0.6664D+...

      PROD(  VLVOO2       ) =    2.0210D-01 * RXRAT( 454 )      ! VLVPO1+OH=0.2021D+...
     &                      +    1.8200D-01 * RXRAT( 455 )      ! VSVPO1+OH=0.1820D+...
     &                      +    1.7640D-01 * RXRAT( 456 )      ! VSVPO2+OH=0.1764D+...
     &                      +    1.6680D-01 * RXRAT( 457 )      ! VSVPO3+OH=0.1668D+...
     &                      +    4.7100D-02 * RXRAT( 458 )      ! VIVPO1+OH=0.4710D-...
     &                      +    1.4300D-02 * RXRAT( 459 )      ! VLVOO1+OH=0.1430D-...
     &                      +    2.2720D-01 * RXRAT( 461 )      ! VSVOO1+OH=0.2272D+...
     &                      +    2.7490D-01 * RXRAT( 462 )      ! VSVOO2+OH=0.2749D+...
     &                      +    2.4210D-01 * RXRAT( 463 )      ! VSVOO3+OH=0.2421D+...
      LOSS(  VLVOO2       ) =    6.0690D-01 * RXRAT( 460 )      ! VLVOO2+OH=0.3931D+...

      PROD(  VSVOO2       ) =    1.9000D-03 * RXRAT( 454 )      ! VLVPO1+OH=0.1900D-...
     &                      +    1.2390D-01 * RXRAT( 459 )      ! VLVOO1+OH=0.1239D+...
     &                      +    1.0270D-01 * RXRAT( 460 )      ! VLVOO2+OH=0.1027D+...
     &                      +    7.0200D-02 * RXRAT( 461 )      ! VSVOO1+OH=0.7020D-...
     &                      +    3.8500D-02 * RXRAT( 463 )      ! VSVOO3+OH=0.3850D-...
      LOSS(  VSVOO2       ) =    7.4230D-01 * RXRAT( 462 )      ! VSVOO2+OH=0.2577D+...

      PROD(  VSVOO3       ) =    2.3000D-03 * RXRAT( 454 )      ! VLVPO1+OH=0.2300D-...
     &                      +    1.8310D-01 * RXRAT( 459 )      ! VLVOO1+OH=0.1831D+...
     &                      +    2.0450D-01 * RXRAT( 460 )      ! VLVOO2+OH=0.2045D+...
     &                      +    1.1160D-01 * RXRAT( 461 )      ! VSVOO1+OH=0.1116D+...
     &                      +    7.3900D-02 * RXRAT( 462 )      ! VSVOO2+OH=0.7390D-...
      LOSS(  VSVOO3       ) =    7.3330D-01 * RXRAT( 463 )      ! VSVOO3+OH=0.2667D+...

      PROD(  VSVOO1       ) =    1.2300D-02 * RXRAT( 459 )      ! VLVOO1+OH=0.1230D-...
     &                      +    1.3900D-02 * RXRAT( 460 )      ! VLVOO2+OH=0.1390D-...
     &                      +    4.9100D-02 * RXRAT( 462 )      ! VSVOO2+OH=0.4910D-...
     &                      +    6.4000D-02 * RXRAT( 463 )      ! VSVOO3+OH=0.6400D-...
      LOSS(  VSVOO1       ) =    7.3930D-01 * RXRAT( 461 )      ! VSVOO1+OH=0.2607D+...

      PROD(  AISO3J       ) =                 RXRAT( 464 )      ! IEPOX=AISO3J
      LOSS(  AISO3J       ) =   0.0D0

      RETURN

      END
